' This version of NucProp allows for an extended table of isotopes.
' Note: In this version of NucProp, the MAT numbers from JEFF are not preserved!
' The MAT numbers are the consecutive numbers of states in NUBASE!
' They do not have any importance for GEF.

' Data extracted from NUBASE 2020 (October 2024), KHS
' Only ground states and isomeric states (up to 4) are included.

Dim Shared As Integer N_MAT_MAX  ' Number of lines in table NuclideData
#DEFINE ISOSOURCE "NUBASE-2020"
'Print "Spins and energies for calculation of isomeric yields provided by "+ISOSOURCE+"."
'Print


Declare Function I_MAT_ENDF(IZ As Integer,IA As Integer) As Integer
Declare Function N_ISO_MAT(IMAT As Integer) As Integer
Declare Function R_AWR_ENDF(IZ As Integer,IA AS Integer) As Single
Declare Function ISO_for_MAT(IMAT As Integer) As Integer
Declare Function ISO_for_ZA(IZ As Integer,IA As Integer) As Integer
Declare Function NStates_for_ZA(IZ As Integer, IA As Integer) As Integer


Type NucProp
  I_Z As Integer    ' Atomic number
  I_A As Integer    ' Mass number
  I_ISO As Integer  ' Nmbr of isomeric state, 0 for ground state
  R_SPI As Single   ' Spin
  I_PAR As Integer  ' Parity
  R_AWR As Double   ' Atomic mass of nucleus in units of neutron mass
  R_EXC As Single   ' Excitation energy of isomeric state in MeV
  C_Lifetime As String  ' Life time of state
End Type


Dim Shared As Integer N_ISO_TOT  ' Total number of nuclides with isomers
N_ISO_TOT = 0

'Print "NucProp 2 **********"

Dim As Integer I_MAT_original
Dim As Single R_Dummy_NuclideData
Dim As String C_Dummy_NuclideData
Dim As Integer I_NuclideData

' Determine N_MAT_MAX (number of states in table NuclideData)
N_MAT_MAX = 0
Do 
  Read I_MAT_original
  If I_MAT_original = 9999 Then
    Exit Do
  End If
  N_MAT_MAX = N_MAT_MAX + 1
  For I_NuclideData = 1 To 7
    Read R_Dummy_NuclideData
  Next I_NuclideData
  Read C_Dummy_NUclideData
Loop 

Redim Shared NucTab(N_MAT_MAX) As NucProp
Redim Shared MAT_for_ISO_prov(N_MAT_MAX) As Integer

Scope
Dim As Integer I_Mat
Restore NuclideData
Do Until I_MAT = N_MAT_MAX 
  ' Read nuclide properties into UDT NucTab
  Read I_MAT_original
  I_MAT = I_MAT + 1
  If I_MAT > N_MAT_MAX Then Print "<E> NucPropx: N_MAT_MAX too small!"
  Read NucTab(I_MAT).I_Z, _
       NucTab(I_MAT).I_A, _
       NucTab(I_MAT).I_ISO, _
       NucTab(I_MAT).R_SPI, _
       NucTab(I_MAT).I_PAR, _
       NucTab(I_MAT).R_AWR, _
       NucTab(I_MAT).R_EXC, _
       NucTab(I_MAT).C_Lifetime 
  If NucTab(I_MAT).I_ISO < 0 or NucTab(I_MAT).I_ISO > 9 Then
    Print "<E> Error in NucProp"
    Print "GEF stopped."
    Sleep
  End If     
  If NucTab(I_MAT).R_SPI < 0 Or NucTab(I_MAT).R_SPI > 1.E3 Then _
          NucTab(I_MAT).R_SPI = 0     
  If NucTab(I_MAT).I_ISO = 1 Then  ' At least one isomeric state is in NucTab
    ' Establish table of MAT numbers of nuclides with isomers
    N_ISO_TOT = N_ISO_TOT + 1
    MAT_for_ISO_prov(N_ISO_TOT) = I_MAT - 1
  End If
'  PRINT I_MAT,NucTab(I_MAT).I_Z,NucTab(I_MAT).I_A     
'  If NucTab(I_MAT).I_Z = 111 Then Exit Do
Loop

If I_MAT < N_MAT_MAX Then 
  Print "<E> Nucprop: N_MAT_MAX too large, should be ";I_MAT
End If  
End Scope

Redim Shared MAT_for_ISO(N_ISO_TOT) As Integer  
   ' List of MAT numbers of nuclides with isomers
   ' MAT number refer to ground state !
   
'Scope  


   
Dim As Integer I1,J1
Dim As Single R1
For I1 = 1 To N_ISO_TOT
  MAT_for_ISO(I1) = MAT_for_ISO_prov(I1)
Next
' Erase MAT_for_ISO_prov



Type Isoprop
   I_MAT As Integer
   I_Z As Integer
   I_A As Integer
   N_STATES As Integer
   I_ISO(10) As Integer
   R_SPI(10) As Single
   I_PAR(10) As Integer
   R_EXC(10) As Single
   R_Lim(10) As Single
   R_Prob(10) As Single
   C_lifetime(10) As String
End Type


Redim Shared Isotab(N_ISO_TOT) As Isoprop



Scope

Dim Inmbr As Integer

For I1 = 1 To N_ISO_TOT
  Isotab(I1).I_MAT = MAT_for_ISO(I1)
  Isotab(I1).I_Z = NucTab(MAT_for_ISO(I1)).I_Z
  Isotab(I1).I_A = NucTab(MAT_for_ISO(I1)).I_A
  Isotab(I1).N_STATES = N_ISO_MAT(Isotab(I1).I_MAT) + 1  ' Number of states
  

  ' Sorting the spin in ascending order
  Inmbr = 0 
  For R1 = 0 To 50.0 Step 0.5
    For J1 = 1 To Isotab(I1).N_STATES
      If NucTab(MAT_for_ISO(I1)+J1-1).R_SPI = R1 Then
        Inmbr = Inmbr + 1
        Isotab(I1).I_ISO(Inmbr) = NucTab(MAT_for_ISO(I1)+J1-1).I_ISO
        Isotab(I1).R_SPI(Inmbr) = NucTab(MAT_for_ISO(I1)+J1-1).R_SPI
        Isotab(I1).I_PAR(Inmbr) = NucTab(MAT_for_ISO(I1)+J1-1).I_PAR
        Isotab(I1).R_EXC(Inmbr) = NucTab(MAT_for_ISO(I1)+J1-1).R_EXC 
        Isotab(I1).C_Lifetime(Inmbr) = NucTab(MAT_for_ISO(I1)+J1-1).C_Lifetime
  '     Print Inmbr,Mat_for_ISO(I1)+J1-1,NucTab(MAT_for_ISO(I1)+J1-1).R_SPI,NucTab(MAT_for_ISO(I1)+J1-1).R_EXC
      End If
    Next
  Next

  
  Dim As Single R_J_diff,R_E_diff,R_J_1
  ' Setting the limits of the angular-momentum distribution
  For J1 = 1 To Isotab(I1).N_STATES - 1
    R_J_diff = Isotab(I1).R_SPI(J1+1) - Isotab(I1).R_SPI(J1)
    R_E_diff = Isotab(I1).R_EXC(J1+1) - Isotab(I1).R_EXC(J1)
'   R_J_1 = R_J_diff * (0.5 + 0.5 * (R_E_diff / (Abs(R_E_diff) + 0.2 ) ) )
    R_J_1 = R_J_diff * (0.5 + 0.5 * (R_E_diff/R_J_diff / (Abs(R_E_diff/R_J_diff) + 0.05 ) ) )
    Isotab(I1).R_lim(J1) = Isotab(I1).R_SPI(J1) + R_J_1
    
    If Isotab(I1).R_SPI(J1+1) = Isotab(I1).R_SPI(J1) Then
      Isotab(I1).R_lim(J1) = 1.E3
    End If
  Next 
  Isotab(I1).R_lim(Isotab(I1).N_STATES) = 1.E3 
Next  

End Scope

#Include "NucProp_Functions.mac"

NuclideData:
' Data extracted from NUBASE 2016.
' MAT no., Z, A, Isomer, Spin, Parity, AWR, EXC, t(1/2)
' In NucPropNUBASE, AWR is the mass excess!!!
' The MAT numbers are determined by counting. 
' They differ from the original MAT no. of JEFF 3.1.1!
' This is necessary, because the GEFY tables cover nuclides 
' beyond the range of MAT numbers of JEFF 3.1.1. 

' The following table can be modified just by changing the values for specific states or by
' adding new lines for additional states.
' No further adjustments of GEF are necessary.

Data _
 1, 0, 1, 0,0.5,             1,8071.3181    , 0         , "t=609.8s",_
 2, 1, 1, 0,0.5,             1,7288.97106   , 0         , "t=stbl",_
 3, 1, 2, 0,1,               1,13135.72289  , 0         , "t=stbl",_
 4, 1, 3, 0,0.5,             1,14949.81090  , 0         , "t=12.32y",_
 5, 2, 3, 0,0.5,             1,14931.21888  , 0         , "t=stbl",_
 6, 3, 3, 0,1.5,            -1,28670        , 0         , "t=p-unst",_
 7, 1, 4, 0,2,              -1,24620        , 0         , "t=139ys",_
 8, 2, 4, 0,0,               1,2424.91587   , 0         , "t=stbl",_
 9, 3, 4, 0,2,              -1,25320        , 0         , "t=91ys",_
 10, 1, 5, 0,0.5,            1,32890        , 0         , "t=86ys",_
 11, 2, 5, 0,1.5,           -1,11231        , 0         , "t=602ys",_
 12, 3, 5, 0,1.5,           -1,11680        , 0         , "t=370ys",_
 13, 4, 5, 0,0.5,            1,37140        , 0         , "t=p-unst",_
 14, 1, 6, 0,2,             -1,41880        , 0         , "t=294ys",_
 15, 2, 6, 0,0,              1,17592.10     , 0         , "t=806.92ms",_
 16, 3, 6, 0,1,              1,14086.8804   , 0         , "t=stbl",_
 17, 4, 6, 0,0,              1,18375        , 0         , "t=5.0zs",_
 18, 5, 6, 0,2,             -1,47320        , 0         , "t=p-unst",_
 19, 1, 7, 0,0.5,            1,49140        , 0         , "t=652ys",_
 20, 2, 7, 0,1.5,           -1,26073        , 0         , "t=2.51zs",_
 21, 3, 7, 0,1.5,           -1,14907.105    , 0         , "t=stbl",_
 22, 4, 7, 0,1.5,           -1,15769.00     , 0         , "t=53.22d",_
 23, 5, 7, 0,1.5,           -1,27677        , 0         , "t=570ys",_
 24, 2, 8, 0,0,              1,31609.68     , 0         , "t=119.5ms",_
 25, 3, 8, 0,2,              1,20945.80     , 0         , "t=838.7ms",_
 26, 4, 8, 0,0,              1,4941.67      , 0         , "t=81.9as",_
 27, 5, 8, 0,2,              1,22921.6      , 0         , "t=771.9ms",_
 28, 6, 8, 0,0,              1,35064        , 0         , "t=3.5zs",_
 29, 2, 9, 0,0.5,            1,40940        , 0         , "t=2.5zs",_
 30, 3, 9, 0,1.5,           -1,24954.91     , 0         , "t=178.2ms",_
 31, 4, 9, 0,1.5,           -1,11348.45     , 0         , "t=stbl",_
 32, 5, 9, 0,1.5,           -1,12416.5      , 0         , "t=800zs",_
 33, 6, 9, 0,1.5,           -1,28911.0      , 0         , "t=126.5ms",_
 34, 2, 10, 0,0,             1,49200        , 0         , "t=260ys",_
 35, 3, 10, 0,1,            -1,33053        , 0         , "t=2.0zs",_
 36, 3, 10, 1,1,             1,33250        , 0.2       , "t=3.7zs",_
 37, 4, 10, 0,0,             1,12607.49     , 0         , "t=1.387My",_
 38, 5, 10, 0,3,             1,12050.611    , 0         , "t=stbl",_
 39, 6, 10, 0,0,             1,15698.67     , 0         , "t=19.3011s",_
 40, 7, 10, 0,1,            -1,38800        , 0         , "t=143ys",_
 41, 3, 11, 0,1.5,          -1,40728.3      , 0         , "t=8.75ms",_
 42, 4, 11, 0,0.5,           1,20177.17     , 0         , "t=13.76s",_
 43, 5, 11, 0,1.5,          -1,8667.708     , 0         , "t=stbl",_
 44, 6, 11, 0,1.5,          -1,10649.40     , 0         , "t=20.3402m",_
 45, 7, 11, 0,0.5,           1,24366        , 0         , "t=585ys",_
 46, 7, 11, 1,0.5,          -1,25110        , 0.74      , "t=690ys",_
 47, 8, 11, 0,1.5,          -1,47740        , 0         , "t=198ys",_
 48, 3, 12, 0,1,            -1,49010        , 0         , "t=?",_
 49, 4, 12, 0,0,             1,25077.8      , 0         , "t=21.46ms",_
 50, 4, 12, 1,0,             1,27328.8      , 2.251     , "t=233ns",_
 51, 5, 12, 0,1,             1,13369.4      , 0         , "t=20.20ms",_
 52, 6, 12, 0,0,             1,0.0          , 0         , "t=stbl",_
 53, 7, 12, 0,1,             1,17338.1      , 0         , "t=11.000ms",_
 54, 8, 12, 0,0,             1,32013        , 0         , "t=8.9zs",_
 55, 3, 13, 0,1.5,          -1,56980        , 0         , "t=3.3zs",_
 56, 4, 13, 0,0.5,          -1,33659        , 0         , "t=1.0zs",_
 57, 5, 13, 0,1.5,          -1,16561.9      , 0         , "t=17.16ms",_
 58, 6, 13, 0,0.5,          -1,3125.0093    , 0         , "t=stbl",_
 59, 7, 13, 0,0.5,          -1,5345.48      , 0         , "t=9.965m",_
 60, 8, 13, 0,1.5,          -1,23115        , 0         , "t=8.58ms",_
 61, 9, 13, 0,0.5,           1,42030        , 0         , "t=?",_
 62, 4, 14, 0,0,             1,39950        , 0         , "t=4.53ms",_
 63, 5, 14, 0,2,            -1,23664        , 0         , "t=12.36ms",_
 64, 6, 14, 0,0,             1,3019.893     , 0         , "t=5.70ky",_
 65, 7, 14, 0,1,             1,2863.4168    , 0         , "t=stbl",_
 66, 8, 14, 0,0,             1,8007.781     , 0         , "t=70.621s",_
 67, 9, 14, 0,2,            -1,31960        , 0         , "t=500ys",_
 68, 4, 15, 0,2.5,           1,49830        , 0         , "t=790ys",_
 69, 5, 15, 0,1.5,          -1,28957        , 0         , "t=10.18ms",_
 70, 6, 15, 0,0.5,           1,9873.1       , 0         , "t=2.449s",_
 71, 7, 15, 0,0.5,          -1,101.4381     , 0         , "t=stbl",_
 72, 8, 15, 0,0.5,          -1,2855.6       , 0         , "t=122.266s",_
 73, 9, 15, 0,0.5,           1,16567        , 0         , "t=1.1zs",_
 74, 10, 15, 0,1.5,         -1,40220        , 0         , "t=770ys",_
 75, 4, 16, 0,0,             1,57450        , 0         , "t=650ys",_
 76, 5, 16, 0,0,            -1,37112        , 0         , "t=&gt;4.6zs",_
 77, 6, 16, 0,0,             1,13694        , 0         , "t=750ms",_
 78, 7, 16, 0,2,            -1,5683.9       , 0         , "t=7.13s",_
 79, 7, 16, 1,0,            -1,5804.3       , 0.12042   , "t=5.25us",_
 80, 8, 16, 0,0,             1,-4737.0021   , 0         , "t=stbl",_
 81, 9, 16, 0,0,            -1,10675        , 0         , "t=21zs",_
 82, 10, 16, 0,0,            1,23987        , 0         , "t=&gt;5.7zs",_
 83, 5, 17, 0,1.5,          -1,43720        , 0         , "t=5.08ms",_
 84, 6, 17, 0,1.5,           1,21032        , 0         , "t=193ms",_
 85, 7, 17, 0,0.5,          -1,7870         , 0         , "t=4.173s",_
 86, 8, 17, 0,2.5,           1,-808.7642    , 0         , "t=stbl",_
 87, 9, 17, 0,2.5,           1,1951.70      , 0         , "t=64.370s",_
 88, 10, 17, 0,0.5,         -1,16500.5      , 0         , "t=109.2ms",_
 89, 11, 17, 0,0.5,          1,34720        , 0         , "t=?",_
 90, 5, 18, 0,2,            -1,51790        , 0         , "t=?",_
 91, 6, 18, 0,0,             1,24920        , 0         , "t=92ms",_
 92, 7, 18, 0,1,            -1,13113        , 0         , "t=619.2ms",_
 93, 8, 18, 0,0,             1,-782.8163    , 0         , "t=stbl",_
 94, 9, 18, 0,1,             1,873.1        , 0         , "t=109.734m",_
 95, 9, 18, 1,5,             1,1994.5       , 1.12136   , "t=162ns",_
 96, 10, 18, 0,0,            1,5317.6       , 0         , "t=1664.20ms",_
 97, 11, 18, 0,1,           -1,25040        , 0         , "t=1.3zs",_
 98, 5, 19, 0,1.5,          -1,59770        , 0         , "t=2.92ms",_
 99, 6, 19, 0,0.5,           1,32410        , 0         , "t=46.2ms",_
 100, 7, 19, 0,0.5,         -1,15856        , 0         , "t=336ms",_
 101, 8, 19, 0,2.5,          1,3332.9       , 0         , "t=26.470s",_
 102, 9, 19, 0,0.5,          1,-1487.4451   , 0         , "t=stbl",_
 103, 10, 19, 0,0.5,         1,1752.05      , 0         , "t=17.2569s",_
 104, 11, 19, 0,2.5,         1,12929        , 0         , "t=&gt;1as",_
 105, 12, 19, 0,0.5,        -1,31840        , 0         , "t=5ps",_
 106, 5, 20, 0,1,           -1,69400        , 0         , "t=&gt;912.4ys",_
 107, 6, 20, 0,0,            1,37500        , 0         , "t=16ms",_
 108, 7, 20, 0,2,           -1,21770        , 0         , "t=136ms",_
 109, 8, 20, 0,0,            1,3796.2       , 0         , "t=13.51s",_
 110, 9, 20, 0,2,            1,-17.463      , 0         , "t=11.0062s",_
 111, 10, 20, 0,0,           1,-7041.9322   , 0         , "t=stbl",_
 112, 11, 20, 0,2,           1,6850.5       , 0         , "t=447.9ms",_
 113, 12, 20, 0,0,           1,17477.7      , 0         , "t=90.4ms",_
 114, 5, 21, 0,1.5,         -1,78380        , 0         , "t=&gt;760ys",_
 115, 6, 21, 0,0.5,          1,45640        , 0         , "t=?",_
 116, 7, 21, 0,0.5,         -1,25230        , 0         , "t=85ms",_
 117, 8, 21, 0,2.5,          1,8062         , 0         , "t=3.42s",_
 118, 9, 21, 0,2.5,          1,-47.6        , 0         , "t=4.158s",_
 119, 10, 21, 0,1.5,         1,-5731.78     , 0         , "t=stbl",_
 120, 11, 21, 0,1.5,         1,-2184.86     , 0         , "t=22.4550s",_
 121, 12, 21, 0,2.5,         1,10903.9      , 0         , "t=120.0ms",_
 122, 13, 21, 0,2.5,         1,27090        , 0         , "t=?",_
 123, 6, 22, 0,0,            1,53610        , 0         , "t=6.2ms",_
 124, 7, 22, 0,0,           -1,31760        , 0         , "t=23ms",_
 125, 8, 22, 0,0,            1,9280         , 0         , "t=2.25s",_
 126, 9, 22, 0,4,            1,2793         , 0         , "t=4.23s",_
 127, 10, 22, 0,0,           1,-8024.716    , 0         , "t=stbl",_
 128, 11, 22, 0,3,           1,-5181.39     , 0         , "t=2.6019y",_
 129, 11, 22, 1,1,           1,-4598.34     , 0.58305   , "t=243ns",_
 130, 12, 22, 0,0,           1,-399.99      , 0         , "t=3.8745s",_
 131, 13, 22, 0,4,           1,18200        , 0         , "t=91.1ms",_
 132, 14, 22, 0,0,           1,33640        , 0         , "t=28.7ms",_
 133, 6, 23, 0,1.5,          1,64170        , 0         , "t=?",_
 134, 7, 23, 0,0.5,         -1,36720        , 0         , "t=13.9ms",_
 135, 8, 23, 0,0.5,          1,14620        , 0         , "t=97ms",_
 136, 9, 23, 0,2.5,          1,3290         , 0         , "t=2.23s",_
 137, 10, 23, 0,2.5,         1,-5154.05     , 0         , "t=37.15s",_
 138, 11, 23, 0,1.5,         1,-9529.8535   , 0         , "t=stbl",_
 139, 12, 23, 0,1.5,         1,-5473.67     , 0         , "t=11.3039s",_
 140, 13, 23, 0,2.5,         1,6748.1       , 0         , "t=446ms",_
 141, 14, 23, 0,1.5,         1,23950        , 0         , "t=42.3ms",_
 142, 7, 24, 0,-77.777,      0,46940        , 0         , "t=?",_
 143, 8, 24, 0,0,            1,18500        , 0         , "t=77.4ms",_
 144, 9, 24, 0,3,            1,7540         , 0         , "t=384ms",_
 145, 10, 24, 0,0,           1,-5951.6      , 0         , "t=3.38m",_
 146, 11, 24, 0,4,           1,-8417.901    , 0         , "t=14.9560h",_
 147, 11, 24, 1,1,           1,-7945.694    , 0.4722074 , "t=20.18ms",_
 148, 12, 24, 0,0,           1,-13933.578   , 0         , "t=stbl",_
 149, 13, 24, 0,4,           1,-48.81       , 0         , "t=2.053s",_
 150, 13, 24, 1,1,           1,376.99       , 0.4258    , "t=130ms",_
 151, 14, 24, 0,0,           1,10745        , 0         , "t=143.2ms",_
 152, 15, 24, 0,1,           1,34020        , 0         , "t=?",_
 153, 7, 25, 0,0.5,         -1,55980        , 0         , "t=?",_
 154, 8, 25, 0,1.5,          1,27330        , 0         , "t=5.18zs",_
 155, 9, 25, 0,2.5,          1,11330        , 0         , "t=80ms",_
 156, 10, 25, 0,0.5,         1,-2036        , 0         , "t=602ms",_
 157, 11, 25, 0,2.5,         1,-9357.8      , 0         , "t=59.1s",_
 158, 12, 25, 0,2.5,         1,-13192.78    , 0         , "t=stbl",_
 159, 13, 25, 0,2.5,         1,-8915.97     , 0         , "t=7.1666s",_
 160, 14, 25, 0,2.5,         1,3827         , 0         , "t=220.6ms",_
 161, 15, 25, 0,0.5,         1,20190        , 0         , "t=?",_
 162, 8, 26, 0,0,            1,34660        , 0         , "t=4.2ps",_
 163, 9, 26, 0,1,            1,18670        , 0         , "t=8.2ms",_
 164, 9, 26, 1,4,            1,19310        , 0.6434    , "t=2.2ms",_
 165, 10, 26, 0,0,           1,481          , 0         , "t=197ms",_
 166, 11, 26, 0,3,           1,-6861        , 0         , "t=1071.28ms",_
 167, 11, 26, 1,1,           1,-6779        , 0.0824    , "t=4.35us",_
 168, 12, 26, 0,0,           1,-16214.544   , 0         , "t=stbl",_
 169, 13, 26, 0,5,           1,-12210.14    , 0         , "t=717ky",_
 170, 13, 26, 1,0,           1,-11981.83    , 0.228306  , "t=6346.0ms",_
 171, 14, 26, 0,0,           1,-7141.00     , 0         , "t=2.2453s",_
 172, 15, 26, 0,3,           1,10970        , 0         , "t=43.6ms",_
 173, 15, 26, 1,1,           1,11130        , 0.1644    , "t=115ns",_
 174, 16, 26, 0,0,           1,27680        , 0         , "t=?",_
 175, 8, 27, 0,1.5,          1,44670        , 0         , "t=?",_
 176, 9, 27, 0,2.5,          1,25130        , 0         , "t=5.0ms",_
 177, 10, 27, 0,1.5,         1,7050         , 0         , "t=30.9ms",_
 178, 11, 27, 0,2.5,         1,-5518        , 0         , "t=301ms",_
 179, 12, 27, 0,0.5,         1,-14586.59    , 0         , "t=9.435m",_
 180, 13, 27, 0,2.5,         1,-17196.86    , 0         , "t=stbl",_
 181, 14, 27, 0,2.5,         1,-12384.51    , 0         , "t=4.117s",_
 182, 15, 27, 0,0.5,         1,-659         , 0         , "t=260ms",_
 183, 16, 27, 0,2.5,         1,17490        , 0         , "t=16.3ms",_
 184, 8, 28, 0,0,            1,52080        , 0         , "t=?",_
 185, 9, 28, 0,4,           -1,33400        , 0         , "t=46zs",_
 186, 10, 28, 0,0,           1,11300        , 0         , "t=18.8ms",_
 187, 11, 28, 0,1,           1,-988         , 0         , "t=33.1ms",_
 188, 12, 28, 0,0,           1,-15019.95    , 0         , "t=20.915h",_
 189, 13, 28, 0,3,           1,-16850.72    , 0         , "t=2.245m",_
 190, 14, 28, 0,0,           1,-21492.7971  , 0         , "t=stbl",_
 191, 15, 28, 0,3,           1,-7147.9      , 0         , "t=270.3ms",_
 192, 16, 28, 0,0,           1,4070         , 0         , "t=125ms",_
 193, 17, 28, 0,1,           1,28270        , 0         , "t=?",_
 194, 9, 29, 0,2.5,          1,40150        , 0         , "t=2.5ms",_
 195, 10, 29, 0,1.5,        -1,18400        , 0         , "t=14.7ms",_
 196, 11, 29, 0,1.5,         1,2680         , 0         , "t=43.2ms",_
 197, 12, 29, 0,1.5,         1,-10612.4     , 0         , "t=1.30s",_
 198, 13, 29, 0,2.5,         1,-18207.8     , 0         , "t=6.56m",_
 199, 14, 29, 0,0.5,         1,-21895.0815  , 0         , "t=stbl",_
 200, 15, 29, 0,0.5,         1,-16952.8     , 0         , "t=4.102s",_
 201, 16, 29, 0,2.5,         1,-3094        , 0         , "t=188ms",_
 202, 17, 29, 0,0.5,         1,14020        , 0         , "t=5.4zs",_
 203, 18, 29, 0,2.5,         1,37970        , 0         , "t=?",_
 204, 9, 30, 0,-77.777,      0,48960        , 0         , "t=?",_
 205, 10, 30, 0,0,           1,23280        , 0         , "t=7.22ms",_
 206, 11, 30, 0,2,           1,8475         , 0         , "t=45.9ms",_
 207, 12, 30, 0,0,           1,-8881.4      , 0         , "t=317ms",_
 208, 13, 30, 0,3,           1,-15864.1     , 0         , "t=3.62s",_
 209, 14, 30, 0,0,           1,-24432.962   , 0         , "t=stbl",_
 210, 15, 30, 0,1,           1,-20200.86    , 0         , "t=2.5000m",_
 211, 16, 30, 0,0,           1,-14059.25    , 0         , "t=1.1798s",_
 212, 17, 30, 0,3,           1,4675         , 0         , "t=?",_
 213, 18, 30, 0,0,           1,22070        , 0         , "t=&lt;10ps",_
 214, 9, 31, 0,2.5,          1,56840        , 0         , "t=2ms",_
 215, 10, 31, 0,1.5,        -1,31180        , 0         , "t=3.4ms",_
 216, 11, 31, 0,1.5,         1,12246        , 0         , "t=16.8ms",_
 217, 12, 31, 0,0.5,         1,-3122        , 0         , "t=270ms",_
 218, 13, 31, 0,2.5,         1,-14950.7     , 0         , "t=644ms",_
 219, 14, 31, 0,1.5,         1,-22949.04    , 0         , "t=157.16m",_
 220, 15, 31, 0,0.5,         1,-24440.5444  , 0         , "t=stbl",_
 221, 16, 31, 0,0.5,         1,-19042.53    , 0         , "t=2.5534s",_
 222, 17, 31, 0,1.5,         1,-7035        , 0         , "t=190ms",_
 223, 18, 31, 0,2.5,         1,11330        , 0         , "t=15.0ms",_
 224, 19, 31, 0,1.5,         1,34260        , 0         , "t=&gt;10ps",_
 225, 10, 32, 0,0,           1,37000        , 0         , "t=3.5ms",_
 226, 11, 32, 0,3,          -1,18640        , 0         , "t=12.9ms",_
 227, 12, 32, 0,0,           1,-829         , 0         , "t=80.4ms",_
 228, 13, 32, 0,1,           1,-11099       , 0         , "t=32.6ms",_
 229, 13, 32, 1,4,           1,-10142       , 0.9566    , "t=200ns",_
 230, 14, 32, 0,0,           1,-24077.69    , 0         , "t=157y",_
 231, 15, 32, 0,1,           1,-24304.88    , 0         , "t=14.269d",_
 232, 16, 32, 0,0,           1,-26015.5371  , 0         , "t=stbl",_
 233, 17, 32, 0,1,           1,-13334.7     , 0         , "t=298ms",_
 234, 18, 32, 0,0,           1,-2200.4      , 0         , "t=98ms",_
 235, 19, 32, 0,1,           1,21990        , 0         , "t=?",_
 236, 19, 32, 1,4,           1,22940        , 0.95      , "t=?",_
 237, 10, 33, 0,3.5,        -1,46130        , 0         , "t=?",_
 238, 11, 33, 0,1.5,         1,23780        , 0         , "t=8.2ms",_
 239, 12, 33, 0,1.5,        -1,4962.9       , 0         , "t=92.0ms",_
 240, 13, 33, 0,2.5,         1,-8497        , 0         , "t=41.46ms",_
 241, 14, 33, 0,1.5,         1,-20514.3     , 0         , "t=6.18s",_
 242, 15, 33, 0,0.5,         1,-26337.4     , 0         , "t=25.35d",_
 243, 16, 33, 0,1.5,         1,-26585.8583  , 0         , "t=stbl",_
 244, 17, 33, 0,1.5,         1,-21003.3     , 0         , "t=2.5038s",_
 245, 18, 33, 0,0.5,         1,-9384.3      , 0         , "t=173.0ms",_
 246, 19, 33, 0,1.5,         1,7540         , 0         , "t=?",_
 247, 20, 33, 0,2.5,         1,31030        , 0         , "t=?",_
 248, 10, 34, 0,0,           1,52840        , 0         , "t=2ms",_
 249, 11, 34, 0,1,           1,31680        , 0         , "t=5.5ms",_
 250, 12, 34, 0,0,           1,8323         , 0         , "t=44.9ms",_
 251, 13, 34, 0,4,          -1,-2997.6      , 0         , "t=53.73ms",_
 252, 13, 34, 1,1,           1,-2951.1      , 0.04647   , "t=22.1ms",_
 253, 14, 34, 0,0,           1,-19991.7     , 0         , "t=2.77s",_
 254, 14, 34, 1,3,          -1,-15735.6     , 4.2561    , "t=&lt;210ns",_
 255, 15, 34, 0,1,           1,-24548.7     , 0         , "t=12.43s",_
 256, 16, 34, 0,0,           1,-29931.69    , 0         , "t=stbl",_
 257, 17, 34, 0,0,           1,-24440.09    , 0         , "t=1.5267s",_
 258, 17, 34, 1,3,           1,-24293.73    , 0.14636   , "t=31.99m",_
 259, 18, 34, 0,0,           1,-18378.29    , 0         , "t=846.46ms",_
 260, 19, 34, 0,1,           1,-1220        , 0         , "t=?",_
 261, 20, 34, 0,0,           1,14890        , 0         , "t=?",_
 262, 11, 35, 0,1.5,         1,37830        , 0         , "t=1.5ms",_
 263, 12, 35, 0,1.5,        -1,15640        , 0         , "t=11.3ms",_
 264, 13, 35, 0,2.5,         1,-224         , 0         , "t=38.16ms",_
 265, 14, 35, 0,3.5,        -1,-14390       , 0         , "t=780ms",_
 266, 15, 35, 0,0.5,         1,-24857.8     , 0         , "t=47.3s",_
 267, 16, 35, 0,1.5,         1,-28846.21    , 0         , "t=87.37d",_
 268, 17, 35, 0,1.5,         1,-29013.53    , 0         , "t=stbl",_
 269, 18, 35, 0,1.5,         1,-23047.3     , 0         , "t=1.7756s",_
 270, 19, 35, 0,1.5,         1,-11172.9     , 0         , "t=175.2ms",_
 271, 20, 35, 0,0.5,         1,5190         , 0         , "t=25.7ms",_
 272, 21, 35, 0,3.5,        -1,27100        , 0         , "t=?",_
 273, 11, 36, 0,-77.777,     0,45900        , 0         , "t=?",_
 274, 12, 36, 0,0,           1,20380        , 0         , "t=3.9ms",_
 275, 13, 36, 0,-77.777,     0,5950         , 0         , "t=90ms",_
 276, 14, 36, 0,0,           1,-12440       , 0         , "t=503ms",_
 277, 15, 36, 0,4,          -1,-20251       , 0         , "t=5.6s",_
 278, 16, 36, 0,0,           1,-30664.14    , 0         , "t=stbl",_
 279, 17, 36, 0,2,           1,-29522.01    , 0         , "t=301.3ky",_
 280, 18, 36, 0,0,           1,-30231.542   , 0         , "t=stbl",_
 281, 19, 36, 0,2,           1,-17417.2     , 0         , "t=341ms",_
 282, 20, 36, 0,0,           1,-6450        , 0         , "t=100.9ms",_
 283, 21, 36, 0,-77.777,     0,16150        , 0         , "t=?",_
 284, 11, 37, 0,1.5,         1,53130        , 0         , "t=1ms",_
 285, 12, 37, 0,1.5,        -1,28210        , 0         , "t=8ms",_
 286, 13, 37, 0,2.5,         1,9810         , 0         , "t=11.4ms",_
 287, 14, 37, 0,2.5,        -1,-6570        , 0         , "t=141.0ms",_
 288, 15, 37, 0,0.5,         1,-19000       , 0         , "t=2.31s",_
 289, 16, 37, 0,3.5,        -1,-26896.43    , 0         , "t=5.05m",_
 290, 17, 37, 0,1.5,         1,-31761.55    , 0         , "t=stbl",_
 291, 18, 37, 0,1.5,         1,-30947.68    , 0         , "t=35.011d",_
 292, 19, 37, 0,1.5,         1,-24800.20    , 0         , "t=1.23651s",_
 293, 20, 37, 0,1.5,         1,-13136.1     , 0         , "t=181.0ms",_
 294, 21, 37, 0,3.5,        -1,3780         , 0         , "t=?",_
 295, 22, 37, 0,0.5,         1,25170        , 0         , "t=?",_
 296, 11, 38, 0,-77.777,     0,61910        , 0         , "t=?",_
 297, 12, 38, 0,0,           1,34070        , 0         , "t=2ms",_
 298, 13, 38, 0,0,          -1,16470        , 0         , "t=9.0ms",_
 299, 14, 38, 0,0,           1,-4170        , 0         , "t=63ms",_
 300, 15, 38, 0,2,          -1,-14620       , 0         , "t=640ms",_
 301, 16, 38, 0,0,           1,-26861       , 0         , "t=170.3m",_
 302, 17, 38, 0,2,          -1,-29798.12    , 0         , "t=37.230m",_
 303, 17, 38, 1,5,          -1,-29126.75    , 0.671365  , "t=715ms",_
 304, 18, 38, 0,0,           1,-34714.83    , 0         , "t=stbl",_
 305, 19, 38, 0,3,           1,-28800.76    , 0         , "t=7.651m",_
 306, 19, 38, 1,0,           1,-28670.61    , 0.13015   , "t=924.35ms",_
 307, 20, 38, 0,0,           1,-22058.50    , 0         , "t=443.70ms",_
 308, 21, 38, 0,2,          -1,-4250        , 0         , "t=?",_
 309, 21, 38, 1,5,          -1,-3580        , 0.67      , "t=?",_
 310, 22, 38, 0,0,           1,11370        , 0         , "t=?",_
 311, 11, 39, 0,1.5,         1,69980        , 0         , "t=1ms",_
 312, 12, 39, 0,3.5,        -1,42780        , 0         , "t=?",_
 313, 13, 39, 0,2.5,         1,21490        , 0         , "t=7.6ms",_
 314, 14, 39, 0,2.5,        -1,2320         , 0         , "t=41.2ms",_
 315, 15, 39, 0,0.5,         1,-12770       , 0         , "t=282ms",_
 316, 16, 39, 0,3.5,        -1,-23160       , 0         , "t=11.5s",_
 317, 17, 39, 0,1.5,         1,-29800.2     , 0         , "t=56.2m",_
 318, 18, 39, 0,3.5,        -1,-33242       , 0         , "t=268y",_
 319, 19, 39, 0,1.5,         1,-33807.195   , 0         , "t=stbl",_
 320, 20, 39, 0,1.5,         1,-27282.7     , 0         , "t=860.3ms",_
 321, 21, 39, 0,3.5,        -1,-14173       , 0         , "t=?",_
 322, 22, 39, 0,1.5,         1,2500         , 0         , "t=28.5ms",_
 323, 23, 39, 0,3.5,        -1,22570        , 0         , "t=?",_
 324, 12, 40, 0,0,           1,49550        , 0         , "t=1ms",_
 325, 13, 40, 0,-77.777,     0,28820        , 0         , "t=10ms",_
 326, 14, 40, 0,0,           1,5670         , 0         , "t=31.2ms",_
 327, 15, 40, 0,2,          -1,-8140        , 0         , "t=150ms",_
 328, 16, 40, 0,0,           1,-22838       , 0         , "t=8.8s",_
 329, 17, 40, 0,2,          -1,-27560       , 0         , "t=1.35m",_
 330, 18, 40, 0,0,           1,-35039.9000  , 0         , "t=stbl",_
 331, 19, 40, 0,4,          -1,-33535.50    , 0         , "t=1.248Gy",_
 332, 19, 40, 1,0,           1,-31891.86    , 1.643638  , "t=336ns",_
 333, 20, 40, 0,0,           1,-34846.402   , 0         , "t=stbl",_
 334, 21, 40, 0,4,          -1,-20523.4     , 0         , "t=182.3ms",_
 335, 22, 40, 0,0,           1,-8990        , 0         , "t=52.4ms",_
 336, 23, 40, 0,2,          -1,12470        , 0         , "t=?",_
 337, 12, 41, 0,1.5,        -1,58100        , 0         , "t=?",_
 338, 13, 41, 0,2.5,         1,34590        , 0         , "t=6ms",_
 339, 14, 41, 0,3.5,        -1,13200        , 0         , "t=20.0ms",_
 340, 15, 41, 0,0.5,         1,-4980        , 0         , "t=101ms",_
 341, 16, 41, 0,3.5,        -1,-19009       , 0         , "t=1.99s",_
 342, 17, 41, 0,0.5,         1,-27310       , 0         , "t=38.4s",_
 343, 18, 41, 0,3.5,        -1,-33067.5     , 0         , "t=109.61m",_
 344, 19, 41, 0,1.5,         1,-35559.549   , 0         , "t=stbl",_
 345, 20, 41, 0,3.5,        -1,-35137.91    , 0         , "t=99.4ky",_
 346, 21, 41, 0,3.5,        -1,-28642.36    , 0         , "t=596.3ms",_
 347, 22, 41, 0,1.5,         1,-15698       , 0         , "t=81.9ms",_
 348, 23, 41, 0,3.5,        -1,310          , 0         , "t=?",_
 349, 24, 41, 0,1.5,         1,20410        , 0         , "t=?",_
 350, 13, 42, 0,-77.777,     0,41990        , 0         , "t=3ms",_
 351, 14, 42, 0,0,           1,16840        , 0         , "t=12.5ms",_
 352, 15, 42, 0,-77.777,     0,1090         , 0         , "t=48.5ms",_
 353, 16, 42, 0,0,           1,-17637.7     , 0         , "t=1.016s",_
 354, 17, 42, 0,2,          -1,-24830       , 0         , "t=6.8s",_
 355, 18, 42, 0,0,           1,-34423       , 0         , "t=32.9y",_
 356, 19, 42, 0,2,          -1,-35022.03    , 0         , "t=12.355h",_
 357, 20, 42, 0,0,           1,-38547.29    , 0         , "t=stbl",_
 358, 21, 42, 0,0,           1,-32121.00    , 0         , "t=680.72ms",_
 359, 21, 42, 1,7,           1,-31504.19    , 0.61681   , "t=61.7s",_
 360, 22, 42, 0,0,           1,-25104.35    , 0         , "t=208.3ms",_
 361, 23, 42, 0,2,          -1,-7620        , 0         , "t=?",_
 362, 24, 42, 0,0,           1,7060         , 0         , "t=13.3ms",_
 363, 13, 43, 0,2.5,         1,48270        , 0         , "t=4ms",_
 364, 14, 43, 0,1.5,        -1,24330        , 0         , "t=30ms",_
 365, 15, 43, 0,0.5,         1,5040         , 0         , "t=35.8ms",_
 366, 16, 43, 0,1.5,        -1,-12195       , 0         , "t=265ms",_
 367, 16, 43, 1,3.5,        -1,-11874       , 0.3207    , "t=415.0ns",_
 368, 17, 43, 0,1.5,         1,-24160       , 0         , "t=3.13s",_
 369, 18, 43, 0,2.5,        -1,-32010       , 0         , "t=5.37m",_
 370, 19, 43, 0,1.5,         1,-36575.4     , 0         , "t=22.3h",_
 371, 19, 43, 1,3.5,        -1,-35837.1     , 0.7383    , "t=200ns",_
 372, 20, 43, 0,3.5,        -1,-38408.87    , 0         , "t=stbl",_
 373, 21, 43, 0,3.5,        -1,-36188.1     , 0         , "t=3.891h",_
 374, 21, 43, 1,1.5,         1,-36036.3     , 0.15179   , "t=438us",_
 375, 22, 43, 0,3.5,        -1,-29316       , 0         , "t=509ms",_
 376, 22, 43, 1,1.5,         1,-29003       , 0.313     , "t=11.9us",_
 377, 23, 43, 0,3.5,        -1,-17920       , 0         , "t=79.3ms",_
 378, 24, 43, 0,1.5,         1,-1970        , 0         , "t=21.1ms",_
 379, 25, 43, 0,2.5,        -1,17370        , 0         , "t=?",_
 380, 14, 44, 0,0,           1,29310        , 0         , "t=4ms",_
 381, 15, 44, 0,-77.777,     0,11110        , 0         , "t=18.5ms",_
 382, 16, 44, 0,0,           1,-9204        , 0         , "t=100ms",_
 383, 16, 44, 1,0,           1,-7839        , 1.365     , "t=2.619us",_
 384, 17, 44, 0,2,          -1,-20480       , 0         , "t=562ms",_
 385, 18, 44, 0,0,           1,-32673.3     , 0         , "t=11.87m",_
 386, 19, 44, 0,2,          -1,-35781.5     , 0         , "t=22.13m",_
 387, 20, 44, 0,0,           1,-41468.7     , 0         , "t=stbl",_
 388, 21, 44, 0,2,           1,-37816.0     , 0         , "t=4.0421h",_
 389, 21, 44, 1,1,          -1,-37748.1     , 0.0678679 , "t=154.8ns",_
 390, 22, 44, 0,0,           1,-37548.6     , 0         , "t=59.1y",_
 391, 23, 44, 0,2,           1,-23808       , 0         , "t=111ms",_
 392, 23, 44, 1,6,           1,-23537       , 0.271     , "t=150ms",_
 393, 24, 44, 0,0,           1,-13420       , 0         , "t=42.8ms",_
 394, 25, 44, 0,2,          -1,7460         , 0         , "t=?",_
 395, 14, 45, 0,1.5,        -1,37090        , 0         , "t=4ms",_
 396, 15, 45, 0,0.5,         1,15960        , 0         , "t=10ms",_
 397, 16, 45, 0,1.5,        -1,-3340        , 0         , "t=68ms",_
 398, 17, 45, 0,1.5,         1,-18260       , 0         , "t=413ms",_
 399, 18, 45, 0,2.5,        -1,-29770.8     , 0         , "t=21.48s",_
 400, 19, 45, 0,1.5,         1,-36615.6     , 0         , "t=17.8m",_
 401, 20, 45, 0,3.5,        -1,-40812.2     , 0         , "t=162.61d",_
 402, 21, 45, 0,3.5,        -1,-41072.3     , 0         , "t=stbl",_
 403, 21, 45, 1,1.5,         1,-41059.9     , 0.0124    , "t=318ms",_
 404, 22, 45, 0,3.5,        -1,-39010.3     , 0         , "t=184.8m",_
 405, 22, 45, 1,1.5,        -1,-38973.8     , 0.03653   , "t=3.0us",_
 406, 23, 45, 0,3.5,        -1,-31886.4     , 0         , "t=547ms",_
 407, 23, 45, 1,1.5,        -1,-31829.6     , 0.0568    , "t=512ns",_
 408, 24, 45, 0,3.5,        -1,-19510       , 0         , "t=60.9ms",_
 409, 24, 45, 1,1.5,         0,-19400       , 0.107     , "t=&gt;80us",_
 410, 25, 45, 0,2.5,        -1,-4980        , 0         , "t=?",_
 411, 26, 45, 0,1.5,         1,14410        , 0         , "t=2.5ms",_
 412, 15, 46, 0,-77.777,     0,22840        , 0         , "t=9ms",_
 413, 16, 46, 0,0,           1,640          , 0         , "t=50ms",_
 414, 17, 46, 0,2,          -1,-13730       , 0         , "t=232ms",_
 415, 18, 46, 0,0,           1,-29771.3     , 0         , "t=8.4s",_
 416, 19, 46, 0,2,          -1,-35413.9     , 0         , "t=96.30s",_
 417, 20, 46, 0,0,           1,-43139.6     , 0         , "t=stbl",_
 418, 21, 46, 0,4,           1,-41761.6     , 0         , "t=83.757d",_
 419, 21, 46, 1,6,           1,-41709.6     , 0.052011  , "t=9.4us",_
 420, 22, 46, 0,0,           1,-44128.27    , 0         , "t=stbl",_
 421, 23, 46, 0,0,           1,-37075.90    , 0         , "t=422.62ms",_
 422, 23, 46, 1,3,           1,-36274.44    , 0.80146   , "t=1.02ms",_
 423, 24, 46, 0,0,           1,-29472       , 0         , "t=224.3ms",_
 424, 25, 46, 0,4,           1,-12420       , 0         , "t=36.2ms",_
 425, 25, 46, 1,1,          -1,-12270       , 0.15      , "t=1ms",_
 426, 26, 46, 0,0,           1,1210         , 0         , "t=13.0ms",_
 427, 15, 47, 0,0.5,         1,28810        , 0         , "t=4ms",_
 428, 16, 47, 0,1.5,        -1,7200         , 0         , "t=24ms",_
 429, 17, 47, 0,1.5,         1,-9580        , 0         , "t=101ms",_
 430, 18, 47, 0,1.5,        -1,-25367.3     , 0         , "t=1.23s",_
 431, 19, 47, 0,0.5,         1,-35712.0     , 0         , "t=17.38s",_
 432, 20, 47, 0,3.5,        -1,-42344.7     , 0         , "t=4.536d",_
 433, 21, 47, 0,3.5,        -1,-44336.8     , 0         , "t=3.3492d",_
 434, 21, 47, 1,1.5,         1,-43570.0     , 0.76683   , "t=272ns",_
 435, 22, 47, 0,2.5,        -1,-44937.61    , 0         , "t=stbl",_
 436, 23, 47, 0,1.5,        -1,-42007.07    , 0         , "t=32.6m",_
 437, 24, 47, 0,1.5,        -1,-34563       , 0         , "t=461.6ms",_
 438, 25, 47, 0,2.5,        -1,-22570       , 0         , "t=88.0ms",_
 439, 26, 47, 0,3.5,        -1,-7130        , 0         , "t=21.9ms",_
 440, 26, 47, 1,1.5,         1,-6360        , 0.77      , "t=?",_
 441, 27, 47, 0,3.5,        -1,10620        , 0         , "t=?",_
 442, 16, 48, 0,0,           1,12390        , 0         , "t=10ms",_
 443, 17, 48, 0,-77.777,     0,-4280        , 0         , "t=30ms",_
 444, 18, 48, 0,0,           1,-22355       , 0         , "t=415ms",_
 445, 19, 48, 0,1,          -1,-32284.5     , 0         , "t=6.83s",_
 446, 20, 48, 0,0,           1,-44224.868   , 0         , "t=56Ey",_
 447, 21, 48, 0,6,           1,-44504       , 0         , "t=43.67h",_
 448, 22, 48, 0,0,           1,-48492.95    , 0         , "t=stbl",_
 449, 23, 48, 0,4,           1,-44478.0     , 0         , "t=15.9735d",_
 450, 24, 48, 0,0,           1,-42821       , 0         , "t=21.56h",_
 451, 25, 48, 0,4,           1,-29297       , 0         , "t=158.1ms",_
 452, 26, 48, 0,0,           1,-18010       , 0         , "t=45.3ms",_
 453, 27, 48, 0,6,           1,1730         , 0         , "t=?",_
 454, 28, 48, 0,0,           1,18180        , 0         , "t=2.8ms",_
 455, 16, 49, 0,0.5,        -1,20390        , 0         , "t=4ms",_
 456, 17, 49, 0,1.5,         1,740          , 0         , "t=35ms",_
 457, 18, 49, 0,1.5,        -1,-17060       , 0         , "t=236ms",_
 458, 19, 49, 0,0.5,         1,-29611.5     , 0         , "t=1.26s",_
 459, 20, 49, 0,1.5,        -1,-41300.00    , 0         , "t=8.718m",_
 460, 21, 49, 0,3.5,        -1,-46562.4     , 0         , "t=57.18m",_
 461, 22, 49, 0,3.5,        -1,-48564.01    , 0         , "t=stbl",_
 462, 23, 49, 0,3.5,        -1,-47962.2     , 0         , "t=330d",_
 463, 24, 49, 0,2.5,        -1,-45332.4     , 0         , "t=42.3m",_
 464, 25, 49, 0,2.5,        -1,-37619.9     , 0         , "t=382ms",_
 465, 26, 49, 0,3.5,        -1,-24751       , 0         , "t=64.7ms",_
 466, 27, 49, 0,3.5,        -1,-9780        , 0         , "t=?",_
 467, 28, 49, 0,3.5,        -1,8530         , 0         , "t=7.5ms",_
 468, 17, 50, 0,-77.777,     0,7700         , 0         , "t=10ms",_
 469, 18, 50, 0,0,           1,-13230       , 0         , "t=106ms",_
 470, 19, 50, 0,0,          -1,-25728       , 0         , "t=472ms",_
 471, 19, 50, 1,2,          -1,-25556       , 0.172     , "t=125ns",_
 472, 20, 50, 0,0,           1,-39589.2     , 0         , "t=13.45s",_
 473, 21, 50, 0,5,           1,-44537.1     , 0         , "t=102.5s",_
 474, 21, 50, 1,2,           1,-44280.2     , 0.256895  , "t=350ms",_
 475, 22, 50, 0,0,           1,-51431.87    , 0         , "t=stbl",_
 476, 23, 50, 0,6,           1,-49223.24    , 0         , "t=271Py",_
 477, 24, 50, 0,0,           1,-50261.36    , 0         , "t=stbl",_
 478, 25, 50, 0,0,           1,-42626.89    , 0         , "t=283.21ms",_
 479, 25, 50, 1,5,           1,-42401.57    , 0.22531   , "t=1.75m",_
 480, 26, 50, 0,0,           1,-34476       , 0         , "t=152.0ms",_
 481, 27, 50, 0,6,           1,-17590       , 0         , "t=38.8ms",_
 482, 28, 50, 0,0,           1,-3460        , 0         , "t=18.5ms",_
 483, 17, 51, 0,1.5,         1,14290        , 0         , "t=5ms",_
 484, 18, 51, 0,0.5,        -1,-6490        , 0         , "t=30ms",_
 485, 19, 51, 0,1.5,         1,-22515       , 0         , "t=365ms",_
 486, 20, 51, 0,1.5,        -1,-36332.3     , 0         , "t=10.0s",_
 487, 21, 51, 0,3.5,        -1,-43250.4     , 0         , "t=12.4s",_
 488, 22, 51, 0,1.5,        -1,-49733.0     , 0         , "t=5.76m",_
 489, 23, 51, 0,3.5,        -1,-52203.11    , 0         , "t=stbl",_
 490, 24, 51, 0,3.5,        -1,-51450.71    , 0         , "t=27.7015d",_
 491, 25, 51, 0,2.5,        -1,-48243.2     , 0         , "t=45.81m",_
 492, 26, 51, 0,2.5,        -1,-40189.2     , 0         , "t=305.4ms",_
 493, 27, 51, 0,3.5,        -1,-27340       , 0         , "t=68.8ms",_
 494, 28, 51, 0,3.5,        -1,-11650       , 0         , "t=23.8ms",_
 495, 17, 52, 0,-77.777,     0,22360        , 0         , "t=2ms",_
 496, 18, 52, 0,0,           1,-1380        , 0         , "t=40ms",_
 497, 19, 52, 0,2,          -1,-17140       , 0         , "t=110ms",_
 498, 20, 52, 0,0,           1,-34266.3     , 0         , "t=4.6s",_
 499, 21, 52, 0,3,           1,-40524       , 0         , "t=8.2s",_
 500, 22, 52, 0,0,           1,-49477.7     , 0         , "t=1.7m",_
 501, 23, 52, 0,3,           1,-51443.03    , 0         , "t=3.743m",_
 502, 24, 52, 0,0,           1,-55419.51    , 0         , "t=stbl",_
 503, 25, 52, 0,6,           1,-50711.39    , 0         , "t=5.591d",_
 504, 25, 52, 1,2,           1,-50333.64    , 0.377749  , "t=21.1m",_
 505, 26, 52, 0,0,           1,-48332.10    , 0         , "t=8.275h",_
 506, 26, 52, 1,12,          1,-41371.43    , 6.9607    , "t=45.9s",_
 507, 27, 52, 0,6,           1,-34344       , 0         , "t=111.7ms",_
 508, 27, 52, 1,2,           1,-33968       , 0.376     , "t=102ms",_
 509, 28, 52, 0,0,           1,-22560       , 0         , "t=41.8ms",_
 510, 29, 52, 0,3,           1,-1880        , 0         , "t=?",_
 511, 18, 53, 0,2.5,        -1,6790         , 0         , "t=20ms",_
 512, 19, 53, 0,1.5,         1,-12300       , 0         , "t=30ms",_
 513, 20, 53, 0,0.5,        -1,-29390       , 0         , "t=461ms",_
 514, 21, 53, 0,3.5,        -1,-38770       , 0         , "t=2.4s",_
 515, 22, 53, 0,1.5,        -1,-46881.4     , 0         , "t=32.7s",_
 516, 23, 53, 0,3.5,        -1,-51852       , 0         , "t=1.543m",_
 517, 24, 53, 0,1.5,        -1,-55287.62    , 0         , "t=stbl",_
 518, 25, 53, 0,3.5,        -1,-54690.3     , 0         , "t=3.7My",_
 519, 26, 53, 0,3.5,        -1,-50947.5     , 0         , "t=8.51m",_
 520, 26, 53, 1,9.5,        -1,-47907.1     , 3.0404    , "t=2.54m",_
 521, 27, 53, 0,3.5,        -1,-42659.4     , 0         , "t=244.6ms",_
 522, 27, 53, 1,9.5,        -1,-39485.1     , 3.1743    , "t=250ms",_
 523, 28, 53, 0,3.5,        -1,-29631       , 0         , "t=55.2ms",_
 524, 29, 53, 0,1.5,        -1,-13140       , 0         , "t=?",_
 525, 18, 54, 0,0,           1,12560        , 0         , "t=5ms",_
 526, 19, 54, 0,2,          -1,-5150        , 0         , "t=10ms",_
 527, 20, 54, 0,0,           1,-25160       , 0         , "t=90ms",_
 528, 21, 54, 0,3,           1,-34438       , 0         , "t=526ms",_
 529, 21, 54, 1,5,           1,-34328       , 0.1105    , "t=2.77us",_
 530, 22, 54, 0,0,           1,-45744       , 0         , "t=2.1s",_
 531, 23, 54, 0,3,           1,-49898       , 0         , "t=49.8s",_
 532, 23, 54, 1,5,           1,-49790       , 0.108     , "t=900ns",_
 533, 24, 54, 0,0,           1,-56935.38    , 0         , "t=stbl",_
 534, 25, 54, 0,3,           1,-55558.2     , 0         , "t=312.081d",_
 535, 26, 54, 0,0,           1,-56254.6     , 0         , "t=stbl",_
 536, 26, 54, 1,10,          1,-49727.5     , 6.5271    , "t=364ns",_
 537, 27, 54, 0,0,           1,-48010.1     , 0         , "t=193.27ms",_
 538, 27, 54, 1,7,           1,-47812.5     , 0.19757   , "t=1.48m",_
 539, 28, 54, 0,0,           1,-39278       , 0         , "t=114.1ms",_
 540, 28, 54, 1,10,          1,-32821       , 6.4574    , "t=152ns",_
 541, 29, 54, 0,3,           1,-21240       , 0         , "t=?",_
 542, 30, 54, 0,0,           1,-5700        , 0         , "t=1.8ms",_
 543, 19, 55, 0,1.5,         1,470          , 0         , "t=10ms",_
 544, 20, 55, 0,2.5,        -1,-18650       , 0         , "t=22ms",_
 545, 21, 55, 0,3.5,        -1,-30840       , 0         , "t=96ms",_
 546, 22, 55, 0,0.5,        -1,-41832       , 0         , "t=1.3s",_
 547, 23, 55, 0,3.5,        -1,-49125       , 0         , "t=6.54s",_
 548, 24, 55, 0,1.5,        -1,-55110.32    , 0         , "t=3.497m",_
 549, 25, 55, 0,2.5,        -1,-57712.54    , 0         , "t=stbl",_
 550, 26, 55, 0,1.5,        -1,-57481.4     , 0         , "t=2.7562y",_
 551, 27, 55, 0,3.5,        -1,-54030.0     , 0         , "t=17.53h",_
 552, 28, 55, 0,3.5,        -1,-45336.0     , 0         , "t=203.9ms",_
 553, 29, 55, 0,1.5,        -1,-31640       , 0         , "t=55.9ms",_
 554, 30, 55, 0,2.5,        -1,-14270       , 0         , "t=19.8ms",_
 555, 19, 56, 0,2,          -1,7980         , 0         , "t=5ms",_
 556, 20, 56, 0,0,           1,-13510       , 0         , "t=11ms",_
 557, 21, 56, 0,1,           1,-25520       , 0         , "t=26ms",_
 558, 21, 56, 1,6,           1,-25520       , 0         , "t=75ms",_
 559, 22, 56, 0,0,           1,-39420       , 0         , "t=200ms",_
 560, 23, 56, 0,1,           1,-46180       , 0         , "t=216ms",_
 561, 24, 56, 0,0,           1,-55285.1     , 0         , "t=5.94m",_
 562, 25, 56, 0,3,           1,-56911.67    , 0         , "t=2.5789h",_
 563, 26, 56, 0,0,           1,-60607.16    , 0         , "t=stbl",_
 564, 27, 56, 0,4,           1,-56040.5     , 0         , "t=77.236d",_
 565, 28, 56, 0,0,           1,-53907.6     , 0         , "t=6.075d",_
 566, 29, 56, 0,4,           1,-38630       , 0         , "t=80.8ms",_
 567, 30, 56, 0,0,           1,-25390       , 0         , "t=32.4ms",_
 568, 31, 56, 0,3,           1,-3840        , 0         , "t=?",_
 569, 19, 57, 0,1.5,         1,14130        , 0         , "t=2ms",_
 570, 20, 57, 0,2.5,        -1,-6560        , 0         , "t=8ms",_
 571, 21, 57, 0,3.5,        -1,-21380       , 0         , "t=22ms",_
 572, 22, 57, 0,2.5,        -1,-34400       , 0         , "t=95ms",_
 573, 23, 57, 0,3.5,        -1,-44440       , 0         , "t=350ms",_
 574, 24, 57, 0,1.5,        -1,-52525.0     , 0         , "t=21.1s",_
 575, 25, 57, 0,2.5,        -1,-57486.3     , 0         , "t=85.4s",_
 576, 26, 57, 0,0.5,        -1,-60182.02    , 0         , "t=stbl",_
 577, 27, 57, 0,3.5,        -1,-59345.7     , 0         , "t=271.811d",_
 578, 28, 57, 0,1.5,        -1,-56084.0     , 0         , "t=35.60h",_
 579, 29, 57, 0,1.5,        -1,-47309.0     , 0         , "t=196.4ms",_
 580, 30, 57, 0,3.5,        -1,-32550       , 0         , "t=45.7ms",_
 581, 31, 57, 0,0.5,        -1,-15410       , 0         , "t=?",_
 582, 19, 58, 0,2,          -1,21930        , 0         , "t=2ms",_
 583, 20, 58, 0,0,           1,-1530        , 0         , "t=4ms",_
 584, 21, 58, 0,3,           1,-15480       , 0         , "t=12ms",_
 585, 21, 58, 1,-77.777,     0,-14060       , 1.4207    , "t=0.60us",_
 586, 22, 58, 0,0,           1,-30920       , 0         , "t=55ms",_
 587, 23, 58, 0,1,           1,-40430       , 0         , "t=191ms",_
 588, 24, 58, 0,0,           1,-51991.8     , 0         , "t=7.0s",_
 589, 25, 58, 0,1,           1,-55827.6     , 0         , "t=3.0s",_
 590, 25, 58, 1,4,           1,-55755.8     , 0.07177   , "t=65.4s",_
 591, 26, 58, 0,0,           1,-62155.3     , 0         , "t=stbl",_
 592, 27, 58, 0,2,           1,-59847.3     , 0         , "t=70.844d",_
 593, 27, 58, 1,5,           1,-59822.4     , 0.02495   , "t=8.853h",_
 594, 28, 58, 0,0,           1,-60228.9     , 0         , "t=stbl",_
 595, 29, 58, 0,1,           1,-51667.9     , 0         , "t=3.204s",_
 596, 30, 58, 0,0,           1,-42300       , 0         , "t=86.0ms",_
 597, 31, 58, 0,2,           1,-23540       , 0         , "t=?",_
 598, 31, 58, 1,5,           1,-23510       , 0.03      , "t=?",_
 599, 32, 58, 0,0,           1,-7580        , 0         , "t=?",_
 600, 19, 59, 0,1.5,         1,28750        , 0         , "t=1ms",_
 601, 20, 59, 0,2.5,        -1,5810         , 0         , "t=5ms",_
 602, 21, 59, 0,3.5,        -1,-10830       , 0         , "t=12ms",_
 603, 22, 59, 0,2.5,        -1,-25880       , 0         , "t=28.5ms",_
 604, 22, 59, 1,0.5,        -1,-25770       , 0.1085    , "t=615ns",_
 605, 23, 59, 0,2.5,        -1,-37610       , 0         , "t=95ms",_
 606, 24, 59, 0,0.5,        -1,-48115.9     , 0         , "t=1050ms",_
 607, 24, 59, 1,4.5,         1,-47613.2     , 0.5027    , "t=96us",_
 608, 25, 59, 0,2.5,        -1,-55525.3     , 0         , "t=4.59s",_
 609, 26, 59, 0,1.5,        -1,-60665.0     , 0         , "t=44.500d",_
 610, 27, 59, 0,3.5,        -1,-62229.8     , 0         , "t=stbl",_
 611, 28, 59, 0,1.5,        -1,-61156.8     , 0         , "t=81ky",_
 612, 29, 59, 0,1.5,        -1,-56358.5     , 0         , "t=81.5s",_
 613, 30, 59, 0,1.5,        -1,-47215.7     , 0         , "t=178.7ms",_
 614, 31, 59, 0,1.5,        -1,-33760       , 0         , "t=?",_
 615, 32, 59, 0,3.5,        -1,-16370       , 0         , "t=13.3ms",_
 616, 20, 60, 0,0,           1,11000        , 0         , "t=2ms",_
 617, 21, 60, 0,3,           1,-4550        , 0         , "t=10ms",_
 618, 22, 60, 0,0,           1,-22100       , 0         , "t=22.2ms",_
 619, 23, 60, 0,3,           1,-33090       , 0         , "t=122ms",_
 620, 23, 60, 1,1,           1,-33090       , 0         , "t=40ms",_
 621, 24, 60, 0,0,           1,-46908.5     , 0         , "t=490ms",_
 622, 25, 60, 0,1,           1,-52967.9     , 0         , "t=280ms",_
 623, 25, 60, 1,4,           1,-52696.0     , 0.2719    , "t=1.77s",_
 624, 26, 60, 0,0,           1,-61413       , 0         , "t=2.62My",_
 625, 27, 60, 0,5,           1,-61650.4     , 0         , "t=5.2714y",_
 626, 27, 60, 1,2,           1,-61591.8     , 0.05859   , "t=10.467m",_
 627, 28, 60, 0,0,           1,-64473.2     , 0         , "t=stbl",_
 628, 29, 60, 0,2,           1,-58345.3     , 0         , "t=23.7m",_
 629, 30, 60, 0,0,           1,-54174.5     , 0         , "t=2.38m",_
 630, 31, 60, 0,2,           1,-39590       , 0         , "t=72.4ms",_
 631, 32, 60, 0,0,           1,-27530       , 0         , "t=21ms",_
 632, 33, 60, 0,5,           1,-5640        , 0         , "t=?",_
 633, 33, 60, 1,2,           1,-5580        , 0.06      , "t=?",_
 634, 20, 61, 0,0.5,        -1,19010        , 0         , "t=1ms",_
 635, 21, 61, 0,3.5,        -1,500          , 0         , "t=7ms",_
 636, 22, 61, 0,0.5,        -1,-16370       , 0         , "t=15ms",_
 637, 22, 61, 1,2.5,        -1,-16250       , 0.125     , "t=200ns",_
 638, 23, 61, 0,1.5,        -1,-30180       , 0         , "t=48.2ms",_
 639, 24, 61, 0,2.5,        -1,-42496.5     , 0         , "t=243ms",_
 640, 25, 61, 0,2.5,        -1,-51742.1     , 0         , "t=709ms",_
 641, 26, 61, 0,1.5,        -1,-58920.5     , 0         , "t=5.98m",_
 642, 26, 61, 1,4.5,         1,-58058.8     , 0.86167   , "t=238ns",_
 643, 27, 61, 0,3.5,        -1,-62898.2     , 0         , "t=1.649h",_
 644, 28, 61, 0,1.5,        -1,-64222.0     , 0         , "t=stbl",_
 645, 29, 61, 0,1.5,        -1,-61984.1     , 0         , "t=3.343h",_
 646, 30, 61, 0,1.5,        -1,-56349       , 0         , "t=89.1s",_
 647, 31, 61, 0,1.5,        -1,-47130       , 0         , "t=165.9ms",_
 648, 31, 61, 1,0.5,        -1,-47040       , 0.09      , "t=?",_
 649, 32, 61, 0,1.5,        -1,-33790       , 0         , "t=40.7ms",_
 650, 33, 61, 0,1.5,        -1,-17200       , 0         , "t=?",_
 651, 21, 62, 0,-77.777,     0,7310         , 0         , "t=2ms",_
 652, 22, 62, 0,0,           1,-12200       , 0         , "t=9ms",_
 653, 23, 62, 0,3,           1,-25210       , 0         , "t=33.6ms",_
 654, 24, 62, 0,0,           1,-40853       , 0         , "t=206ms",_
 655, 25, 62, 0,1,           1,-48524       , 0         , "t=92ms",_
 656, 25, 62, 1,4,           1,-48181.0     , 0.343     , "t=671ms",_
 657, 26, 62, 0,0,           1,-58878.1     , 0         , "t=68s",_
 658, 27, 62, 0,2,           1,-61424       , 0         , "t=1.54m",_
 659, 27, 62, 1,5,           1,-61402       , 0.022     , "t=13.86m",_
 660, 28, 62, 0,0,           1,-66746.4     , 0         , "t=stbl",_
 661, 29, 62, 0,1,           1,-62787.5     , 0         , "t=9.672m",_
 662, 30, 62, 0,0,           1,-61168.1     , 0         , "t=9.193h",_
 663, 31, 62, 0,0,           1,-51987.0     , 0         , "t=116.122ms",_
 664, 32, 62, 0,0,           1,-42140       , 0         , "t=82.5ms",_
 665, 33, 62, 0,1,           1,-24420       , 0         , "t=?",_
 666, 21, 63, 0,3.5,        -1,13070        , 0         , "t=1ms",_
 667, 22, 63, 0,0.5,        -1,-5860        , 0         , "t=10ms",_
 668, 23, 63, 0,1.5,        -1,-21740       , 0         , "t=19.6ms",_
 669, 24, 63, 0,0.5,        -1,-36180       , 0         , "t=129ms",_
 670, 25, 63, 0,2.5,        -1,-46887       , 0         , "t=275ms",_
 671, 26, 63, 0,2.5,        -1,-55636       , 0         , "t=6.1s",_
 672, 27, 63, 0,3.5,        -1,-61852       , 0         , "t=26.9s",_
 673, 28, 63, 0,0.5,        -1,-65512.9     , 0         , "t=101.2y",_
 674, 28, 63, 1,2.5,        -1,-65425.8     , 0.08715   , "t=1.67us",_
 675, 29, 63, 0,1.5,        -1,-65579.9     , 0         , "t=stbl",_
 676, 30, 63, 0,1.5,        -1,-62213.4     , 0         , "t=38.47m",_
 677, 31, 63, 0,1.5,        -1,-56547.1     , 0         , "t=32.4s",_
 678, 32, 63, 0,1.5,        -1,-46920       , 0         , "t=153.6ms",_
 679, 33, 63, 0,1.5,        -1,-33500       , 0         , "t=?",_
 680, 34, 63, 0,1.5,        -1,-16850       , 0         , "t=13.2ms",_
 681, 22, 64, 0,0,           1,-1480        , 0         , "t=5ms",_
 682, 23, 64, 0,1,           0,-16320       , 0         , "t=15ms",_
 683, 23, 64, 1,-77.777,     0,-16240       , 0.081     , "t=&lt;1us",_
 684, 24, 64, 0,0,           1,-33640       , 0         , "t=43ms",_
 685, 25, 64, 0,1,           1,-42989       , 0         , "t=88.8ms",_
 686, 25, 64, 1,4,           1,-42815       , 0.1741    , "t=439us",_
 687, 26, 64, 0,0,           1,-54970       , 0         , "t=2.0s",_
 688, 27, 64, 0,1,           1,-59792       , 0         , "t=300ms",_
 689, 27, 64, 1,5,           1,-59686       , 0.107     , "t=300ms",_
 690, 28, 64, 0,0,           1,-67099.0     , 0         , "t=stbl",_
 691, 29, 64, 0,1,           1,-65424.4     , 0         , "t=12.7004h",_
 692, 30, 64, 0,0,           1,-66004.0     , 0         , "t=stbl",_
 693, 31, 64, 0,0,           1,-58832.8     , 0         , "t=2.627m",_
 694, 31, 64, 1,2,           1,-58790.0     , 0.04285   , "t=21.9us",_
 695, 32, 64, 0,0,           1,-54316       , 0         , "t=63.7s",_
 696, 33, 64, 0,0,           1,-39530       , 0         , "t=69.0ms",_
 697, 34, 64, 0,0,           1,-26860       , 0         , "t=22.6ms",_
 698, 22, 65, 0,0.5,        -1,5210         , 0         , "t=1ms",_
 699, 23, 65, 0,2.5,        -1,-12110       , 0         , "t=14ms",_
 700, 24, 65, 0,0.5,        -1,-28310       , 0         , "t=27.5ms",_
 701, 25, 65, 0,2.5,        -1,-40967       , 0         , "t=91.9ms",_
 702, 26, 65, 0,0.5,        -1,-51218       , 0         , "t=805ms",_
 703, 26, 65, 1,4.5,         1,-50824       , 0.3937    , "t=1.12s",_
 704, 27, 65, 0,3.5,        -1,-59185.2     , 0         , "t=1.16s",_
 705, 28, 65, 0,2.5,        -1,-65125.8     , 0         , "t=2.5175h",_
 706, 28, 65, 1,0.5,        -1,-65062.4     , 0.06337   , "t=69us",_
 707, 29, 65, 0,1.5,        -1,-67263.7     , 0         , "t=stbl",_
 708, 30, 65, 0,2.5,        -1,-65912.0     , 0         , "t=243.94d",_
 709, 30, 65, 1,0.5,        -1,-65858.1     , 0.053928  , "t=1.6us",_
 710, 31, 65, 0,1.5,        -1,-62657.5     , 0         , "t=15.133m",_
 711, 32, 65, 0,1.5,        -1,-56478.2     , 0         , "t=30.9s",_
 712, 33, 65, 0,1.5,        -1,-46940       , 0         , "t=130.3ms",_
 713, 34, 65, 0,1.5,        -1,-33020       , 0         , "t=34.2ms",_
 714, 35, 65, 0,2.5,        -1,-16490       , 0         , "t=?",_
 715, 23, 66, 0,-77.777,     0,-6300        , 0         , "t=10ms",_
 716, 24, 66, 0,0,           1,-25140       , 0         , "t=23.8ms",_
 717, 25, 66, 0,1,           1,-36750       , 0         , "t=63.8ms",_
 718, 25, 66, 1,5,          -1,-36286       , 0.4645    , "t=780us",_
 719, 26, 66, 0,0,           1,-50068       , 0         , "t=467ms",_
 720, 27, 66, 0,1,           1,-56409       , 0         , "t=194ms",_
 721, 27, 66, 1,3,           1,-56234       , 0.1751    , "t=824ns",_
 722, 28, 66, 0,0,           1,-66006.3     , 0         , "t=54.6h",_
 723, 29, 66, 0,1,           1,-66258.3     , 0         , "t=5.120m",_
 724, 29, 66, 1,6,          -1,-65104.1     , 1.1542    , "t=600ns",_
 725, 30, 66, 0,0,           1,-68899.2     , 0         , "t=stbl",_
 726, 31, 66, 0,0,           1,-63723.7     , 0         , "t=9.304h",_
 727, 32, 66, 0,0,           1,-61607.0     , 0         , "t=2.26h",_
 728, 33, 66, 0,0,           1,-52025       , 0         , "t=95.77ms",_
 729, 33, 66, 1,5,           1,-50668       , 1.35663   , "t=1.14us",_
 730, 34, 66, 0,0,           1,-41660       , 0         , "t=54ms",_
 731, 35, 66, 0,0,           1,-23570       , 0         , "t=?",_
 732, 23, 67, 0,2.5,        -1,-1740        , 0         , "t=8ms",_
 733, 24, 67, 0,0.5,        -1,-19270       , 0         , "t=11ms",_
 734, 25, 67, 0,2.5,        -1,-33580       , 0         , "t=46.7ms",_
 735, 26, 67, 0,0.5,        -1,-45708       , 0         , "t=394ms",_
 736, 26, 67, 1,2.5,         1,-45305       , 0.403     , "t=64us",_
 737, 27, 67, 0,3.5,        -1,-55322       , 0         , "t=329ms",_
 738, 27, 67, 1,0.5,        -1,-54830       , 0.49155   , "t=496ms",_
 739, 28, 67, 0,0.5,        -1,-63742.7     , 0         , "t=21s",_
 740, 28, 67, 1,4.5,         1,-62736.1     , 1.0066    , "t=13.34us",_
 741, 29, 67, 0,1.5,        -1,-67319.6     , 0         , "t=61.83h",_
 742, 30, 67, 0,2.5,        -1,-67880.4     , 0         , "t=stbl",_
 743, 30, 67, 1,0.5,        -1,-67787.1     , 0.093312  , "t=9.15us",_
 744, 31, 67, 0,1.5,        -1,-66879.2     , 0         , "t=3.2617d",_
 745, 32, 67, 0,0.5,        -1,-62674       , 0         , "t=18.9m",_
 746, 32, 67, 1,2.5,        -1,-62656       , 0.0182    , "t=13.7us",_
 747, 33, 67, 0,2.5,        -1,-56587.2     , 0         , "t=42.5s",_
 748, 34, 67, 0,2.5,        -1,-46580       , 0         , "t=133ms",_
 749, 35, 67, 0,0.5,        -1,-32530       , 0         , "t=?",_
 750, 36, 67, 0,1.5,        -1,-15550       , 0         , "t=7.4ms",_
 751, 24, 68, 0,0,           1,-15690       , 0         , "t=10ms",_
 752, 25, 68, 0,3,           0,-28920       , 0         , "t=33.7ms",_
 753, 26, 68, 0,0,           1,-43900       , 0         , "t=188ms",_
 754, 27, 68, 0,7,          -1,-51643       , 0         , "t=200ms",_
 755, 27, 68, 1,2,          -1,-51490       , 0.15      , "t=1.6s",_
 756, 28, 68, 0,0,           1,-63463.8     , 0         , "t=29s",_
 757, 28, 68, 1,0,           1,-61860       , 1.60351   , "t=270ns",_
 758, 29, 68, 0,1,           1,-65567.0     , 0         , "t=30.9s",_
 759, 29, 68, 1,6,          -1,-64845.7     , 0.72126   , "t=3.75m",_
 760, 30, 68, 0,0,           1,-70007.2     , 0         , "t=stbl",_
 761, 31, 68, 0,1,           1,-67086.1     , 0         , "t=67.842m",_
 762, 32, 68, 0,0,           1,-66978.8     , 0         , "t=271.05d",_
 763, 33, 68, 0,3,           1,-58894.5     , 0         , "t=151.6s",_
 764, 33, 68, 1,1,           1,-58469.4     , 0.4251    , "t=111ns",_
 765, 34, 68, 0,0,           1,-54189.4     , 0         , "t=35.5s",_
 766, 35, 68, 0,3,           1,-38790       , 0         , "t=?",_
 767, 36, 68, 0,0,           1,-25630       , 0         , "t=21.6ms",_
 768, 24, 69, 0,3.5,         1,-9630        , 0         , "t=6ms",_
 769, 25, 69, 0,2.5,        -1,-25360       , 0         , "t=22.1ms",_
 770, 26, 69, 0,0.5,        -1,-39200       , 0         , "t=162ms",_
 771, 27, 69, 0,3.5,        -1,-50390       , 0         , "t=180ms",_
 772, 27, 69, 1,0.5,        -1,-50213       , 0.17      , "t=750ms",_
 773, 28, 69, 0,4.5,         1,-59979       , 0         , "t=11.4s",_
 774, 28, 69, 1,0.5,        -1,-59658       , 0.321     , "t=3.5s",_
 775, 29, 69, 0,1.5,        -1,-65736.2     , 0         , "t=2.85m",_
 776, 29, 69, 1,6.5,         1,-62994.2     , 2.742     , "t=357ns",_
 777, 30, 69, 0,0.5,        -1,-68417.9     , 0         , "t=56.4m",_
 778, 30, 69, 1,4.5,         1,-67979.3     , 0.438636  , "t=13.747h",_
 779, 31, 69, 0,1.5,        -1,-69327.8     , 0         , "t=stbl",_
 780, 32, 69, 0,2.5,        -1,-67100.7     , 0         , "t=39.05h",_
 781, 32, 69, 1,0.5,        -1,-67013.9     , 0.08676   , "t=5.1us",_
 782, 33, 69, 0,2.5,        -1,-63110       , 0         , "t=15.2m",_
 783, 34, 69, 0,0.5,        -1,-56434.7     , 0         , "t=27.4s",_
 784, 34, 69, 1,2.5,        -1,-56395.9     , 0.03885   , "t=2.0us",_
 785, 35, 69, 0,2.5,        -1,-46260       , 0         , "t=&lt;24ns",_
 786, 35, 69, 1,2.5,        -1,-46220       , 0.04      , "t=?",_
 787, 36, 69, 0,2.5,        -1,-32140       , 0         , "t=27.9ms",_
 788, 24, 70, 0,0,           1,-5640        , 0         , "t=6ms",_
 789, 25, 70, 0,4,           0,-20450       , 0         , "t=19.9ms",_
 790, 26, 70, 0,0,           1,-36890       , 0         , "t=61.4ms",_
 791, 27, 70, 0,1,           1,-46525       , 0         , "t=508ms",_
 792, 27, 70, 1,7,          -1,-46330       , 0.2       , "t=112ms",_
 793, 28, 70, 0,0,           1,-59213.9     , 0         , "t=6.0s",_
 794, 28, 70, 1,8,           1,-56353.0     , 2.86091   , "t=232ns",_
 795, 29, 70, 0,6,          -1,-62976.4     , 0         , "t=44.5s",_
 796, 29, 70, 1,3,          -1,-62875.3     , 0.1011    , "t=33s",_
 797, 30, 70, 0,0,           1,-69564.7     , 0         , "t=stbl",_
 798, 31, 70, 0,1,           1,-68910.2     , 0         , "t=21.14m",_
 799, 32, 70, 0,0,           1,-70562.0     , 0         , "t=stbl",_
 800, 33, 70, 0,4,           1,-64334.0     , 0         , "t=52.6m",_
 801, 33, 70, 1,2,           1,-64302.0     , 0.032046  , "t=96us",_
 802, 34, 70, 0,0,           1,-61929.9     , 0         , "t=41.1m",_
 803, 35, 70, 0,0,           1,-51426       , 0         , "t=78.8ms",_
 804, 35, 70, 1,9,           1,-49134       , 2.2923    , "t=2.16s",_
 805, 36, 70, 0,0,           1,-41100       , 0         , "t=45.00ms",_
 806, 25, 71, 0,2.5,        -1,-16620       , 0         , "t=16ms",_
 807, 26, 71, 0,3.5,         1,-31930       , 0         , "t=34.3ms",_
 808, 27, 71, 0,3.5,        -1,-44370       , 0         , "t=80ms",_
 809, 28, 71, 0,4.5,         1,-55406.2     , 0         , "t=2.56s",_
 810, 28, 71, 1,0.5,        -1,-55406.0     , 0.499     , "t=2.3s",_
 811, 29, 71, 0,1.5,        -1,-62711.1     , 0         , "t=19.4s",_
 812, 29, 71, 1,9.5,        -1,-59955.4     , 2.7557    , "t=271ns",_
 813, 30, 71, 0,0.5,        -1,-67328.8     , 0         , "t=2.40m",_
 814, 30, 71, 1,4.5,         1,-67171.1     , 0.1577    , "t=4.148h",_
 815, 31, 71, 0,1.5,        -1,-70139.1     , 0         , "t=stbl",_
 816, 32, 71, 0,0.5,        -1,-69906.7     , 0         , "t=11.43d",_
 817, 32, 71, 1,4.5,         1,-69708.3     , 0.198354  , "t=20.41ms",_
 818, 33, 71, 0,2.5,        -1,-67893       , 0         , "t=65.30h",_
 819, 34, 71, 0,2.5,        -1,-63146.5     , 0         , "t=4.74m",_
 820, 34, 71, 1,0.5,        -1,-63097.7     , 0.04879   , "t=5.6us",_
 821, 35, 71, 0,2.5,        -1,-56502       , 0         , "t=21.4s",_
 822, 36, 71, 0,2.5,        -1,-46330       , 0         , "t=98.8ms",_
 823, 37, 71, 0,2.5,        -1,-32290       , 0         , "t=?",_
 824, 37, 71, 1,0.5,        -1,-32240       , 0.05      , "t=?",_
 825, 25, 72, 0,-77.777,     0,-11170       , 0         , "t=12ms",_
 826, 26, 72, 0,0,           1,-29250       , 0         , "t=17.0ms",_
 827, 27, 72, 0,6,          -1,-40300       , 0         , "t=51.5ms",_
 828, 27, 72, 1,0,           1,-40100       , 0.2       , "t=47.8ms",_
 829, 28, 72, 0,0,           1,-54226.1     , 0         , "t=1.57s",_
 830, 29, 72, 0,2,          -1,-59783.0     , 0         , "t=6.63s",_
 831, 29, 72, 1,6,          -1,-59512.7     , 0.2703    , "t=1.76us",_
 832, 30, 72, 0,0,           1,-68145.5     , 0         , "t=46.5h",_
 833, 31, 72, 0,3,          -1,-68588.3     , 0         , "t=14.025h",_
 834, 31, 72, 1,0,           1,-68468.6     , 0.11966   , "t=39.68ms",_
 835, 32, 72, 0,0,           1,-72585.91    , 0         , "t=stbl",_
 836, 32, 72, 1,0,           1,-71894.48    , 0.69143   , "t=444.2ns",_
 837, 33, 72, 0,2,          -1,-68230       , 0         , "t=26.0h",_
 838, 34, 72, 0,0,           1,-67868.2     , 0         , "t=8.40d",_
 839, 35, 72, 0,1,           1,-59061.8     , 0         , "t=78.6s",_
 840, 35, 72, 1,3,          -1,-58961.0     , 0.10076   , "t=10.6s",_
 841, 36, 72, 0,0,           1,-53941       , 0         , "t=17.16s",_
 842, 37, 72, 0,1,           1,-38330       , 0         , "t=103ns",_
 843, 37, 72, 1,3,          -1,-38230       , 0.1       , "t=?",_
 844, 25, 73, 0,2.5,        -1,-6700        , 0         , "t=12ms",_
 845, 26, 73, 0,3.5,         1,-23990       , 0         , "t=12.9ms",_
 846, 27, 73, 0,3.5,        -1,-37970       , 0         , "t=42.0ms",_
 847, 28, 73, 0,4.5,         1,-50108.2     , 0         , "t=840ms",_
 848, 29, 73, 0,1.5,        -1,-58987.4     , 0         , "t=4.20s",_
 849, 30, 73, 0,0.5,        -1,-65593.4     , 0         , "t=24.5s",_
 850, 30, 73, 1,2.5,         1,-65397.9     , 0.1955    , "t=13.0ms",_
 851, 31, 73, 0,0.5,        -1,-69699.3     , 0         , "t=4.86h",_
 852, 31, 73, 1,1.5,        -1,-69699.2     , 0.00015   , "t=&lt;200ms",_
 853, 32, 73, 0,4.5,         1,-71297.53    , 0         , "t=stbl",_
 854, 32, 73, 1,2.5,         1,-71284.25    , 0.0132845 , "t=2.91us",_
 855, 33, 73, 0,1.5,        -1,-70953       , 0         , "t=80.30d",_
 856, 33, 73, 1,4.5,         1,-70525       , 0.427902  , "t=5.7us",_
 857, 34, 73, 0,4.5,         1,-68227       , 0         , "t=7.15h",_
 858, 34, 73, 1,1.5,        -1,-68201       , 0.02571   , "t=39.8m",_
 859, 35, 73, 0,0.5,        -1,-63646       , 0         , "t=3.4m",_
 860, 36, 73, 0,1.5,        -1,-56552       , 0         , "t=27.3s",_
 861, 36, 73, 1,4.5,         1,-56118       , 0.43355   , "t=107ns",_
 862, 37, 73, 0,1.5,        -1,-46010       , 0         , "t=&lt;81ns",_
 863, 37, 73, 1,4.5,         1,-45580       , 0.43      , "t=?",_
 864, 38, 73, 0,2.5,        -1,-31950       , 0         , "t=25.3ms",_
 865, 26, 74, 0,0,           1,-20660       , 0         , "t=5ms",_
 866, 27, 74, 0,7,          -1,-33540       , 0         , "t=31.3ms",_
 867, 28, 74, 0,0,           1,-48700       , 0         , "t=507.7ms",_
 868, 29, 74, 0,2,          -1,-56006       , 0         , "t=1.606s",_
 869, 30, 74, 0,0,           1,-65756.7     , 0         , "t=95.6s",_
 870, 31, 74, 0,3,          -1,-68049.6     , 0         , "t=8.12m",_
 871, 31, 74, 1,0,           1,-67990       , 0.059571  , "t=9.5s",_
 872, 32, 74, 0,0,           1,-73422.451   , 0         , "t=stbl",_
 873, 33, 74, 0,2,          -1,-70860.1     , 0         , "t=17.77d",_
 874, 34, 74, 0,0,           1,-72213.210   , 0         , "t=stbl",_
 875, 35, 74, 0,0,          -1,-65288       , 0         , "t=25.4m",_
 876, 35, 74, 1,4,           1,-65274       , 0.01358   , "t=46m",_
 877, 36, 74, 0,0,           1,-62331.8     , 0         , "t=11.50m",_
 878, 37, 74, 0,0,           1,-51916       , 0         , "t=64.78ms",_
 879, 38, 74, 0,0,           1,-40830       , 0         , "t=27.6ms",_
 880, 26, 75, 0,4.5,         1,-14700       , 0         , "t=9ms",_
 881, 27, 75, 0,3.5,        -1,-30560       , 0         , "t=26.5ms",_
 882, 28, 75, 0,4.5,         1,-44240       , 0         , "t=331.6ms",_
 883, 29, 75, 0,2.5,        -1,-54470.2     , 0         , "t=1.224s",_
 884, 29, 75, 1,0.5,        -1,-54408.5     , 0.0617    , "t=310ns",_
 885, 30, 75, 0,3.5,         1,-62558.9     , 0         , "t=10.2s",_
 886, 30, 75, 1,0.5,        -1,-62432.0     , 0.12694   , "t=5s",_
 887, 31, 75, 0,1.5,        -1,-68460.6     , 0         , "t=126s",_
 888, 32, 75, 0,0.5,        -1,-71856.97    , 0         , "t=82.78m",_
 889, 32, 75, 1,3.5,         1,-71717.28    , 0.13969   , "t=47.7s",_
 890, 33, 75, 0,1.5,        -1,-73034.2     , 0         , "t=stbl",_
 891, 33, 75, 1,4.5,         1,-72730.3     , 0.3039243 , "t=17.62ms",_
 892, 34, 75, 0,2.5,         1,-72169.49    , 0         , "t=119.78d",_
 893, 35, 75, 0,1.5,        -1,-69107       , 0         , "t=96.7m",_
 894, 36, 75, 0,2.5,         1,-64324       , 0         , "t=4.60m",_
 895, 37, 75, 0,1.5,        -1,-57218.7     , 0         , "t=19.0s",_
 896, 38, 75, 0,1.5,        -1,-46620       , 0         , "t=85.2ms",_
 897, 39, 75, 0,2.5,         1,-31820       , 0         , "t=100us",_
 898, 26, 76, 0,0,           1,-10590       , 0         , "t=3ms",_
 899, 27, 76, 0,8,          -1,-25660       , 0         , "t=23ms",_
 900, 27, 76, 1,1,          -1,-25560       , 0.1       , "t=16ms",_
 901, 28, 76, 0,0,           1,-42190       , 0         , "t=234.6ms",_
 902, 28, 76, 1,8,           1,-39770       , 2.418     , "t=547.8ns",_
 903, 29, 76, 0,3,          -1,-50981.6     , 0         , "t=637.7ms",_
 904, 30, 76, 0,0,           1,-62303.0     , 0         , "t=5.7s",_
 905, 31, 76, 0,2,          -1,-66296.6     , 0         , "t=30.6s",_
 906, 32, 76, 0,0,           1,-73212.898   , 0         , "t=1.88Zy",_
 907, 33, 76, 0,2,          -1,-72291.4     , 0         , "t=1.0933d",_
 908, 33, 76, 1,1,           1,-72247.0     , 0.044425  , "t=1.84us",_
 909, 34, 76, 0,0,           1,-75251.959   , 0         , "t=stbl",_
 910, 35, 76, 0,1,          -1,-70289       , 0         , "t=16.2h",_
 911, 35, 76, 1,4,           1,-70186       , 0.10258   , "t=1.31s",_
 912, 36, 76, 0,0,           1,-69014       , 0         , "t=14.8h",_
 913, 37, 76, 0,1,          -1,-60479.1     , 0         , "t=36.5s",_
 914, 37, 76, 1,4,           1,-60162.2     , 0.31693   , "t=3.050us",_
 915, 38, 76, 0,0,           1,-54250       , 0         , "t=7.89s",_
 916, 39, 76, 0,1,          -1,-38250       , 0         , "t=28ms",_
 917, 27, 77, 0,3.5,        -1,-21910       , 0         , "t=15ms",_
 918, 28, 77, 0,4.5,         1,-37350       , 0         , "t=158.9ms",_
 919, 29, 77, 0,2.5,        -1,-48862.8     , 0         , "t=470.3ms",_
 920, 30, 77, 0,3.5,         1,-58789.2     , 0         , "t=2.08s",_
 921, 30, 77, 1,0.5,        -1,-58016.8     , 0.77244   , "t=1.05s",_
 922, 31, 77, 0,1.5,        -1,-65992.4     , 0         , "t=13.2s",_
 923, 32, 77, 0,3.5,         1,-71212.87    , 0         , "t=11.211h",_
 924, 32, 77, 1,0.5,        -1,-71053.16    , 0.15971   , "t=53.7s",_
 925, 33, 77, 0,1.5,        -1,-73916.3     , 0         , "t=38.79h",_
 926, 33, 77, 1,4.5,         1,-73440.8     , 0.47548   , "t=114.0us",_
 927, 34, 77, 0,0.5,        -1,-74599.50    , 0         , "t=stbl",_
 928, 34, 77, 1,3.5,         1,-74437.58    , 0.1619223 , "t=17.36s",_
 929, 35, 77, 0,1.5,        -1,-73234.8     , 0         , "t=57.04h",_
 930, 35, 77, 1,4.5,         1,-73128.9     , 0.10586   , "t=4.28m",_
 931, 36, 77, 0,2.5,         1,-70169.5     , 0         , "t=72.6m",_
 932, 36, 77, 1,1.5,        -1,-70103.0     , 0.0665    , "t=118ns",_
 933, 37, 77, 0,1.5,        -1,-64830.5     , 0         , "t=3.78m",_
 934, 38, 77, 0,2.5,         1,-57803       , 0         , "t=9.0s",_
 935, 39, 77, 0,2.5,         1,-46440       , 0         , "t=63ms",_
 936, 40, 77, 0,1.5,        -1,-31600       , 0         , "t=100us",_
 937, 27, 78, 0,-77.777,     0,-15320       , 0         , "t=11ms",_
 938, 28, 78, 0,0,           1,-34880       , 0         , "t=122.2ms",_
 939, 29, 78, 0,6,          -1,-44789       , 0         , "t=330.7ms",_
 940, 30, 78, 0,0,           1,-57483.2     , 0         , "t=1.47s",_
 941, 30, 78, 1,8,           1,-54809.5     , 2.6737    , "t=320ns",_
 942, 31, 78, 0,2,          -1,-63704.1     , 0         , "t=5.09s",_
 943, 31, 78, 1,-77.777,     0,-63205.2     , 0.4989    , "t=110ns",_
 944, 32, 78, 0,0,           1,-71862       , 0         , "t=88.0m",_
 945, 33, 78, 0,2,          -1,-72817       , 0         , "t=90.7m",_
 946, 34, 78, 0,0,           1,-77025.95    , 0         , "t=stbl",_
 947, 35, 78, 0,1,           1,-73452       , 0         , "t=6.45m",_
 948, 35, 78, 1,4,           1,-73271       , 0.18089   , "t=119.4us",_
 949, 36, 78, 0,0,           1,-74178.3     , 0         , "t=stbl",_
 950, 37, 78, 0,0,           1,-66935       , 0         , "t=17.66m",_
 951, 37, 78, 1,1,          -1,-66888       , 0.04684   , "t=910ns",_
 952, 38, 78, 0,0,           1,-63174       , 0         , "t=156.1s",_
 953, 39, 78, 0,0,           1,-52170       , 0         , "t=54ms",_
 954, 39, 78, 1,5,           1,-52170       , 0         , "t=5.8s",_
 955, 40, 78, 0,0,           1,-40850       , 0         , "t=50ms",_
 956, 28, 79, 0,2.5,         1,-28160       , 0         , "t=44ms",_
 957, 29, 79, 0,2.5,        -1,-42410       , 0         , "t=241.3ms",_
 958, 30, 79, 0,4.5,         1,-53432.3     , 0         , "t=746ms",_
 959, 30, 79, 1,0.5,         1,-52330       , 1.1       , "t=&gt;200ms",_
 960, 31, 79, 0,1.5,        -1,-62548.4     , 0         , "t=2.848s",_
 961, 32, 79, 0,0.5,        -1,-69530       , 0         , "t=18.98s",_
 962, 32, 79, 1,3.5,         1,-69340       , 0.18595   , "t=39.0s",_
 963, 33, 79, 0,1.5,        -1,-73636       , 0         , "t=9.01m",_
 964, 33, 79, 1,4.5,         1,-72863       , 0.77281   , "t=1.21us",_
 965, 34, 79, 0,3.5,         1,-75917.47    , 0         , "t=327ky",_
 966, 34, 79, 1,0.5,        -1,-75821.70    , 0.09577   , "t=3.900m",_
 967, 35, 79, 0,1.5,        -1,-76068.1     , 0         , "t=stbl",_
 968, 35, 79, 1,4.5,         1,-75860.5     , 0.20761   , "t=4.85s",_
 969, 36, 79, 0,0.5,        -1,-74442       , 0         , "t=35.04h",_
 970, 36, 79, 1,3.5,         1,-74312       , 0.12977   , "t=50s",_
 971, 37, 79, 0,2.5,         1,-70802.8     , 0         , "t=22.9m",_
 972, 38, 79, 0,1.5,        -1,-65480       , 0         , "t=2.25m",_
 973, 39, 79, 0,2.5,         1,-57800       , 0         , "t=14.8s",_
 974, 40, 79, 0,2.5,         1,-46770       , 0         , "t=56ms",_
 975, 41, 79, 0,4.5,         1,-31650       , 0         , "t=?",_
 976, 28, 80, 0,0,           1,-23240       , 0         , "t=30ms",_
 977, 29, 80, 0,-77.777,     0,-36680       , 0         , "t=113.3ms",_
 978, 30, 80, 0,0,           1,-51648.6     , 0         , "t=562.2ms",_
 979, 31, 80, 0,6,          -1,-59223.7     , 0         , "t=1.9s",_
 980, 31, 80, 1,3,          -1,-59201.3     , 0.02245   , "t=1.3s",_
 981, 32, 80, 0,0,           1,-69535.3     , 0         , "t=29.5s",_
 982, 33, 80, 0,1,           1,-72215       , 0         , "t=15.2s",_
 983, 34, 80, 0,0,           1,-77759.5     , 0         , "t=stbl",_
 984, 35, 80, 0,1,           1,-75889.0     , 0         , "t=17.68m",_
 985, 35, 80, 1,5,          -1,-75803.2     , 0.085843  , "t=4.4205h",_
 986, 36, 80, 0,0,           1,-77893.5     , 0         , "t=stbl",_
 987, 37, 80, 0,1,           1,-72175.5     , 0         , "t=33.4s",_
 988, 37, 80, 1,6,           1,-71681.6     , 0.4939    , "t=1.63us",_
 989, 38, 80, 0,0,           1,-70311       , 0         , "t=106.3m",_
 990, 39, 80, 0,4,          -1,-61148       , 0         , "t=30.1s",_
 991, 39, 80, 1,1,          -1,-60920       , 0.2285    , "t=4.8s",_
 992, 40, 80, 0,0,           1,-54760       , 0         , "t=4.6s",_
 993, 41, 80, 0,4,          -1,-38420       , 0         , "t=?",_
 994, 28, 81, 0,1.5,         1,-16090       , 0         , "t=30ms",_
 995, 29, 81, 0,2.5,        -1,-31910       , 0         , "t=73.2ms",_
 996, 30, 81, 0,0.5,         1,-46200       , 0         , "t=299.4ms",_
 997, 31, 81, 0,2.5,        -1,-57628       , 0         , "t=1.217s",_
 998, 32, 81, 0,4.5,         1,-66291.7     , 0         , "t=9s",_
 999, 32, 81, 1,0.5,         1,-65612.6     , 0.67914   , "t=6s",_
 1000, 33, 81, 0,1.5,       -1,-72533.3     , 0         , "t=33.3s",_
 1001, 34, 81, 0,0.5,       -1,-76389.0     , 0         , "t=18.45m",_
 1002, 34, 81, 1,3.5,        1,-76286.0     , 0.103     , "t=57.28m",_
 1003, 35, 81, 0,1.5,       -1,-77977.1     , 0         , "t=stbl",_
 1004, 35, 81, 1,4.5,        1,-77440.9     , 0.5362    , "t=34.6us",_
 1005, 36, 81, 0,3.5,        1,-77696.2     , 0         , "t=229ky",_
 1006, 36, 81, 1,0.5,       -1,-77505.6     , 0.19064   , "t=13.10s",_
 1007, 37, 81, 0,1.5,       -1,-75457       , 0         , "t=4.572h",_
 1008, 37, 81, 1,4.5,        1,-75371       , 0.08631   , "t=30.5m",_
 1009, 38, 81, 0,0.5,       -1,-71528       , 0         , "t=22.3m",_
 1010, 38, 81, 1,2.5,       -1,-71449       , 0.07923   , "t=390ns",_
 1011, 39, 81, 0,2.5,        1,-65713       , 0         , "t=70.4s",_
 1012, 40, 81, 0,1.5,       -1,-57520       , 0         , "t=5.5s",_
 1013, 41, 81, 0,4.5,        1,-46360       , 0         , "t=?",_
 1014, 42, 81, 0,2.5,        1,-31460       , 0         , "t=1ms",_
 1015, 28, 82, 0,0,          1,-10720       , 0         , "t=16ms",_
 1016, 29, 82, 0,-77.777,    0,-25730       , 0         , "t=34ms",_
 1017, 30, 82, 0,0,          1,-42314       , 0         , "t=177.9ms",_
 1018, 31, 82, 0,2,         -1,-52930.7     , 0         , "t=600ms",_
 1019, 31, 82, 1,4,         -1,-52790.0     , 0.1407    , "t=93.5ns",_
 1020, 32, 82, 0,0,          1,-65415.1     , 0         , "t=4.31s",_
 1021, 33, 82, 0,2,         -1,-70105       , 0         , "t=19.1s",_
 1022, 33, 82, 1,5,         -1,-69973       , 0.1316    , "t=13.6s",_
 1023, 34, 82, 0,0,          1,-77593.9     , 0         , "t=87.6Ey",_
 1024, 35, 82, 0,5,         -1,-77498.7     , 0         , "t=35.282h",_
 1025, 35, 82, 1,2,         -1,-77452.8     , 0.0459492 , "t=6.13m",_
 1026, 36, 82, 0,0,          1,-80591.795   , 0         , "t=stbl",_
 1027, 37, 82, 0,1,          1,-76188       , 0         , "t=1.2575m",_
 1028, 37, 82, 1,5,         -1,-76118.8     , 0.069     , "t=6.472h",_
 1029, 38, 82, 0,0,          1,-76010       , 0         , "t=25.35d",_
 1030, 39, 82, 0,1,          1,-68064       , 0         , "t=8.30s",_
 1031, 39, 82, 1,4,         -1,-67661       , 0.40263   , "t=258ns",_
 1032, 40, 82, 0,0,          1,-63614.1     , 0         , "t=32s",_
 1033, 41, 82, 0,0,          1,-51810       , 0         , "t=51ms",_
 1034, 41, 82, 1,5,          1,-50630       , 1.18      , "t=93ns",_
 1035, 42, 82, 0,0,          1,-40370       , 0         , "t=30ms",_
 1036, 29, 83, 0,2.5,       -1,-20390       , 0         , "t=21ms",_
 1037, 30, 83, 0,1.5,        1,-36290       , 0         , "t=100ms",_
 1038, 31, 83, 0,2.5,       -1,-49257.1     , 0         , "t=310.0ms",_
 1039, 32, 83, 0,2.5,        1,-60976.4     , 0         , "t=1.85s",_
 1040, 33, 83, 0,2.5,       -1,-69669.3     , 0         , "t=13.4s",_
 1041, 34, 83, 0,4.5,        1,-75341       , 0         , "t=22.25m",_
 1042, 34, 83, 1,0.5,       -1,-75112       , 0.22892   , "t=70.1s",_
 1043, 35, 83, 0,1.5,       -1,-79014       , 0         , "t=2.374h",_
 1044, 35, 83, 1,9.5,       -1,-75945       , 3.0692    , "t=729ns",_
 1045, 36, 83, 0,4.5,        1,-79990.643   , 0         , "t=stbl",_
 1046, 36, 83, 1,3.5,        1,-79981.238   , 0.0094053 , "t=156.8ns",_
 1047, 37, 83, 0,2.5,       -1,-79070.6     , 0         , "t=86.2d",_
 1048, 37, 83, 1,4.5,        1,-79028.5     , 0.042078  , "t=7.8ms",_
 1049, 38, 83, 0,3.5,        1,-76798       , 0         , "t=32.41h",_
 1050, 38, 83, 1,0.5,       -1,-76539       , 0.25915   , "t=4.95s",_
 1051, 39, 83, 0,4.5,        1,-72206       , 0         , "t=7.08m",_
 1052, 39, 83, 1,1.5,       -1,-72144       , 0.06204   , "t=2.85m",_
 1053, 40, 83, 0,0.5,       -1,-65912       , 0         , "t=42s",_
 1054, 40, 83, 1,2.5,       -1,-65859       , 0.05272   , "t=530ns",_
 1055, 41, 83, 0,4.5,        1,-57610       , 0         , "t=3.9s",_
 1056, 42, 83, 0,1.5,       -1,-46340       , 0         , "t=23ms",_
 1057, 43, 83, 0,0.5,       -1,-31320       , 0         , "t=?",_
 1058, 29, 84, 0,-77.777,    0,-13720       , 0         , "t=?",_
 1059, 30, 84, 0,0,          1,-31830       , 0         , "t=54ms",_
 1060, 31, 84, 0,0,         -1,-44094       , 0         , "t=97.6ms",_
 1061, 32, 84, 0,0,          1,-58148       , 0         , "t=951ms",_
 1062, 33, 84, 0,2,         -1,-65854       , 0         , "t=3.16s",_
 1063, 34, 84, 0,0,          1,-75947.7     , 0         , "t=3.26m",_
 1064, 35, 84, 0,2,         -1,-77783       , 0         , "t=31.76m",_
 1065, 35, 84, 1,6,         -1,-77470       , 0.31      , "t=6.0m",_
 1066, 36, 84, 0,0,          1,-82439.345   , 0         , "t=stbl",_
 1067, 36, 84, 1,8,          1,-79203.27    , 3.23607   , "t=1.83us",_
 1068, 37, 84, 0,2,         -1,-79759.0     , 0         , "t=32.82d",_
 1069, 37, 84, 1,6,         -1,-79295.4     , 0.46359   , "t=20.26m",_
 1070, 38, 84, 0,0,          1,-80649.6     , 0         , "t=stbl",_
 1071, 39, 84, 0,6,          1,-73894       , 0         , "t=39.5m",_
 1072, 39, 84, 1,1,          1,-73827       , 0.067     , "t=4.6s",_
 1073, 40, 84, 0,0,          1,-71422       , 0         , "t=25.8m",_
 1074, 41, 84, 0,1,          1,-61193.8     , 0         , "t=9.8s",_
 1075, 41, 84, 1,3,          1,-61145.8     , 0.048     , "t=176ns",_
 1076, 42, 84, 0,0,          1,-54170       , 0         , "t=2.3s",_
 1077, 43, 84, 0,1,          1,-37700       , 0         , "t=?",_
 1078, 30, 85, 0,2.5,        1,-25100       , 0         , "t=40ms",_
 1079, 31, 85, 0,2.5,       -1,-39740       , 0         , "t=95.3ms",_
 1080, 32, 85, 0,1.5,        1,-53123       , 0         , "t=495ms",_
 1081, 33, 85, 0,2.5,       -1,-63189       , 0         , "t=2.022s",_
 1082, 34, 85, 0,2.5,        1,-72413.6     , 0         , "t=32.9s",_
 1083, 35, 85, 0,1.5,       -1,-78575       , 0         , "t=2.90m",_
 1084, 36, 85, 0,4.5,        1,-81480.3     , 0         , "t=10.728y",_
 1085, 36, 85, 1,0.5,       -1,-81175.4     , 0.304871  , "t=4.480h",_
 1086, 37, 85, 0,2.5,       -1,-82167.341   , 0         , "t=stbl",_
 1087, 37, 85, 1,4.5,        1,-81653.335   , 0.5140065 , "t=1.015us",_
 1088, 38, 85, 0,4.5,        1,-81103.3     , 0         , "t=64.846d",_
 1089, 38, 85, 1,0.5,       -1,-80864.5     , 0.23879   , "t=67.63m",_
 1090, 39, 85, 0,0.5,       -1,-77842       , 0         , "t=2.68h",_
 1091, 39, 85, 1,4.5,        1,-77822       , 0.01968   , "t=4.86h",_
 1092, 40, 85, 0,3.5,        1,-73175       , 0         , "t=7.86m",_
 1093, 40, 85, 1,0.5,       -1,-72883       , 0.2922    , "t=10.9s",_
 1094, 41, 85, 0,4.5,        1,-66280       , 0         , "t=20.5s",_
 1095, 41, 85, 1,0.5,       -1,-66130       , 0.15      , "t=3.3s",_
 1096, 42, 85, 0,0.5,        1,-57510       , 0         , "t=3.2s",_
 1097, 43, 85, 0,0.5,       -1,-45850       , 0         , "t=?",_
 1098, 44, 85, 0,1.5,       -1,-30630       , 0         , "t=1ms",_
 1099, 30, 86, 0,0,          1,-20060       , 0         , "t=?",_
 1100, 31, 86, 0,-77.777,    0,-33760       , 0         , "t=49ms",_
 1101, 32, 86, 0,0,          1,-49400       , 0         , "t=221.6ms",_
 1102, 33, 86, 0,1,         -1,-58962       , 0         , "t=945ms",_
 1103, 34, 86, 0,0,          1,-70503.2     , 0         , "t=14.3s",_
 1104, 35, 86, 0,1,         -1,-75632       , 0         , "t=55.1s",_
 1105, 36, 86, 0,0,          1,-83265.676   , 0         , "t=stbl",_
 1106, 37, 86, 0,2,         -1,-82747.00    , 0         , "t=18.645d",_
 1107, 37, 86, 1,6,         -1,-82190.95    , 0.55605   , "t=1.017m",_
 1108, 38, 86, 0,0,          1,-84523.100   , 0         , "t=stbl",_
 1109, 38, 86, 1,8,          1,-81567.01    , 2.95609   , "t=455ns",_
 1110, 39, 86, 0,4,         -1,-79283       , 0         , "t=14.74h",_
 1111, 39, 86, 1,8,          1,-79065       , 0.21821   , "t=47.4m",_
 1112, 40, 86, 0,0,          1,-77969       , 0         , "t=16.5h",_
 1113, 41, 86, 0,6,          1,-69134       , 0         , "t=88s",_
 1114, 41, 86, 1,0,         -1,-68980       , 0.15      , "t=20s",_
 1115, 42, 86, 0,0,          1,-64110.9     , 0         , "t=19.1s",_
 1116, 43, 86, 0,0,          1,-51570       , 0         , "t=55ms",_
 1117, 43, 86, 1,6,          1,-50050       , 1.524     , "t=1.10us",_
 1118, 44, 86, 0,0,          1,-39770       , 0         , "t=50ms",_
 1119, 31, 87, 0,2.5,       -1,-28870       , 0         , "t=29ms",_
 1120, 32, 87, 0,2.5,        1,-43590       , 0         , "t=103ms",_
 1121, 33, 87, 0,2.5,       -1,-55617.9     , 0         , "t=492ms",_
 1122, 34, 87, 0,1.5,        1,-66426.1     , 0         , "t=5.50s",_
 1123, 35, 87, 0,2.5,       -1,-73892       , 0         , "t=55.68s",_
 1124, 36, 87, 0,2.5,        1,-80709.53    , 0         , "t=76.3m",_
 1125, 37, 87, 0,1.5,       -1,-84597.802   , 0         , "t=49.7Gy",_
 1126, 38, 87, 0,4.5,        1,-84880.076   , 0         , "t=stbl",_
 1127, 38, 87, 1,0.5,       -1,-84491.547   , 0.3885287 , "t=2.805h",_
 1128, 39, 87, 0,0.5,       -1,-83018.4     , 0         , "t=79.8h",_
 1129, 39, 87, 1,4.5,        1,-82637.6     , 0.38082   , "t=13.37h",_
 1130, 40, 87, 0,4.5,        1,-79347       , 0         , "t=1.68h",_
 1131, 40, 87, 1,0.5,       -1,-79011       , 0.33584   , "t=14.0s",_
 1132, 41, 87, 0,0.5,       -1,-73874       , 0         , "t=3.7m",_
 1133, 41, 87, 1,4.5,        1,-73870       , 0.0039    , "t=2.6m",_
 1134, 42, 87, 0,3.5,        1,-66884.8     , 0         , "t=14.1s",_
 1135, 43, 87, 0,4.5,        1,-57690       , 0         , "t=2.14s",_
 1136, 43, 87, 1,0.5,       -1,-57683       , 0.007     , "t=2s",_
 1137, 44, 87, 0,0.5,       -1,-45730       , 0         , "t=50ms",_
 1138, 31, 88, 0,-77.777,    0,-22390       , 0         , "t=?",_
 1139, 32, 88, 0,0,          1,-39520       , 0         , "t=61ms",_
 1140, 33, 88, 0,-77.777,    0,-50450       , 0         , "t=270ms",_
 1141, 34, 88, 0,0,          1,-63884       , 0         , "t=1.53s",_
 1142, 35, 88, 0,1,         -1,-70716       , 0         , "t=16.34s",_
 1143, 35, 88, 1,4,         -1,-70446       , 0.27017   , "t=5.51us",_
 1144, 36, 88, 0,0,          1,-79691.3     , 0         , "t=2.825h",_
 1145, 37, 88, 0,2,         -1,-82609.00    , 0         , "t=17.78m",_
 1146, 37, 88, 1,7,          1,-81235.2     , 1.3738    , "t=123ns",_
 1147, 38, 88, 0,0,          1,-87921.629   , 0         , "t=stbl",_
 1148, 39, 88, 0,4,         -1,-84299.0     , 0         , "t=106.629d",_
 1149, 39, 88, 1,1,          1,-83906.1     , 0.39286   , "t=301us",_
 1150, 40, 88, 0,0,          1,-83629       , 0         , "t=83.4d",_
 1151, 40, 88, 1,8,          1,-80741       , 2.88779   , "t=1.320us",_
 1152, 41, 88, 0,8,          1,-76170       , 0         , "t=14.50m",_
 1153, 41, 88, 1,4,         -1,-76040       , 0.13      , "t=7.7m",_
 1154, 42, 88, 0,0,          1,-72687       , 0         , "t=8.0m",_
 1155, 43, 88, 0,2,          1,-61670       , 0         , "t=6.4s",_
 1156, 43, 88, 1,6,          1,-61600       , 0.07      , "t=5.8s",_
 1157, 44, 88, 0,0,          1,-54340       , 0         , "t=1.5s",_
 1158, 45, 88, 0,-77.777,    0,-36860       , 0         , "t=1ms",_
 1159, 32, 89, 0,1.5,        1,-33040       , 0         , "t=60ms",_
 1160, 33, 89, 0,2.5,       -1,-46530       , 0         , "t=220ms",_
 1161, 34, 89, 0,2.5,        1,-58992       , 0         , "t=430ms",_
 1162, 35, 89, 0,1.5,       -1,-68274       , 0         , "t=4.357s",_
 1163, 36, 89, 0,1.5,        1,-76535.8     , 0         , "t=3.15m",_
 1164, 37, 89, 0,1.5,       -1,-81712       , 0         , "t=15.32m",_
 1165, 38, 89, 0,2.5,        1,-86209.03    , 0         , "t=50.563d",_
 1166, 39, 89, 0,0.5,       -1,-87711.2     , 0         , "t=stbl",_
 1167, 39, 89, 1,4.5,        1,-86802.2     , 0.90897   , "t=15.663s",_
 1168, 40, 89, 0,4.5,        1,-84878.0     , 0         , "t=78.360h",_
 1169, 40, 89, 1,0.5,       -1,-84290.2     , 0.58782   , "t=4.161m",_
 1170, 41, 89, 0,4.5,        1,-80626       , 0         , "t=2.03h",_
 1171, 41, 89, 1,0.5,       -1,-80630       , 0         , "t=1.10h",_
 1172, 42, 89, 0,4.5,        1,-75015       , 0         , "t=2.11m",_
 1173, 42, 89, 1,0.5,       -1,-74628       , 0.3875    , "t=190ms",_
 1174, 43, 89, 0,4.5,        1,-67395       , 0         , "t=12.8s",_
 1175, 43, 89, 1,0.5,       -1,-67332       , 0.0626    , "t=12.9s",_
 1176, 44, 89, 0,4.5,        1,-58369       , 0         , "t=1.32s",_
 1177, 45, 89, 0,4.5,        1,-45650       , 0         , "t=?",_
 1178, 32, 90, 0,0,          1,-28470       , 0         , "t=30ms",_
 1179, 33, 90, 0,-77.777,    0,-40990       , 0         , "t=70ms",_
 1180, 33, 90, 1,-77.777,    0,-40870       , 0.1245    , "t=220ns",_
 1181, 34, 90, 0,0,          1,-55800       , 0         , "t=210ms",_
 1182, 35, 90, 0,-77.777,    0,-64000       , 0         , "t=1.910s",_
 1183, 36, 90, 0,0,          1,-74959.3     , 0         , "t=32.32s",_
 1184, 37, 90, 0,0,         -1,-79366       , 0         , "t=158s",_
 1185, 37, 90, 1,3,         -1,-79259       , 0.1069    , "t=258s",_
 1186, 38, 90, 0,0,          1,-85950.9     , 0         , "t=28.91y",_
 1187, 39, 90, 0,2,         -1,-86496.9     , 0         , "t=64.05h",_
 1188, 39, 90, 1,7,          1,-85814.9     , 0.68201   , "t=3.226h",_
 1189, 40, 90, 0,0,          1,-88772.55    , 0         , "t=stbl",_
 1190, 40, 90, 1,5,         -1,-86453.55    , 2.319     , "t=809.2ms",_
 1191, 41, 90, 0,8,          1,-82662       , 0         , "t=14.60h",_
 1192, 41, 90, 1,6,          1,-82540       , 0.12237   , "t=63us",_
 1193, 42, 90, 0,0,          1,-80173       , 0         , "t=5.56h",_
 1194, 42, 90, 1,8,          1,-77298       , 2.87473   , "t=1.14us",_
 1195, 43, 90, 0,8,          1,-70724.7     , 0         , "t=49.2s",_
 1196, 43, 90, 1,1,          1,-70580.7     , 0.144     , "t=8.7s",_
 1197, 44, 90, 0,0,          1,-64884       , 0         , "t=11.7s",_
 1198, 45, 90, 0,0,          1,-51630       , 0         , "t=29ms",_
 1199, 45, 90, 1,7,          1,-51630       , 0         , "t=0.56s",_
 1200, 46, 90, 0,0,          1,-39710       , 0         , "t=10ms",_
 1201, 33, 91, 0,2.5,       -1,-36500       , 0         , "t=100ms",_
 1202, 34, 91, 0,0.5,        1,-50580       , 0         , "t=270ms",_
 1203, 35, 91, 0,2.5,       -1,-61107       , 0         , "t=543ms",_
 1204, 36, 91, 0,2.5,        1,-70974.0     , 0         , "t=8.57s",_
 1205, 37, 91, 0,1.5,       -1,-77745       , 0         , "t=58.2s",_
 1206, 38, 91, 0,2.5,        1,-83652       , 0         , "t=9.65h",_
 1207, 39, 91, 0,0.5,       -1,-86351.3     , 0         , "t=58.51d",_
 1208, 39, 91, 1,4.5,        1,-85795.7     , 0.55558   , "t=49.71m",_
 1209, 40, 91, 0,2.5,        1,-87895.59    , 0         , "t=stbl",_
 1210, 40, 91, 1,10.5,       1,-84728.3     , 3.1673    , "t=4.35us",_
 1211, 41, 91, 0,4.5,        1,-86638.0     , 0         , "t=680y",_
 1212, 41, 91, 1,0.5,       -1,-86533.4     , 0.1046    , "t=60.86d",_
 1213, 42, 91, 0,4.5,        1,-82209       , 0         , "t=15.49m",_
 1214, 42, 91, 1,0.5,       -1,-81556       , 0.65301   , "t=64.6s",_
 1215, 43, 91, 0,4.5,        1,-75986.7     , 0         , "t=3.14m",_
 1216, 43, 91, 1,0.5,       -1,-75847.4     , 0.1393    , "t=3.3m",_
 1217, 44, 91, 0,4.5,        1,-68239.8     , 0         , "t=8.0s",_
 1218, 44, 91, 1,0.5,       -1,-68580       ,-0.34      , "t=7.6s",_
 1219, 45, 91, 0,4.5,        1,-58570       , 0         , "t=1.47s",_
 1220, 45, 91, 1,0.5,       -1,-58400       , 0.1729    , "t=1.8s",_
 1221, 46, 91, 0,3.5,        1,-46170       , 0         , "t=32ms",_
 1222, 33, 92, 0,-77.777,    0,-30380       , 0         , "t=45ms",_
 1223, 34, 92, 0,0,          1,-46720       , 0         , "t=90ms",_
 1224, 34, 92, 1,9,         -1,-44780       , 3.072     , "t=15.7us",_
 1225, 35, 92, 0,2,         -1,-56233       , 0         , "t=314ms",_
 1226, 35, 92, 1,-77.777,    0,-55571       , 0.662     , "t=88ns",_
 1227, 36, 92, 0,0,          1,-68769.3     , 0         , "t=1.840s",_
 1228, 37, 92, 0,0,         -1,-74772       , 0         , "t=4.48s",_
 1229, 38, 92, 0,0,          1,-82867       , 0         , "t=2.611h",_
 1230, 39, 92, 0,2,         -1,-84816       , 0         , "t=3.54h",_
 1231, 39, 92, 1,7,          1,-84010       , 0.807     , "t=3.7us",_
 1232, 40, 92, 0,0,          1,-88459.02    , 0         , "t=stbl",_
 1233, 41, 92, 0,7,          1,-86453.3     , 0         , "t=34.7My",_
 1234, 41, 92, 1,2,          1,-86317.8     , 0.1355    , "t=10.116d",_
 1235, 42, 92, 0,0,          1,-86808.59    , 0         , "t=stbl",_
 1236, 42, 92, 1,8,          1,-84048.07    , 2.76052   , "t=190ns",_
 1237, 43, 92, 0,8,          1,-78926       , 0         , "t=4.25m",_
 1238, 43, 92, 1,4,          1,-78656       , 0.27009   , "t=1.03us",_
 1239, 44, 92, 0,0,          1,-74301.2     , 0         , "t=3.65m",_
 1240, 44, 92, 1,8,          1,-71467       , 2.8339    , "t=100ns",_
 1241, 45, 92, 0,6,          1,-62999       , 0         , "t=5.61s",_
 1242, 45, 92, 1,2,          1,-62950       , 0.05      , "t=3.18s",_
 1243, 46, 92, 0,0,          1,-54780       , 0         , "t=1.06s",_
 1244, 47, 92, 0,-77.777,    0,-37530       , 0         , "t=1ms",_
 1245, 34, 93, 0,0.5,        1,-40860       , 0         , "t=130ms",_
 1246, 34, 93, 1,-77.777,    0,-40180       , 0.6782    , "t=420ns",_
 1247, 35, 93, 0,2.5,       -1,-52890       , 0         , "t=152ms",_
 1248, 36, 93, 0,0.5,        1,-64136.0     , 0         , "t=1.287s",_
 1249, 37, 93, 0,2.5,       -1,-72620       , 0         , "t=5.84s",_
 1250, 37, 93, 1,13.5,      -1,-68197       , 4.4231    , "t=111ns",_
 1251, 38, 93, 0,2.5,        1,-80086       , 0         , "t=7.43m",_
 1252, 39, 93, 0,0.5,       -1,-84227       , 0         , "t=10.18h",_
 1253, 39, 93, 1,4.5,        1,-83468       , 0.758719  , "t=820ms",_
 1254, 40, 93, 0,2.5,        1,-87122.0     , 0         , "t=1.61My",_
 1255, 41, 93, 0,4.5,        1,-87212.8     , 0         , "t=stbl",_
 1256, 41, 93, 1,0.5,       -1,-87182.0     , 0.03076   , "t=16.12y",_
 1257, 42, 93, 0,2.5,        1,-86807.08    , 0         , "t=4.0ky",_
 1258, 42, 93, 1,10.5,       1,-84382.13    , 2.42495   , "t=6.85h",_
 1259, 43, 93, 0,4.5,        1,-83606.1     , 0         , "t=2.75h",_
 1260, 43, 93, 1,0.5,       -1,-83214.3     , 0.39184   , "t=43.5m",_
 1261, 44, 93, 0,4.5,        1,-77216.7     , 0         , "t=59.7s",_
 1262, 44, 93, 1,0.5,       -1,-76482.3     , 0.7344    , "t=10.8s",_
 1263, 45, 93, 0,4.5,        1,-69011.8     , 0         , "t=13.9s",_
 1264, 46, 93, 0,4.5,        1,-58980       , 0         , "t=1.17s",_
 1265, 47, 93, 0,4.5,        1,-46400       , 0         , "t=228ns",_
 1266, 34, 94, 0,0,          1,-36800       , 0         , "t=50ms",_
 1267, 34, 94, 1,7,         -1,-34370       , 2.43      , "t=680ns",_
 1268, 35, 94, 0,2,         -1,-47650       , 0         , "t=70ms",_
 1269, 35, 94, 1,-77.777,    0,-47360       , 0.2946    , "t=530ns",_
 1270, 36, 94, 0,0,          1,-61348       , 0         , "t=212ms",_
 1271, 37, 94, 0,3,         -1,-68562.8     , 0         , "t=2.702s",_
 1272, 37, 94, 1,0,         -1,-68458.6     , 0.1042    , "t=130ns",_
 1273, 38, 94, 0,0,          1,-78845.7     , 0         , "t=75.3s",_
 1274, 39, 94, 0,2,         -1,-82351       , 0         , "t=18.7m",_
 1275, 39, 94, 1,5,          1,-81149       , 1.2023    , "t=1.304us",_
 1276, 40, 94, 0,0,          1,-87269.33    , 0         , "t=stbl",_
 1277, 41, 94, 0,6,          1,-86369.1     , 0         , "t=20.4ky",_
 1278, 41, 94, 1,3,          1,-86328.2     , 0.040892  , "t=6.263m",_
 1279, 42, 94, 0,0,          1,-88414.08    , 0         , "t=stbl",_
 1280, 43, 94, 0,7,          1,-84158       , 0         , "t=293m",_
 1281, 43, 94, 1,2,          1,-84082       , 0.076     , "t=52m",_
 1282, 44, 94, 0,0,          1,-82584       , 0         , "t=51.8m",_
 1283, 44, 94, 1,8,          1,-79940       , 2.6441    , "t=67.5us",_
 1284, 45, 94, 0,4,          1,-72908       , 0         , "t=70.6s",_
 1285, 45, 94, 1,2,          1,-72853       , 0.0546    , "t=480ns",_
 1286, 46, 94, 0,0,          1,-66102       , 0         , "t=9.1s",_
 1287, 46, 94, 1,14,         1,-61219       , 4.8831    , "t=515ns",_
 1288, 47, 94, 0,0,          1,-52400       , 0         , "t=27ms",_
 1289, 47, 94, 1,7,          1,-51050       , 1.35      , "t=470ms",_
 1290, 48, 94, 0,0,          1,-40440       , 0         , "t=80ms",_
 1291, 34, 95, 0,1.5,        1,-30460       , 0         , "t=70ms",_
 1292, 35, 95, 0,2.5,       -1,-43850       , 0         , "t=80ms",_
 1293, 35, 95, 1,-77.777,    0,-43310       , 0.5379    , "t=6.8us",_
 1294, 36, 95, 0,0.5,        1,-56159       , 0         , "t=114ms",_
 1295, 36, 95, 1,3.5,        1,-55964       , 0.1955    , "t=1.582us",_
 1296, 37, 95, 0,2.5,       -1,-65890       , 0         , "t=377.7ms",_
 1297, 37, 95, 1,4.5,        1,-65055       , 0.835     , "t=&lt;500ns",_
 1298, 38, 95, 0,0.5,        1,-75117       , 0         , "t=23.90s",_
 1299, 39, 95, 0,0.5,       -1,-81208       , 0         , "t=10.3m",_
 1300, 39, 95, 1,4.5,        1,-80120       , 1.0876    , "t=48.6us",_
 1301, 40, 95, 0,2.5,        1,-85659.9     , 0         , "t=64.032d",_
 1302, 41, 95, 0,4.5,        1,-86786.3     , 0         , "t=34.991d",_
 1303, 41, 95, 1,0.5,       -1,-86550.6     , 0.23569   , "t=3.61d",_
 1304, 42, 95, 0,2.5,        1,-87711.87    , 0         , "t=stbl",_
 1305, 43, 95, 0,4.5,        1,-86021       , 0         , "t=19.258h",_
 1306, 43, 95, 1,0.5,       -1,-85982       , 0.03891   , "t=61.96d",_
 1307, 44, 95, 0,2.5,        1,-83458       , 0         , "t=1.607h",_
 1308, 45, 95, 0,4.5,        1,-78341       , 0         , "t=5.02m",_
 1309, 45, 95, 1,0.5,       -1,-77798       , 0.5433    , "t=1.96m",_
 1310, 46, 95, 0,4.5,        1,-69966       , 0         , "t=7.4s",_
 1311, 46, 95, 1,10.5,       1,-68091       , 1.87513   , "t=13.3s",_
 1312, 47, 95, 0,4.5,        1,-59910       , 0         , "t=1.78s",_
 1313, 47, 95, 1,0.5,       -1,-59570       , 0.3442    , "t=&lt;500ms",_
 1314, 48, 95, 0,4.5,        1,-47060       , 0         , "t=32ms",_
 1315, 35, 96, 0,-77.777,    0,-38210       , 0         , "t=20ms",_
 1316, 35, 96, 1,-77.777,    0,-37900       , 0.3115    , "t=3.0us",_
 1317, 36, 96, 0,0,          1,-53082       , 0         , "t=80ms",_
 1318, 37, 96, 0,2,         -1,-61354       , 0         , "t=201.5ms",_
 1319, 37, 96, 1,1,          1,-61350       , 0         , "t=200ms",_
 1320, 38, 96, 0,0,          1,-72918       , 0         , "t=1.059s",_
 1321, 39, 96, 0,0,         -1,-78330       , 0         , "t=5.34s",_
 1322, 39, 96, 1,8,          1,-76790       , 1.54      , "t=9.6s",_
 1323, 40, 96, 0,0,          1,-85438.86    , 0         , "t=23.4Ey",_
 1324, 41, 96, 0,6,          1,-85602.83    , 0         , "t=23.35h",_
 1325, 42, 96, 0,0,          1,-88794.89    , 0         , "t=stbl",_
 1326, 43, 96, 0,7,          1,-85822       , 0         , "t=4.28d",_
 1327, 43, 96, 1,4,          1,-85788       , 0.03423   , "t=51.5m",_
 1328, 44, 96, 0,0,          1,-86080.39    , 0         , "t=stbl",_
 1329, 45, 96, 0,6,          1,-79688       , 0         , "t=9.90m",_
 1330, 45, 96, 1,3,          1,-79636       , 0.05198   , "t=1.51m",_
 1331, 46, 96, 0,0,          1,-76183       , 0         , "t=122s",_
 1332, 46, 96, 1,8,          1,-73652       , 2.53057   , "t=1.804us",_
 1333, 47, 96, 0,8,          1,-64510       , 0         , "t=4.45s",_
 1334, 47, 96, 1,2,          1,-64510       , 0         , "t=6.9s",_
 1335, 48, 96, 0,0,          1,-55570       , 0         , "t=1003ms",_
 1336, 48, 96, 1,16,         1,-49540       , 6.03      , "t=511ms",_
 1337, 49, 96, 0,-77.777,    0,-38090       , 0         , "t=1ms",_
 1338, 35, 97, 0,2.5,       -1,-34000       , 0         , "t=40ms",_
 1339, 36, 97, 0,1.5,        1,-47420       , 0         , "t=62.2ms",_
 1340, 37, 97, 0,1.5,        1,-58519.1     , 0         , "t=169.1ms",_
 1341, 37, 97, 1,0.5,        0,-58442.5     , 0.0766    , "t=5.7us",_
 1342, 38, 97, 0,0.5,        1,-68581       , 0         , "t=432ms",_
 1343, 38, 97, 1,3.5,        1,-68273       , 0.30813   , "t=175.2ns",_
 1344, 39, 97, 0,0.5,       -1,-76115       , 0         , "t=3.75s",_
 1345, 39, 97, 1,4.5,        1,-75447       , 0.66752   , "t=1.17s",_
 1346, 40, 97, 0,0.5,        1,-82936.69    , 0         , "t=16.749h",_
 1347, 40, 97, 1,3.5,        1,-81672.34    , 1.26435   , "t=104.8ns",_
 1348, 41, 97, 0,4.5,        1,-85603       , 0         , "t=72.1m",_
 1349, 41, 97, 1,0.5,       -1,-84860       , 0.74335   , "t=58.7s",_
 1350, 42, 97, 0,2.5,        1,-87544.70    , 0         , "t=stbl",_
 1351, 43, 97, 0,4.5,        1,-87224       , 0         , "t=4.21My",_
 1352, 43, 97, 1,0.5,       -1,-87127       , 0.09657   , "t=91.1d",_
 1353, 44, 97, 0,2.5,        1,-86120.6     , 0         , "t=2.8370d",_
 1354, 45, 97, 0,4.5,        1,-82600       , 0         , "t=30.7m",_
 1355, 45, 97, 1,0.5,       -1,-82340       , 0.25876   , "t=46.2m",_
 1356, 46, 97, 0,2.5,        1,-77806       , 0         , "t=3.10m",_
 1357, 47, 97, 0,4.5,        1,-70904       , 0         , "t=25.5s",_
 1358, 47, 97, 1,0.5,       -1,-70290       , 0.62      , "t=100ms",_
 1359, 48, 97, 0,4.5,        1,-60730       , 0         , "t=1.16s",_
 1360, 48, 97, 1,0.5,       -1,-59480       , 1.2451    , "t=730us",_
 1361, 49, 97, 0,4.5,        1,-47390       , 0         , "t=36ms",_
 1362, 49, 97, 1,0.5,       -1,-46990       , 0.4       , "t=0.12ms",_
 1363, 35, 98, 0,-77.777,    0,-28050       , 0         , "t=15ms",_
 1364, 36, 98, 0,0,          1,-44120       , 0         , "t=42.8ms",_
 1365, 37, 98, 0,0,         -1,-54369       , 0         , "t=115ms",_
 1366, 37, 98, 1,3,          1,-54296       , 0.073     , "t=96ms",_
 1367, 38, 98, 0,0,          1,-66422       , 0         , "t=653ms",_
 1368, 39, 98, 0,0,         -1,-72289       , 0         , "t=548ms",_
 1369, 39, 98, 1,2,         -1,-72118       , 0.17078   , "t=615ns",_
 1370, 40, 98, 0,0,          1,-81282       , 0         , "t=30.7s",_
 1371, 40, 98, 1,17,        -1,-74680       , 6.6019    , "t=1.9us",_
 1372, 41, 98, 0,1,          1,-83525       , 0         , "t=2.86s",_
 1373, 41, 98, 1,5,          1,-83441       , 0.084     , "t=51.1m",_
 1374, 42, 98, 0,0,          1,-88115.98    , 0         , "t=stbl",_
 1375, 43, 98, 0,6,          1,-86432       , 0         , "t=4.2My",_
 1376, 43, 98, 1,2,          0,-86341       , 0.09077   , "t=14.7us",_
 1377, 44, 98, 0,0,          1,-88225       , 0         , "t=stbl",_
 1378, 45, 98, 0,2,          1,-83175       , 0         , "t=8.72m",_
 1379, 45, 98, 1,5,          1,-83119       , 0.0563    , "t=3.6m",_
 1380, 46, 98, 0,0,          1,-81321       , 0         , "t=17.7m",_
 1381, 47, 98, 0,6,          1,-73070       , 0         , "t=47.5s",_
 1382, 47, 98, 1,4,          1,-72960       , 0.10728   , "t=161ns",_
 1383, 48, 98, 0,0,          1,-67640       , 0         , "t=9.29s",_
 1384, 48, 98, 1,8,          1,-65210       , 2.4283    , "t=154ns",_
 1385, 49, 98, 0,0,          1,-53910       , 0         , "t=30ms",_
 1386, 49, 98, 1,9,          1,-53090       , 0.82      , "t=890ms",_
 1387, 36, 99, 0,2.5,       -1,-38400       , 0         , "t=40ms",_
 1388, 37, 99, 0,1.5,        1,-51121       , 0         , "t=54ms",_
 1389, 38, 99, 0,1.5,        1,-62519       , 0         , "t=269.2ms",_
 1390, 39, 99, 0,2.5,        1,-70644       , 0         , "t=1.484s",_
 1391, 39, 99, 1,8.5,        1,-68502       , 2.14165   , "t=8.2us",_
 1392, 40, 99, 0,0.5,        1,-77617       , 0         , "t=2.1s",_
 1393, 40, 99, 1,3.5,        1,-77365       , 0.25196   , "t=336ns",_
 1394, 41, 99, 0,4.5,        1,-82335       , 0         , "t=15.0s",_
 1395, 41, 99, 1,0.5,       -1,-81970       , 0.36527   , "t=2.5m",_
 1396, 42, 99, 0,0.5,        1,-85970.11    , 0         , "t=65.932h",_
 1397, 42, 99, 1,2.5,        1,-85872.33    , 0.097785  , "t=15.5us",_
 1398, 43, 99, 0,4.5,        1,-87327.9     , 0         , "t=211.1ky",_
 1399, 43, 99, 1,0.5,       -1,-87185.2     , 0.1426836 , "t=6.0066h",_
 1400, 44, 99, 0,2.5,        1,-87625.4     , 0         , "t=stbl",_
 1401, 45, 99, 0,0.5,       -1,-85585       , 0         , "t=16.1d",_
 1402, 45, 99, 1,4.5,        1,-85521       , 0.0644    , "t=4.7h",_
 1403, 46, 99, 0,2.5,        1,-82183       , 0         , "t=21.4m",_
 1404, 47, 99, 0,4.5,        1,-76712       , 0         , "t=2.07m",_
 1405, 47, 99, 1,0.5,       -1,-76206       , 0.5062    , "t=10.5s",_
 1406, 48, 99, 0,2.5,        1,-69931.1     , 0         , "t=17s",_
 1407, 49, 99, 0,4.5,        1,-61380       , 0         , "t=3.11s",_
 1408, 49, 99, 1,0.5,       -1,-60980       , 0.4       , "t=1s",_
 1409, 50, 99, 0,4.5,        1,-47980       , 0         , "t=24ms",_
 1410, 36, 100, 0,0,         1,-34470       , 0         , "t=12ms",_
 1411, 37, 100, 0,4,        -1,-46266       , 0         , "t=51.3ms",_
 1412, 38, 100, 0,0,         1,-59818       , 0         , "t=202.1ms",_
 1413, 38, 100, 1,4,        -1,-58199       , 1.61872   , "t=122ns",_
 1414, 39, 100, 0,4,         1,-67321       , 0         , "t=940ms",_
 1415, 39, 100, 1,1,         1,-67177       , 0.144     , "t=727ms",_
 1416, 40, 100, 0,0,         1,-76373       , 0         , "t=7.1s",_
 1417, 41, 100, 0,1,         1,-79791       , 0         , "t=1.5s",_
 1418, 41, 100, 1,5,         1,-79478.5     , 0.313     , "t=2.99s",_
 1419, 42, 100, 0,0,         1,-86193.0     , 0         , "t=7.07Ey",_
 1420, 43, 100, 0,1,         1,-86021.0     , 0         , "t=15.46s",_
 1421, 43, 100, 1,4,         1,-85820.3     , 0.20067   , "t=8.32us",_
 1422, 44, 100, 0,0,         1,-89227.4     , 0         , "t=stbl",_
 1423, 45, 100, 0,1,        -1,-85591       , 0         , "t=20.8h",_
 1424, 45, 100, 1,2,         1,-85516       , 0.074782  , "t=214.0ns",_
 1425, 46, 100, 0,0,         1,-85213       , 0         , "t=3.63d",_
 1426, 47, 100, 0,5,         1,-78138       , 0         , "t=2.01m",_
 1427, 47, 100, 1,2,         1,-78122       , 0.01552   , "t=2.24m",_
 1428, 48, 100, 0,0,         1,-74194.6     , 0         , "t=49.1s",_
 1429, 49, 100, 0,6,         1,-64178.1     , 0         , "t=5.62s",_
 1430, 50, 100, 0,0,         1,-57150       , 0         , "t=1.18s",_
 1431, 50, 100, 1,6,         1,-52650       , 4.5       , "t=100ns",_
 1432, 36, 101, 0,2.5,       1,-28580       , 0         , "t=9ms",_
 1433, 37, 101, 0,1.5,       1,-42567       , 0         , "t=31.8ms",_
 1434, 38, 101, 0,2.5,      -1,-55325       , 0         , "t=113.7ms",_
 1435, 39, 101, 0,2.5,       1,-65055       , 0         , "t=426ms",_
 1436, 39, 101, 1,6.5,      -1,-63850       , 1.205     , "t=870ns",_
 1437, 40, 101, 0,1.5,       1,-73161       , 0         , "t=2.29s",_
 1438, 41, 101, 0,2.5,       1,-78891       , 0         , "t=7.1s",_
 1439, 42, 101, 0,0.5,       1,-83520.0     , 0         , "t=14.61m",_
 1440, 42, 101, 1,1.5,       1,-83506.5     , 0.013497  , "t=226ns",_
 1441, 43, 101, 0,4.5,       1,-86345       , 0         , "t=14.22m",_
 1442, 43, 101, 1,0.5,      -1,-86137       , 0.207526  , "t=636us",_
 1443, 44, 101, 0,2.5,       1,-87958.1     , 0         , "t=stbl",_
 1444, 44, 101, 1,5.5,      -1,-87430.5     , 0.52756   , "t=17.5us",_
 1445, 45, 101, 0,0.5,      -1,-87412       , 0         , "t=4.07y",_
 1446, 45, 101, 1,4.5,       1,-87255       , 0.15732   , "t=4.343d",_
 1447, 46, 101, 0,2.5,       1,-85432       , 0         , "t=8.47h",_
 1448, 47, 101, 0,4.5,       1,-81334       , 0         , "t=11.1m",_
 1449, 47, 101, 1,0.5,      -1,-81060       , 0.2741    , "t=3.10s",_
 1450, 48, 101, 0,2.5,       1,-75836.5     , 0         , "t=1.36m",_
 1451, 49, 101, 0,4.5,       1,-68545       , 0         , "t=15.1s",_
 1452, 49, 101, 1,0.5,      -1,-67910       , 0.64      , "t=10s",_
 1453, 50, 101, 0,3.5,       1,-60310       , 0         , "t=2.22s",_
 1454, 37, 102, 0,4,         1,-37250       , 0         , "t=37ms",_
 1455, 38, 102, 0,0,         1,-52160       , 0         , "t=69ms",_
 1456, 39, 102, 0,5,        -1,-61173       , 0         , "t=360ms",_
 1457, 39, 102, 1,0,        -1,-61070       , 0.1       , "t=300ms",_
 1458, 40, 102, 0,0,         1,-71581       , 0         , "t=2.01s",_
 1459, 41, 102, 0,4,         1,-76298.3     , 0         , "t=4.3s",_
 1460, 41, 102, 1,1,         1,-76204       , 0.094     , "t=1.31s",_
 1461, 42, 102, 0,0,         1,-83561       , 0         , "t=11.3m",_
 1462, 43, 102, 0,1,         1,-84573       , 0         , "t=5.28s",_
 1463, 43, 102, 1,4,         1,-84520       , 0.05      , "t=4.35m",_
 1464, 44, 102, 0,0,         1,-89106.4     , 0         , "t=stbl",_
 1465, 45, 102, 0,2,        -1,-86783       , 0         , "t=207.0d",_
 1466, 45, 102, 1,6,         1,-86642       , 0.14073   , "t=3.742y",_
 1467, 46, 102, 0,0,         1,-87903.0     , 0         , "t=stbl",_
 1468, 47, 102, 0,5,         1,-82247       , 0         , "t=12.9m",_
 1469, 47, 102, 1,2,         1,-82238       , 0.0094    , "t=7.7m",_
 1470, 48, 102, 0,0,         1,-79659.7     , 0         , "t=5.5m",_
 1471, 49, 102, 0,6,         1,-70695       , 0         , "t=23.3s",_
 1472, 50, 102, 0,0,         1,-64930       , 0         , "t=3.8s",_
 1473, 50, 102, 1,6,         1,-62910       , 2.017     , "t=367ns",_
 1474, 51, 102, 0,-77.777,   0,-51100       , 0         , "t=?",_
 1475, 37, 103, 0,1.5,       1,-33160       , 0         , "t=26ms",_
 1476, 38, 103, 0,2.5,       1,-47280       , 0         , "t=53ms",_
 1477, 39, 103, 0,2.5,       1,-58457       , 0         , "t=239ms",_
 1478, 40, 103, 0,2.5,      -1,-67809       , 0         , "t=1.38s",_
 1479, 41, 103, 0,2.5,       1,-75029       , 0         , "t=1.34s",_
 1480, 42, 103, 0,1.5,       1,-80954       , 0         , "t=67.5s",_
 1481, 43, 103, 0,2.5,       1,-84604       , 0         , "t=54.2s",_
 1482, 44, 103, 0,1.5,       1,-87267.2     , 0         , "t=39.245d",_
 1483, 44, 103, 1,5.5,      -1,-87029.0     , 0.2382    , "t=1.69ms",_
 1484, 45, 103, 0,0.5,      -1,-88031.7     , 0         , "t=stbl",_
 1485, 45, 103, 1,3.5,       1,-87991.9     , 0.039753  , "t=56.114m",_
 1486, 46, 103, 0,2.5,       1,-87457.0     , 0         , "t=16.991d",_
 1487, 47, 103, 0,3.5,       1,-84803       , 0         , "t=65.7m",_
 1488, 47, 103, 1,0.5,      -1,-84669       , 0.13445   , "t=5.7s",_
 1489, 48, 103, 0,2.5,       1,-80651.6     , 0         , "t=7.3m",_
 1490, 49, 103, 0,4.5,       1,-74632       , 0         , "t=60s",_
 1491, 49, 103, 1,0.5,      -1,-74000       , 0.6317    , "t=34s",_
 1492, 50, 103, 0,2.5,       1,-67090       , 0         , "t=7.0s",_
 1493, 51, 103, 0,2.5,       1,-56670       , 0         , "t=?",_
 1494, 37, 104, 0,-77.777,   0,-27450       , 0         , "t=35ms",_
 1495, 38, 104, 0,0,         1,-43760       , 0         , "t=50.6ms",_
 1496, 39, 104, 0,0,         1,-54080       , 0         , "t=197ms",_
 1497, 40, 104, 0,0,         1,-65718       , 0         , "t=920ms",_
 1498, 41, 104, 0,5,        -1,-71811.0     , 0         , "t=0.98s",_
 1499, 41, 104, 1,0,        -1,-71801.2     , 0.0098    , "t=4.9s",_
 1500, 42, 104, 0,0,         1,-80344       , 0         , "t=60s",_
 1501, 43, 104, 0,3,        -1,-82499       , 0         , "t=18.3m",_
 1502, 43, 104, 1,5,        -1,-82429       , 0.0697    , "t=3.5us",_
 1503, 44, 104, 0,0,         1,-88095.8     , 0         , "t=stbl",_
 1504, 45, 104, 0,1,         1,-86959.3     , 0         , "t=42.3s",_
 1505, 45, 104, 1,5,         1,-86830.3     , 0.1289679 , "t=4.34m",_
 1506, 46, 104, 0,0,         1,-89395.1     , 0         , "t=stbl",_
 1507, 47, 104, 0,5,         1,-85116       , 0         , "t=69.2m",_
 1508, 47, 104, 1,2,         1,-85109       , 0.0069    , "t=33.5m",_
 1509, 48, 104, 0,0,         1,-83968.4     , 0         , "t=57.7m",_
 1510, 49, 104, 0,5,         1,-76183       , 0         , "t=1.80m",_
 1511, 49, 104, 1,3,         1,-76090       , 0.09348   , "t=15.7s",_
 1512, 50, 104, 0,0,         1,-71627       , 0         , "t=20.8s",_
 1513, 51, 104, 0,-77.777,   0,-59300       , 0         , "t=470ms",_
 1514, 52, 104, 0,0,         1,-49630       , 0         , "t=&lt;4ns",_
 1515, 38, 105, 0,2.5,       1,-38190       , 0         , "t=39ms",_
 1516, 39, 105, 0,2.5,       1,-50570       , 0         , "t=95ms",_
 1517, 40, 105, 0,0.5,       1,-61458       , 0         , "t=670ms",_
 1518, 41, 105, 0,2.5,       1,-69916       , 0         , "t=2.91s",_
 1519, 42, 105, 0,2.5,      -1,-77331       , 0         , "t=36.3s",_
 1520, 43, 105, 0,1.5,      -1,-82290       , 0         , "t=7.64m",_
 1521, 44, 105, 0,1.5,       1,-85934.5     , 0         , "t=4.439h",_
 1522, 44, 105, 1,2.5,       1,-85913.9     , 0.020606  , "t=340ns",_
 1523, 45, 105, 0,3.5,       1,-87851.3     , 0         , "t=35.341h",_
 1524, 45, 105, 1,0.5,      -1,-87721.6     , 0.129742  , "t=42.8s",_
 1525, 46, 105, 0,2.5,       1,-88417.9     , 0         , "t=stbl",_
 1526, 46, 105, 1,5.5,      -1,-87928.8     , 0.4891    , "t=35.5us",_
 1527, 47, 105, 0,0.5,      -1,-87071       , 0         , "t=41.29d",_
 1528, 47, 105, 1,3.5,       1,-87046       , 0.025468  , "t=7.23m",_
 1529, 48, 105, 0,2.5,       1,-84333.8     , 0         , "t=55.5m",_
 1530, 48, 105, 1,10.5,      1,-81816.2     , 2.5176    , "t=4.5us",_
 1531, 49, 105, 0,4.5,       1,-79641       , 0         , "t=5.07m",_
 1532, 49, 105, 1,0.5,      -1,-78967       , 0.67409   , "t=48s",_
 1533, 50, 105, 0,2.5,       1,-73338       , 0         , "t=32.7s",_
 1534, 51, 105, 0,2.5,       1,-64015       , 0         , "t=1.12s",_
 1535, 52, 105, 0,3.5,       1,-52810       , 0         , "t=633ns",_
 1536, 38, 106, 0,0,         1,-34300       , 0         , "t=21ms",_
 1537, 39, 106, 0,2,         1,-45790       , 0         , "t=75ms",_
 1538, 40, 106, 0,0,         1,-58750       , 0         , "t=179ms",_
 1539, 41, 106, 0,1,        -1,-66202.7     , 0         , "t=900ms",_
 1540, 41, 106, 1,4,        -1,-66100       , 0.1       , "t=1.20s",_
 1541, 42, 106, 0,0,         1,-76128       , 0         , "t=8.73s",_
 1542, 43, 106, 0,1,         0,-79776       , 0         , "t=35.6s",_
 1543, 44, 106, 0,0,         1,-86323       , 0         , "t=371.8d",_
 1544, 45, 106, 0,1,         1,-86363       , 0         , "t=30.07s",_
 1545, 45, 106, 1,6,         1,-86231       , 0.132     , "t=131m",_
 1546, 46, 106, 0,0,         1,-89907.5     , 0         , "t=stbl",_
 1547, 47, 106, 0,1,         1,-86942       , 0         , "t=23.96m",_
 1548, 47, 106, 1,6,         1,-86852       , 0.08966   , "t=8.28d",_
 1549, 48, 106, 0,0,         1,-87132.2     , 0         , "t=stbl",_
 1550, 49, 106, 0,7,         1,-80608       , 0         , "t=6.2m",_
 1551, 49, 106, 1,2,         1,-80579       , 0.0286    , "t=5.2m",_
 1552, 50, 106, 0,0,         1,-77354       , 0         , "t=1.92m",_
 1553, 51, 106, 0,2,         1,-66473       , 0         , "t=600ms",_
 1554, 51, 106, 1,4,         1,-66370       , 0.1035    , "t=226ns",_
 1555, 52, 106, 0,0,         1,-58220       , 0         , "t=78us",_
 1556, 53, 106, 0,-77.777,   0,-43300       , 0         , "t=?",_
 1557, 38, 107, 0,0.5,       1,-28250       , 0         , "t=25ms",_
 1558, 39, 107, 0,2.5,       1,-41970       , 0         , "t=33.5ms",_
 1559, 40, 107, 0,2.5,       1,-54020       , 0         , "t=145.7ms",_
 1560, 41, 107, 0,2.5,       1,-63724       , 0         , "t=286ms",_
 1561, 42, 107, 0,0.5,       1,-72545       , 0         , "t=3.5s",_
 1562, 42, 107, 1,2.5,       1,-72480       , 0.0654    , "t=445ns",_
 1563, 43, 107, 0,1.5,      -1,-78750       , 0         , "t=21.2s",_
 1564, 43, 107, 1,0.5,       1,-78720       , 0.0301    , "t=3.85us",_
 1565, 44, 107, 0,2.5,       1,-83863       , 0         , "t=3.75m",_
 1566, 45, 107, 0,3.5,       1,-86864       , 0         , "t=21.7m",_
 1567, 45, 107, 1,0.5,      -1,-86596       , 0.26836   , "t=&gt;10us",_
 1568, 46, 107, 0,2.5,       1,-88372.7     , 0         , "t=6.5My",_
 1569, 46, 107, 1,0.5,       1,-88257.0     , 0.11574   , "t=850ns",_
 1570, 47, 107, 0,0.5,      -1,-88406.7     , 0         , "t=stbl",_
 1571, 47, 107, 1,3.5,       1,-88313.6     , 0.093125  , "t=44.3s",_
 1572, 48, 107, 0,2.5,       1,-86990.3     , 0         , "t=6.50h",_
 1573, 49, 107, 0,4.5,       1,-83567       , 0         , "t=32.4m",_
 1574, 49, 107, 1,0.5,      -1,-82889       , 0.6785    , "t=50.4s",_
 1575, 50, 107, 0,2.5,       1,-78512       , 0         , "t=2.90m",_
 1576, 51, 107, 0,2.5,       1,-70653       , 0         , "t=4.0s",_
 1577, 52, 107, 0,2.5,       1,-60660       , 0         , "t=3.22ms",_
 1578, 53, 107, 0,2.5,       1,-49430       , 0         , "t=20us",_
 1579, 39, 108, 0,6,        -1,-36780       , 0         , "t=30ms",_
 1580, 40, 108, 0,0,         1,-50950       , 0         , "t=78.5ms",_
 1581, 40, 108, 1,6,         1,-48880       , 2.0745    , "t=540ns",_
 1582, 41, 108, 0,2,         1,-59545       , 0         , "t=201ms",_
 1583, 41, 108, 1,6,        -1,-59378       , 0.1666    , "t=109ns",_
 1584, 42, 108, 0,0,         1,-70749       , 0         , "t=1.105s",_
 1585, 43, 108, 0,2,         1,-75923       , 0         , "t=5.17s",_
 1586, 44, 108, 0,0,         1,-83661       , 0         , "t=4.55m",_
 1587, 45, 108, 0,1,         1,-85031       , 0         , "t=16.8s",_
 1588, 45, 108, 1,5,         1,-84917       , 0.115     , "t=6.0m",_
 1589, 46, 108, 0,0,         1,-89524.2     , 0         , "t=stbl",_
 1590, 47, 108, 0,1,         1,-87606.8     , 0         , "t=2.382m",_
 1591, 47, 108, 1,6,         1,-87497.3     , 0.109466  , "t=439y",_
 1592, 48, 108, 0,0,         1,-89252.4     , 0         , "t=stbl",_
 1593, 49, 108, 0,7,         1,-84120       , 0         , "t=58.0m",_
 1594, 49, 108, 1,2,         1,-84090       , 0.02975   , "t=39.6m",_
 1595, 50, 108, 0,0,         1,-82070       , 0         , "t=10.30m",_
 1596, 51, 108, 0,4,         1,-72445       , 0         , "t=7.4s",_
 1597, 52, 108, 0,0,         1,-65782       , 0         , "t=2.1s",_
 1598, 53, 108, 0,1,         1,-52770       , 0         , "t=26.4ms",_
 1599, 54, 108, 0,0,         1,-42630       , 0         , "t=72us",_
 1600, 39, 109, 0,2.5,       1,-32480       , 0         , "t=25ms",_
 1601, 40, 109, 0,2.5,       1,-45730       , 0         , "t=56ms",_
 1602, 41, 109, 0,1.5,      -1,-56690       , 0         , "t=106.9ms",_
 1603, 41, 109, 1,3.5,       1,-56380       , 0.3125    , "t=115ns",_
 1604, 42, 109, 0,0.5,       1,-66659       , 0         , "t=700ms",_
 1605, 42, 109, 1,2.5,       1,-66589       , 0.0697    , "t=210ns",_
 1606, 43, 109, 0,2.5,       1,-74283       , 0         , "t=905ms",_
 1607, 44, 109, 0,2.5,       1,-80738       , 0         , "t=34.4s",_
 1608, 44, 109, 1,2.5,      -1,-80642       , 0.09614   , "t=680ns",_
 1609, 45, 109, 0,3.5,       1,-84999       , 0         , "t=80.8s",_
 1610, 45, 109, 1,1.5,       1,-84773       , 0.225873  , "t=1.66us",_
 1611, 46, 109, 0,2.5,       1,-87606.5     , 0         , "t=13.59h",_
 1612, 46, 109, 1,0.5,       1,-87493.1     , 0.1134    , "t=380ns",_
 1613, 47, 109, 0,0.5,      -1,-88719.4     , 0         , "t=stbl",_
 1614, 47, 109, 1,3.5,       1,-88631.4     , 0.0880337 , "t=39.79s",_
 1615, 48, 109, 0,2.5,       1,-88504.3     , 0         , "t=461.3d",_
 1616, 48, 109, 1,0.5,       1,-88444.7     , 0.0596    , "t=11.8us",_
 1617, 49, 109, 0,4.5,       1,-86490       , 0         , "t=4.159h",_
 1618, 49, 109, 1,0.5,      -1,-85840       , 0.64979   , "t=1.34m",_
 1619, 50, 109, 0,2.5,       1,-82630       , 0         , "t=18.1m",_
 1620, 51, 109, 0,2.5,       1,-76251       , 0         , "t=17.2s",_
 1621, 52, 109, 0,2.5,       1,-67715       , 0         , "t=4.4s",_
 1622, 53, 109, 0,0.5,       1,-57673       , 0         , "t=92.8us",_
 1623, 54, 109, 0,3.5,       1,-46170       , 0         , "t=13ms",_
 1624, 40, 110, 0,0,         1,-42220       , 0         , "t=37.5ms",_
 1625, 41, 110, 0,5,         1,-52310       , 0         , "t=75ms",_
 1626, 41, 110, 1,2,         1,-52210       , 0.1       , "t=94ms",_
 1627, 42, 110, 0,0,         1,-64536       , 0         , "t=292ms",_
 1628, 43, 110, 0,2,         1,-71035       , 0         , "t=900ms",_
 1629, 44, 110, 0,0,         1,-80073       , 0         , "t=12.04s",_
 1630, 45, 110, 0,1,         1,-82829       , 0         , "t=3.35s",_
 1631, 45, 110, 1,6,         1,-82610       , 0.22      , "t=28.5s",_
 1632, 46, 110, 0,0,         1,-88330.9     , 0         , "t=stbl",_
 1633, 47, 110, 0,1,         1,-87457.3     , 0         , "t=24.56s",_
 1634, 47, 110, 1,2,        -1,-87456.2     , 0.001112  , "t=660ns",_
 1635, 48, 110, 0,0,         1,-90348.0     , 0         , "t=stbl",_
 1636, 49, 110, 0,7,         1,-86470       , 0         , "t=4.92h",_
 1637, 49, 110, 1,2,         1,-86408       , 0.06208   , "t=69.1m",_
 1638, 50, 110, 0,0,         1,-85842       , 0         , "t=4.154h",_
 1639, 51, 110, 0,3,         1,-77450       , 0         , "t=23.6s",_
 1640, 52, 110, 0,0,         1,-72230       , 0         , "t=18.6s",_
 1641, 53, 110, 0,1,         1,-60470       , 0         , "t=664ms",_
 1642, 54, 110, 0,0,         1,-51920       , 0         , "t=93ms",_
 1643, 40, 111, 0,2.5,       1,-36480       , 0         , "t=24.0ms",_
 1644, 41, 111, 0,1.5,      -1,-48960       , 0         , "t=54ms",_
 1645, 42, 111, 0,0.5,       1,-59940       , 0         , "t=193.6ms",_
 1646, 42, 111, 1,3.5,      -1,-59840       , 0.1       , "t=~200ms",_
 1647, 43, 111, 0,2.5,       1,-69025       , 0         , "t=350ms",_
 1648, 44, 111, 0,2.5,       1,-76785       , 0         , "t=2.12s",_
 1649, 45, 111, 0,3.5,       1,-82304       , 0         , "t=11s",_
 1650, 46, 111, 0,2.5,       1,-85985.9     , 0         , "t=23.56m",_
 1651, 46, 111, 1,5.5,      -1,-85813.7     , 0.17218   , "t=5.563h",_
 1652, 47, 111, 0,0.5,      -1,-88215.4     , 0         , "t=7.433d",_
 1653, 47, 111, 1,3.5,       1,-88155.6     , 0.05982   , "t=64.8s",_
 1654, 48, 111, 0,0.5,       1,-89252.2     , 0         , "t=stbl",_
 1655, 48, 111, 1,5.5,      -1,-88856.0     , 0.396214  , "t=48.50m",_
 1656, 49, 111, 0,4.5,       1,-88392       , 0         , "t=2.8048d",_
 1657, 49, 111, 1,0.5,      -1,-87855       , 0.53699   , "t=7.7m",_
 1658, 50, 111, 0,3.5,       1,-85939       , 0         , "t=35.3m",_
 1659, 50, 111, 1,0.5,       1,-85684       , 0.25471   , "t=12.5us",_
 1660, 51, 111, 0,2.5,       1,-80837       , 0         , "t=75s",_
 1661, 52, 111, 0,2.5,       1,-73587       , 0         , "t=26.2s",_
 1662, 53, 111, 0,2.5,       1,-64954       , 0         , "t=2.5s",_
 1663, 54, 111, 0,2.5,       1,-54520       , 0         , "t=740ms",_
 1664, 55, 111, 0,1.5,       1,-42900       , 0         , "t=1us",_
 1665, 40, 112, 0,0,         1,-32420       , 0         , "t=43ms",_
 1666, 41, 112, 0,1,         1,-44070       , 0         , "t=38ms",_
 1667, 42, 112, 0,0,         1,-57480       , 0         , "t=125ms",_
 1668, 43, 112, 0,2,         1,-65259       , 0         , "t=323ms",_
 1669, 43, 112, 1,-77.777,   0,-64907       , 0.3523    , "t=150ns",_
 1670, 44, 112, 0,0,         1,-75631       , 0         , "t=1.75s",_
 1671, 45, 112, 0,1,         1,-79730       , 0         , "t=3.4s",_
 1672, 45, 112, 1,6,         1,-79390       , 0.34      , "t=6.73s",_
 1673, 46, 112, 0,0,         1,-86321       , 0         , "t=21.04h",_
 1674, 47, 112, 0,2,        -1,-86583.7     , 0         , "t=3.130h",_
 1675, 48, 112, 0,0,         1,-90574.86    , 0         , "t=stbl",_
 1676, 49, 112, 0,1,         1,-87990       , 0         , "t=14.88m",_
 1677, 49, 112, 1,4,         1,-87833       , 0.156592  , "t=20.67m",_
 1678, 50, 112, 0,0,         1,-88655.05    , 0         , "t=stbl",_
 1679, 51, 112, 0,3,         1,-81599       , 0         , "t=53.5s",_
 1680, 51, 112, 1,8,        -1,-80773       , 0.8259    , "t=536ns",_
 1681, 52, 112, 0,0,         1,-77568       , 0         , "t=2.0m",_
 1682, 53, 112, 0,1,         1,-67063       , 0         , "t=3.34s",_
 1683, 54, 112, 0,0,         1,-60026       , 0         , "t=2.7s",_
 1684, 55, 112, 0,1,         1,-46420       , 0         , "t=490us",_
 1685, 40, 113, 0,1.5,       1,-26340       , 0         , "t=15ms",_
 1686, 41, 113, 0,1.5,      -1,-40210       , 0         , "t=32ms",_
 1687, 42, 113, 0,2.5,       1,-52650       , 0         , "t=80ms",_
 1688, 43, 113, 0,2.5,       1,-62812       , 0         , "t=152ms",_
 1689, 43, 113, 1,2.5,      -1,-62698       , 0.1144    , "t=527ns",_
 1690, 44, 113, 0,0.5,       1,-71870       , 0         , "t=800ms",_
 1691, 44, 113, 1,3.5,      -1,-71740       , 0.131     , "t=510ms",_
 1692, 45, 113, 0,3.5,       1,-78767       , 0         , "t=2.80s",_
 1693, 46, 113, 0,2.5,       1,-83590       , 0         , "t=93s",_
 1694, 46, 113, 1,4.5,      -1,-83509       , 0.0811    , "t=300ms",_
 1695, 47, 113, 0,0.5,      -1,-87027       , 0         , "t=5.37h",_
 1696, 47, 113, 1,3.5,       1,-86984       , 0.0435    , "t=68.7s",_
 1697, 48, 113, 0,0.5,       1,-89043.29    , 0         , "t=8.04Py",_
 1698, 48, 113, 1,5.5,      -1,-88779.75    , 0.26354   , "t=13.89y",_
 1699, 49, 113, 0,4.5,       1,-89367.12    , 0         , "t=stbl",_
 1700, 49, 113, 1,0.5,      -1,-88975.42    , 0.391699  , "t=1.6579h",_
 1701, 50, 113, 0,0.5,       1,-88328.1     , 0         , "t=115.08d",_
 1702, 50, 113, 1,3.5,       1,-88250.7     , 0.077389  , "t=21.4m",_
 1703, 51, 113, 0,2.5,       1,-84417       , 0         , "t=6.67m",_
 1704, 52, 113, 0,3.5,       1,-78347       , 0         , "t=1.7m",_
 1705, 53, 113, 0,2.5,       1,-71120       , 0         , "t=6.6s",_
 1706, 54, 113, 0,2.5,       1,-62204       , 0         , "t=2.74s",_
 1707, 54, 113, 1,5.5,      -1,-61800       , 0.4036    , "t=6.9us",_
 1708, 55, 113, 0,1.5,       1,-51765       , 0         , "t=16.94us",_
 1709, 56, 113, 0,2.5,       1,-39710       , 0         , "t=30ms",_
 1710, 41, 114, 0,2,        -1,-34960       , 0         , "t=17ms",_
 1711, 42, 114, 0,0,         1,-49680       , 0         , "t=58ms",_
 1712, 43, 114, 0,5,         1,-58600       , 0         , "t=121ms",_
 1713, 43, 114, 1,1,         1,-58437       , 0.16      , "t=90ms",_
 1714, 44, 114, 0,0,         1,-70221       , 0         , "t=540ms",_
 1715, 45, 114, 0,1,         1,-75710       , 0         , "t=1.85s",_
 1716, 45, 114, 1,7,        -1,-75510       , 0.2       , "t=1.85s",_
 1717, 46, 114, 0,0,         1,-83490       , 0         , "t=2.42m",_
 1718, 47, 114, 0,1,         1,-84931       , 0         , "t=4.6s",_
 1719, 47, 114, 1,6,         1,-84732       , 0.1989    , "t=1.50ms",_
 1720, 48, 114, 0,0,         1,-90014.93    , 0         , "t=stbl",_
 1721, 49, 114, 0,1,         1,-88569.8     , 0         , "t=71.9s",_
 1722, 49, 114, 1,5,         1,-88379.5     , 0.1902682 , "t=49.51d",_
 1723, 50, 114, 0,0,         1,-90559.735   , 0         , "t=stbl",_
 1724, 50, 114, 1,7,        -1,-87472.37    , 3.08737   , "t=733ns",_
 1725, 51, 114, 0,3,         1,-84497       , 0         , "t=3.49m",_
 1726, 51, 114, 1,8,        -1,-84002       , 0.4955    , "t=219us",_
 1727, 52, 114, 0,0,         1,-81890       , 0         , "t=15.2m",_
 1728, 53, 114, 0,1,         1,-72639       , 0         , "t=2.01s",_
 1729, 53, 114, 1,7,        -1,-72373       , 0.2659    , "t=6.2s",_
 1730, 54, 114, 0,0,         1,-67086       , 0         , "t=10.0s",_
 1731, 55, 114, 0,1,         1,-54690       , 0         , "t=570ms",_
 1732, 56, 114, 0,0,         1,-45910       , 0         , "t=460ms",_
 1733, 41, 115, 0,1.5,      -1,-30880       , 0         , "t=23ms",_
 1734, 42, 115, 0,1.5,       1,-44550       , 0         , "t=45.5ms",_
 1735, 43, 115, 0,2.5,       1,-55800       , 0         , "t=78ms",_
 1736, 44, 115, 0,0.5,       1,-66105       , 0         , "t=318ms",_
 1737, 44, 115, 1,3.5,      -1,-66110       , 0.082     , "t=76ms",_
 1738, 45, 115, 0,3.5,       1,-74229       , 0         , "t=1.03s",_
 1739, 46, 115, 0,0.5,       1,-80426       , 0         , "t=25s",_
 1740, 46, 115, 1,3.5,      -1,-80337       , 0.08921   , "t=50s",_
 1741, 47, 115, 0,0.5,      -1,-84983       , 0         , "t=20.0m",_
 1742, 47, 115, 1,3.5,       1,-84942       , 0.04116   , "t=18.0s",_
 1743, 48, 115, 0,0.5,       1,-88084.5     , 0         , "t=53.46h",_
 1744, 48, 115, 1,5.5,      -1,-87903.5     , 0.181     , "t=44.56d",_
 1745, 49, 115, 0,4.5,       1,-89536.357   , 0         , "t=441Ty",_
 1746, 49, 115, 1,0.5,      -1,-89200.113   , 0.336244  , "t=4.486h",_
 1747, 50, 115, 0,0.5,       1,-90033.846   , 0         , "t=stbl",_
 1748, 50, 115, 1,3.5,       1,-89421.04    , 0.61281   , "t=3.26us",_
 1749, 51, 115, 0,2.5,       1,-87003       , 0         , "t=32.1m",_
 1750, 51, 115, 1,9.5,      -1,-84207       , 2.79626   , "t=159ns",_
 1751, 52, 115, 0,3.5,       1,-82063       , 0         , "t=5.8m",_
 1752, 52, 115, 1,0.5,       1,-82053       , 0.01      , "t=6.7m",_
 1753, 53, 115, 0,2.5,       1,-76338       , 0         , "t=1.3m",_
 1754, 54, 115, 0,2.5,       1,-68657       , 0         , "t=18s",_
 1755, 55, 115, 0,4.5,       1,-59700       , 0         , "t=1.4s",_
 1756, 56, 115, 0,2.5,       1,-48920       , 0         , "t=450ms",_
 1757, 41, 116, 0,1,        -1,-25230       , 0         , "t=12ms",_
 1758, 42, 116, 0,0,         1,-41210       , 0         , "t=32ms",_
 1759, 43, 116, 0,2,         1,-51210       , 0         , "t=57ms",_
 1760, 44, 116, 0,0,         1,-64069       , 0         , "t=204ms",_
 1761, 45, 116, 0,1,         1,-70740       , 0         , "t=685ms",_
 1762, 45, 116, 1,6,        -1,-70540       , 0.2       , "t=570ms",_
 1763, 46, 116, 0,0,         1,-79831       , 0         , "t=11.8s",_
 1764, 47, 116, 0,0,        -1,-82543       , 0         , "t=3.83m",_
 1765, 47, 116, 1,3,         1,-82495       , 0.0479    , "t=20s",_
 1766, 48, 116, 0,0,         1,-88712.49    , 0         , "t=26.9Ey",_
 1767, 49, 116, 0,1,         1,-88249.76    , 0         , "t=14.10s",_
 1768, 49, 116, 1,5,         1,-88122.49    , 0.127267  , "t=54.29m",_
 1769, 50, 116, 0,0,         1,-91525.98    , 0         , "t=stbl",_
 1770, 50, 116, 1,5,        -1,-89160.00    , 2.365975  , "t=348ns",_
 1771, 51, 116, 0,3,         1,-86822       , 0         , "t=15.8m",_
 1772, 51, 116, 1,1,         1,-86728       , 0.09399   , "t=194ns",_
 1773, 52, 116, 0,0,         1,-85264       , 0         , "t=2.49h",_
 1774, 53, 116, 0,1,         1,-77420       , 0         , "t=2.91s",_
 1775, 53, 116, 1,7,        -1,-76990       , 0.4304    , "t=3.27us",_
 1776, 54, 116, 0,0,         1,-73047       , 0         , "t=59s",_
 1777, 55, 116, 0,1,         1,-62040       , 0         , "t=700ms",_
 1778, 55, 116, 1,7,         1,-61940       , 0.1       , "t=3.85s",_
 1779, 56, 116, 0,0,         1,-54380       , 0         , "t=1.3s",_
 1780, 57, 116, 0,-77.777,   0,-40050       , 0         , "t=10ms",_
 1781, 42, 117, 0,1.5,       1,-35690       , 0         , "t=22ms",_
 1782, 43, 117, 0,2.5,       1,-48140       , 0         , "t=44.5ms",_
 1783, 44, 117, 0,1.5,       1,-59490       , 0         , "t=151ms",_
 1784, 44, 117, 1,3.5,      -1,-59310       , 0.185     , "t=2.49us",_
 1785, 45, 117, 0,3.5,       1,-68897       , 0         , "t=421ms",_
 1786, 45, 117, 1,1.5,       1,-68576       , 0.3212    , "t=138ns",_
 1787, 46, 117, 0,1.5,       1,-76424       , 0         , "t=4.3s",_
 1788, 46, 117, 1,4.5,      -1,-76221       , 0.2033    , "t=19.1ms",_
 1789, 47, 117, 0,0.5,      -1,-82182       , 0         , "t=73.6s",_
 1790, 47, 117, 1,3.5,       1,-82153       , 0.0286    , "t=5.34s",_
 1791, 48, 117, 0,0.5,       1,-86418.4     , 0         , "t=2.503h",_
 1792, 48, 117, 1,5.5,      -1,-86282.0     , 0.1364    , "t=3.441h",_
 1793, 49, 117, 0,4.5,       1,-88943       , 0         , "t=43.2m",_
 1794, 49, 117, 1,0.5,      -1,-88628       , 0.315303  , "t=116.2m",_
 1795, 50, 117, 0,0.5,       1,-90397.7     , 0         , "t=stbl",_
 1796, 50, 117, 1,5.5,      -1,-90083.1     , 0.31458   , "t=13.939d",_
 1797, 51, 117, 0,2.5,       1,-88640       , 0         , "t=2.97h",_
 1798, 51, 117, 1,12.5,      1,-85509       , 3.13076   , "t=355us",_
 1799, 52, 117, 0,0.5,       1,-85096       , 0         , "t=62m",_
 1800, 52, 117, 1,5.5,      -1,-84800       , 0.2961    , "t=103ms",_
 1801, 53, 117, 0,2.5,       1,-80439       , 0         , "t=2.22m",_
 1802, 54, 117, 0,2.5,       1,-74185       , 0         , "t=61s",_
 1803, 55, 117, 0,4.5,       1,-66490       , 0         , "t=8.4s",_
 1804, 55, 117, 1,1.5,       1,-66340       , 0.15      , "t=6.5s",_
 1805, 56, 117, 0,1.5,       1,-57460       , 0         , "t=1.75s",_
 1806, 57, 117, 0,1.5,       1,-46270       , 0         , "t=21.7ms",_
 1807, 42, 118, 0,0,         1,-32370       , 0         , "t=21ms",_
 1808, 43, 118, 0,2,         1,-43290       , 0         , "t=30ms",_
 1809, 44, 118, 0,0,         1,-57000       , 0         , "t=99ms",_
 1810, 45, 118, 0,1,         1,-64887       , 0         , "t=282ms",_
 1811, 45, 118, 1,6,        -1,-64690       , 0.2       , "t=310ms",_
 1812, 46, 118, 0,0,         1,-75388.4     , 0         , "t=1.9s",_
 1813, 47, 118, 0,2,        -1,-79553.8     , 0         , "t=3.76s",_
 1814, 47, 118, 1,1,         0,-79508.0     , 0.04579   , "t=~0.1us",_
 1815, 48, 118, 0,0,         1,-86702       , 0         , "t=50.3m",_
 1816, 49, 118, 0,1,         1,-87228       , 0         , "t=5.0s",_
 1817, 49, 118, 1,5,         1,-87130       , 0.1       , "t=4.364m",_
 1818, 50, 118, 0,0,         1,-91652.8     , 0         , "t=stbl",_
 1819, 50, 118, 1,7,        -1,-89077.9     , 2.57491   , "t=230ns",_
 1820, 51, 118, 0,1,         1,-87996       , 0         , "t=3.6m",_
 1821, 51, 118, 1,3,         1,-87945       , 0.050814  , "t=20.6us",_
 1822, 52, 118, 0,0,         1,-87691       , 0         , "t=6.00d",_
 1823, 53, 118, 0,2,        -1,-80971       , 0         , "t=13.7m",_
 1824, 53, 118, 1,7,        -1,-80782       , 0.1888    , "t=8.5m",_
 1825, 54, 118, 0,0,         1,-78079       , 0         , "t=3.8m",_
 1826, 55, 118, 0,2,         1,-68409       , 0         , "t=14s",_
 1827, 55, 118, 1,7,        -1,-68310       , 0.1       , "t=17s",_
 1828, 56, 118, 0,0,         1,-62200       , 0         , "t=5.2s",_
 1829, 57, 118, 0,1,        -1,-49620       , 0         , "t=200ms",_
 1830, 42, 119, 0,1.5,       1,-26580       , 0         , "t=12ms",_
 1831, 43, 119, 0,2.5,       1,-40170       , 0         , "t=22ms",_
 1832, 44, 119, 0,1.5,       1,-52080       , 0         , "t=69.5ms",_
 1833, 44, 119, 1,-77.777,   0,-51850       , 0.2271    , "t=384ns",_
 1834, 45, 119, 0,3.5,       1,-62823       , 0         , "t=190ms",_
 1835, 46, 119, 0,1.5,       1,-71407       , 0         , "t=920ms",_
 1836, 46, 119, 1,5.5,      -1,-71110       , 0.3       , "t=3ms",_
 1837, 47, 119, 0,0.5,      -1,-78646       , 0         , "t=6.0s",_
 1838, 47, 119, 1,3.5,       1,-78626       , 0.02      , "t=2.1s",_
 1839, 48, 119, 0,0.5,       1,-83980       , 0         , "t=2.69m",_
 1840, 48, 119, 1,5.5,      -1,-83830       , 0.14654   , "t=2.20m",_
 1841, 49, 119, 0,4.5,       1,-87699       , 0         , "t=2.4m",_
 1842, 49, 119, 1,0.5,      -1,-87388       , 0.31137   , "t=18.0m",_
 1843, 50, 119, 0,0.5,       1,-90065.0     , 0         , "t=stbl",_
 1844, 50, 119, 1,5.5,      -1,-89975.5     , 0.089531  , "t=293.1d",_
 1845, 51, 119, 0,2.5,       1,-89476       , 0         , "t=38.19h",_
 1846, 51, 119, 1,9.5,      -1,-86922       , 2.5536    , "t=130ns",_
 1847, 52, 119, 0,0.5,       1,-87183       , 0         , "t=16.05h",_
 1848, 52, 119, 1,5.5,      -1,-86922       , 0.26096   , "t=4.70d",_
 1849, 53, 119, 0,2.5,       1,-83778       , 0         , "t=19.1m",_
 1850, 54, 119, 0,2.5,       1,-78794       , 0         , "t=5.8m",_
 1851, 55, 119, 0,4.5,       1,-72305       , 0         , "t=43.0s",_
 1852, 55, 119, 1,1.5,       1,-72260       , 0.05      , "t=30.4s",_
 1853, 56, 119, 0,2.5,       1,-64590       , 0         , "t=5.4s",_
 1854, 57, 119, 0,5.5,      -1,-55020       , 0         , "t=1s",_
 1855, 58, 119, 0,2.5,       1,-43820       , 0         , "t=200ms",_
 1856, 43, 120, 0,3,         1,-35000       , 0         , "t=21ms",_
 1857, 44, 120, 0,0,         1,-49720       , 0         , "t=45ms",_
 1858, 45, 120, 0,8,        -1,-58620       , 0         , "t=129.6ms",_
 1859, 45, 120, 1,6,         0,-58460       , 0.1572    , "t=295ns",_
 1860, 46, 120, 0,0,         1,-70279.6     , 0         , "t=492ms",_
 1861, 47, 120, 0,4,         1,-75652       , 0         , "t=1.52s",_
 1862, 47, 120, 1,0,        -1,-75650       , 0         , "t=940ms",_
 1863, 48, 120, 0,0,         1,-83957       , 0         , "t=50.80s",_
 1864, 49, 120, 0,1,         1,-85730       , 0         , "t=3.08s",_
 1865, 49, 120, 1,5,         1,-85680       , 0.05      , "t=46.2s",_
 1866, 50, 120, 0,0,         1,-91097.7     , 0         , "t=stbl",_
 1867, 50, 120, 1,7,        -1,-88616.1     , 2.48163   , "t=11.8us",_
 1868, 51, 120, 0,1,         1,-88417       , 0         , "t=15.89m",_
 1869, 51, 120, 1,8,        -1,-88420       , 0         , "t=5.76d",_
 1870, 52, 120, 0,0,         1,-89362.2     , 0         , "t=stbl",_
 1871, 53, 120, 0,2,        -1,-83747       , 0         , "t=81.67m",_
 1872, 53, 120, 1,3,         1,-83674       , 0.07261   , "t=242ns",_
 1873, 54, 120, 0,0,         1,-82172       , 0         , "t=46.0m",_
 1874, 55, 120, 0,2,         1,-73889       , 0         , "t=60.4s",_
 1875, 55, 120, 1,7,        -1,-73790       , 0.1       , "t=57s",_
 1876, 56, 120, 0,0,         1,-68890       , 0         , "t=24s",_
 1877, 57, 120, 0,1,        -1,-57570       , 0         , "t=2.8s",_
 1878, 58, 120, 0,0,         1,-49730       , 0         , "t=250ms",_
 1879, 43, 121, 0,2.5,       1,-31540       , 0         , "t=22ms",_
 1880, 44, 121, 0,1.5,       1,-44620       , 0         , "t=29ms",_
 1881, 45, 121, 0,3.5,       1,-56250       , 0         , "t=74ms",_
 1882, 46, 121, 0,1.5,       1,-66182       , 0         , "t=290ms",_
 1883, 46, 121, 1,3.5,       1,-66047       , 0.1355    , "t=460ns",_
 1884, 47, 121, 0,3.5,       1,-74403       , 0         , "t=777ms",_
 1885, 47, 121, 1,0.5,      -1,-74383       , 0.02      , "t=200ms",_
 1886, 48, 121, 0,1.5,       1,-81073.8     , 0         , "t=13.5s",_
 1887, 48, 121, 1,5.5,      -1,-80858.9     , 0.21486   , "t=8.3s",_
 1888, 49, 121, 0,4.5,       1,-85835       , 0         , "t=23.1s",_
 1889, 49, 121, 1,0.5,      -1,-85521       , 0.31368   , "t=3.88m",_
 1890, 50, 121, 0,1.5,       1,-89196.6     , 0         , "t=27.03h",_
 1891, 50, 121, 1,5.5,      -1,-89190.3     , 0.00631   , "t=43.9y",_
 1892, 51, 121, 0,2.5,       1,-89599.2     , 0         , "t=stbl",_
 1893, 51, 121, 1,12.5,      1,-86848       , 2.751     , "t=179us",_
 1894, 52, 121, 0,0.5,       1,-88543       , 0         , "t=19.31d",_
 1895, 52, 121, 1,5.5,      -1,-88249       , 0.293974  , "t=164.7d",_
 1896, 53, 121, 0,2.5,       1,-86246       , 0         , "t=2.12h",_
 1897, 53, 121, 1,10.5,      1,-83869       , 2.3769    , "t=9.0us",_
 1898, 54, 121, 0,2.5,       1,-82481       , 0         , "t=40.1m",_
 1899, 55, 121, 0,1.5,       1,-77102       , 0         , "t=155s",_
 1900, 55, 121, 1,4.5,       1,-77034       , 0.0685    , "t=122s",_
 1901, 56, 121, 0,2.5,       1,-70740       , 0         , "t=29.7s",_
 1902, 57, 121, 0,5.5,      -1,-62190       , 0         , "t=5.3s",_
 1903, 58, 121, 0,2.5,       1,-52690       , 0         , "t=1.1s",_
 1904, 59, 121, 0,1.5,       1,-41550       , 0         , "t=12ms",_
 1905, 43, 122, 0,1,         1,-26310       , 0         , "t=13ms",_
 1906, 44, 122, 0,0,         1,-41780       , 0         , "t=25ms",_
 1907, 45, 122, 0,7,        -1,-51880       , 0         , "t=51ms",_
 1908, 45, 122, 1,4,         1,-51610       , 0.271     , "t=830ns",_
 1909, 46, 122, 0,0,         1,-64616       , 0         , "t=193ms",_
 1910, 47, 122, 0,3,         1,-71110       , 0         , "t=529ms",_
 1911, 47, 122, 1,1,        -1,-71030       , 0.08      , "t=550ms",_
 1912, 48, 122, 0,0,         1,-80612.4     , 0         , "t=5.24s",_
 1913, 49, 122, 0,1,         1,-83570       , 0         , "t=1.5s",_
 1914, 49, 122, 1,5,         1,-83530       , 0.04      , "t=10.3s",_
 1915, 50, 122, 0,0,         1,-89940.0     , 0         , "t=stbl",_
 1916, 50, 122, 1,7,        -1,-87531.0     , 2.40903   , "t=7.5us",_
 1917, 51, 122, 0,2,        -1,-88334.2     , 0         , "t=2.7238d",_
 1918, 51, 122, 1,3,         1,-88272.8     , 0.0614131 , "t=1.86us",_
 1919, 52, 122, 0,0,         1,-90313.3     , 0         , "t=stbl",_
 1920, 53, 122, 0,1,         1,-86079       , 0         , "t=3.63m",_
 1921, 53, 122, 1,7,        -1,-85764       , 0.3149    , "t=193.3ns",_
 1922, 54, 122, 0,0,         1,-85355       , 0         , "t=20.1h",_
 1923, 55, 122, 0,1,         1,-78140       , 0         , "t=21.18s",_
 1924, 55, 122, 1,3,         1,-78090       , 0.04587   , "t=&gt;1us",_
 1925, 56, 122, 0,0,         1,-74609       , 0         , "t=1.95m",_
 1926, 57, 122, 0,1,        -1,-64540       , 0         , "t=8.6s",_
 1927, 58, 122, 0,0,         1,-57870       , 0         , "t=2s",_
 1928, 59, 122, 0,-77.777,   0,-44780       , 0         , "t=500ms",_
 1929, 44, 123, 0,1.5,       1,-36550       , 0         , "t=19ms",_
 1930, 45, 123, 0,3.5,       1,-49190       , 0         , "t=42ms",_
 1931, 46, 123, 0,1.5,       1,-60430       , 0         , "t=108ms",_
 1932, 46, 123, 1,5.5,      -1,-60330       , 0.1       , "t=100ms",_
 1933, 47, 123, 0,3.5,       1,-69570       , 0         , "t=294ms",_
 1934, 47, 123, 1,0.5,      -1,-69510       , 0.0595    , "t=100ms",_
 1935, 48, 123, 0,1.5,       1,-77414.2     , 0         , "t=2.10s",_
 1936, 48, 123, 1,5.5,      -1,-77271       , 0.143     , "t=1.82s",_
 1937, 49, 123, 0,4.5,       1,-83429       , 0         , "t=6.17s",_
 1938, 49, 123, 1,0.5,      -1,-83102       , 0.32721   , "t=47.4s",_
 1939, 50, 123, 0,5.5,      -1,-87814.7     , 0         , "t=129.2d",_
 1940, 50, 123, 1,1.5,       1,-87790.1     , 0.0246    , "t=40.06m",_
 1941, 51, 123, 0,3.5,       1,-89222.9     , 0         , "t=stbl",_
 1942, 51, 123, 1,9.5,      -1,-86985.1     , 2.2378    , "t=214ns",_
 1943, 52, 123, 0,0.5,       1,-89171.0     , 0         , "t=stbl",_
 1944, 52, 123, 1,5.5,      -1,-88923.5     , 0.24747   , "t=119.2d",_
 1945, 53, 123, 0,2.5,       1,-87943       , 0         , "t=13.2232h",_
 1946, 54, 123, 0,0.5,       1,-85248       , 0         , "t=2.08h",_
 1947, 54, 123, 1,3.5,      -1,-85063       , 0.18518   , "t=5.49us",_
 1948, 55, 123, 0,0.5,       1,-81044       , 0         , "t=5.88m",_
 1949, 55, 123, 1,5.5,      -1,-80888       , 0.15627   , "t=1.64s",_
 1950, 56, 123, 0,2.5,       1,-75655       , 0         , "t=2.7m",_
 1951, 56, 123, 1,0.5,       1,-75534       , 0.12095   , "t=830ns",_
 1952, 57, 123, 0,5.5,      -1,-68650       , 0         , "t=17s",_
 1953, 58, 123, 0,2.5,       1,-60290       , 0         , "t=3.8s",_
 1954, 59, 123, 0,1.5,       1,-50230       , 0         , "t=800ms",_
 1955, 44, 124, 0,0,         1,-33590       , 0         , "t=15ms",_
 1956, 45, 124, 0,2,         1,-44710       , 0         , "t=30ms",_
 1957, 46, 124, 0,0,         1,-58400       , 0         , "t=88ms",_
 1958, 46, 124, 1,-77.777,   0,-57400       , 1         , "t=&gt;20us",_
 1959, 47, 124, 0,2,        -1,-66230       , 0         , "t=177.9ms",_
 1960, 47, 124, 1,9,        -1,-66180       , 0.05      , "t=144ms",_
 1961, 48, 124, 0,0,         1,-76699.4     , 0         , "t=1.25s",_
 1962, 49, 124, 0,3,         1,-80870       , 0         , "t=3.12s",_
 1963, 49, 124, 1,8,        -1,-80890       ,-0.02      , "t=3.67s",_
 1964, 50, 124, 0,0,         1,-88231.5     , 0         , "t=stbl",_
 1965, 50, 124, 1,5,        -1,-86026.9     , 2.20462   , "t=270ns",_
 1966, 51, 124, 0,3,        -1,-87619.1     , 0         , "t=60.20d",_
 1967, 51, 124, 1,5,         1,-87608.2     , 0.0108627 , "t=93s",_
 1968, 52, 124, 0,0,         1,-90524.1     , 0         , "t=stbl",_
 1969, 53, 124, 0,2,        -1,-87364.6     , 0         , "t=4.1760d",_
 1970, 54, 124, 0,0,         1,-87667.4     , 0         , "t=stbl",_
 1971, 55, 124, 0,1,         1,-81741       , 0         , "t=30.9s",_
 1972, 55, 124, 1,7,         1,-81278       , 0.46263   , "t=6.41s",_
 1973, 56, 124, 0,0,         1,-79090       , 0         , "t=11.0m",_
 1974, 57, 124, 0,7,         0,-70260       , 0         , "t=29.21s",_
 1975, 57, 124, 1,2,        -1,-70160       , 0.1       , "t=21s",_
 1976, 58, 124, 0,0,         1,-64920       , 0         , "t=9.1s",_
 1977, 59, 124, 0,-77.777,   0,-53150       , 0         , "t=1.2s",_
 1978, 60, 124, 0,0,         1,-44830       , 0         , "t=500ms",_
 1979, 44, 125, 0,1.5,       1,-28370       , 0         , "t=12ms",_
 1980, 45, 125, 0,3.5,       1,-41830       , 0         , "t=26.5ms",_
 1981, 46, 125, 0,1.5,       1,-53960       , 0         , "t=60ms",_
 1982, 46, 125, 1,5.5,      -1,-53860       , 0.1       , "t=50ms",_
 1983, 47, 125, 0,4.5,       1,-64520       , 0         , "t=160ms",_
 1984, 47, 125, 1,0.5,      -1,-64420       , 0.0971    , "t=50ms",_
 1985, 48, 125, 0,1.5,       1,-73348.1     , 0         , "t=680ms",_
 1986, 48, 125, 1,5.5,      -1,-73162       , 0.186     , "t=480ms",_
 1987, 49, 125, 0,4.5,       1,-80412.3     , 0         , "t=2.36s",_
 1988, 49, 125, 1,0.5,      -1,-80060       , 0.352     , "t=12.2s",_
 1989, 50, 125, 0,5.5,      -1,-85893.7     , 0         , "t=9.634d",_
 1990, 50, 125, 1,1.5,       1,-85866.2     , 0.0275    , "t=9.77m",_
 1991, 51, 125, 0,3.5,       1,-88255.1     , 0         , "t=2.7576y",_
 1992, 51, 125, 1,7.5,      -1,-86283.9     , 1.97125   , "t=4.1us",_
 1993, 52, 125, 0,0.5,       1,-89021.8     , 0         , "t=stbl",_
 1994, 52, 125, 1,5.5,      -1,-88877.0     , 0.144775  , "t=57.40d",_
 1995, 53, 125, 0,2.5,       1,-88836.0     , 0         , "t=59.392d",_
 1996, 54, 125, 0,0.5,       1,-87199.4     , 0         , "t=16.87h",_
 1997, 54, 125, 1,4.5,      -1,-86946.8     , 0.25261   , "t=56.9s",_
 1998, 55, 125, 0,0.5,       1,-84090       , 0         , "t=44.35m",_
 1999, 55, 125, 1,5.5,      -1,-83824       , 0.2661    , "t=900us",_
 2000, 56, 125, 0,0.5,       1,-79669       , 0         , "t=3.3m",_
 2001, 56, 125, 1,3.5,      -1,-79549       , 0.12      , "t=2.76us",_
 2002, 57, 125, 0,5.5,      -1,-73759       , 0         , "t=64.8s",_
 2003, 57, 125, 1,1.5,       1,-73652       , 0.107     , "t=390ms",_
 2004, 58, 125, 0,3.5,      -1,-66660       , 0         , "t=9.7s",_
 2005, 58, 125, 1,0.5,       1,-66570       , 0.0936    , "t=13s",_
 2006, 59, 125, 0,1.5,       1,-58070       , 0         , "t=3.3s",_
 2007, 60, 125, 0,2.5,       1,-48070       , 0         , "t=650ms",_
 2008, 45, 126, 0,1,        -1,-37200       , 0         , "t=19ms",_
 2009, 46, 126, 0,0,         1,-51790       , 0         , "t=48.6ms",_
 2010, 46, 126, 1,5,        -1,-49770       , 2.0235    , "t=330ns",_
 2011, 47, 126, 0,3,         1,-60720       , 0         , "t=52ms",_
 2012, 47, 126, 1,9,        -1,-60620       , 0.1       , "t=108.4ms",_
 2013, 48, 126, 0,0,         1,-72255.7     , 0         , "t=512ms",_
 2014, 49, 126, 0,3,         1,-77809       , 0         , "t=1.53s",_
 2015, 49, 126, 1,8,        -1,-77719       , 0.09      , "t=1.64s",_
 2016, 50, 126, 0,0,         1,-86015       , 0         , "t=230ky",_
 2017, 50, 126, 1,7,        -1,-83796       , 2.21899   , "t=6.1us",_
 2018, 51, 126, 0,8,        -1,-86390       , 0         , "t=12.35d",_
 2019, 51, 126, 1,5,         1,-86370       , 0.0177    , "t=19.15m",_
 2020, 52, 126, 0,0,         1,-90064.2     , 0         , "t=stbl",_
 2021, 53, 126, 0,2,        -1,-87910       , 0         , "t=12.93d",_
 2022, 53, 126, 1,3,         1,-87799       , 0.111     , "t=128ns",_
 2023, 54, 126, 0,0,         1,-89146.387   , 0         , "t=stbl",_
 2024, 55, 126, 0,1,         1,-84351       , 0         , "t=1.64m",_
 2025, 55, 126, 1,4,        -1,-84078       , 0.273     , "t=~1us",_
 2026, 56, 126, 0,0,         1,-82670       , 0         , "t=100m",_
 2027, 57, 126, 0,5,        -1,-74970       , 0         , "t=54s",_
 2028, 57, 126, 1,1,        -1,-74760       , 0.21      , "t=20s",_
 2029, 58, 126, 0,0,         1,-70821       , 0         , "t=51.0s",_
 2030, 59, 126, 0,4,         0,-60320       , 0         , "t=3.12s",_
 2031, 60, 126, 0,0,         1,-53380       , 0         , "t=1s",_
 2032, 61, 126, 0,-77.777,   0,-39750       , 0         , "t=500ms",_
 2033, 45, 127, 0,3.5,       1,-33730       , 0         , "t=28ms",_
 2034, 46, 127, 0,5.5,      -1,-47220       , 0         , "t=38ms",_
 2035, 46, 127, 1,9.5,       1,-45500       , 1.71791   , "t=39us",_
 2036, 47, 127, 0,4.5,       1,-58650       , 0         , "t=89ms",_
 2037, 47, 127, 1,0.5,      -1,-58630       , 0.02      , "t=20ms",_
 2038, 48, 127, 0,1.5,       1,-68741       , 0         , "t=480ms",_
 2039, 48, 127, 1,5.5,      -1,-68456       , 0.285     , "t=360ms",_
 2040, 49, 127, 0,4.5,       1,-76880       , 0         , "t=1.086s",_
 2041, 49, 127, 1,0.5,      -1,-76486       , 0.394     , "t=3.618s",_
 2042, 50, 127, 0,5.5,      -1,-83470       , 0         , "t=2.10h",_
 2043, 50, 127, 1,1.5,       1,-83465       , 0.00507   , "t=4.13m",_
 2044, 51, 127, 0,3.5,       1,-86698       , 0         , "t=3.85d",_
 2045, 51, 127, 1,7.5,      -1,-84778       , 1.92019   , "t=11.7us",_
 2046, 52, 127, 0,1.5,       1,-88280.5     , 0         , "t=9.35h",_
 2047, 52, 127, 1,5.5,      -1,-88192.3     , 0.08823   , "t=106.1d",_
 2048, 53, 127, 0,2.5,       1,-88983       , 0         , "t=stbl",_
 2049, 54, 127, 0,0.5,       1,-88321       , 0         , "t=36.342d",_
 2050, 54, 127, 1,4.5,      -1,-88024       , 0.2971    , "t=69.2s",_
 2051, 55, 127, 0,0.5,       1,-86240       , 0         , "t=6.25h",_
 2052, 55, 127, 1,5.5,      -1,-85788       , 0.45223   , "t=55us",_
 2053, 56, 127, 0,0.5,       1,-82818       , 0         , "t=12.7m",_
 2054, 56, 127, 1,3.5,      -1,-82738       , 0.08032   , "t=1.93s",_
 2055, 57, 127, 0,5.5,      -1,-77896       , 0         , "t=5.1m",_
 2056, 57, 127, 1,1.5,       1,-77882       , 0.0142    , "t=3.7m",_
 2057, 58, 127, 0,0.5,       1,-71979       , 0         , "t=34s",_
 2058, 58, 127, 1,2.5,       1,-71972       , 0.0073    , "t=28.6s",_
 2059, 59, 127, 0,1.5,       1,-64540       , 0         , "t=4.2s",_
 2060, 59, 127, 1,5.5,      -1,-63940       , 0.6       , "t=2us",_
 2061, 60, 127, 0,2.5,       1,-55910       , 0         , "t=1.8s",_
 2062, 61, 127, 0,1.5,       1,-45310       , 0         , "t=1s",_
 2063, 45, 128, 0,-77.777,   0,-27340       , 0         , "t=8ms",_
 2064, 46, 128, 0,0,         1,-44390       , 0         , "t=35ms",_
 2065, 46, 128, 1,8,         1,-42240       , 2.151     , "t=5.8us",_
 2066, 47, 128, 0,3,         1,-54710       , 0         , "t=60ms",_
 2067, 48, 128, 0,0,         1,-67238       , 0         , "t=246ms",_
 2068, 48, 128, 1,5,        -1,-65368       , 1.8705    , "t=270ns",_
 2069, 49, 128, 0,3,         1,-74190.1     , 0         , "t=816ms",_
 2070, 49, 128, 1,1,        -1,-73942.2     , 0.24787   , "t=23us",_
 2071, 50, 128, 0,0,         1,-83361       , 0         , "t=59.07m",_
 2072, 50, 128, 1,7,        -1,-81270       , 2.0915    , "t=6.5s",_
 2073, 51, 128, 0,8,        -1,-84630       , 0         , "t=9.05h",_
 2074, 51, 128, 1,5,         1,-84620       , 0.01      , "t=10.41m",_
 2075, 52, 128, 0,0,         1,-88993.8     , 0         , "t=2.25Yy",_
 2076, 52, 128, 1,10,        1,-86203.0     , 2.7908    , "t=363ns",_
 2077, 53, 128, 0,1,         1,-87738       , 0         , "t=24.99m",_
 2078, 53, 128, 1,4,        -1,-87600       , 0.137851  , "t=845ns",_
 2079, 54, 128, 0,0,         1,-89860.534   , 0         , "t=stbl",_
 2080, 54, 128, 1,8,        -1,-87073.3     , 2.7872    , "t=83ns",_
 2081, 55, 128, 0,1,         1,-85932       , 0         , "t=3.640m",_
 2082, 56, 128, 0,0,         1,-85369.2     , 0         , "t=2.43d",_
 2083, 57, 128, 0,5,         1,-78630       , 0         , "t=5.18m",_
 2084, 57, 128, 1,1,         1,-78530       , 0.1       , "t=&lt;1.4m",_
 2085, 58, 128, 0,0,         1,-75534       , 0         , "t=3.93m",_
 2086, 59, 128, 0,3,         1,-66331       , 0         , "t=2.85s",_
 2087, 60, 128, 0,0,         1,-60530       , 0         , "t=5s",_
 2088, 61, 128, 0,4,         1,-48220       , 0         , "t=1.0s",_
 2089, 62, 128, 0,0,         1,-39150       , 0         , "t=500ms",_
 2090, 46, 129, 0,3.5,      -1,-37880       , 0         , "t=31ms",_
 2091, 47, 129, 0,4.5,       1,-51870       , 0         , "t=49.9ms",_
 2092, 47, 129, 1,0.5,      -1,-51850       , 0.02      , "t=10ms",_
 2093, 48, 129, 0,5.5,      -1,-63122       , 0         , "t=147ms",_
 2094, 48, 129, 1,1.5,       1,-62779       , 0.343     , "t=157ms",_
 2095, 49, 129, 0,4.5,       1,-72834.9     , 0         , "t=570ms",_
 2096, 49, 129, 1,0.5,      -1,-72384.2     , 0.45073   , "t=1.23s",_
 2097, 50, 129, 0,1.5,       1,-80591       , 0         , "t=2.23m",_
 2098, 50, 129, 1,5.5,      -1,-80556       , 0.03515   , "t=6.9m",_
 2099, 51, 129, 0,3.5,       1,-84629       , 0         , "t=4.366h",_
 2100, 51, 129, 1,9.5,      -1,-82778       , 1.85131   , "t=17.7m",_
 2101, 52, 129, 0,1.5,       1,-87004.9     , 0         , "t=69.6m",_
 2102, 52, 129, 1,5.5,      -1,-86899.4     , 0.10551   , "t=33.6d",_
 2103, 53, 129, 0,3.5,       1,-88507       , 0         , "t=16.14My",_
 2104, 54, 129, 0,0.5,       1,-88696.070   , 0         , "t=stbl",_
 2105, 54, 129, 1,5.5,      -1,-88459.93    , 0.23614   , "t=8.88d",_
 2106, 55, 129, 0,0.5,       1,-87499       , 0         , "t=32.06h",_
 2107, 55, 129, 1,5.5,      -1,-86924       , 0.5754    , "t=718ns",_
 2108, 56, 129, 0,0.5,       1,-85061       , 0         , "t=2.23h",_
 2109, 56, 129, 1,3.5,       1,-85053       , 0.00842   , "t=2.135h",_
 2110, 57, 129, 0,1.5,       1,-81324       , 0         , "t=11.6m",_
 2111, 57, 129, 1,5.5,      -1,-81152       , 0.17233   , "t=560ms",_
 2112, 58, 129, 0,2.5,       1,-76288       , 0         , "t=3.5m",_
 2113, 59, 129, 0,1.5,       1,-69774       , 0         , "t=30s",_
 2114, 59, 129, 1,5.5,      -1,-69390       , 0.38257   , "t=26us",_
 2115, 60, 129, 0,3.5,      -1,-62380       , 0         , "t=6.8s",_
 2116, 60, 129, 1,0.5,       1,-62330       , 0.05      , "t=2.6s",_
 2117, 61, 129, 0,2.5,       1,-53180       , 0         , "t=2.4s",_
 2118, 62, 129, 0,0.5,       1,-42330       , 0         , "t=550ms",_
 2119, 46, 130, 0,0,         1,-32730       , 0         , "t=27ms",_
 2120, 47, 130, 0,1,        -1,-45900       , 0         , "t=40.6ms",_
 2121, 48, 130, 0,0,         1,-61118       , 0         , "t=126.8ms",_
 2122, 48, 130, 1,8,         1,-58988       , 2.1296    , "t=240ns",_
 2123, 49, 130, 0,1,        -1,-69906.5     , 0         , "t=273ms",_
 2124, 49, 130, 1,10,       -1,-69840.0     , 0.0665    , "t=540ms",_
 2125, 50, 130, 0,0,         1,-80132.2     , 0         , "t=3.72m",_
 2126, 50, 130, 1,7,        -1,-78185.3     , 1.94688   , "t=1.7m",_
 2127, 51, 130, 0,8,        -1,-82286       , 0         , "t=39.5m",_
 2128, 51, 130, 1,4,         1,-82281       , 0.0048    , "t=6.3m",_
 2129, 52, 130, 0,0,         1,-87352.960   , 0         , "t=791Ey",_
 2130, 52, 130, 1,7,        -1,-85206.55    , 2.14641   , "t=186ns",_
 2131, 53, 130, 0,5,         1,-86936       , 0         , "t=12.36h",_
 2132, 53, 130, 1,2,         1,-86896       , 0.0399525 , "t=8.84m",_
 2133, 54, 130, 0,0,         1,-89880.474   , 0         , "t=stbl",_
 2134, 55, 130, 0,1,         1,-86900       , 0         , "t=29.21m",_
 2135, 55, 130, 1,5,        -1,-86737       , 0.16325   , "t=3.46m",_
 2136, 56, 130, 0,0,         1,-87256.78    , 0         , "t=stbl",_
 2137, 56, 130, 1,8,        -1,-84781.7     , 2.47512   , "t=9.54ms",_
 2138, 57, 130, 0,3,         1,-81627       , 0         , "t=8.7m",_
 2139, 57, 130, 1,5,         1,-81413       , 0.214     , "t=742ns",_
 2140, 58, 130, 0,0,         1,-79423       , 0         , "t=22.9m",_
 2141, 58, 130, 1,7,        -1,-76969       , 2.4536    , "t=100ns",_
 2142, 59, 130, 0,6,         0,-71180       , 0         , "t=40.0s",_
 2143, 59, 130, 1,2,         1,-71080       , 0.1       , "t=10s",_
 2144, 60, 130, 0,0,         1,-66596       , 0         , "t=21s",_
 2145, 61, 130, 0,5,         1,-55470       , 0         , "t=2.6s",_
 2146, 62, 130, 0,0,         1,-47700       , 0         , "t=1s",_
 2147, 63, 130, 0,1,         1,-33510       , 0         , "t=1.0ms",_
 2148, 46, 131, 0,3.5,      -1,-25740       , 0         , "t=20ms",_
 2149, 47, 131, 0,4.5,       1,-40750       , 0         , "t=35ms",_
 2150, 48, 131, 0,3.5,      -1,-55212       , 0         , "t=98ms",_
 2151, 49, 131, 0,4.5,       1,-68024.4     , 0         , "t=261.5ms",_
 2152, 49, 131, 1,0.5,      -1,-67648.4     , 0.376     , "t=328ms",_
 2153, 50, 131, 0,1.5,       1,-77265       , 0         , "t=56.0s",_
 2154, 50, 131, 1,5.5,      -1,-77200       , 0.0651    , "t=58.4s",_
 2155, 51, 131, 0,3.5,       1,-81981.4     , 0         , "t=23.03m",_
 2156, 51, 131, 1,7.5,      -1,-80305.3     , 1.67606   , "t=64.2us",_
 2157, 52, 131, 0,1.5,       1,-85211.02    , 0         , "t=25.0m",_
 2158, 52, 131, 1,5.5,      -1,-85028.76    , 0.182258  , "t=32.48h",_
 2159, 53, 131, 0,3.5,       1,-87442.7     , 0         , "t=8.0249d",_
 2160, 53, 131, 1,9.5,      -1,-85524.3     , 1.9184    , "t=24us",_
 2161, 54, 131, 0,1.5,       1,-88413.575   , 0         , "t=stbl",_
 2162, 54, 131, 1,5.5,      -1,-88249.645   , 0.16393   , "t=11.948d",_
 2163, 55, 131, 0,2.5,       1,-88055.57    , 0         , "t=9.689d",_
 2164, 56, 131, 0,0.5,       1,-86679.0     , 0         , "t=11.52d",_
 2165, 56, 131, 1,4.5,      -1,-86491.0     , 0.187995  , "t=14.26m",_
 2166, 57, 131, 0,1.5,       1,-83769       , 0         , "t=59m",_
 2167, 57, 131, 1,5.5,      -1,-83464       , 0.3046    , "t=170us",_
 2168, 58, 131, 0,3.5,       1,-79710       , 0         , "t=10.3m",_
 2169, 58, 131, 1,0.5,       1,-79650       , 0.06309   , "t=5.4m",_
 2170, 59, 131, 0,1.5,       1,-74300       , 0         , "t=1.50m",_
 2171, 59, 131, 1,5.5,      -1,-74150       , 0.1524    , "t=5.73s",_
 2172, 60, 131, 0,2.5,       1,-67768       , 0         , "t=25.4s",_
 2173, 61, 131, 0,5.5,      -1,-59770       , 0         , "t=6.3s",_
 2174, 62, 131, 0,2.5,       1,-50280       , 0         , "t=1.2s",_
 2175, 63, 131, 0,1.5,       1,-39460       , 0         , "t=17.8ms",_
 2176, 47, 132, 0,6,        -1,-34400       , 0         , "t=30ms",_
 2177, 48, 132, 0,0,         1,-50470       , 0         , "t=84ms",_
 2178, 49, 132, 0,7,        -1,-62410       , 0         , "t=202.2ms",_
 2179, 50, 132, 0,0,         1,-76546.6     , 0         , "t=39.7s",_
 2180, 50, 132, 1,8,         1,-71698.1     , 4.84852   , "t=2.080us",_
 2181, 51, 132, 0,4,         1,-79635.3     , 0         , "t=2.79m",_
 2182, 51, 132, 1,8,        -1,-79490       , 0.15      , "t=4.10m",_
 2183, 52, 132, 0,0,         1,-85188       , 0         , "t=3.204d",_
 2184, 52, 132, 1,6,         1,-83413       , 1.7748    , "t=145ns",_
 2185, 53, 132, 0,4,         1,-85704       , 0         , "t=2.295h",_
 2186, 53, 132, 1,8,        -1,-85594       , 0.11      , "t=1.387h",_
 2187, 54, 132, 0,0,         1,-89278.975   , 0         , "t=stbl",_
 2188, 54, 132, 1,10,        1,-86526.77    , 2.75221   , "t=8.39ms",_
 2189, 55, 132, 0,2,         1,-87152.7     , 0         , "t=6.480d",_
 2190, 56, 132, 0,0,         1,-88434.9     , 0         , "t=stbl",_
 2191, 57, 132, 0,2,        -1,-83720       , 0         , "t=4.59h",_
 2192, 57, 132, 1,6,        -1,-83530       , 0.1882    , "t=24.3m",_
 2193, 58, 132, 0,0,         1,-82469       , 0         , "t=3.51h",_
 2194, 58, 132, 1,8,        -1,-80128       , 2.34115   , "t=9.4ms",_
 2195, 59, 132, 0,2,         1,-75227       , 0         , "t=1.49m",_
 2196, 59, 132, 1,5,         1,-75200       , 0.03      , "t=1s",_
 2197, 60, 132, 0,0,         1,-71426       , 0         , "t=1.56m",_
 2198, 61, 132, 0,3,         1,-61630       , 0         , "t=6.2s",_
 2199, 62, 132, 0,0,         1,-55140       , 0         , "t=4.0s",_
 2200, 63, 132, 0,1,         1,-42200       , 0         , "t=100ms",_
 2201, 47, 133, 0,4.5,       1,-29080       , 0         , "t=?",_
 2202, 48, 133, 0,3.5,      -1,-44140       , 0         , "t=61ms",_
 2203, 49, 133, 0,4.5,       1,-57690       , 0         , "t=163.0ms",_
 2204, 49, 133, 1,0.5,      -1,-57360       , 0.33      , "t=167ms",_
 2205, 50, 133, 0,3.5,      -1,-70873.9     , 0         , "t=1.37s",_
 2206, 51, 133, 0,3.5,       1,-78924       , 0         , "t=2.34m",_
 2207, 51, 133, 1,10.5,      1,-74383       , 4.541     , "t=16.54us",_
 2208, 52, 133, 0,1.5,       1,-82937.1     , 0         , "t=12.5m",_
 2209, 52, 133, 1,5.5,      -1,-82602.8     , 0.33426   , "t=55.4m",_
 2210, 53, 133, 0,3.5,       1,-85857       , 0         , "t=20.83h",_
 2211, 53, 133, 1,9.5,      -1,-84223       , 1.634148  , "t=9s",_
 2212, 54, 133, 0,1.5,       1,-87643.6     , 0         , "t=5.2474d",_
 2213, 54, 133, 1,5.5,      -1,-87410.4     , 0.233221  , "t=2.198d",_
 2214, 55, 133, 0,3.5,       1,-88070.943   , 0         , "t=stbl",_
 2215, 56, 133, 0,0.5,       1,-87553.5     , 0         , "t=10.5379y",_
 2216, 56, 133, 1,5.5,      -1,-87265.2     , 0.288252  , "t=38.90h",_
 2217, 57, 133, 0,2.5,       1,-85494       , 0         , "t=3.912h",_
 2218, 58, 133, 0,0.5,       1,-82418       , 0         , "t=97m",_
 2219, 58, 133, 1,4.5,      -1,-82381       , 0.0372    , "t=5.1h",_
 2220, 59, 133, 0,2.5,       1,-77938       , 0         , "t=6.5m",_
 2221, 59, 133, 1,5.5,      -1,-77746       , 0.19212   , "t=1.1s",_
 2222, 60, 133, 0,3.5,       1,-72330       , 0         , "t=70s",_
 2223, 60, 133, 1,0.5,       1,-72200       , 0.12797   , "t=~70s",_
 2224, 61, 133, 0,1.5,       1,-65410       , 0         , "t=13.5s",_
 2225, 61, 133, 1,5.5,      -1,-65280       , 0.1297    , "t=8s",_
 2226, 62, 133, 0,2.5,       1,-57230       , 0         , "t=2.89s",_
 2227, 62, 133, 1,0.5,      -1,-57110       , 0.12      , "t=3.5s",_
 2228, 63, 133, 0,2.5,       1,-47240       , 0         , "t=200ms",_
 2229, 64, 133, 0,2.5,       1,-36060       , 0         , "t=10ms",_
 2230, 48, 134, 0,0,         1,-39460       , 0         , "t=65ms",_
 2231, 49, 134, 0,7,        -1,-51970       , 0         , "t=136ms",_
 2232, 49, 134, 1,5,        -1,-51910       , 0.0567    , "t=3.5us",_
 2233, 50, 134, 0,0,         1,-66434       , 0         , "t=0.93s",_
 2234, 50, 134, 1,6,         1,-65187       , 1.2474    , "t=87ns",_
 2235, 51, 134, 0,0,        -1,-74019       , 0         , "t=674ms",_
 2236, 51, 134, 1,7,        -1,-73740       , 0.279     , "t=10.01s",_
 2237, 52, 134, 0,0,         1,-82533.8     , 0         , "t=41.8m",_
 2238, 52, 134, 1,6,         1,-80842.5     , 1.69134   , "t=164.5ns",_
 2239, 53, 134, 0,4,         1,-84043       , 0         , "t=52.5m",_
 2240, 53, 134, 1,8,        -1,-83727       , 0.31649   , "t=3.52m",_
 2241, 54, 134, 0,0,         1,-88125.834   , 0         , "t=stbl",_
 2242, 54, 134, 1,7,        -1,-86160.3     , 1.9655    , "t=290ms",_
 2243, 55, 134, 0,4,         1,-86891.165   , 0         , "t=2.0650y",_
 2244, 55, 134, 1,8,        -1,-86752.421   , 0.1387441 , "t=2.912h",_
 2245, 56, 134, 0,0,         1,-88950.00    , 0         , "t=stbl",_
 2246, 56, 134, 1,10,        1,-85992.8     , 2.9572    , "t=2.61us",_
 2247, 57, 134, 0,1,         1,-85219       , 0         , "t=6.45m",_
 2248, 57, 134, 1,6,        -1,-84780       , 0.44      , "t=29us",_
 2249, 58, 134, 0,0,         1,-84833       , 0         , "t=3.16d",_
 2250, 58, 134, 1,10,        1,-81624       , 3.2086    , "t=308ns",_
 2251, 59, 134, 0,2,        -1,-78528       , 0         , "t=17m",_
 2252, 59, 134, 1,6,        -1,-78460       , 0.0677    , "t=~11m",_
 2253, 60, 134, 0,0,         1,-75646       , 0         , "t=8.5m",_
 2254, 60, 134, 1,8,        -1,-73353       , 2.293     , "t=389us",_
 2255, 61, 134, 0,5,         1,-66760       , 0         , "t=22s",_
 2256, 61, 134, 1,2,         1,-66710       , 0.05      , "t=~5s",_
 2257, 62, 134, 0,0,         1,-61380       , 0         , "t=9.5s",_
 2258, 63, 134, 0,-77.777,   0,-49800       , 0         , "t=500ms",_
 2259, 64, 134, 0,0,         1,-41530       , 0         , "t=400ms",_
 2260, 48, 135, 0,2.5,      -1,-32820       , 0         , "t=?",_
 2261, 49, 135, 0,4.5,       1,-47110       , 0         , "t=103ms",_
 2262, 50, 135, 0,3.5,      -1,-60632       , 0         , "t=515ms",_
 2263, 51, 135, 0,3.5,       1,-69690.3     , 0         , "t=1.668s",_
 2264, 52, 135, 0,3.5,      -1,-77728.8     , 0         , "t=19.0s",_
 2265, 52, 135, 1,9.5,      -1,-76173.9     , 1.55489   , "t=511ns",_
 2266, 53, 135, 0,3.5,       1,-83779.2     , 0         , "t=6.58h",_
 2267, 54, 135, 0,1.5,       1,-86413       , 0         , "t=9.14h",_
 2268, 54, 135, 1,5.5,      -1,-85886       , 0.526551  , "t=15.29m",_
 2269, 55, 135, 0,3.5,       1,-87582.0     , 0         , "t=1.33My",_
 2270, 55, 135, 1,9.5,      -1,-85949.1     , 1.6329    , "t=53m",_
 2271, 56, 135, 0,1.5,       1,-87850.65    , 0         , "t=stbl",_
 2272, 56, 135, 1,5.5,      -1,-87582.43    , 0.268218  , "t=28.11h",_
 2273, 57, 135, 0,2.5,       1,-86643       , 0         , "t=18.91h",_
 2274, 58, 135, 0,0.5,       1,-84616       , 0         , "t=17.7h",_
 2275, 58, 135, 1,5.5,      -1,-84170       , 0.44581   , "t=20s",_
 2276, 59, 135, 0,1.5,       1,-80936       , 0         , "t=24m",_
 2277, 59, 135, 1,5.5,      -1,-80578       , 0.35806   , "t=105us",_
 2278, 60, 135, 0,4.5,      -1,-76214       , 0         , "t=12.4m",_
 2279, 60, 135, 1,0.5,       1,-76149       , 0.06495   , "t=5.5m",_
 2280, 61, 135, 0,1.5,       1,-70060       , 0         , "t=49s",_
 2281, 61, 135, 1,5.5,      -1,-69830       , 0.24      , "t=40s",_
 2282, 62, 135, 0,3.5,       1,-62860       , 0         , "t=10.3s",_
 2283, 63, 135, 0,2.5,       1,-54150       , 0         , "t=1.5s",_
 2284, 64, 135, 0,2.5,       1,-44250       , 0         , "t=1.1s",_
 2285, 65, 135, 0,3.5,      -1,-33050       , 0         , "t=1.01ms",_
 2286, 49, 136, 0,7,        -1,-40970       , 0         , "t=86ms",_
 2287, 50, 136, 0,0,         1,-56170       , 0         , "t=355ms",_
 2288, 51, 136, 0,1,        -1,-64507       , 0         , "t=923ms",_
 2289, 51, 136, 1,6,        -1,-64238       , 0.2693    , "t=570ns",_
 2290, 52, 136, 0,0,         1,-74425.3     , 0         , "t=17.63s",_
 2291, 53, 136, 0,1,        -1,-79545       , 0         , "t=83.4s",_
 2292, 53, 136, 1,6,        -1,-79339       , 0.206     , "t=46.6s",_
 2293, 54, 136, 0,0,         1,-86429.170   , 0         , "t=2.18Zy",_
 2294, 54, 136, 1,6,         1,-84537.43    , 1.89174   , "t=2.92us",_
 2295, 55, 136, 0,5,         1,-86338.9     , 0         , "t=13.01d",_
 2296, 55, 136, 1,8,        -1,-85821.0     , 0.5179    , "t=17.5s",_
 2297, 56, 136, 0,0,         1,-88887.08    , 0         , "t=stbl",_
 2298, 56, 136, 1,7,        -1,-86856.55    , 2.030535  , "t=308.4ms",_
 2299, 57, 136, 0,1,         1,-86040       , 0         , "t=9.87m",_
 2300, 57, 136, 1,7,        -1,-85780       , 0.2595    , "t=114ms",_
 2301, 58, 136, 0,0,         1,-86508.5     , 0         , "t=stbl",_
 2302, 58, 136, 1,10,        1,-83413.5     , 3.095     , "t=1.96us",_
 2303, 59, 136, 0,2,         1,-81340       , 0         , "t=13.1m",_
 2304, 60, 136, 0,0,         1,-79199       , 0         , "t=50.65m",_
 2305, 61, 136, 0,7,         1,-71170       , 0         , "t=107s",_
 2306, 61, 136, 1,2,         1,-71070       , 0.1       , "t=90s",_
 2307, 62, 136, 0,0,         1,-66811       , 0         , "t=47s",_
 2308, 62, 136, 1,8,        -1,-64546       , 2.2647    , "t=15us",_
 2309, 63, 136, 0,6,         1,-56240       , 0         , "t=3.3s",_
 2310, 63, 136, 1,1,         1,-56140       , 0.1       , "t=3.8s",_
 2311, 64, 136, 0,0,         1,-49090       , 0         , "t=1s",_
 2312, 65, 136, 0,5,        -1,-35900       , 0         , "t=200ms",_
 2313, 49, 137, 0,4.5,       1,-35830       , 0         , "t=70ms",_
 2314, 50, 137, 0,2.5,      -1,-50150       , 0         , "t=249ms",_
 2315, 51, 137, 0,3.5,       1,-60060       , 0         , "t=497ms",_
 2316, 52, 137, 0,1.5,      -1,-69303.8     , 0         , "t=2.49s",_
 2317, 53, 137, 0,3.5,       1,-76356       , 0         , "t=24.13s",_
 2318, 54, 137, 0,3.5,      -1,-82383.41    , 0         , "t=3.818m",_
 2319, 55, 137, 0,3.5,       1,-86545.8     , 0         , "t=30.04y",_
 2320, 56, 137, 0,1.5,       1,-87721.40    , 0         , "t=stbl",_
 2321, 56, 137, 1,5.5,      -1,-87059.74    , 0.661659  , "t=2.552m",_
 2322, 57, 137, 0,3.5,       1,-87140.9     , 0         , "t=60ky",_
 2323, 57, 137, 1,9.5,      -1,-85271.4     , 1.8695    , "t=342ns",_
 2324, 58, 137, 0,1.5,       1,-85918.8     , 0         , "t=9.0h",_
 2325, 58, 137, 1,5.5,      -1,-85664.5     , 0.25429   , "t=34.4h",_
 2326, 59, 137, 0,2.5,       1,-83202       , 0         , "t=1.28h",_
 2327, 59, 137, 1,5.5,      -1,-82641       , 0.56122   , "t=2.66us",_
 2328, 60, 137, 0,0.5,       1,-79584       , 0         , "t=38.5m",_
 2329, 60, 137, 1,5.5,      -1,-79065       , 0.51943   , "t=1.60s",_
 2330, 61, 137, 0,2.5,      -1,-74073       , 0         , "t=2m",_
 2331, 61, 137, 1,5.5,      -1,-73910       , 0.16      , "t=2.4m",_
 2332, 62, 137, 0,4.5,      -1,-67992       , 0         , "t=45s",_
 2333, 62, 137, 1,0.5,       1,-67890       , 0.1       , "t=20s",_
 2334, 63, 137, 0,2.5,       1,-60146       , 0         , "t=8.4s",_
 2335, 64, 137, 0,3.5,       1,-51210       , 0         , "t=2.2s",_
 2336, 65, 137, 0,1.5,       1,-40970       , 0         , "t=600ms",_
 2337, 50, 138, 0,0,         1,-45510       , 0         , "t=148ms",_
 2338, 50, 138, 1,6,         1,-44170       , 1.344     , "t=210ns",_
 2339, 51, 138, 0,3,        -1,-54650       , 0         , "t=333ms",_
 2340, 52, 138, 0,0,         1,-65696       , 0         , "t=1.46s",_
 2341, 53, 138, 0,1,        -1,-71980       , 0         , "t=6.26s",_
 2342, 53, 138, 1,3,        -1,-71912       , 0.0679    , "t=1.26us",_
 2343, 54, 138, 0,0,         1,-79972.2     , 0         , "t=14.14m",_
 2344, 55, 138, 0,3,        -1,-82887       , 0         , "t=33.5m",_
 2345, 55, 138, 1,6,        -1,-82807       , 0.0799    , "t=2.91m",_
 2346, 56, 138, 0,0,         1,-88261.81    , 0         , "t=stbl",_
 2347, 56, 138, 1,6,         1,-86171.27    , 2.090536  , "t=850ns",_
 2348, 57, 138, 0,5,         1,-86513.4     , 0         , "t=103Gy",_
 2349, 57, 138, 1,3,         1,-86440.8     , 0.07257   , "t=116ns",_
 2350, 58, 138, 0,0,         1,-87565.9     , 0         , "t=stbl",_
 2351, 58, 138, 1,7,        -1,-85436.6     , 2.12928   , "t=8.73ms",_
 2352, 59, 138, 0,1,         1,-83129       , 0         , "t=1.45m",_
 2353, 59, 138, 1,7,        -1,-82779       , 0.35      , "t=2.12h",_
 2354, 60, 138, 0,0,         1,-82017       , 0         , "t=5.04h",_
 2355, 60, 138, 1,10,        1,-78843       , 3.1745    , "t=370ns",_
 2356, 61, 138, 0,3,        -1,-74914       , 0         , "t=3.24m",_
 2357, 62, 138, 0,0,         1,-71498       , 0         , "t=3.1m",_
 2358, 63, 138, 0,2,        -1,-61750       , 0         , "t=5s",_
 2359, 63, 138, 1,7,        -1,-61650       , 0.1       , "t=12.1s",_
 2360, 64, 138, 0,0,         1,-55660       , 0         , "t=4.7s",_
 2361, 64, 138, 1,8,        -1,-53430       , 2.2326    , "t=6.2us",_
 2362, 65, 138, 0,2,         1,-43600       , 0         , "t=800ms",_
 2363, 66, 138, 0,0,         1,-34930       , 0         , "t=200ms",_
 2364, 50, 139, 0,2.5,      -1,-39310       , 0         , "t=120ms",_
 2365, 51, 139, 0,3.5,       1,-50050       , 0         , "t=182ms",_
 2366, 52, 139, 0,2.5,      -1,-60205       , 0         , "t=724ms",_
 2367, 53, 139, 0,3.5,       1,-68471       , 0         , "t=2.280s",_
 2368, 54, 139, 0,1.5,      -1,-75644.6     , 0         , "t=39.68s",_
 2369, 55, 139, 0,3.5,       1,-80701       , 0         , "t=9.27m",_
 2370, 56, 139, 0,3.5,      -1,-84913.92    , 0         , "t=82.93m",_
 2371, 57, 139, 0,3.5,       1,-87222.4     , 0         , "t=stbl",_
 2372, 57, 139, 1,8.5,       1,-85422.0     , 1.8004    , "t=315ns",_
 2373, 58, 139, 0,1.5,       1,-86957.7     , 0         , "t=137.642d",_
 2374, 58, 139, 1,5.5,      -1,-86203.5     , 0.75424   , "t=57.58s",_
 2375, 59, 139, 0,2.5,       1,-84829       , 0         , "t=4.41h",_
 2376, 60, 139, 0,1.5,       1,-82017       , 0         , "t=29.7m",_
 2377, 60, 139, 1,5.5,      -1,-81786       , 0.23116   , "t=5.50h",_
 2378, 61, 139, 0,2.5,       1,-77501       , 0         , "t=4.15m",_
 2379, 61, 139, 1,5.5,      -1,-77312       , 0.1887    , "t=180ms",_
 2380, 62, 139, 0,0.5,       1,-72380       , 0         , "t=2.57m",_
 2381, 62, 139, 1,5.5,      -1,-71923       , 0.45738   , "t=10.7s",_
 2382, 63, 139, 0,5.5,      -1,-65398       , 0         , "t=17.9s",_
 2383, 63, 139, 1,3.5,       1,-65250       , 0.1483    , "t=10us",_
 2384, 64, 139, 0,4.5,      -1,-57630       , 0         , "t=5.7s",_
 2385, 64, 139, 1,0.5,       1,-57380       , 0.25      , "t=4.8s",_
 2386, 65, 139, 0,2.5,      -1,-48130       , 0         , "t=1.6s",_
 2387, 66, 139, 0,3.5,       1,-37700       , 0         , "t=600ms",_
 2388, 50, 140, 0,0,         1,-34490       , 0         , "t=50ms",_
 2389, 51, 140, 0,3,        -1,-44390       , 0         , "t=170ms",_
 2390, 51, 140, 1,6,        -1,-44060       , 0.33      , "t=41us",_
 2391, 52, 140, 0,0,         1,-56367       , 0         , "t=351ms",_
 2392, 53, 140, 0,2,        -1,-63606       , 0         , "t=588ms",_
 2393, 54, 140, 0,0,         1,-72986.5     , 0         , "t=13.60s",_
 2394, 55, 140, 0,1,        -1,-77050       , 0         , "t=63.7s",_
 2395, 55, 140, 1,2,        -1,-77036       , 0.013931  , "t=471ns",_
 2396, 56, 140, 0,0,         1,-83268       , 0         , "t=12.7534d",_
 2397, 57, 140, 0,3,        -1,-84312.1     , 0         , "t=40.289h",_
 2398, 58, 140, 0,0,         1,-88074.2     , 0         , "t=stbl",_
 2399, 58, 140, 1,6,         1,-85966.3     , 2.107854  , "t=7.3us",_
 2400, 59, 140, 0,1,         1,-84686       , 0         , "t=3.39m",_
 2401, 59, 140, 1,5,         1,-84558       , 0.1278    , "t=350ns",_
 2402, 60, 140, 0,0,         1,-84257       , 0         , "t=3.37d",_
 2403, 60, 140, 1,7,        -1,-82035       , 2.22165   , "t=600us",_
 2404, 61, 140, 0,1,         1,-78212       , 0         , "t=9.2s",_
 2405, 61, 140, 1,8,        -1,-77783       , 0.429     , "t=5.95m",_
 2406, 62, 140, 0,0,         1,-75456       , 0         , "t=14.82m",_
 2407, 63, 140, 0,1,         1,-66990       , 0         , "t=1.51s",_
 2408, 63, 140, 1,5,        -1,-66780       , 0.21      , "t=125ms",_
 2409, 64, 140, 0,0,         1,-61782       , 0         , "t=15.8s",_
 2410, 65, 140, 0,7,         1,-50480       , 0         , "t=2.29s",_
 2411, 66, 140, 0,0,         1,-42830       , 0         , "t=700ms",_
 2412, 66, 140, 1,8,        -1,-40660       , 2.1661    , "t=7.0us",_
 2413, 67, 140, 0,8,         1,-29320       , 0         , "t=6ms",_
 2414, 51, 141, 0,3.5,       1,-39540       , 0         , "t=103ms",_
 2415, 52, 141, 0,2.5,      -1,-50670       , 0         , "t=193ms",_
 2416, 53, 141, 0,3.5,       1,-59927       , 0         , "t=420ms",_
 2417, 54, 141, 0,2.5,      -1,-68197.3     , 0         , "t=1.73s",_
 2418, 55, 141, 0,3.5,       1,-74477       , 0         , "t=24.84s",_
 2419, 56, 141, 0,1.5,      -1,-79732       , 0         , "t=18.27m",_
 2420, 57, 141, 0,3.5,       1,-82930       , 0         , "t=3.92h",_
 2421, 58, 141, 0,3.5,      -1,-85431.1     , 0         , "t=32.505d",_
 2422, 59, 141, 0,2.5,       1,-86014.5     , 0         , "t=stbl",_
 2423, 60, 141, 0,1.5,       1,-84192       , 0         , "t=2.49h",_
 2424, 60, 141, 1,5.5,      -1,-83435       , 0.75651   , "t=62.0s",_
 2425, 61, 141, 0,2.5,       1,-80523       , 0         , "t=20.90m",_
 2426, 61, 141, 1,5.5,      -1,-79894       , 0.62862   , "t=630ns",_
 2427, 62, 141, 0,0.5,       1,-75934       , 0         , "t=10.2m",_
 2428, 62, 141, 1,5.5,      -1,-75758       , 0.1759    , "t=22.6m",_
 2429, 63, 141, 0,2.5,       1,-69926       , 0         , "t=40.7s",_
 2430, 63, 141, 1,5.5,      -1,-69830       , 0.09645   , "t=2.7s",_
 2431, 64, 141, 0,0.5,       1,-63224       , 0         , "t=14s",_
 2432, 64, 141, 1,5.5,      -1,-62846       , 0.37776   , "t=24.5s",_
 2433, 65, 141, 0,2.5,      -1,-54540       , 0         , "t=3.5s",_
 2434, 65, 141, 1,5.5,      -1,-54540       , 0         , "t=7.9s",_
 2435, 66, 141, 0,4.5,      -1,-45380       , 0         , "t=900ms",_
 2436, 67, 141, 0,3.5,      -1,-34360       , 0         , "t=4.1ms",_
 2437, 67, 141, 1,0.5,       1,-34290       , 0.066     , "t=7.3us",_
 2438, 51, 142, 0,-77.777,   0,-33610       , 0         , "t=80ms",_
 2439, 52, 142, 0,0,         1,-46550       , 0         , "t=147ms",_
 2440, 53, 142, 0,2,        -1,-54803       , 0         , "t=235ms",_
 2441, 54, 142, 0,0,         1,-65229.6     , 0         , "t=1.23s",_
 2442, 55, 142, 0,0,        -1,-70515       , 0         , "t=1.687s",_
 2443, 56, 142, 0,0,         1,-77842       , 0         , "t=10.6m",_
 2444, 57, 142, 0,2,        -1,-80024       , 0         , "t=91.1m",_
 2445, 57, 142, 1,4,        -1,-79878       , 0.14582   , "t=870ns",_
 2446, 58, 142, 0,0,         1,-84532.9     , 0         , "t=stbl",_
 2447, 59, 142, 0,2,        -1,-83786.4     , 0         , "t=19.12h",_
 2448, 59, 142, 1,5,        -1,-83782.7     , 0.003694  , "t=14.6m",_
 2449, 60, 142, 0,0,         1,-85950.1     , 0         , "t=stbl",_
 2450, 61, 142, 0,1,         1,-81142       , 0         , "t=40.5s",_
 2451, 61, 142, 1,8,        -1,-80259       , 0.88317   , "t=2.0ms",_
 2452, 62, 142, 0,0,         1,-78981.9     , 0         , "t=72.49m",_
 2453, 62, 142, 1,7,        -1,-76609.8     , 2.3721    , "t=170ns",_
 2454, 63, 142, 0,1,         1,-71310       , 0         , "t=2.36s",_
 2455, 63, 142, 1,8,        -1,-70856       , 0.45      , "t=1.223m",_
 2456, 64, 142, 0,0,         1,-66960       , 0         , "t=70.2s",_
 2457, 65, 142, 0,1,         1,-56560       , 0         , "t=597ms",_
 2458, 65, 142, 1,5,        -1,-56280       , 0.2797    , "t=303ms",_
 2459, 66, 142, 0,0,         1,-50120       , 0         , "t=2.3s",_
 2460, 67, 142, 0,7,        -1,-37250       , 0         , "t=400ms",_
 2461, 68, 142, 0,0,         1,-27930       , 0         , "t=10us",_
 2462, 52, 143, 0,3.5,       1,-40530       , 0         , "t=120ms",_
 2463, 53, 143, 0,3.5,       1,-50790       , 0         , "t=182ms",_
 2464, 54, 143, 0,2.5,      -1,-60203       , 0         , "t=511ms",_
 2465, 55, 143, 0,1.5,       1,-67676       , 0         , "t=1.802s",_
 2466, 56, 143, 0,2.5,      -1,-73937       , 0         , "t=14.5s",_
 2467, 57, 143, 0,3.5,       1,-78171       , 0         , "t=14.2m",_
 2468, 58, 143, 0,1.5,      -1,-81606.4     , 0         , "t=33.039h",_
 2469, 59, 143, 0,3.5,       1,-83068.2     , 0         , "t=13.57d",_
 2470, 60, 143, 0,3.5,      -1,-84002.3     , 0         , "t=stbl",_
 2471, 61, 143, 0,2.5,       1,-82960.7     , 0         , "t=265d",_
 2472, 62, 143, 0,1.5,       1,-79517.1     , 0         , "t=8.75m",_
 2473, 62, 143, 1,5.5,      -1,-78763.1     , 0.75399   , "t=66s",_
 2474, 63, 143, 0,2.5,       1,-74241       , 0         , "t=2.59m",_
 2475, 63, 143, 1,5.5,      -1,-73851       , 0.38951   , "t=50.0us",_
 2476, 64, 143, 0,0.5,       1,-68230       , 0         , "t=39s",_
 2477, 64, 143, 1,5.5,      -1,-68080       , 0.1526    , "t=110.0s",_
 2478, 65, 143, 0,5.5,      -1,-60420       , 0         , "t=12s",_
 2479, 65, 143, 1,2.5,       1,-60420       , 0         , "t=17s",_
 2480, 66, 143, 0,0.5,       1,-52169       , 0         , "t=5.6s",_
 2481, 66, 143, 1,5.5,      -1,-51858       , 0.3107    , "t=3.0s",_
 2482, 67, 143, 0,5.5,      -1,-42050       , 0         , "t=300ms",_
 2483, 68, 143, 0,4.5,      -1,-31160       , 0         , "t=200ms",_
 2484, 52, 144, 0,0,         1,-36220       , 0         , "t=93ms",_
 2485, 53, 144, 0,1,        -1,-45330       , 0         , "t=94ms",_
 2486, 54, 144, 0,0,         1,-56872       , 0         , "t=388ms",_
 2487, 55, 144, 0,1,        -1,-63271       , 0         , "t=994ms",_
 2488, 55, 144, 1,4,        -1,-63179       , 0.0922    , "t=1.1us",_
 2489, 56, 144, 0,0,         1,-71767       , 0         , "t=11.73s",_
 2490, 57, 144, 0,3,        -1,-74850       , 0         , "t=44.0s",_
 2491, 58, 144, 0,0,         1,-80431.9     , 0         , "t=284.886d",_
 2492, 59, 144, 0,0,        -1,-80750.6     , 0         , "t=17.28m",_
 2493, 59, 144, 1,3,        -1,-80691.6     , 0.05903   , "t=7.2m",_
 2494, 60, 144, 0,0,         1,-83748.0     , 0         , "t=2.29Py",_
 2495, 61, 144, 0,5,        -1,-81416.1     , 0         , "t=363d",_
 2496, 61, 144, 1,9,         1,-80575.2     , 0.8409    , "t=780ns",_
 2497, 62, 144, 0,0,         1,-81965.6     , 0         , "t=stbl",_
 2498, 62, 144, 1,6,         1,-79642.0     , 2.3236    , "t=880ns",_
 2499, 63, 144, 0,1,         1,-75619       , 0         , "t=10.2s",_
 2500, 63, 144, 1,8,        -1,-74491       , 1.1276    , "t=1.0us",_
 2501, 64, 144, 0,0,         1,-71760       , 0         , "t=4.47m",_
 2502, 64, 144, 1,10,        1,-68327       , 3.4331    , "t=145ns",_
 2503, 65, 144, 0,1,         1,-62368       , 0         , "t=~1s",_
 2504, 65, 144, 1,6,        -1,-61971       , 0.3969    , "t=4.25s",_
 2505, 66, 144, 0,0,         1,-56570       , 0         , "t=9.1s",_
 2506, 67, 144, 0,5,        -1,-44610       , 0         , "t=700ms",_
 2507, 67, 144, 1,8,         1,-44345       , 0.2653    , "t=519ns",_
 2508, 68, 144, 0,0,         1,-36610       , 0         , "t=400ms",_
 2509, 69, 144, 0,10,        1,-22160       , 0         , "t=2.3us",_
 2510, 52, 145, 0,0,         1,-30010       , 0         , "t=75ms",_
 2511, 53, 145, 0,3.5,       1,-41130       , 0         , "t=89.7ms",_
 2512, 54, 145, 0,1.5,      -1,-51493       , 0         , "t=188ms",_
 2513, 55, 145, 0,1.5,       1,-60054       , 0         , "t=582ms",_
 2514, 55, 145, 1,6.5,       0,-59291       , 0.7629    , "t=500ns",_
 2515, 56, 145, 0,2.5,      -1,-67516       , 0         , "t=4.31s",_
 2516, 57, 145, 0,2.5,       1,-72835       , 0         , "t=24.8s",_
 2517, 58, 145, 0,2.5,      -1,-77070       , 0         , "t=3.01m",_
 2518, 59, 145, 0,3.5,       1,-79626       , 0         , "t=5.984h",_
 2519, 60, 145, 0,3.5,      -1,-81432.0     , 0         , "t=stbl",_
 2520, 61, 145, 0,2.5,       1,-81267.5     , 0         , "t=17.7y",_
 2521, 62, 145, 0,3.5,      -1,-80651.4     , 0         , "t=340d",_
 2522, 62, 145, 1,24.5,      1,-71836.4     , 8.815     , "t=3.52us",_
 2523, 63, 145, 0,2.5,       1,-77992       , 0         , "t=5.93d",_
 2524, 63, 145, 1,5.5,      -1,-77276       , 0.716     , "t=490ns",_
 2525, 64, 145, 0,0.5,       1,-72927       , 0         , "t=23.0m",_
 2526, 64, 145, 1,5.5,      -1,-72178       , 0.7491    , "t=85s",_
 2527, 65, 145, 0,5.5,      -1,-66400       , 0         , "t=30.9s",_
 2528, 65, 145, 1,1.5,       1,-65540       , 0.86      , "t=?",_
 2529, 66, 145, 0,0.5,       1,-58243       , 0         , "t=9.5s",_
 2530, 66, 145, 1,5.5,      -1,-58125       , 0.1182    , "t=14.1s",_
 2531, 67, 145, 0,5.5,      -1,-49120       , 0         , "t=2.4s",_
 2532, 67, 145, 1,2.5,       1,-49020       , 0.1       , "t=100ms",_
 2533, 68, 145, 0,0.5,       1,-39240       , 0         , "t=900ms",_
 2534, 68, 145, 1,5.5,      -1,-39040       , 0.205     , "t=1.0s",_
 2535, 69, 145, 0,5.5,      -1,-27580       , 0         , "t=3.17us",_
 2536, 53, 146, 0,-77.777,   0,-35540       , 0         , "t=94ms",_
 2537, 54, 146, 0,0,         1,-47955       , 0         , "t=146ms",_
 2538, 55, 146, 0,1,        -1,-55310.4     , 0         , "t=321.6ms",_
 2539, 55, 146, 1,4,        -1,-55263.7     , 0.0467    , "t=1.25us",_
 2540, 56, 146, 0,0,         1,-64866.3     , 0         , "t=2.15s",_
 2541, 57, 146, 0,5,        -1,-69221.2     , 0         , "t=9.9s",_
 2542, 57, 146, 1,1,        -1,-69079.7     , 0.1415    , "t=6.08s",_
 2543, 58, 146, 0,0,         1,-75626       , 0         , "t=13.49m",_
 2544, 59, 146, 0,2,        -1,-76670       , 0         , "t=24.09m",_
 2545, 60, 146, 0,0,         1,-80925.9     , 0         , "t=stbl",_
 2546, 61, 146, 0,3,        -1,-79454       , 0         , "t=5.53y",_
 2547, 62, 146, 0,0,         1,-80996       , 0         , "t=68My",_
 2548, 63, 146, 0,4,        -1,-77118       , 0         , "t=4.61d",_
 2549, 63, 146, 1,9,         1,-76452       , 0.66633   , "t=235us",_
 2550, 64, 146, 0,0,         1,-76086       , 0         , "t=48.27d",_
 2551, 65, 146, 0,1,         1,-67760       , 0         , "t=8s",_
 2552, 65, 146, 1,5,        -1,-67610       , 0.15      , "t=24.1s",_
 2553, 66, 146, 0,0,         1,-62555       , 0         , "t=33.2s",_
 2554, 66, 146, 1,10,        1,-59621       , 2.9345    , "t=150ms",_
 2555, 67, 146, 0,6,        -1,-51238       , 0         , "t=3.32s",_
 2556, 68, 146, 0,0,         1,-44322       , 0         , "t=1.7s",_
 2557, 69, 146, 0,1,         1,-31060       , 0         , "t=155ms",_
 2558, 69, 146, 1,5,        -1,-30750       , 0.304     , "t=73ms",_
 2559, 53, 147, 0,1.5,      -1,-31200       , 0         , "t=60ms",_
 2560, 54, 147, 0,1.5,      -1,-42400       , 0         , "t=88ms",_
 2561, 55, 147, 0,1.5,       1,-51920       , 0         , "t=230.5ms",_
 2562, 55, 147, 1,6.5,       0,-51219       , 0.7014    , "t=190ns",_
 2563, 56, 147, 0,2.5,      -1,-60264       , 0         , "t=893ms",_
 2564, 57, 147, 0,2.5,       1,-66678       , 0         , "t=4.026s",_
 2565, 58, 147, 0,2.5,      -1,-72014       , 0         , "t=56.4s",_
 2566, 59, 147, 0,1.5,       1,-75444       , 0         , "t=13.39m",_
 2567, 60, 147, 0,2.5,      -1,-78146.8     , 0         , "t=10.98d",_
 2568, 61, 147, 0,3.5,       1,-79042.0     , 0         , "t=2.6234y",_
 2569, 62, 147, 0,3.5,      -1,-79266.0     , 0         , "t=106.6Gy",_
 2570, 63, 147, 0,2.5,       1,-77544.6     , 0         , "t=24.1d",_
 2571, 63, 147, 1,5.5,      -1,-76919.3     , 0.62527   , "t=765ns",_
 2572, 64, 147, 0,3.5,      -1,-75356.9     , 0         , "t=38.06h",_
 2573, 64, 147, 1,24.5,      1,-66769.1     , 8.5878    , "t=510ns",_
 2574, 65, 147, 0,0.5,       1,-70743       , 0         , "t=1.64h",_
 2575, 65, 147, 1,5.5,      -1,-70692       , 0.0506    , "t=1.87m",_
 2576, 66, 147, 0,0.5,       1,-64196       , 0         , "t=67s",_
 2577, 66, 147, 1,5.5,      -1,-63446       , 0.7505    , "t=55.2s",_
 2578, 67, 147, 0,5.5,      -1,-55757       , 0         , "t=5.8s",_
 2579, 67, 147, 1,13.5,     -1,-53070       , 2.6871    , "t=315ns",_
 2580, 68, 147, 0,0.5,       1,-46610       , 0         , "t=3.2s",_
 2581, 68, 147, 1,5.5,      -1,-46510       , 0.1       , "t=1.6s",_
 2582, 69, 147, 0,5.5,      -1,-35974       , 0         , "t=580ms",_
 2583, 69, 147, 1,1.5,       1,-35913       , 0.062     , "t=360us",_
 2584, 54, 148, 0,0,         1,-38650       , 0         , "t=85ms",_
 2585, 55, 148, 0,2,        -1,-46911       , 0         , "t=151.8ms",_
 2586, 55, 148, 1,4,        -1,-46866       , 0.0452    , "t=4.8us",_
 2587, 56, 148, 0,0,         1,-57544.9     , 0         , "t=620ms",_
 2588, 57, 148, 0,2,        -1,-62709       , 0         , "t=1.414s",_
 2589, 58, 148, 0,0,         1,-70398       , 0         , "t=56.8s",_
 2590, 59, 148, 0,1,        -1,-72535       , 0         , "t=2.29m",_
 2591, 59, 148, 1,4,         0,-72458       , 0.0768    , "t=2.01m",_
 2592, 60, 148, 0,0,         1,-77408.1     , 0         , "t=stbl",_
 2593, 61, 148, 0,1,        -1,-76866       , 0         , "t=5.368d",_
 2594, 61, 148, 1,5,        -1,-76728       , 0.1379    , "t=41.29d",_
 2595, 62, 148, 0,0,         1,-79336.1     , 0         , "t=6.3Py",_
 2596, 63, 148, 0,5,        -1,-76297       , 0         , "t=54.5d",_
 2597, 63, 148, 1,9,         1,-75577       , 0.7204    , "t=162ns",_
 2598, 64, 148, 0,0,         1,-76269.4     , 0         , "t=71.3y",_
 2599, 65, 148, 0,2,        -1,-70537       , 0         , "t=60m",_
 2600, 65, 148, 1,9,         1,-70447       , 0.0901    , "t=2.20m",_
 2601, 66, 148, 0,0,         1,-67859       , 0         , "t=3.3m",_
 2602, 66, 148, 1,10,        1,-64940       , 2.9191    , "t=471ns",_
 2603, 67, 148, 0,1,         1,-57990       , 0         , "t=2.2s",_
 2604, 67, 148, 1,5,        -1,-57740       , 0.25      , "t=9.49s",_
 2605, 68, 148, 0,0,         1,-51479       , 0         , "t=4.6s",_
 2606, 68, 148, 1,10,        1,-48566       , 2.9132    , "t=13us",_
 2607, 69, 148, 0,10,        1,-38765       , 0         , "t=700ms",_
 2608, 70, 148, 0,0,         1,-30230       , 0         , "t=250ms",_
 2609, 54, 149, 0,1.5,      -1,-33000       , 0         , "t=50ms",_
 2610, 55, 149, 0,1.5,       1,-43300       , 0         , "t=112.3ms",_
 2611, 56, 149, 0,1.5,      -1,-52830.6     , 0         , "t=349ms",_
 2612, 57, 149, 0,1.5,      -1,-60220       , 0         , "t=1.071s",_
 2613, 58, 149, 0,1.5,      -1,-66670       , 0         , "t=4.94s",_
 2614, 59, 149, 0,2.5,       1,-71039       , 0         , "t=2.26m",_
 2615, 60, 149, 0,2.5,      -1,-74375.5     , 0         , "t=1.728h",_
 2616, 61, 149, 0,3.5,       1,-76064.4     , 0         , "t=53.08h",_
 2617, 61, 149, 1,5.5,      -1,-75824.2     , 0.240214  , "t=35us",_
 2618, 62, 149, 0,3.5,      -1,-77135.9     , 0         , "t=stbl",_
 2619, 63, 149, 0,2.5,       1,-76441       , 0         , "t=93.1d",_
 2620, 63, 149, 1,5.5,      -1,-75945       , 0.496386  , "t=2.45us",_
 2621, 64, 149, 0,3.5,      -1,-75127       , 0         , "t=9.28d",_
 2622, 65, 149, 0,0.5,       1,-71489       , 0         , "t=4.118h",_
 2623, 65, 149, 1,5.5,      -1,-71453       , 0.03578   , "t=4.16m",_
 2624, 66, 149, 0,3.5,      -1,-67694       , 0         , "t=4.20m",_
 2625, 66, 149, 1,13.5,     -1,-65033       , 2.6611    , "t=490ms",_
 2626, 67, 149, 0,5.5,      -1,-61646       , 0         , "t=21.1s",_
 2627, 67, 149, 1,0.5,       1,-61597       , 0.0488    , "t=56s",_
 2628, 68, 149, 0,0.5,       1,-53742       , 0         , "t=4s",_
 2629, 68, 149, 1,5.5,      -1,-53000       , 0.7418    , "t=8.9s",_
 2630, 69, 149, 0,5.5,      -1,-43940       , 0         , "t=900ms",_
 2631, 69, 149, 1,0.5,       1,-43840       , 0.1       , "t=500ms",_
 2632, 70, 149, 0,0.5,       1,-33330       , 0         , "t=700ms",_
 2633, 54, 150, 0,0,         1,-28990       , 0         , "t=40ms",_
 2634, 55, 150, 0,2,        -1,-38170       , 0         , "t=81.0ms",_
 2635, 56, 150, 0,0,         1,-49890       , 0         , "t=258ms",_
 2636, 57, 150, 0,3,         1,-56311.1     , 0         , "t=504ms",_
 2637, 58, 150, 0,0,         1,-64847       , 0         , "t=6.05s",_
 2638, 59, 150, 0,1,        -1,-68301       , 0         , "t=6.19s",_
 2639, 60, 150, 0,0,         1,-73680.0     , 0         , "t=9.3Ey",_
 2640, 61, 150, 0,1,        -1,-73597       , 0         , "t=2.698h",_
 2641, 62, 150, 0,0,         1,-77051.3     , 0         , "t=stbl",_
 2642, 63, 150, 0,5,        -1,-74792       , 0         , "t=36.9y",_
 2643, 63, 150, 1,0,        -1,-74750       , 0.0417    , "t=12.8h",_
 2644, 64, 150, 0,0,         1,-75764       , 0         , "t=1.79My",_
 2645, 65, 150, 0,2,        -1,-71106       , 0         , "t=3.48h",_
 2646, 65, 150, 1,9,         1,-70645       , 0.461     , "t=5.8m",_
 2647, 66, 150, 0,0,         1,-69310       , 0         , "t=7.17m",_
 2648, 67, 150, 0,2,        -1,-61946       , 0         , "t=76.8s",_
 2649, 67, 150, 1,9,         1,-61950       , 0         , "t=23.3s",_
 2650, 68, 150, 0,0,         1,-57831       , 0         , "t=18.5s",_
 2651, 68, 150, 1,10,        1,-55035       , 2.7965    , "t=2.55us",_
 2652, 69, 150, 0,1,         1,-46490       , 0         , "t=3s",_
 2653, 69, 150, 1,6,        -1,-46350       , 0.14      , "t=2.20s",_
 2654, 70, 150, 0,0,         1,-38830       , 0         , "t=700ms",_
 2655, 71, 150, 0,5,        -1,-24770       , 0         , "t=45ms",_
 2656, 71, 150, 1,8,         1,-24750       , 0.022     , "t=40us",_
 2657, 55, 151, 0,1.5,       1,-34280       , 0         , "t=59ms",_
 2658, 56, 151, 0,1.5,      -1,-44940       , 0         , "t=167ms",_
 2659, 57, 151, 0,0.5,       1,-53310       , 0         , "t=465ms",_
 2660, 58, 151, 0,1.5,      -1,-61225       , 0         , "t=1.76s",_
 2661, 59, 151, 0,1.5,      -1,-66780       , 0         , "t=18.90s",_
 2662, 59, 151, 1,3.5,       1,-66745       , 0.0351    , "t=50us",_
 2663, 60, 151, 0,1.5,       1,-70943.2     , 0         , "t=12.44m",_
 2664, 61, 151, 0,2.5,       1,-73386       , 0         , "t=28.40h",_
 2665, 62, 151, 0,2.5,      -1,-74576.5     , 0         , "t=94.6y",_
 2666, 62, 151, 1,5.5,      -1,-74315.4     , 0.26113   , "t=1.4us",_
 2667, 63, 151, 0,2.5,       1,-74653.1     , 0         , "t=4.6Ey",_
 2668, 63, 151, 1,5.5,      -1,-74456.9     , 0.196245  , "t=58.9us",_
 2669, 64, 151, 0,3.5,      -1,-74188.9     , 0         , "t=123.9d",_
 2670, 65, 151, 0,0.5,       1,-71624       , 0         , "t=17.609h",_
 2671, 65, 151, 1,5.5,      -1,-71524       , 0.09953   , "t=25s",_
 2672, 66, 151, 0,3.5,      -1,-68752       , 0         , "t=17.9m",_
 2673, 67, 151, 0,5.5,      -1,-63623       , 0         , "t=35.2s",_
 2674, 67, 151, 1,0.5,       1,-63582       , 0.041     , "t=47.2s",_
 2675, 68, 151, 0,3.5,      -1,-58266       , 0         , "t=23.5s",_
 2676, 68, 151, 1,13.5,     -1,-55680       , 2.586     , "t=580ms",_
 2677, 69, 151, 0,5.5,      -1,-50772       , 0         , "t=4.17s",_
 2678, 69, 151, 1,0.5,       1,-50679       , 0.093     , "t=6.6s",_
 2679, 70, 151, 0,0.5,       1,-41540       , 0         , "t=1.6s",_
 2680, 70, 151, 1,5.5,      -1,-40800       , 0.74      , "t=1.6s",_
 2681, 71, 151, 0,5.5,      -1,-30300       , 0         , "t=78.4ms",_
 2682, 71, 151, 1,1.5,       1,-30240       , 0.057     , "t=16.0us",_
 2683, 55, 152, 0,-77.777,   0,-29130       , 0         , "t=17ms",_
 2684, 56, 152, 0,0,         1,-41610       , 0         , "t=139ms",_
 2685, 57, 152, 0,2,        -1,-49290       , 0         , "t=287ms",_
 2686, 58, 152, 0,0,         1,-58980       , 0         , "t=1.42s",_
 2687, 59, 152, 0,4,         1,-63758       , 0         , "t=3.57s",_
 2688, 59, 152, 1,1,         1,-63643       , 0.1151    , "t=4.16us",_
 2689, 60, 152, 0,0,         1,-70150       , 0         , "t=11.4m",_
 2690, 61, 152, 0,1,         1,-71254       , 0         , "t=4.12m",_
 2691, 61, 152, 1,4,        -1,-71110       , 0.14      , "t=7.52m",_
 2692, 62, 152, 0,0,         1,-74763.0     , 0         , "t=stbl",_
 2693, 63, 152, 0,3,        -1,-72888.5     , 0         , "t=13.517y",_
 2694, 63, 152, 1,0,        -1,-72842.9     , 0.0455998 , "t=9.3116h",_
 2695, 64, 152, 0,0,         1,-74707.3     , 0         , "t=108Ty",_
 2696, 65, 152, 0,2,        -1,-70720       , 0         , "t=17.5h",_
 2697, 65, 152, 1,5,        -1,-70380       , 0.34215   , "t=960ns",_
 2698, 66, 152, 0,0,         1,-70118       , 0         , "t=2.38h",_
 2699, 67, 152, 0,2,        -1,-63605       , 0         , "t=161.8s",_
 2700, 67, 152, 1,9,         1,-63445       , 0.16      , "t=49.8s",_
 2701, 68, 152, 0,0,         1,-60500       , 0         , "t=10.3s",_
 2702, 69, 152, 0,2,        -1,-51720       , 0         , "t=8.0s",_
 2703, 69, 152, 1,9,         1,-51820       ,-0.1       , "t=5.2s",_
 2704, 70, 152, 0,0,         1,-46270       , 0         , "t=3.03s",_
 2705, 70, 152, 1,10,        1,-43530       , 2.7445    , "t=30us",_
 2706, 71, 152, 0,4,        -1,-33420       , 0         , "t=650ms",_
 2707, 56, 153, 0,2.5,      -1,-36470       , 0         , "t=113ms",_
 2708, 57, 153, 0,0.5,       1,-46060       , 0         , "t=245ms",_
 2709, 58, 153, 0,1.5,      -1,-54910       , 0         , "t=865ms",_
 2710, 59, 153, 0,1.5,      -1,-61568       , 0         , "t=4.28s",_
 2711, 60, 153, 0,1.5,      -1,-67330.4     , 0         , "t=31.6s",_
 2712, 60, 153, 1,2.5,       1,-67138.7     , 0.19171   , "t=1.10us",_
 2713, 61, 153, 0,2.5,      -1,-70648       , 0         , "t=5.25m",_
 2714, 62, 153, 0,1.5,       1,-72560.1     , 0         , "t=46.2846h",_
 2715, 62, 153, 1,5.5,      -1,-72461.7     , 0.09839   , "t=10.6ms",_
 2716, 63, 153, 0,2.5,       1,-73367.5     , 0         , "t=stbl",_
 2717, 63, 153, 1,9.5,      -1,-71596.5     , 1.771     , "t=475ns",_
 2718, 64, 153, 0,1.5,      -1,-72882.9     , 0         , "t=240.6d",_
 2719, 64, 153, 1,4.5,       1,-72787.7     , 0.0951737 , "t=3.5us",_
 2720, 65, 153, 0,2.5,       1,-71314       , 0         , "t=2.34d",_
 2721, 65, 153, 1,5.5,      -1,-71151       , 0.163175  , "t=186us",_
 2722, 66, 153, 0,3.5,      -1,-69143       , 0         , "t=6.4h",_
 2723, 67, 153, 0,5.5,      -1,-65012       , 0         , "t=2.01m",_
 2724, 67, 153, 1,0.5,       1,-64943       , 0.0687    , "t=9.3m",_
 2725, 68, 153, 0,3.5,      -1,-60467       , 0         , "t=37.1s",_
 2726, 68, 153, 1,13.5,     -1,-57669       , 2.7982    , "t=373ns",_
 2727, 69, 153, 0,5.5,      -1,-53973       , 0         , "t=1.48s",_
 2728, 69, 153, 1,0.5,       1,-53930       , 0.0432    , "t=2.5s",_
 2729, 70, 153, 0,3.5,      -1,-47160       , 0         , "t=4.2s",_
 2730, 70, 153, 1,13.5,     -1,-44530       , 2.63      , "t=15us",_
 2731, 71, 153, 0,5.5,      -1,-38380       , 0         , "t=900ms",_
 2732, 71, 153, 1,0.5,       1,-38300       , 0.08      , "t=1s",_
 2733, 72, 153, 0,0.5,       1,-27300       , 0         , "t=400ms",_
 2734, 72, 153, 1,5.5,      -1,-26550       , 0.75      , "t=500ms",_
 2735, 56, 154, 0,0,         1,-32920       , 0         , "t=53ms",_
 2736, 57, 154, 0,2,        -1,-41530       , 0         , "t=161ms",_
 2737, 58, 154, 0,0,         1,-52220       , 0         , "t=722ms",_
 2738, 59, 154, 0,3,         1,-57860       , 0         , "t=2.30s",_
 2739, 60, 154, 0,0,         1,-65579.6     , 0         , "t=25.9s",_
 2740, 60, 154, 1,4,        -1,-64281.7     , 1.2979    , "t=3.2us",_
 2741, 61, 154, 0,4,         1,-68267       , 0         , "t=2.68m",_
 2742, 61, 154, 1,1,        -1,-68490       ,-0.23      , "t=1.73m",_
 2743, 62, 154, 0,0,         1,-72455.6     , 0         , "t=stbl",_
 2744, 63, 154, 0,3,        -1,-71738.4     , 0         , "t=8.592y",_
 2745, 63, 154, 1,2,         1,-71670.2     , 0.0681702 , "t=2.2us",_
 2746, 64, 154, 0,0,         1,-73706.4     , 0         , "t=stbl",_
 2747, 65, 154, 0,3,        -1,-70160       , 0         , "t=9.994h",_
 2748, 65, 154, 1,0,        -1,-70030       , 0.13      , "t=21.5h",_
 2749, 66, 154, 0,0,         1,-70394       , 0         , "t=3.0My",_
 2750, 67, 154, 0,2,        -1,-64639       , 0         , "t=11.76m",_
 2751, 67, 154, 1,8,         1,-64397       , 0.243     , "t=3.10m",_
 2752, 68, 154, 0,0,         1,-62605       , 0         , "t=3.73m",_
 2753, 69, 154, 0,2,        -1,-54427       , 0         , "t=8.1s",_
 2754, 69, 154, 1,9,         1,-54350       , 0.07      , "t=3.30s",_
 2755, 70, 154, 0,0,         1,-49932       , 0         , "t=409ms",_
 2756, 71, 154, 0,2,        -1,-39670       , 0         , "t=1s",_
 2757, 71, 154, 1,9,         1,-39600       , 0.062     , "t=1.12s",_
 2758, 72, 154, 0,0,         1,-32730       , 0         , "t=2s",_
 2759, 72, 154, 1,10,        1,-30010       , 2.721     , "t=9us",_
 2760, 57, 155, 0,0.5,       1,-37930       , 0         , "t=101ms",_
 2761, 58, 155, 0,2.5,      -1,-47780       , 0         , "t=313ms",_
 2762, 59, 155, 0,1.5,      -1,-55415       , 0         , "t=1.47s",_
 2763, 60, 155, 0,1.5,      -1,-62284       , 0         , "t=8.9s",_
 2764, 61, 155, 0,2.5,      -1,-66940       , 0         , "t=41.5s",_
 2765, 62, 155, 0,1.5,      -1,-70191.2     , 0         , "t=22.18m",_
 2766, 62, 155, 1,2.5,       1,-70174.7     , 0.0165467 , "t=2.8us",_
 2767, 63, 155, 0,2.5,       1,-71818.3     , 0         , "t=4.742y",_
 2768, 64, 155, 0,1.5,      -1,-72070.3     , 0         , "t=stbl",_
 2769, 64, 155, 1,5.5,      -1,-71949.2     , 0.1211    , "t=31.97ms",_
 2770, 65, 155, 0,1.5,       1,-71250       , 0         , "t=5.32d",_
 2771, 66, 155, 0,1.5,      -1,-69156       , 0         , "t=9.9h",_
 2772, 66, 155, 1,5.5,      -1,-68922       , 0.23433   , "t=6us",_
 2773, 67, 155, 0,2.5,       1,-66040       , 0         , "t=48m",_
 2774, 67, 155, 1,5.5,      -1,-65898       , 0.14187   , "t=880us",_
 2775, 68, 155, 0,3.5,      -1,-62209       , 0         , "t=5.3m",_
 2776, 69, 155, 0,5.5,      -1,-56626       , 0         , "t=21.6s",_
 2777, 69, 155, 1,0.5,       1,-56585       , 0.041     , "t=45s",_
 2778, 70, 155, 0,3.5,      -1,-50503       , 0         , "t=1.793s",_
 2779, 71, 155, 0,5.5,      -1,-42545       , 0         , "t=68ms",_
 2780, 71, 155, 1,0.5,       1,-42524       , 0.021     , "t=138ms",_
 2781, 72, 155, 0,3.5,      -1,-34310       , 0         , "t=843ms",_
 2782, 73, 155, 0,5.5,      -1,-23990       , 0         , "t=3.2ms",_
 2783, 57, 156, 0,4,         1,-33050       , 0         , "t=84ms",_
 2784, 58, 156, 0,0,         1,-44820       , 0         , "t=233ms",_
 2785, 59, 156, 0,1,         1,-51449.3     , 0         , "t=444ms",_
 2786, 60, 156, 0,0,         1,-60202.1     , 0         , "t=5.06s",_
 2787, 60, 156, 1,5,        -1,-58770.8     , 1.4313    , "t=365ns",_
 2788, 61, 156, 0,4,         1,-64166.8     , 0         , "t=27.4s",_
 2789, 61, 156, 1,1,         1,-64016.5     , 0.1503    , "t=2.3s",_
 2790, 62, 156, 0,0,         1,-69361       , 0         , "t=9.4h",_
 2791, 62, 156, 1,5,        -1,-67963       , 1.39755   , "t=185ns",_
 2792, 63, 156, 0,0,         1,-70083       , 0         , "t=15.19d",_
 2793, 64, 156, 0,0,         1,-72535.3     , 0         , "t=stbl",_
 2794, 64, 156, 1,7,        -1,-70397.7     , 2.1376    , "t=1.3us",_
 2795, 65, 156, 0,3,        -1,-70091       , 0         , "t=5.35d",_
 2796, 65, 156, 1,0,         1,-70003       , 0.0884    , "t=5.3h",_
 2797, 66, 156, 0,0,         1,-70529.4     , 0         , "t=stbl",_
 2798, 67, 156, 0,4,        -1,-65540       , 0         , "t=56m",_
 2799, 67, 156, 1,1,        -1,-65490       , 0.05237   , "t=9.5s",_
 2800, 68, 156, 0,0,         1,-64212       , 0         , "t=19.5m",_
 2801, 69, 156, 0,2,        -1,-56834       , 0         , "t=83.8s",_
 2802, 69, 156, 1,11,       -1,-56430       , 0.4       , "t=~400ns",_
 2803, 70, 156, 0,0,         1,-53266       , 0         , "t=26.1s",_
 2804, 71, 156, 0,2,        -1,-43700       , 0         , "t=494ms",_
 2805, 71, 156, 1,10,        1,-43680       , 0.01      , "t=198ms",_
 2806, 72, 156, 0,0,         1,-37820       , 0         , "t=23ms",_
 2807, 72, 156, 1,8,         1,-35860       , 1.9588    , "t=480us",_
 2808, 73, 156, 0,2,        -1,-26000       , 0         , "t=106ms",_
 2809, 73, 156, 1,9,         1,-25910       , 0.094     , "t=360ms",_
 2810, 57, 157, 0,0.5,       1,-29070       , 0         , "t=30ms",_
 2811, 58, 157, 0,3.5,       1,-39930       , 0         , "t=175ms",_
 2812, 59, 157, 0,1.5,      -1,-48435       , 0         , "t=307ms",_
 2813, 60, 157, 0,2.5,      -1,-56494.1     , 0         , "t=1.15s",_
 2814, 61, 157, 0,2.5,      -1,-62297       , 0         , "t=10.56s",_
 2815, 62, 157, 0,1.5,      -1,-66678       , 0         , "t=8.03m",_
 2816, 63, 157, 0,2.5,       1,-69459       , 0         , "t=15.18h",_
 2817, 64, 157, 0,1.5,      -1,-70823.9     , 0         , "t=stbl",_
 2818, 64, 157, 1,2.5,       1,-70760.0     , 0.063916  , "t=460ns",_
 2819, 65, 157, 0,1.5,       1,-70763.8     , 0         , "t=71y",_
 2820, 66, 157, 0,1.5,      -1,-69425       , 0         , "t=8.14h",_
 2821, 66, 157, 1,4.5,       1,-69263       , 0.16199   , "t=1.3us",_
 2822, 67, 157, 0,3.5,      -1,-66833       , 0         , "t=12.6m",_
 2823, 68, 157, 0,1.5,      -1,-63414       , 0         , "t=18.65m",_
 2824, 68, 157, 1,4.5,       1,-63259       , 0.1554    , "t=76ms",_
 2825, 69, 157, 0,0.5,       1,-58709       , 0         , "t=3.63m",_
 2826, 69, 157, 1,3.5,      -1,-58610       , 0.1       , "t=1.6s",_
 2827, 70, 157, 0,3.5,      -1,-53420       , 0         , "t=38.6s",_
 2828, 71, 157, 0,0.5,       1,-46440       , 0         , "t=7.7s",_
 2829, 71, 157, 1,5.5,      -1,-46419       , 0.0209    , "t=4.79s",_
 2830, 72, 157, 0,3.5,      -1,-38860       , 0         , "t=115ms",_
 2831, 73, 157, 0,0.5,       1,-29600       , 0         , "t=10.1ms",_
 2832, 73, 157, 1,5.5,      -1,-29570       , 0.022     , "t=4.3ms",_
 2833, 74, 157, 0,3.5,      -1,-19690       , 0         , "t=275ms",_
 2834, 58, 158, 0,0,         1,-36540       , 0         , "t=99ms",_
 2835, 59, 158, 0,5,        -1,-44150       , 0         , "t=181ms",_
 2836, 60, 158, 0,0,         1,-53835.1     , 0         , "t=810ms",_
 2837, 60, 158, 1,6,        -1,-52187.0     , 1.6481    , "t=339ns",_
 2838, 61, 158, 0,0,         1,-59106.1     , 0         , "t=4.8s",_
 2839, 61, 158, 1,5,         1,-58960       , 0.15      , "t=&gt;16us",_
 2840, 62, 158, 0,0,         1,-65252       , 0         , "t=5.30m",_
 2841, 63, 158, 0,1,        -1,-67270.5     , 0         , "t=45.9m",_
 2842, 64, 158, 0,0,         1,-70690.0     , 0         , "t=stbl",_
 2843, 65, 158, 0,3,        -1,-69470.9     , 0         , "t=180y",_
 2844, 65, 158, 1,0,        -1,-69360.6     , 0.1103    , "t=10.70s",_
 2845, 66, 158, 0,0,         1,-70407.2     , 0         , "t=stbl",_
 2846, 67, 158, 0,5,         1,-66187       , 0         , "t=11.3m",_
 2847, 67, 158, 1,2,        -1,-66120       , 0.0672    , "t=28m",_
 2848, 68, 158, 0,0,         1,-65304       , 0         , "t=2.29h",_
 2849, 69, 158, 0,2,        -1,-58703       , 0         , "t=3.98m",_
 2850, 69, 158, 1,5,        -1,-58600       , 0.1       , "t=~20s",_
 2851, 70, 158, 0,0,         1,-56010       , 0         , "t=1.49m",_
 2852, 71, 158, 0,2,        -1,-47212       , 0         , "t=10.6s",_
 2853, 72, 158, 0,0,         1,-42102       , 0         , "t=2.85s",_
 2854, 73, 158, 0,2,        -1,-31120       , 0         , "t=49ms",_
 2855, 73, 158, 1,9,         1,-30980       , 0.141     , "t=36.0ms",_
 2856, 74, 158, 0,0,         1,-23690       , 0         , "t=1.43ms",_
 2857, 74, 158, 1,8,         1,-21800       , 1.889     , "t=143us",_
 2858, 58, 159, 0,0.5,      -1,-31340       , 0         , "t=?",_
 2859, 59, 159, 0,1.5,      -1,-40770       , 0         , "t=134ms",_
 2860, 60, 159, 0,3.5,       1,-49724       , 0         , "t=500ms",_
 2861, 61, 159, 0,2.5,      -1,-56554       , 0         , "t=1.49s",_
 2862, 61, 159, 1,8.5,       1,-55089       , 1.465     , "t=4.42us",_
 2863, 62, 159, 0,2.5,      -1,-62208       , 0         , "t=11.37s",_
 2864, 62, 159, 1,7.5,       1,-60932       , 1.2765    , "t=116ns",_
 2865, 63, 159, 0,2.5,       1,-66043       , 0         , "t=18.1m",_
 2866, 64, 159, 0,1.5,      -1,-68561.9     , 0         , "t=18.479h",_
 2867, 65, 159, 0,1.5,       1,-69532.6     , 0         , "t=stbl",_
 2868, 66, 159, 0,1.5,      -1,-69167.2     , 0         , "t=144.4d",_
 2869, 66, 159, 1,5.5,      -1,-68814.4     , 0.35277   , "t=122us",_
 2870, 67, 159, 0,3.5,      -1,-67330       , 0         , "t=33.05m",_
 2871, 67, 159, 1,0.5,       1,-67124       , 0.20591   , "t=8.30s",_
 2872, 68, 159, 0,1.5,      -1,-64561       , 0         , "t=36m",_
 2873, 68, 159, 1,4.5,       1,-64378       , 0.182602  , "t=337ns",_
 2874, 69, 159, 0,2.5,       1,-60570       , 0         , "t=9.13m",_
 2875, 70, 159, 0,2.5,      -1,-55834       , 0         , "t=1.67m",_
 2876, 71, 159, 0,0.5,       1,-49710       , 0         , "t=12.1s",_
 2877, 71, 159, 1,5.5,      -1,-49610       , 0.1       , "t=10s",_
 2878, 72, 159, 0,3.5,      -1,-42853       , 0         , "t=5.20s",_
 2879, 73, 159, 0,0.5,       1,-34439       , 0         , "t=1.04s",_
 2880, 73, 159, 1,5.5,      -1,-34375       , 0.064     , "t=560ms",_
 2881, 74, 159, 0,3.5,      -1,-25430       , 0         , "t=8.2ms",_
 2882, 75, 159, 0,0.5,       1,-14810       , 0         , "t=40us",_
 2883, 75, 159, 1,5.5,      -1,-14600       , 0.21      , "t=20us",_
 2884, 59, 160, 0,1,         1,-36200       , 0         , "t=170ms",_
 2885, 60, 160, 0,0,         1,-46720       , 0         , "t=439ms",_
 2886, 60, 160, 1,4,        -1,-45610       , 1.1079    , "t=1.63us",_
 2887, 61, 160, 0,6,        -1,-52894.6     , 0         , "t=725ms",_
 2888, 61, 160, 1,1,        -1,-52704       , 0.191     , "t=&gt;700ms",_
 2889, 62, 160, 0,0,         1,-60233.2     , 0         , "t=9.6s",_
 2890, 62, 160, 1,5,        -1,-58871.9     , 1.3613    , "t=120ns",_
 2891, 63, 160, 0,5,        -1,-63493.4     , 0         , "t=42.6s",_
 2892, 63, 160, 1,1,        -1,-63400.4     , 0.093     , "t=30.8s",_
 2893, 64, 160, 0,0,         1,-67942.1     , 0         , "t=stbl",_
 2894, 65, 160, 0,3,        -1,-67836.5     , 0         , "t=72.3d",_
 2895, 66, 160, 0,0,         1,-69672.4     , 0         , "t=stbl",_
 2896, 67, 160, 0,5,         1,-66382       , 0         , "t=25.6m",_
 2897, 67, 160, 1,2,        -1,-66322       , 0.05998   , "t=5.02h",_
 2898, 68, 160, 0,0,         1,-66064       , 0         , "t=28.58h",_
 2899, 69, 160, 0,1,        -1,-60300       , 0         , "t=9.4m",_
 2900, 69, 160, 1,5,         1,-60230       , 0.067     , "t=74.5s",_
 2901, 70, 160, 0,0,         1,-58163       , 0         , "t=4.8m",_
 2902, 71, 160, 0,2,        -1,-50270       , 0         , "t=36.1s",_
 2903, 71, 160, 1,-77.777,   0,-50270       , 0         , "t=40s",_
 2904, 72, 160, 0,0,         1,-45939       , 0         , "t=13.6s",_
 2905, 73, 160, 0,2,        -1,-35820       , 0         , "t=1.70s",_
 2906, 73, 160, 1,9,         0,-35710       , 0.11      , "t=1.55s",_
 2907, 74, 160, 0,0,         1,-29330       , 0         , "t=90ms",_
 2908, 75, 160, 0,4,        -1,-16880       , 0         , "t=611us",_
 2909, 75, 160, 1,9,         1,-16700       , 0.177     , "t=2.8us",_
 2910, 59, 161, 0,1.5,      -1,-32490       , 0         , "t=90ms",_
 2911, 60, 161, 0,0.5,      -1,-42230       , 0         , "t=215ms",_
 2912, 61, 161, 0,2.5,      -1,-50087       , 0         , "t=1.05s",_
 2913, 61, 161, 1,6.5,       1,-49121       , 0.9659    , "t=0.89us",_
 2914, 62, 161, 0,3.5,       1,-56672       , 0         , "t=4.8s",_
 2915, 62, 161, 1,8.5,      -1,-55284       , 1.3881    , "t=2.6us",_
 2916, 63, 161, 0,2.5,       1,-61792       , 0         , "t=26.2s",_
 2917, 64, 161, 0,2.5,      -1,-65506.1     , 0         , "t=3.646m",_
 2918, 65, 161, 0,1.5,       1,-67461.8     , 0         , "t=6.948d",_
 2919, 66, 161, 0,2.5,       1,-68055.5     , 0         , "t=stbl",_
 2920, 66, 161, 1,5.5,      -1,-67569.9     , 0.48556   , "t=760ns",_
 2921, 67, 161, 0,3.5,      -1,-67196.3     , 0         , "t=2.48h",_
 2922, 67, 161, 1,0.5,       1,-66985.2     , 0.21115   , "t=6.76s",_
 2923, 68, 161, 0,1.5,      -1,-65201       , 0         , "t=3.21h",_
 2924, 68, 161, 1,5.5,      -1,-64805       , 0.39644   , "t=7.5us",_
 2925, 69, 161, 0,3.5,       1,-61899       , 0         , "t=30.2m",_
 2926, 69, 161, 1,0.5,       1,-61891       , 0.00751   , "t=5m",_
 2927, 70, 161, 0,1.5,      -1,-57834       , 0         , "t=4.2m",_
 2928, 71, 161, 0,0.5,       1,-52562       , 0         , "t=77s",_
 2929, 71, 161, 1,4.5,      -1,-52380       , 0.182     , "t=7.3ms",_
 2930, 72, 161, 0,3.5,      -1,-46316       , 0         , "t=18.4s",_
 2931, 72, 161, 1,6.5,       1,-45987       , 0.329     , "t=4.8us",_
 2932, 73, 161, 0,0.5,       1,-38779       , 0         , "t=3s",_
 2933, 73, 161, 1,5.5,      -1,-38717       , 0.061     , "t=3.08s",_
 2934, 74, 161, 0,3.5,      -1,-30510       , 0         , "t=409ms",_
 2935, 75, 161, 0,0.5,       1,-20840       , 0         , "t=440us",_
 2936, 75, 161, 1,5.5,      -1,-20720       , 0.1237    , "t=14.7ms",_
 2937, 76, 161, 0,3.5,      -1,-10200       , 0         , "t=640us",_
 2938, 60, 162, 0,0,         1,-39010       , 0         , "t=310ms",_
 2939, 61, 162, 0,2,         1,-46040       , 0         , "t=630ms",_
 2940, 62, 162, 0,0,         1,-54379       , 0         , "t=2.7s",_
 2941, 62, 162, 1,4,        -1,-53370       , 1.0094    , "t=1.78us",_
 2942, 63, 162, 0,1,         1,-58722.9     , 0         , "t=~10s",_
 2943, 63, 162, 1,6,         1,-58565.0     , 0.158     , "t=15.0s",_
 2944, 64, 162, 0,0,         1,-64281       , 0         , "t=8.4m",_
 2945, 65, 162, 0,1,        -1,-65879.5     , 0         , "t=7.60m",_
 2946, 65, 162, 1,4,        -1,-65594.0     , 0.286     , "t=10m",_
 2947, 66, 162, 0,0,         1,-68181.2     , 0         , "t=stbl",_
 2948, 66, 162, 1,8,         1,-65993.1     , 2.1881    , "t=8.3us",_
 2949, 67, 162, 0,1,         1,-66041       , 0         , "t=15.0m",_
 2950, 67, 162, 1,6,        -1,-65935       , 0.10587   , "t=67.0m",_
 2951, 68, 162, 0,0,         1,-66334.2     , 0         , "t=stbl",_
 2952, 68, 162, 1,7,        -1,-64308.2     , 2.02601   , "t=88ns",_
 2953, 69, 162, 0,1,        -1,-61477       , 0         , "t=21.70m",_
 2954, 69, 162, 1,5,         1,-61350       , 0.13      , "t=24.3s",_
 2955, 70, 162, 0,0,         1,-59821       , 0         , "t=18.87m",_
 2956, 71, 162, 0,1,        -1,-52830       , 0         , "t=1.37m",_
 2957, 71, 162, 1,4,        -1,-52710       , 0.12      , "t=1.5m",_
 2958, 72, 162, 0,0,         1,-49168       , 0         , "t=39.4s",_
 2959, 73, 162, 0,3,        -1,-39780       , 0         , "t=3.57s",_
 2960, 73, 162, 1,7,         1,-39660       , 0.12      , "t=5s",_
 2961, 74, 162, 0,0,         1,-33999       , 0         , "t=1.19s",_
 2962, 75, 162, 0,2,        -1,-22450       , 0         , "t=107ms",_
 2963, 75, 162, 1,9,         1,-22280       , 0.175     , "t=77ms",_
 2964, 76, 162, 0,0,         1,-14500       , 0         , "t=2.1ms",_
 2965, 60, 163, 0,2.5,      -1,-34080       , 0         , "t=80ms",_
 2966, 61, 163, 0,2.5,      -1,-42960       , 0         , "t=255ms",_
 2967, 62, 163, 0,0.5,      -1,-50600       , 0         , "t=1.3s",_
 2968, 63, 163, 0,2.5,       1,-56573.8     , 0         , "t=7.7s",_
 2969, 63, 163, 1,6.5,      -1,-55609.3     , 0.9645    , "t=911ns",_
 2970, 64, 163, 0,3.5,       1,-61388.6     , 0         , "t=68s",_
 2971, 64, 163, 1,0.5,      -1,-61250.4     , 0.13822   , "t=23.5s",_
 2972, 65, 163, 0,1.5,       1,-64596       , 0         , "t=19.5m",_
 2973, 66, 163, 0,2.5,      -1,-66380.9     , 0         , "t=stbl",_
 2974, 67, 163, 0,3.5,      -1,-66378.0     , 0         , "t=4.570ky",_
 2975, 67, 163, 1,0.5,       1,-66080.1     , 0.29788   , "t=1.09s",_
 2976, 68, 163, 0,2.5,      -1,-65167       , 0         , "t=75.0m",_
 2977, 68, 163, 1,5.5,      -1,-64722       , 0.4455    , "t=580ns",_
 2978, 69, 163, 0,0.5,       1,-62728       , 0         , "t=1.810h",_
 2979, 69, 163, 1,3.5,      -1,-62641       , 0.08692   , "t=380ns",_
 2980, 70, 163, 0,1.5,      -1,-59294       , 0         , "t=11.05m",_
 2981, 71, 163, 0,0.5,       1,-54791       , 0         , "t=3.97m",_
 2982, 72, 163, 0,2.5,      -1,-49269       , 0         , "t=40.0s",_
 2983, 73, 163, 0,0.5,       1,-42530       , 0         , "t=10.6s",_
 2984, 73, 163, 1,4.5,      -1,-42400       , 0.138     , "t=10s",_
 2985, 74, 163, 0,3.5,      -1,-34910       , 0         , "t=2.63s",_
 2986, 74, 163, 1,6.5,       1,-34430       , 0.4803    , "t=154ns",_
 2987, 75, 163, 0,0.5,       1,-26002       , 0         , "t=390ms",_
 2988, 75, 163, 1,5.5,      -1,-25882       , 0.12      , "t=214ms",_
 2989, 76, 163, 0,3.5,      -1,-16340       , 0         , "t=5.7ms",_
 2990, 77, 163, 0,0.5,       1,-5310        , 0         , "t=?",_
 2991, 61, 164, 0,5,        -1,-38360       , 0         , "t=300ms",_
 2992, 62, 164, 0,0,         1,-47925       , 0         , "t=1.43s",_
 2993, 62, 164, 1,6,        -1,-46440       , 1.4855    , "t=600ns",_
 2994, 63, 164, 0,3,        -1,-53232.1     , 0         , "t=4.16s",_
 2995, 64, 164, 0,0,         1,-59693.7     , 0         , "t=45s",_
 2996, 64, 164, 1,4,        -1,-58597.9     , 1.0958    , "t=589ns",_
 2997, 65, 164, 0,5,         1,-62105.0     , 0         , "t=3.0m",_
 2998, 65, 164, 1,2,         1,-61960       , 0.145     , "t=2m",_
 2999, 66, 164, 0,0,         1,-65967.6     , 0         , "t=stbl",_
 3000, 67, 164, 0,1,         1,-64980.5     , 0         , "t=28.8m",_
 3001, 67, 164, 1,6,        -1,-64840.7     , 0.13978   , "t=36.6m",_
 3002, 68, 164, 0,0,         1,-65942.6     , 0         , "t=stbl",_
 3003, 69, 164, 0,1,         1,-61909       , 0         , "t=2.0m",_
 3004, 69, 164, 1,6,        -1,-61889       , 0.02      , "t=5.1m",_
 3005, 70, 164, 0,0,         1,-61012       , 0         , "t=75.8m",_
 3006, 71, 164, 0,1,        -1,-54642       , 0         , "t=3.14m",_
 3007, 72, 164, 0,0,         1,-51818       , 0         , "t=111s",_
 3008, 73, 164, 0,3,         1,-43283       , 0         , "t=14.2s",_
 3009, 74, 164, 0,0,         1,-38236       , 0         , "t=6.3s",_
 3010, 75, 164, 0,2,        -1,-27470       , 0         , "t=719ms",_
 3011, 75, 164, 1,9,         0,-27520       ,-0.05      , "t=890ms",_
 3012, 76, 164, 0,0,         1,-20420       , 0         , "t=21ms",_
 3013, 77, 164, 0,2,        -1,-7480        , 0         , "t=1ms",_
 3014, 77, 164, 1,9,         1,-7220        , 0.26      , "t=70us",_
 3015, 61, 165, 0,2.5,      -1,-34670       , 0         , "t=260ms",_
 3016, 62, 165, 0,2.5,      -1,-43510       , 0         , "t=980ms",_
 3017, 63, 165, 0,2.5,       1,-50729       , 0         , "t=2.53s",_
 3018, 64, 165, 0,0.5,      -1,-56525.8     , 0         , "t=11.6s",_
 3019, 65, 165, 0,1.5,       1,-60588.8     , 0         , "t=2.11m",_
 3020, 65, 165, 1,3.5,      -1,-60382       , 0.207     , "t=0.81us",_
 3021, 66, 165, 0,3.5,       1,-63612.3     , 0         , "t=2.332h",_
 3022, 66, 165, 1,0.5,      -1,-63504.1     , 0.1081552 , "t=1.257m",_
 3023, 67, 165, 0,3.5,      -1,-64898.0     , 0         , "t=stbl",_
 3024, 67, 165, 1,1.5,       1,-64536.3     , 0.361675  , "t=1.512us",_
 3025, 68, 165, 0,2.5,      -1,-64521.4     , 0         , "t=10.36h",_
 3026, 68, 165, 1,5.5,      -1,-63970.1     , 0.5513    , "t=250ns",_
 3027, 69, 165, 0,0.5,       1,-62930.0     , 0         , "t=30.06h",_
 3028, 69, 165, 1,3.5,       1,-62849.6     , 0.08037   , "t=80us",_
 3029, 70, 165, 0,2.5,      -1,-60295       , 0         , "t=9.9m",_
 3030, 70, 165, 1,4.5,       1,-60168       , 0.1268    , "t=300ns",_
 3031, 71, 165, 0,0.5,       1,-56442       , 0         , "t=10.74m",_
 3032, 72, 165, 0,2.5,      -1,-51636       , 0         , "t=76s",_
 3033, 73, 165, 0,0.5,       1,-45848       , 0         , "t=31.0s",_
 3034, 73, 165, 1,4.5,      -1,-45823       , 0.024     , "t=30s",_
 3035, 74, 165, 0,2.5,      -1,-38861       , 0         , "t=5.1s",_
 3036, 75, 165, 0,0.5,       1,-30659       , 0         , "t=1.6s",_
 3037, 75, 165, 1,5.5,      -1,-30632       , 0.028     , "t=1.74s",_
 3038, 76, 165, 0,3.5,      -1,-21750       , 0         , "t=71ms",_
 3039, 77, 165, 0,0.5,       1,-11600       , 0         , "t=50ns",_
 3040, 77, 165, 1,5.5,      -1,-11420       , 0.18      , "t=325us",_
 3041, 78, 165, 0,3.5,      -1,-320         , 0         , "t=370us",_
 3042, 62, 166, 0,0,         1,-40450       , 0         , "t=800ms",_
 3043, 63, 166, 0,0,        -1,-46750       , 0         , "t=1.24s",_
 3044, 64, 166, 0,0,         1,-54370.9     , 0         , "t=5.1s",_
 3045, 64, 166, 1,6,        -1,-52769.4     , 1.6015    , "t=950ns",_
 3046, 65, 166, 0,1,        -1,-57808.8     , 0         , "t=27.1s",_
 3047, 65, 166, 1,4,        -1,-57649.8     , 0.159     , "t=3.5us",_
 3048, 66, 166, 0,0,         1,-62584.5     , 0         , "t=81.6h",_
 3049, 67, 166, 0,0,        -1,-63070.3     , 0         , "t=26.812h",_
 3050, 67, 166, 1,7,        -1,-63064.3     , 0.005969  , "t=1.1326ky",_
 3051, 68, 166, 0,0,         1,-64924.1     , 0         , "t=stbl",_
 3052, 69, 166, 0,2,         1,-61886       , 0         , "t=7.70h",_
 3053, 69, 166, 1,6,        -1,-61764       , 0.122     , "t=348ms",_
 3054, 70, 166, 0,0,         1,-61594       , 0         , "t=56.7h",_
 3055, 71, 166, 0,6,        -1,-56021       , 0         , "t=2.65m",_
 3056, 71, 166, 1,3,        -1,-55990       , 0.03437   , "t=1.41m",_
 3057, 72, 166, 0,0,         1,-53859       , 0         , "t=6.77m",_
 3058, 73, 166, 0,2,         1,-46098       , 0         , "t=34.4s",_
 3059, 74, 166, 0,0,         1,-41887       , 0         , "t=19.2s",_
 3060, 75, 166, 0,7,         1,-31840       , 0         , "t=2.25s",_
 3061, 76, 166, 0,0,         1,-25432       , 0         , "t=213ms",_
 3062, 77, 166, 0,2,        -1,-13310       , 0         , "t=10.5ms",_
 3063, 77, 166, 1,9,         1,-13130       , 0.171     , "t=15.1ms",_
 3064, 78, 166, 0,0,         1,-4780        , 0         , "t=294us",_
 3065, 62, 167, 0,3.5,      -1,-35330       , 0         , "t=190ms",_
 3066, 63, 167, 0,2.5,       1,-43770       , 0         , "t=1.33s",_
 3067, 64, 167, 0,2.5,      -1,-50776       , 0         , "t=4.2s",_
 3068, 65, 167, 0,1.5,       1,-55883.1     , 0         , "t=18.9s",_
 3069, 65, 167, 1,3.5,      -1,-55683       , 0.2       , "t=1.2us",_
 3070, 66, 167, 0,0.5,      -1,-59911       , 0         , "t=6.20m",_
 3071, 67, 167, 0,3.5,      -1,-62279       , 0         , "t=3.1h",_
 3072, 67, 167, 1,1.5,       1,-62020       , 0.25934   , "t=6.0us",_
 3073, 68, 167, 0,3.5,       1,-63289.26    , 0         , "t=stbl",_
 3074, 68, 167, 1,0.5,      -1,-63081.46    , 0.207801  , "t=2.269s",_
 3075, 69, 167, 0,0.5,       1,-62543.1     , 0         , "t=9.25d",_
 3076, 69, 167, 1,3.5,       1,-62363.6     , 0.17948   , "t=1.16us",_
 3077, 70, 167, 0,2.5,      -1,-60590       , 0         , "t=17.5m",_
 3078, 70, 167, 1,5.5,      -1,-60018       , 0.571548  , "t=~180ns",_
 3079, 71, 167, 0,3.5,       1,-57530       , 0         , "t=51.5m",_
 3080, 71, 167, 1,0.5,       1,-57480       , 0.05      , "t=&gt;1m",_
 3081, 72, 167, 0,2.5,      -1,-53468       , 0         , "t=2.05m",_
 3082, 73, 167, 0,1.5,       1,-48351       , 0         , "t=1.33m",_
 3083, 74, 167, 0,2.5,      -1,-42093       , 0         , "t=19.9s",_
 3084, 74, 167, 1,6.5,       1,-41967       , 0.1257    , "t=&gt;1us",_
 3085, 75, 167, 0,4.5,      -1,-34830       , 0         , "t=3.4s",_
 3086, 75, 167, 1,0.5,       1,-34700       , 0.131     , "t=5.9s",_
 3087, 76, 167, 0,3.5,      -1,-26500       , 0         , "t=839ms",_
 3088, 76, 167, 1,6.5,       1,-26070       , 0.4343    , "t=672ns",_
 3089, 77, 167, 0,0.5,       1,-17072       , 0         , "t=29.3ms",_
 3090, 77, 167, 1,5.5,      -1,-16897       , 0.1755    , "t=28.5ms",_
 3091, 78, 167, 0,3.5,      -1,-6750        , 0         , "t=915us",_
 3092, 62, 168, 0,0,         1,-31640       , 0         , "t=340ms",_
 3093, 63, 168, 0,6,        -1,-39250       , 0         , "t=200ms",_
 3094, 64, 168, 0,0,         1,-48150       , 0         , "t=3.03s",_
 3095, 65, 168, 0,4,        -1,-52781       , 0         , "t=9.4s",_
 3096, 65, 168, 1,6,         1,-52570       , 0.211     , "t=0.71us",_
 3097, 66, 168, 0,0,         1,-58560       , 0         , "t=8.7m",_
 3098, 66, 168, 1,4,        -1,-57180       , 1.3782    , "t=0.57us",_
 3099, 67, 168, 0,3,         1,-60060       , 0         , "t=2.99m",_
 3100, 67, 168, 1,6,         1,-60000       , 0.059     , "t=132s",_
 3101, 68, 168, 0,0,         1,-62989.23    , 0         , "t=stbl",_
 3102, 68, 168, 1,4,        -1,-61895.19    , 1.094038  , "t=109.0ns",_
 3103, 69, 168, 0,3,         1,-61312.4     , 0         , "t=93.1d",_
 3104, 70, 168, 0,0,         1,-61579.87    , 0         , "t=stbl",_
 3105, 71, 168, 0,6,        -1,-57070       , 0         , "t=5.5m",_
 3106, 71, 168, 1,3,         1,-56908       , 0.16      , "t=6.7m",_
 3107, 72, 168, 0,0,         1,-55361       , 0         , "t=25.95m",_
 3108, 73, 168, 0,3,         1,-48394       , 0         , "t=2.0m",_
 3109, 74, 168, 0,0,         1,-44893       , 0         , "t=50.9s",_
 3110, 75, 168, 0,7,         1,-35790       , 0         , "t=4.4s",_
 3111, 76, 168, 0,0,         1,-29995       , 0         , "t=2.1s",_
 3112, 77, 168, 0,2,        -1,-18670       , 0         , "t=230ms",_
 3113, 77, 168, 1,9,         0,-18620       , 0.04      , "t=163ms",_
 3114, 78, 168, 0,0,         1,-11010       , 0         , "t=2.02ms",_
 3115, 79, 168, 0,-77.777,   0,2530         , 0         , "t=?",_
 3116, 63, 169, 0,2.5,       1,-35660       , 0         , "t=420ms",_
 3117, 64, 169, 0,3.5,      -1,-43890       , 0         , "t=750ms",_
 3118, 65, 169, 0,1.5,       1,-50480       , 0         , "t=5.13s",_
 3119, 66, 169, 0,2.5,      -1,-55600       , 0         , "t=39s",_
 3120, 66, 169, 1,0.5,      -1,-55430       , 0.1661    , "t=1.26us",_
 3121, 67, 169, 0,3.5,      -1,-58796       , 0         , "t=4.72m",_
 3122, 67, 169, 1,9.5,       1,-57410       , 1.3862    , "t=118us",_
 3123, 68, 169, 0,0.5,      -1,-60921.2     , 0         , "t=9.392d",_
 3124, 68, 169, 1,2.5,      -1,-60829.2     , 0.09205   , "t=285ns",_
 3125, 69, 169, 0,0.5,       1,-61274.7     , 0         , "t=stbl",_
 3126, 69, 169, 1,3.5,       1,-60958.6     , 0.3161463 , "t=659.9ns",_
 3127, 70, 169, 0,3.5,       1,-60375.53    , 0         , "t=32.014d",_
 3128, 70, 169, 1,0.5,      -1,-60351.33    , 0.0241999 , "t=46s",_
 3129, 71, 169, 0,3.5,       1,-58083       , 0         , "t=34.06h",_
 3130, 71, 169, 1,0.5,      -1,-58054       , 0.029     , "t=160s",_
 3131, 72, 169, 0,2.5,      -1,-54717       , 0         , "t=3.24m",_
 3132, 73, 169, 0,2.5,       1,-50290       , 0         , "t=4.9m",_
 3133, 74, 169, 0,2.5,      -1,-44918       , 0         , "t=74s",_
 3134, 75, 169, 0,4.5,      -1,-38409       , 0         , "t=8.1s",_
 3135, 75, 169, 1,0.5,       1,-38234       , 0.175     , "t=15.1s",_
 3136, 76, 169, 0,2.5,      -1,-30723       , 0         , "t=3.46s",_
 3137, 77, 169, 0,0.5,       1,-22093       , 0         , "t=353ms",_
 3138, 77, 169, 1,5.5,      -1,-21940       , 0.153     , "t=280ms",_
 3139, 78, 169, 0,3.5,      -1,-12460       , 0         , "t=6.99ms",_
 3140, 79, 169, 0,0.5,       1,-1790        , 0         , "t=150us",_
 3141, 63, 170, 0,-77.777,   0,-30860       , 0         , "t=?",_
 3142, 64, 170, 0,0,         1,-40850       , 0         , "t=420ms",_
 3143, 65, 170, 0,2,        -1,-46710       , 0         , "t=960ms",_
 3144, 66, 170, 0,0,         1,-53710       , 0         , "t=54.9s",_
 3145, 66, 170, 1,6,         1,-52070       , 1.6438    , "t=0.99us",_
 3146, 67, 170, 0,6,         1,-56240       , 0         , "t=2.76m",_
 3147, 67, 170, 1,1,         1,-56140       , 0.1       , "t=43s",_
 3148, 68, 170, 0,0,         1,-60107.5     , 0         , "t=stbl",_
 3149, 69, 170, 0,1,        -1,-59795.3     , 0         , "t=128.6d",_
 3150, 69, 170, 1,3,         1,-59612.1     , 0.183197  , "t=4.12us",_
 3151, 70, 170, 0,0,         1,-60763.929   , 0         , "t=stbl",_
 3152, 70, 170, 1,4,        -1,-59505.47    , 1.25846   , "t=370ns",_
 3153, 71, 170, 0,0,         1,-57306       , 0         , "t=2.012d",_
 3154, 71, 170, 1,4,        -1,-57213       , 0.09291   , "t=670ms",_
 3155, 72, 170, 0,0,         1,-56254       , 0         , "t=16.01h",_
 3156, 73, 170, 0,3,         1,-50138       , 0         , "t=6.76m",_
 3157, 74, 170, 0,0,         1,-47291       , 0         , "t=2.42m",_
 3158, 75, 170, 0,8,        -1,-38904       , 0         , "t=&gt;1s",_
 3159, 75, 170, 1,5,         1,-38831       , 0.073     , "t=9.2s",_
 3160, 76, 170, 0,0,         1,-33926       , 0         , "t=7.37s",_
 3161, 77, 170, 0,3,        -1,-23180       , 0         , "t=910ms",_
 3162, 77, 170, 1,8,         1,-23140       , 0.04      , "t=811ms",_
 3163, 78, 170, 0,0,         1,-16299       , 0         , "t=13.93ms",_
 3164, 79, 170, 0,2,        -1,-3700        , 0         , "t=290us",_
 3165, 79, 170, 1,9,         1,-3420        , 0.28      , "t=620us",_
 3166, 80, 170, 0,0,         1,5420         , 0         , "t=310us",_
 3167, 64, 171, 0,4.5,       1,-36210       , 0         , "t=300ms",_
 3168, 65, 171, 0,1.5,       1,-43770       , 0         , "t=1.23s",_
 3169, 66, 171, 0,3.5,      -1,-50010       , 0         , "t=4.07s",_
 3170, 67, 171, 0,3.5,      -1,-54520       , 0         , "t=53s",_
 3171, 68, 171, 0,2.5,      -1,-57717.8     , 0         , "t=7.516h",_
 3172, 68, 171, 1,0.5,      -1,-57519.2     , 0.19861   , "t=210ns",_
 3173, 69, 171, 0,0.5,       1,-59210.3     , 0         , "t=1.92y",_
 3174, 69, 171, 1,3.5,      -1,-58785.3     , 0.4249557 , "t=2.60us",_
 3175, 70, 171, 0,0.5,      -1,-59306.818   , 0         , "t=stbl",_
 3176, 70, 171, 1,3.5,       1,-59211.536   , 0.095282  , "t=5.25ms",_
 3177, 71, 171, 0,3.5,       1,-57828.5     , 0         , "t=8.247d",_
 3178, 71, 171, 1,0.5,      -1,-57757.4     , 0.07113   , "t=79s",_
 3179, 72, 171, 0,3.5,       1,-55431       , 0         , "t=12.1h",_
 3180, 72, 171, 1,0.5,      -1,-55409       , 0.02193   , "t=29.5s",_
 3181, 73, 171, 0,2.5,       1,-51720       , 0         , "t=23.3m",_
 3182, 74, 171, 0,2.5,      -1,-47086       , 0         , "t=2.38m",_
 3183, 75, 171, 0,4.5,      -1,-41250       , 0         , "t=15.2s",_
 3184, 76, 171, 0,2.5,      -1,-34297       , 0         , "t=8.3s",_
 3185, 77, 171, 0,0.5,       1,-26410       , 0         , "t=3.1s",_
 3186, 77, 171, 1,5.5,      -1,-26250       , 0.164     , "t=1.47s",_
 3187, 78, 171, 0,3.5,      -1,-17470       , 0         , "t=45.5ms",_
 3188, 78, 171, 1,6.5,       1,-17060       , 0.4126    , "t=901ns",_
 3189, 79, 171, 0,0.5,       1,-7562        , 0         , "t=22.3us",_
 3190, 79, 171, 1,5.5,      -1,-7308        , 0.255     , "t=1.036ms",_
 3191, 80, 171, 0,1.5,      -1,3340         , 0         , "t=70us",_
 3192, 64, 172, 0,0,         1,-32970       , 0         , "t=160ms",_
 3193, 65, 172, 0,6,         1,-39690       , 0         , "t=760ms",_
 3194, 66, 172, 0,0,         1,-47760       , 0         , "t=3.4s",_
 3195, 66, 172, 1,8,        -1,-46480       , 1.278     , "t=710ms",_
 3196, 67, 172, 0,0,         1,-51480       , 0         , "t=25s",_
 3197, 68, 172, 0,0,         1,-56483       , 0         , "t=49.3h",_
 3198, 68, 172, 1,6,         1,-54982       , 1.5009    , "t=579ns",_
 3199, 69, 172, 0,2,        -1,-57374       , 0         , "t=63.6h",_
 3200, 69, 172, 1,6,         1,-56898       , 0.4762    , "t=132us",_
 3201, 70, 172, 0,0,         1,-59255.456   , 0         , "t=stbl",_
 3202, 70, 172, 1,6,        -1,-57705.03    , 1.55043   , "t=3.6us",_
 3203, 71, 172, 0,4,        -1,-56736.1     , 0         , "t=6.70d",_
 3204, 71, 172, 1,1,        -1,-56694.2     , 0.04186   , "t=3.7m",_
 3205, 72, 172, 0,0,         1,-56402       , 0         , "t=1.87y",_
 3206, 72, 172, 1,8,        -1,-54396       , 2.00584   , "t=163ns",_
 3207, 73, 172, 0,3,         1,-51330       , 0         , "t=36.8m",_
 3208, 74, 172, 0,0,         1,-49097       , 0         , "t=6.6m",_
 3209, 75, 172, 0,2,         1,-41570       , 0         , "t=55s",_
 3210, 75, 172, 1,7,         1,-41460       , 0.11      , "t=15s",_
 3211, 76, 172, 0,0,         1,-37244       , 0         , "t=19.2s",_
 3212, 77, 172, 0,3,        -1,-27380       , 0         , "t=4.4s",_
 3213, 77, 172, 1,7,         1,-27240       , 0.139     , "t=2.19s",_
 3214, 78, 172, 0,0,         1,-21107       , 0         , "t=97.6ms",_
 3215, 79, 172, 0,2,        -1,-9320        , 0         , "t=28ms",_
 3216, 79, 172, 1,9,         0,-9160        , 0.16      , "t=11.0ms",_
 3217, 80, 172, 0,0,         1,-1060        , 0         , "t=231us",_
 3218, 65, 173, 0,1.5,       1,-36510       , 0         , "t=400ms",_
 3219, 66, 173, 0,4.5,       1,-43740       , 0         , "t=1.43s",_
 3220, 67, 173, 0,3.5,      -1,-49350       , 0         , "t=7.1s",_
 3221, 67, 173, 1,0.5,       1,-48950       , 0.405     , "t=3.7us",_
 3222, 68, 173, 0,3.5,      -1,-53650       , 0         , "t=1.434m",_
 3223, 69, 173, 0,0.5,       1,-56256       , 0         , "t=8.24h",_
 3224, 69, 173, 1,3.5,      -1,-55938       , 0.31773   , "t=10.7us",_
 3225, 70, 173, 0,2.5,      -1,-57551.234   , 0         , "t=stbl",_
 3226, 70, 173, 1,0.5,      -1,-57152.3     , 0.3989    , "t=2.9us",_
 3227, 71, 173, 0,3.5,       1,-56881.0     , 0         , "t=1.37y",_
 3228, 71, 173, 1,2.5,      -1,-56757.3     , 0.123672  , "t=74.2us",_
 3229, 72, 173, 0,0.5,      -1,-55412       , 0         , "t=23.6h",_
 3230, 72, 173, 1,2.5,      -1,-55305       , 0.10716   , "t=180ns",_
 3231, 73, 173, 0,2.5,      -1,-52397       , 0         , "t=3.14h",_
 3232, 73, 173, 1,4.5,      -1,-52224       , 0.1731    , "t=205.2ns",_
 3233, 74, 173, 0,2.5,      -1,-48727       , 0         , "t=7.6m",_
 3234, 75, 173, 0,2.5,      -1,-43554       , 0         , "t=2.0m",_
 3235, 76, 173, 0,2.5,      -1,-37438       , 0         , "t=22.4s",_
 3236, 77, 173, 0,0.5,       1,-30268       , 0         , "t=9.0s",_
 3237, 77, 173, 1,5.5,      -1,-30042       , 0.226     , "t=2.20s",_
 3238, 78, 173, 0,2.5,      -1,-21940       , 0         , "t=382ms",_
 3239, 79, 173, 0,0.5,       1,-12832       , 0         , "t=25.5ms",_
 3240, 79, 173, 1,5.5,      -1,-12618       , 0.214     , "t=12.2ms",_
 3241, 80, 173, 0,3.5,      -1,-2660        , 0         , "t=800us",_
 3242, 65, 174, 0,2,        -1,-31970       , 0         , "t=240ms",_
 3243, 66, 174, 0,0,         1,-41130       , 0         , "t=1s",_
 3244, 67, 174, 0,8,        -1,-45870       , 0         , "t=3.7s",_
 3245, 68, 174, 0,0,         1,-51950       , 0         , "t=3.2m",_
 3246, 68, 174, 1,8,        -1,-50840       , 1.1115    , "t=3.9s",_
 3247, 69, 174, 0,4,        -1,-53860       , 0         , "t=5.4m",_
 3248, 69, 174, 1,0,         1,-53610       , 0.2524    , "t=2.29s",_
 3249, 70, 174, 0,0,         1,-56944.521   , 0         , "t=stbl",_
 3250, 70, 174, 1,6,         1,-55426.373   , 1.518148  , "t=830us",_
 3251, 71, 174, 0,1,        -1,-55570.3     , 0         , "t=3.31y",_
 3252, 71, 174, 1,6,        -1,-55399.5     , 0.17083   , "t=142d",_
 3253, 71, 174, 0,26,       -1,-49720.7     , 5.8496    , "t=242ns",_
 3254, 72, 174, 0,0,         1,-55844.6     , 0         , "t=2.0Py",_
 3255, 72, 174, 1,6,         1,-54295.3     , 1.54926   , "t=138ns",_
 3256, 73, 174, 0,3,         1,-51741       , 0         , "t=1.14h",_
 3257, 74, 174, 0,0,         1,-50227       , 0         , "t=33.2m",_
 3258, 75, 174, 0,3,         1,-43673       , 0         , "t=2.40m",_
 3259, 75, 174, 1,7,         1,-43570       , 0.1       , "t=1m",_
 3260, 76, 174, 0,0,         1,-39995       , 0         , "t=44s",_
 3261, 77, 174, 0,2,         1,-30786       , 0         , "t=7.9s",_
 3262, 77, 174, 1,6,         0,-30662       , 0.124     , "t=4.9s",_
 3263, 78, 174, 0,0,         1,-25318       , 0         , "t=862ms",_
 3264, 79, 174, 0,3,        -1,-14060       , 0         , "t=139ms",_
 3265, 79, 174, 1,9,         1,-13930       , 0.13      , "t=162ms",_
 3266, 80, 174, 0,0,         1,-6641        , 0         , "t=2.0ms",_
 3267, 66, 175, 0,0.5,      -1,-36730       , 0         , "t=390ms",_
 3268, 67, 175, 0,3.5,      -1,-43300       , 0         , "t=1.88s",_
 3269, 68, 175, 0,4.5,       1,-48650       , 0         , "t=1.2m",_
 3270, 69, 175, 0,0.5,       1,-52310       , 0         , "t=15.2m",_
 3271, 69, 175, 1,3.5,      -1,-51870       , 0.44      , "t=319ns",_
 3272, 70, 175, 0,3.5,      -1,-54695.56    , 0         , "t=4.185d",_
 3273, 70, 175, 1,0.5,      -1,-54180.69    , 0.514866  , "t=68.2ms",_
 3274, 71, 175, 0,3.5,       1,-55165.7     , 0         , "t=stbl",_
 3275, 71, 175, 1,2.5,      -1,-54812.2     , 0.35348   , "t=1.49us",_
 3276, 72, 175, 0,2.5,      -1,-54481.8     , 0         , "t=70.65d",_
 3277, 72, 175, 1,0.5,      -1,-54355.9     , 0.12589   , "t=53.7us",_
 3278, 73, 175, 0,3.5,       1,-52409       , 0         , "t=10.5h",_
 3279, 73, 175, 1,4.5,      -1,-52278       , 0.13141   , "t=222ns",_
 3280, 74, 175, 0,0.5,      -1,-49633       , 0         , "t=35.2m",_
 3281, 74, 175, 1,3.5,       1,-49398       , 0.23496   , "t=216ns",_
 3282, 75, 175, 0,2.5,      -1,-45288       , 0         , "t=5.89m",_
 3283, 76, 175, 0,2.5,      -1,-40105       , 0         , "t=1.4m",_
 3284, 77, 175, 0,0.5,       1,-33395       , 0         , "t=9s",_
 3285, 77, 175, 1,4.5,      -1,-33350       , 0.05      , "t=33s",_
 3286, 78, 175, 0,3.5,      -1,-25709       , 0         , "t=2.43s",_
 3287, 79, 175, 0,0.5,       1,-17400       , 0         , "t=200ms",_
 3288, 79, 175, 1,5.5,      -1,-17240       , 0.164     , "t=136ms",_
 3289, 80, 175, 0,3.5,      -1,-7970        , 0         , "t=10.2ms",_
 3290, 80, 175, 1,6.5,       1,-7480        , 0.494     , "t=340ns",_
 3291, 66, 176, 0,0,         1,-33610       , 0         , "t=440ms",_
 3292, 67, 176, 0,4,         1,-39390       , 0         , "t=1s",_
 3293, 68, 176, 0,0,         1,-46630       , 0         , "t=12s",_
 3294, 69, 176, 0,4,         1,-49370       , 0         , "t=1.85m",_
 3295, 70, 176, 0,0,         1,-53491.322   , 0         , "t=stbl",_
 3296, 70, 176, 1,8,        -1,-52441.5     , 1.0498    , "t=11.4s",_
 3297, 71, 176, 0,7,        -1,-53382.3     , 0         , "t=37.01Gy",_
 3298, 71, 176, 1,1,        -1,-53259.5     , 0.122845  , "t=3.664h",_
 3299, 72, 176, 0,0,         1,-54576.4     , 0         , "t=stbl",_
 3300, 72, 176, 1,6,         1,-53243.3     , 1.33307   , "t=9.6us",_
 3301, 73, 176, 0,1,        -1,-51370       , 0         , "t=8.09h",_
 3302, 73, 176, 1,7,         1,-51270       , 0.103     , "t=1.08ms",_
 3303, 74, 176, 0,0,         1,-50642       , 0         , "t=2.5h",_
 3304, 75, 176, 0,3,         1,-45063       , 0         , "t=5.3m",_
 3305, 76, 176, 0,0,         1,-42131       , 0         , "t=3.6m",_
 3306, 77, 176, 0,3,         1,-33882       , 0         , "t=8.7s",_
 3307, 77, 176, 1,7,         1,-33830       , 0.05      , "t=10s",_
 3308, 78, 176, 0,0,         1,-28934       , 0         , "t=6.33s",_
 3309, 79, 176, 0,3,        -1,-18520       , 0         , "t=1.05s",_
 3310, 79, 176, 1,8,         1,-18380       , 0.139     , "t=1.36s",_
 3311, 80, 176, 0,0,         1,-11785       , 0         , "t=20.3ms",_
 3312, 81, 176, 0,3,        -1,580          , 0         , "t=6.2ms",_
 3313, 67, 177, 0,3.5,      -1,-36280       , 0         , "t=1s",_
 3314, 68, 177, 0,0.5,      -1,-42860       , 0         , "t=8s",_
 3315, 69, 177, 0,0.5,       1,-47570       , 0         , "t=95s",_
 3316, 69, 177, 1,3.5,      -1,-47470       , 0.1       , "t=77s",_
 3317, 70, 177, 0,4.5,       1,-50986.40    , 0         , "t=1.911h",_
 3318, 70, 177, 1,0.5,      -1,-50654.9     , 0.3315    , "t=6.41s",_
 3319, 71, 177, 0,3.5,       1,-52383.9     , 0         , "t=6.6443d",_
 3320, 71, 177, 1,4.5,      -1,-52233.5     , 0.1503984 , "t=130.1ns",_
 3321, 72, 177, 0,3.5,      -1,-52880.7     , 0         , "t=stbl",_
 3322, 72, 177, 1,11.5,      1,-51565.2     , 1.31545   , "t=1.09s",_
 3323, 73, 177, 0,3.5,       1,-51715       , 0         , "t=56.36h",_
 3324, 73, 177, 1,4.5,      -1,-51642       , 0.07316   , "t=410ns",_
 3325, 74, 177, 0,0.5,      -1,-49702       , 0         , "t=132.4m",_
 3326, 75, 177, 0,2.5,      -1,-46269       , 0         , "t=14m",_
 3327, 75, 177, 1,4.5,      -1,-46170       , 0.1       , "t=&gt;100ns",_
 3328, 76, 177, 0,0.5,      -1,-41956       , 0         , "t=3.0m",_
 3329, 77, 177, 0,2.5,      -1,-36047       , 0         , "t=29.8s",_
 3330, 77, 177, 1,4.5,      -1,-35950       , 0.1       , "t=&gt;100ns",_
 3331, 78, 177, 0,2.5,      -1,-29370       , 0         , "t=10.0s",_
 3332, 78, 177, 1,0.5,      -1,-29223       , 0.1475    , "t=2.35us",_
 3333, 79, 177, 0,0.5,       1,-21546       , 0         , "t=1.501s",_
 3334, 79, 177, 1,5.5,      -1,-21356       , 0.19      , "t=1.193s",_
 3335, 80, 177, 0,3.5,      -1,-12780       , 0         , "t=117ms",_
 3336, 80, 177, 1,6.5,       1,-12460       , 0.3232    , "t=1.50us",_
 3337, 81, 177, 0,0.5,       1,-3340        , 0         , "t=18ms",_
 3338, 81, 177, 1,5.5,      -1,-2533        , 0.807     , "t=230us",_
 3339, 67, 178, 0,2,         1,-32130       , 0         , "t=750ms",_
 3340, 68, 178, 0,0,         1,-40260       , 0         , "t=4s",_
 3341, 69, 178, 0,1,        -1,-44240       , 0         , "t=10s",_
 3342, 70, 178, 0,0,         1,-49677       , 0         , "t=74m",_
 3343, 71, 178, 0,1,         1,-50337.9     , 0         , "t=28.4m",_
 3344, 71, 178, 1,9,        -1,-50214       , 0.1238    , "t=23.1m",_
 3345, 72, 178, 0,0,         1,-52435.4     , 0         , "t=stbl",_
 3346, 72, 178, 1,8,        -1,-51288.0     , 1.147416  , "t=4.0s",_
 3347, 73, 178, 0,7,        -1,-50600       , 0         , "t=2.36h",_
 3348, 73, 178, 1,1,         1,-50498       , 0.1       , "t=9.31m",_
 3349, 74, 178, 0,0,         1,-50407       , 0         , "t=21.6d",_
 3350, 74, 178, 1,25,        1,-43834       , 6.5727    , "t=220ns",_
 3351, 75, 178, 0,3,         1,-45653       , 0         , "t=13.2m",_
 3352, 76, 178, 0,0,         1,-43544       , 0         , "t=5.0m",_
 3353, 77, 178, 0,3,         1,-36254       , 0         , "t=12s",_
 3354, 78, 178, 0,0,         1,-31997       , 0         , "t=20.7s",_
 3355, 79, 178, 0,2,         1,-22303       , 0         , "t=3.4s",_
 3356, 79, 178, 1,4,        -1,-22253       , 0.0503    , "t=300ns",_
 3357, 80, 178, 0,0,         1,-16315       , 0         , "t=266.5ms",_
 3358, 81, 178, 0,4,        -1,-4610        , 0         , "t=255ms",_
 3359, 82, 178, 0,0,         1,3573         , 0         , "t=250us",_
 3360, 68, 179, 0,1.5,      -1,-36080       , 0         , "t=3s",_
 3361, 69, 179, 0,0.5,       1,-41900       , 0         , "t=18s",_
 3362, 70, 179, 0,0.5,      -1,-46640       , 0         , "t=8.0m",_
 3363, 71, 179, 0,3.5,       1,-49059       , 0         , "t=4.59h",_
 3364, 71, 179, 1,0.5,       1,-48467       , 0.5924    , "t=3.1ms",_
 3365, 72, 179, 0,4.5,       1,-50463.0     , 0         , "t=stbl",_
 3366, 72, 179, 1,0.5,      -1,-50088.0     , 0.3750352 , "t=18.67s",_
 3367, 73, 179, 0,3.5,       1,-50357.5     , 0         , "t=1.82y",_
 3368, 73, 179, 1,4.5,      -1,-50326.8     , 0.0307    , "t=1.42us",_
 3369, 73, 179, 0,18.5,      1,-47718.2     , 2.6393    , "t=54.1ms",_
 3370, 74, 179, 0,3.5,      -1,-49295       , 0         , "t=37.05m",_
 3371, 74, 179, 1,0.5,      -1,-49073       , 0.22191   , "t=6.40m",_
 3372, 75, 179, 0,2.5,       1,-46584       , 0         , "t=19.5m",_
 3373, 75, 179, 1,2.5,      -1,-46519       , 0.06535   , "t=95us",_
 3374, 76, 179, 0,0.5,      -1,-43020       , 0         , "t=6.5m",_
 3375, 76, 179, 1,3.5,      -1,-42875       , 0.14541   , "t=500ns",_
 3376, 77, 179, 0,2.5,      -1,-38082       , 0         , "t=79s",_
 3377, 78, 179, 0,0.5,      -1,-32268       , 0         , "t=21.2s",_
 3378, 79, 179, 0,0.5,       1,-24989       , 0         , "t=7.1s",_
 3379, 79, 179, 1,1.5,      -1,-24900       , 0.0895    , "t=327ns",_
 3380, 80, 179, 0,3.5,      -1,-16933       , 0         , "t=1.05s",_
 3381, 80, 179, 1,6.5,       1,-16762       , 0.1714    , "t=6.4us",_
 3382, 81, 179, 0,0.5,       1,-8270        , 0         , "t=437ms",_
 3383, 81, 179, 1,5.5,      -1,-7450        , 0.825     , "t=1.41ms",_
 3384, 82, 179, 0,4.5,      -1,2050         , 0         , "t=2.7ms",_
 3385, 68, 180, 0,0,         1,-33180       , 0         , "t=2s",_
 3386, 69, 180, 0,-77.777,   0,-38170       , 0         , "t=3s",_
 3387, 70, 180, 0,0,         1,-44720       , 0         , "t=2.4m",_
 3388, 71, 180, 0,5,         1,-46680       , 0         , "t=5.7m",_
 3389, 71, 180, 1,3,        -1,-46670       , 0.0139    , "t=~1s",_
 3390, 72, 180, 0,0,         1,-49779.5     , 0         , "t=stbl",_
 3391, 72, 180, 1,8,        -1,-48637.9     , 1.141552  , "t=5.53h",_
 3392, 73, 180, 0,1,         1,-48933.6     , 0         , "t=8.154h",_
 3393, 73, 180, 1,9,        -1,-48858.3     , 0.0753    , "t=stbl",_
 3394, 74, 180, 0,0,         1,-49636.2     , 0         , "t=1.59Ey",_
 3395, 74, 180, 1,8,        -1,-48107.1     , 1.52905   , "t=5.47ms",_
 3396, 75, 180, 0,1,        -1,-45837       , 0         , "t=2.46m",_
 3397, 75, 180, 1,4,         1,-45750       , 0.09      , "t=&gt;1us",_
 3398, 76, 180, 0,0,         1,-44356       , 0         , "t=21.5m",_
 3399, 77, 180, 0,5,         1,-37978       , 0         , "t=1.5m",_
 3400, 78, 180, 0,0,         1,-34430       , 0         , "t=56s",_
 3401, 79, 180, 0,1,         1,-25626       , 0         , "t=7.9s",_
 3402, 80, 180, 0,0,         1,-20251       , 0         , "t=2.59s",_
 3403, 81, 180, 0,4,        -1,-9390        , 0         , "t=1.09s",_
 3404, 82, 180, 0,0,         1,-1941        , 0         , "t=4.1ms",_
 3405, 69, 181, 0,0.5,       1,-35440       , 0         , "t=7s",_
 3406, 70, 181, 0,1.5,      -1,-41090       , 0         , "t=1m",_
 3407, 71, 181, 0,3.5,       1,-44800       , 0         , "t=3.5m",_
 3408, 72, 181, 0,0.5,      -1,-47403.0     , 0         , "t=42.39d",_
 3409, 72, 181, 1,4.5,       1,-46807.7     , 0.59527   , "t=80us",_
 3410, 73, 181, 0,3.5,       1,-48439.1     , 0         , "t=stbl",_
 3411, 73, 181, 1,4.5,      -1,-48432.9     , 0.006237  , "t=6.05us",_
 3412, 74, 181, 0,4.5,       1,-48233.9     , 0         , "t=120.956d",_
 3413, 74, 181, 1,2.5,      -1,-47868.4     , 0.36555   , "t=14.59us",_
 3414, 75, 181, 0,2.5,       1,-46517       , 0         , "t=19.9h",_
 3415, 75, 181, 1,4.5,      -1,-46254       , 0.26291   , "t=156.7ns",_
 3416, 76, 181, 0,0.5,      -1,-43550       , 0         , "t=105m",_
 3417, 76, 181, 1,3.5,      -1,-43501       , 0.0492    , "t=2.7m",_
 3418, 77, 181, 0,2.5,      -1,-39463       , 0         , "t=4.90m",_
 3419, 77, 181, 1,2.5,       1,-39174       , 0.28933   , "t=298ns",_
 3420, 78, 181, 0,0.5,      -1,-34381       , 0         , "t=52.0s",_
 3421, 78, 181, 1,3.5,      -1,-34264       , 0.11665   , "t=&gt;300ns",_
 3422, 79, 181, 0,2.5,      -1,-27871       , 0         , "t=13.7s",_
 3423, 80, 181, 0,0.5,      -1,-20661       , 0         , "t=3.6s",_
 3424, 80, 181, 1,6.5,       1,-20450       , 0.21      , "t=480us",_
 3425, 81, 181, 0,0.5,       1,-12799       , 0         , "t=2.9s",_
 3426, 81, 181, 1,4.5,      -1,-11963       , 0.8359    , "t=1.40ms",_
 3427, 82, 181, 0,4.5,      -1,-3110        , 0         , "t=39.0ms",_
 3428, 69, 182, 0,-77.777,   0,-31490       , 0         , "t=?",_
 3429, 70, 182, 0,0,         1,-38900       , 0         , "t=30s",_
 3430, 71, 182, 0,1,        -1,-41770       , 0         , "t=2.0m",_
 3431, 72, 182, 0,0,         1,-46050       , 0         , "t=8.90My",_
 3432, 72, 182, 1,8,        -1,-44877       , 1.17287   , "t=61.5m",_
 3433, 73, 182, 0,3,        -1,-46430.7     , 0         , "t=114.74d",_
 3434, 73, 182, 1,5,         1,-46414.4     , 0.016273  , "t=283ms",_
 3435, 74, 182, 0,0,         1,-48246.1     , 0         , "t=stbl",_
 3436, 74, 182, 1,10,        1,-46015.5     , 2.23065   , "t=1.3us",_
 3437, 75, 182, 0,7,         1,-45450       , 0         , "t=64.2h",_
 3438, 75, 182, 1,2,         1,-45386       , 0.06      , "t=14.14h",_
 3439, 76, 182, 0,0,         1,-44609       , 0         , "t=21.84h",_
 3440, 76, 182, 1,8,        -1,-42778       , 1.8314    , "t=780us",_
 3441, 77, 182, 0,3,         1,-39052       , 0         , "t=15.0m",_
 3442, 77, 182, 1,5,         1,-38981       , 0.07102   , "t=170ns",_
 3443, 78, 182, 0,0,         1,-36168       , 0         , "t=2.67m",_
 3444, 79, 182, 0,2,         1,-28304       , 0         , "t=15.5s",_
 3445, 79, 182, 1,5,        -1,-28180       , 0.12      , "t=10s",_
 3446, 80, 182, 0,0,         1,-23577       , 0         , "t=10.83s",_
 3447, 81, 182, 0,4,        -1,-13327       , 0         , "t=1.9s",_
 3448, 81, 182, 1,7,         1,-13280       , 0.05      , "t=3.1s",_
 3449, 82, 182, 0,0,         1,-6825        , 0         , "t=55ms",_
 3450, 70, 183, 0,1.5,      -1,-35000       , 0         , "t=30s",_
 3451, 71, 183, 0,3.5,       1,-39720       , 0         , "t=58s",_
 3452, 72, 183, 0,1.5,      -1,-43280       , 0         , "t=1.018h",_
 3453, 72, 183, 1,13.5,     -1,-41820       , 1.464     , "t=40s",_
 3454, 73, 183, 0,3.5,       1,-45293.5     , 0         , "t=5.1d",_
 3455, 73, 183, 1,4.5,      -1,-45220.3     , 0.073164  , "t=106ns",_
 3456, 74, 183, 0,0.5,      -1,-46365.7     , 0         , "t=stbl",_
 3457, 74, 183, 1,5.5,       1,-46056.2     , 0.309492  , "t=5.30s",_
 3458, 75, 183, 0,2.5,       1,-45810       , 0         , "t=70.0d",_
 3459, 75, 183, 1,12.5,      1,-43903       , 1.90721   , "t=1.04ms",_
 3460, 76, 183, 0,4.5,       1,-43660       , 0         , "t=13.0h",_
 3461, 76, 183, 1,0.5,      -1,-43490       , 0.17073   , "t=9.9h",_
 3462, 77, 183, 0,2.5,      -1,-40202       , 0         , "t=58m",_
 3463, 78, 183, 0,0.5,      -1,-35773       , 0         , "t=6.5m",_
 3464, 78, 183, 1,3.5,      -1,-35738       , 0.03474   , "t=43s",_
 3465, 79, 183, 0,2.5,      -1,-30191       , 0         , "t=42.8s",_
 3466, 79, 183, 1,0.5,       1,-30118       , 0.0731    , "t=&gt;1us",_
 3467, 80, 183, 0,0.5,      -1,-23805       , 0         , "t=9.4s",_
 3468, 80, 183, 1,6.5,       1,-23601       , 0.204     , "t=&gt;5us",_
 3469, 81, 183, 0,0.5,       1,-16587       , 0         , "t=6.9s",_
 3470, 81, 183, 1,4.5,      -1,-15959       , 0.6287    , "t=53.3ms",_
 3471, 82, 183, 0,1.5,      -1,-7580        , 0         , "t=535ms",_
 3472, 82, 183, 1,6.5,       1,-7486        , 0.094     , "t=415ms",_
 3473, 70, 184, 0,0,         1,-32600       , 0         , "t=7s",_
 3474, 71, 184, 0,3,         1,-36300       , 0         , "t=20s",_
 3475, 72, 184, 0,0,         1,-41500       , 0         , "t=4.12h",_
 3476, 72, 184, 1,8,        -1,-40230       , 1.2722    , "t=48s",_
 3477, 73, 184, 0,5,        -1,-42839       , 0         , "t=8.7h",_
 3478, 74, 184, 0,0,         1,-45705.5     , 0         , "t=stbl",_
 3479, 74, 184, 1,5,        -1,-44420.5     , 1.284997  , "t=8.33us",_
 3480, 75, 184, 0,3,        -1,-44220       , 0         , "t=35.4d",_
 3481, 75, 184, 1,8,         1,-44032       , 0.1880463 , "t=169d",_
 3482, 76, 184, 0,0,         1,-44252.6     , 0         , "t=11.2Ty",_
 3483, 77, 184, 0,5,        -1,-39611       , 0         , "t=3.09h",_
 3484, 77, 184, 1,3,         1,-39385       , 0.22565   , "t=470us",_
 3485, 78, 184, 0,0,         1,-37332       , 0         , "t=17.3m",_
 3486, 78, 184, 1,8,        -1,-35492       , 1.8403    , "t=1.01ms",_
 3487, 79, 184, 0,5,         1,-30319       , 0         , "t=20.6s",_
 3488, 79, 184, 1,2,         1,-30251       , 0.06846   , "t=47.6s",_
 3489, 80, 184, 0,0,         1,-26345       , 0         , "t=30.87s",_
 3490, 81, 184, 0,2,        -1,-16883       , 0         , "t=9.5s",_
 3491, 81, 184, 1,7,         1,-16930       ,-0.05      , "t=10.6s",_
 3492, 82, 184, 0,0,         1,-11052       , 0         , "t=490ms",_
 3493, 83, 184, 0,3,         1,1250         , 0         , "t=6.6ms",_
 3494, 83, 184, 1,10,       -1,1400         , 0.15      , "t=13ms",_
 3495, 70, 185, 0,4.5,      -1,-28480       , 0         , "t=5s",_
 3496, 71, 185, 0,3.5,       1,-33960       , 0         , "t=20s",_
 3497, 72, 185, 0,4.5,      -1,-38320       , 0         , "t=3.5m",_
 3498, 73, 185, 0,3.5,       1,-41394       , 0         , "t=49.4m",_
 3499, 73, 185, 1,1.5,       1,-40988       , 0.406     , "t=900ns",_
 3500, 74, 185, 0,1.5,      -1,-43387.9     , 0         , "t=75.1d",_
 3501, 74, 185, 1,5.5,       1,-43190.5     , 0.197383  , "t=1.597m",_
 3502, 75, 185, 0,2.5,       1,-43819.0     , 0         , "t=stbl",_
 3503, 75, 185, 1,12.5,      1,-41694.9     , 2.1241    , "t=200ns",_
 3504, 76, 185, 0,0.5,      -1,-42805.9     , 0         , "t=92.95d",_
 3505, 76, 185, 1,3.5,      -1,-42703.5     , 0.10237   , "t=3.0us",_
 3506, 77, 185, 0,2.5,      -1,-40336       , 0         , "t=14.4h",_
 3507, 77, 185, 1,11.5,      0,-38140       , 2.197     , "t=120ns",_
 3508, 78, 185, 0,4.5,       1,-36688       , 0         , "t=70.9m",_
 3509, 78, 185, 1,0.5,      -1,-36585       , 0.10341   , "t=33.0m",_
 3510, 79, 185, 0,2.5,      -1,-31858.1     , 0         , "t=4.25m",_
 3511, 79, 185, 1,0.5,       1,-31810       , 0.05      , "t=6.8m",_
 3512, 80, 185, 0,0.5,      -1,-26184       , 0         , "t=49.1s",_
 3513, 80, 185, 1,6.5,       1,-26080       , 0.1037    , "t=21.6s",_
 3514, 81, 185, 0,0.5,       1,-19758       , 0         , "t=19.5s",_
 3515, 81, 185, 1,4.5,      -1,-19303       , 0.4548    , "t=1.93s",_
 3516, 82, 185, 0,1.5,      -1,-11541       , 0         , "t=6.3s",_
 3517, 82, 185, 1,6.5,       1,-11470       , 0.07      , "t=4.07s",_
 3518, 83, 185, 0,4.5,      -1,-2240        , 0         , "t=2ms",_
 3519, 83, 185, 1,0.5,       1,-2156        , 0.08      , "t=58us",_
 3520, 71, 186, 0,-77.777,   0,-30320       , 0         , "t=6s",_
 3521, 72, 186, 0,0,         1,-36420       , 0         , "t=2.6m",_
 3522, 72, 186, 1,17,        1,-33450       , 2.968     , "t=&gt;20s",_
 3523, 73, 186, 0,3,         0,-38610       , 0         , "t=10.5m",_
 3524, 73, 186, 1,9,         1,-38270       , 0.336     , "t=1.54m",_
 3525, 74, 186, 0,0,         1,-42508.6     , 0         , "t=stbl",_
 3526, 74, 186, 1,7,        -1,-40991.4     , 1.5172    , "t=18us",_
 3527, 75, 186, 0,1,        -1,-41927.3     , 0         , "t=3.7185d",_
 3528, 75, 186, 1,8,         1,-41779.1     , 0.1482    , "t=~200ky",_
 3529, 76, 186, 0,0,         1,-43000.0     , 0         , "t=2.0Py",_
 3530, 77, 186, 0,5,         1,-39172       , 0         , "t=16.64h",_
 3531, 77, 186, 1,2,        -1,-39171       , 0.0008    , "t=1.92h",_
 3532, 78, 186, 0,0,         1,-37864       , 0         , "t=2.08h",_
 3533, 79, 186, 0,3,        -1,-31715       , 0         , "t=10.7m",_
 3534, 79, 186, 1,6,        -1,-31670       , 0.05      , "t=&gt;1us",_
 3535, 80, 186, 0,0,         1,-28539       , 0         , "t=1.38m",_
 3536, 80, 186, 1,8,        -1,-26322       , 2.2173    , "t=82us",_
 3537, 81, 186, 0,2,        -1,-19883       , 0         , "t=3.5s",_
 3538, 81, 186, 1,7,         1,-19860       , 0.02      , "t=27.5s",_
 3539, 82, 186, 0,0,         1,-14681       , 0         , "t=4.82s",_
 3540, 83, 186, 0,3,         1,-3145        , 0         , "t=14.8ms",_
 3541, 83, 186, 1,10,       -1,-2980        , 0.17      , "t=9.8ms",_
 3542, 84, 186, 0,0,         1,4102         , 0         , "t=34us",_
 3543, 71, 187, 0,3.5,       1,-27770       , 0         , "t=7s",_
 3544, 72, 187, 0,4.5,      -1,-33000       , 0         , "t=14s",_
 3545, 72, 187, 1,1.5,      -1,-32500       , 0.5       , "t=270ns",_
 3546, 73, 187, 0,3.5,       1,-36900       , 0         , "t=2.3m",_
 3547, 73, 187, 1,12.5,     -1,-35110       , 1.778     , "t=7.3s",_
 3548, 74, 187, 0,1.5,      -1,-39904.0     , 0         , "t=23.809h",_
 3549, 74, 187, 1,5.5,       1,-39493.9     , 0.41006   , "t=1.38us",_
 3550, 75, 187, 0,2.5,       1,-41216.5     , 0         , "t=41.6Gy",_
 3551, 75, 187, 1,4.5,      -1,-41010.3     , 0.2062473 , "t=555.3ns",_
 3552, 76, 187, 0,0.5,      -1,-41219.0     , 0         , "t=stbl",_
 3553, 76, 187, 1,3.5,      -1,-41118.6     , 0.10045   , "t=112ns",_
 3554, 77, 187, 0,1.5,       1,-39549       , 0         , "t=10.5h",_
 3555, 77, 187, 1,4.5,      -1,-39363       , 0.18616   , "t=30.3ms",_
 3556, 78, 187, 0,1.5,      -1,-36685       , 0         , "t=2.35h",_
 3557, 78, 187, 1,5.5,       1,-36511       , 0.17438   , "t=311us",_
 3558, 79, 187, 0,0.5,       1,-33029       , 0         , "t=8.3m",_
 3559, 79, 187, 1,4.5,      -1,-32909       , 0.12033   , "t=2.3s",_
 3560, 80, 187, 0,1.5,      -1,-28119       , 0         , "t=1.9m",_
 3561, 80, 187, 1,6.5,       1,-28060       , 0.058     , "t=2.4m",_
 3562, 81, 187, 0,0.5,       1,-22445       , 0         , "t=~51s",_
 3563, 81, 187, 1,4.5,      -1,-22111       , 0.334     , "t=15.60s",_
 3564, 82, 187, 0,1.5,      -1,-14987       , 0         , "t=15.2s",_
 3565, 82, 187, 1,6.5,       1,-14968       , 0.019     , "t=18.3s",_
 3566, 83, 187, 0,4.5,      -1,-6383        , 0         , "t=37ms",_
 3567, 83, 187, 1,0.5,       1,-6275        , 0.108     , "t=370us",_
 3568, 84, 187, 0,0.5,      -1,2820         , 0         , "t=1.40ms",_
 3569, 84, 187, 1,6.5,       1,2830         , 0.004     , "t=0.5ms",_
 3570, 71, 188, 0,-77.777,   0,-23820       , 0         , "t=1s",_
 3571, 72, 188, 0,0,         1,-30830       , 0         , "t=7s",_
 3572, 73, 188, 0,1,        -1,-33910       , 0         , "t=19.6s",_
 3573, 73, 188, 1,7,        -1,-33810       , 0.099     , "t=19.6s",_
 3574, 74, 188, 0,0,         1,-38668       , 0         , "t=69.77d",_
 3575, 74, 188, 1,8,        -1,-36741       , 1.9267    , "t=109.5ns",_
 3576, 75, 188, 0,1,        -1,-39016.9     , 0         , "t=17.005h",_
 3577, 75, 188, 1,6,        -1,-38844.8     , 0.1720848 , "t=18.59m",_
 3578, 76, 188, 0,0,         1,-41137.3     , 0         , "t=stbl",_
 3579, 77, 188, 0,1,        -1,-38345       , 0         , "t=41.5h",_
 3580, 77, 188, 1,11,       -1,-37381       , 0.964     , "t=4.15ms",_
 3581, 78, 188, 0,0,         1,-37821       , 0         , "t=10.16d",_
 3582, 79, 188, 0,1,        -1,-32371.3     , 0         , "t=8.84m",_
 3583, 80, 188, 0,0,         1,-30198       , 0         , "t=3.25m",_
 3584, 80, 188, 1,12,        1,-27474       , 2.7241    , "t=142ns",_
 3585, 81, 188, 0,2,        -1,-22336       , 0         , "t=71s",_
 3586, 81, 188, 1,7,         1,-22308       , 0.03      , "t=71.5s",_
 3587, 82, 188, 0,0,         1,-17811       , 0         , "t=25.1s",_
 3588, 82, 188, 1,8,        -1,-15234       , 2.5772    , "t=800ns",_
 3589, 83, 188, 0,3,         1,-7195        , 0         , "t=60ms",_
 3590, 83, 188, 1,7,         1,-7130        , 0.066     , "t=&gt;5us",_
 3591, 84, 188, 0,0,         1,-544         , 0         , "t=270us",_
 3592, 72, 189, 0,1.5,      -1,-27150       , 0         , "t=400ms",_
 3593, 73, 189, 0,3.5,       1,-31960       , 0         , "t=20s",_
 3594, 73, 189, 1,10.5,     -1,-30310       , 1.65      , "t=1.6us",_
 3595, 74, 189, 0,4.5,      -1,-35810       , 0         , "t=11.6m",_
 3596, 75, 189, 0,2.5,       1,-37979       , 0         , "t=24.3h",_
 3597, 75, 189, 1,4.5,      -1,-37854       , 0.125     , "t=2us",_
 3598, 76, 189, 0,1.5,      -1,-38986.8     , 0         , "t=stbl",_
 3599, 76, 189, 1,4.5,      -1,-38956.0     , 0.03082   , "t=5.81h",_
 3600, 77, 189, 0,1.5,       1,-38450       , 0         , "t=13.2d",_
 3601, 77, 189, 1,5.5,      -1,-38078       , 0.37217   , "t=13.3ms",_
 3602, 78, 189, 0,1.5,      -1,-36469       , 0         , "t=10.87h",_
 3603, 78, 189, 1,4.5,      -1,-36296       , 0.17279   , "t=464ns",_
 3604, 79, 189, 0,0.5,       1,-33582       , 0         , "t=28.7m",_
 3605, 79, 189, 1,5.5,      -1,-33335       , 0.24725   , "t=4.59m",_
 3606, 80, 189, 0,1.5,      -1,-29630       , 0         , "t=7.6m",_
 3607, 80, 189, 1,6.5,       1,-29548       , 0.08      , "t=8.6m",_
 3608, 81, 189, 0,0.5,       1,-24616       , 0         , "t=2.3m",_
 3609, 81, 189, 1,4.5,      -1,-24331       , 0.285     , "t=1.4m",_
 3610, 82, 189, 0,1.5,      -1,-17844       , 0         , "t=39s",_
 3611, 82, 189, 1,6.5,       1,-17804       , 0.04      , "t=50.5s",_
 3612, 83, 189, 0,4.5,      -1,-10065       , 0         , "t=688ms",_
 3613, 83, 189, 1,0.5,       1,-9881        , 0.184     , "t=5.0ms",_
 3614, 84, 189, 0,2.5,      -1,-1422        , 0         , "t=3.5ms",_
 3615, 72, 190, 0,0,         1,-24800       , 0         , "t=600ms",_
 3616, 73, 190, 0,3,         0,-28720       , 0         , "t=5.3s",_
 3617, 74, 190, 0,0,         1,-34370       , 0         , "t=30.0m",_
 3618, 74, 190, 1,8,         1,-32630       , 1.7436    , "t=111ns",_
 3619, 75, 190, 0,2,        -1,-35583       , 0         , "t=3.0m",_
 3620, 75, 190, 1,6,        -1,-35379       , 0.204     , "t=3.1h",_
 3621, 76, 190, 0,0,         1,-38707.8     , 0         , "t=stbl",_
 3622, 76, 190, 1,10,       -1,-37002.1     , 1.7057    , "t=9.86m",_
 3623, 77, 190, 0,4,        -1,-36753.6     , 0         , "t=11.78d",_
 3624, 77, 190, 1,1,        -1,-36727.5     , 0.0261    , "t=1.120h",_
 3625, 78, 190, 0,0,         1,-37306.5     , 0         , "t=483Gy",_
 3626, 79, 190, 0,1,        -1,-32834       , 0         , "t=42.8m",_
 3627, 79, 190, 1,11,       -1,-32630       , 0.2       , "t=125ms",_
 3628, 80, 190, 0,0,         1,-31371       , 0         , "t=20.0m",_
 3629, 81, 190, 0,2,        -1,-24366       , 0         , "t=2.6m",_
 3630, 81, 190, 1,7,         1,-24296       , 0.07      , "t=3.6m",_
 3631, 82, 190, 0,0,         1,-20417       , 0         , "t=71s",_
 3632, 82, 190, 1,10,        1,-17802       , 2.6148    , "t=150ns",_
 3633, 83, 190, 0,3,         1,-10596       , 0         , "t=6.3s",_
 3634, 83, 190, 1,10,       -1,-10470       , 0.12      , "t=6.2s",_
 3635, 84, 190, 0,0,         1,-4563        , 0         , "t=2.45ms",_
 3636, 73, 191, 0,3.5,       1,-26520       , 0         , "t=460ms",_
 3637, 74, 191, 0,1.5,      -1,-31180       , 0         , "t=14s",_
 3638, 74, 191, 1,4.5,      -1,-30950       , 0.235     , "t=340ns",_
 3639, 75, 191, 0,1.5,       1,-34350       , 0         , "t=9.8m",_
 3640, 75, 191, 1,4.5,      -1,-34205       , 0.145     , "t=20us",_
 3641, 76, 191, 0,4.5,      -1,-36395.2     , 0         , "t=14.99d",_
 3642, 76, 191, 1,1.5,      -1,-36320.8     , 0.074382  , "t=13.10h",_
 3643, 77, 191, 0,1.5,       1,-36708.8     , 0         , "t=stbl",_
 3644, 77, 191, 1,5.5,      -1,-36537.5     , 0.17129   , "t=4.899s",_
 3645, 78, 191, 0,1.5,      -1,-35698       , 0         , "t=2.83d",_
 3646, 78, 191, 1,4.5,      -1,-35597       , 0.100663  , "t=&gt;1us",_
 3647, 79, 191, 0,1.5,       1,-33798       , 0         , "t=3.18h",_
 3648, 79, 191, 1,5.5,      -1,-33532       , 0.2662    , "t=920ms",_
 3649, 80, 191, 0,1.5,      -1,-30592       , 0         , "t=49m",_
 3650, 80, 191, 1,6.5,       1,-30460       , 0.128     , "t=50.8m",_
 3651, 81, 191, 0,0.5,       1,-26283       , 0         , "t=20m",_
 3652, 81, 191, 1,4.5,      -1,-25986       , 0.297     , "t=5.22m",_
 3653, 82, 191, 0,1.5,      -1,-20291       , 0         , "t=1.33m",_
 3654, 82, 191, 1,6.5,       1,-20234       , 0.058     , "t=2.18m",_
 3655, 83, 191, 0,4.5,      -1,-13239       , 0         , "t=12.4s",_
 3656, 83, 191, 1,0.5,       1,-12997       , 0.242     , "t=125ms",_
 3657, 84, 191, 0,1.5,      -1,-5069        , 0         , "t=22ms",_
 3658, 84, 191, 1,6.5,       1,-5008        , 0.061     , "t=93ms",_
 3659, 85, 191, 0,0.5,       1,3864         , 0         , "t=2.1ms",_
 3660, 85, 191, 1,3.5,      -1,3922         , 0.058     , "t=2.2ms",_
 3661, 73, 192, 0,2,         0,-23100       , 0         , "t=2.2s",_
 3662, 74, 192, 0,0,         1,-29620       , 0         , "t=40s",_
 3663, 75, 192, 0,0,        -1,-31590       , 0         , "t=15.4s",_
 3664, 75, 192, 1,-77.777,   0,-31430       , 0.159     , "t=88us",_
 3665, 76, 192, 0,0,         1,-35882.3     , 0         , "t=stbl",_
 3666, 76, 192, 1,10,       -1,-33866.9     , 2.0154    , "t=5.94s",_
 3667, 77, 192, 0,4,         1,-34835.6     , 0         , "t=73.820d",_
 3668, 77, 192, 1,1,        -1,-34778.9     , 0.05672   , "t=1.45m",_
 3669, 78, 192, 0,0,         1,-36288.5     , 0         , "t=stbl",_
 3670, 78, 192, 1,10,       -1,-34116.1     , 2.17237   , "t=272ns",_
 3671, 79, 192, 0,1,        -1,-32772       , 0         , "t=4.94h",_
 3672, 79, 192, 1,5,         1,-32637       , 0.13541   , "t=29ms",_
 3673, 80, 192, 0,0,         1,-32011       , 0         , "t=4.85h",_
 3674, 81, 192, 0,2,        -1,-25870       , 0         , "t=9.6m",_
 3675, 81, 192, 1,7,         1,-25670       , 0.196     , "t=10.8m",_
 3676, 82, 192, 0,0,         1,-22552       , 0         , "t=3.5m",_
 3677, 82, 192, 1,10,        1,-19971       , 2.5811    , "t=166ns",_
 3678, 83, 192, 0,3,         1,-13530       , 0         , "t=34.6s",_
 3679, 83, 192, 1,10,       -1,-13398       , 0.14      , "t=39.6s",_
 3680, 84, 192, 0,0,         1,-8066        , 0         , "t=32.2ms",_
 3681, 84, 192, 1,11,       -1,-5771        , 2.2946    , "t=580ns",_
 3682, 85, 192, 0,3,         1,2926         , 0         , "t=11.5ms",_
 3683, 85, 192, 1,9,        -1,2926         , 0         , "t=88ms",_
 3684, 73, 193, 0,3.5,       1,-20810       , 0         , "t=220ms",_
 3685, 74, 193, 0,0.5,      -1,-26190       , 0         , "t=30s",_
 3686, 75, 193, 0,2.5,       1,-30230       , 0         , "t=3m",_
 3687, 75, 193, 1,4.5,      -1,-30080       , 0.146     , "t=69us",_
 3688, 76, 193, 0,1.5,      -1,-33394.4     , 0         , "t=29.830h",_
 3689, 76, 193, 1,4.5,      -1,-33078.8     , 0.3156    , "t=121ns",_
 3690, 77, 193, 0,1.5,       1,-34536.3     , 0         , "t=stbl",_
 3691, 77, 193, 1,5.5,      -1,-34456.1     , 0.080238  , "t=10.53d",_
 3692, 78, 193, 0,0.5,      -1,-34479.7     , 0         , "t=50y",_
 3693, 78, 193, 1,6.5,       1,-34329.9     , 0.14978   , "t=4.33d",_
 3694, 79, 193, 0,1.5,       1,-33405       , 0         , "t=17.65h",_
 3695, 79, 193, 1,5.5,      -1,-33115       , 0.2902    , "t=3.9s",_
 3696, 80, 193, 0,1.5,      -1,-31062       , 0         , "t=3.80h",_
 3697, 80, 193, 1,6.5,       1,-30921       , 0.14076   , "t=11.8h",_
 3698, 81, 193, 0,0.5,       1,-27477       , 0         , "t=21.6m",_
 3699, 81, 193, 1,4.5,      -1,-27105       , 0.372     , "t=2.11m",_
 3700, 82, 193, 0,1.5,      -1,-22229       , 0         , "t=4m",_
 3701, 82, 193, 1,6.5,       1,-22137       , 0.093     , "t=5.8m",_
 3702, 83, 193, 0,4.5,      -1,-15885       , 0         , "t=63.6s",_
 3703, 83, 193, 1,0.5,       1,-15580       , 0.305     , "t=3.20s",_
 3704, 84, 193, 0,1.5,      -1,-8325        , 0         , "t=399ms",_
 3705, 84, 193, 1,6.5,       1,-8225        , 0.1       , "t=245ms",_
 3706, 85, 193, 0,0.5,       1,-67          , 0         , "t=29ms",_
 3707, 85, 193, 1,3.5,      -1,-59          , 0.008     , "t=21ms",_
 3708, 86, 193, 0,1.5,      -1,9043         , 0         , "t=1.15ms",_
 3709, 73, 194, 0,-77.777,   0,-17130       , 0         , "t=2s",_
 3710, 74, 194, 0,0,         1,-24410       , 0         , "t=20s",_
 3711, 75, 194, 0,1,        -1,-27260       , 0         , "t=5s",_
 3712, 75, 194, 1,4,        -1,-27110       , 0.15      , "t=45us",_
 3713, 76, 194, 0,0,         1,-32435.2     , 0         , "t=6.0y",_
 3714, 77, 194, 0,1,        -1,-32531.8     , 0         , "t=19.35h",_
 3715, 77, 194, 1,4,         1,-32384.7     , 0.147072  , "t=31.85ms",_
 3716, 78, 194, 0,0,         1,-34760.1     , 0         , "t=stbl",_
 3717, 79, 194, 0,1,        -1,-32211.9     , 0         , "t=38.02h",_
 3718, 79, 194, 1,5,         1,-32104.5     , 0.1074    , "t=600ms",_
 3719, 80, 194, 0,0,         1,-32184.0     , 0         , "t=447y",_
 3720, 81, 194, 0,2,        -1,-26937       , 0         , "t=33.0m",_
 3721, 81, 194, 1,7,         1,-26677       , 0.26      , "t=32.8m",_
 3722, 82, 194, 0,0,         1,-24208       , 0         , "t=10.7m",_
 3723, 82, 194, 1,12,        1,-21580       , 2.6281    , "t=370ns",_
 3724, 83, 194, 0,3,         1,-16023       , 0         , "t=95s",_
 3725, 83, 194, 1,6,         1,-15880       , 0.15      , "t=125s",_
 3726, 84, 194, 0,0,         1,-11005       , 0         , "t=392ms",_
 3727, 84, 194, 1,10,       -1,-8692        , 2.3134    , "t=12.9us",_
 3728, 85, 194, 0,5,        -1,-716         , 0         , "t=286ms",_
 3729, 85, 194, 1,10,       -1,-740         ,-0.02      , "t=323ms",_
 3730, 86, 194, 0,0,         1,5725         , 0         , "t=780us",_
 3731, 74, 195, 0,1.5,      -1,-20740       , 0         , "t=30s",_
 3732, 75, 195, 0,2.5,       1,-25560       , 0         , "t=6s",_
 3733, 76, 195, 0,1.5,      -1,-29510       , 0         , "t=6.5m",_
 3734, 76, 195, 1,6.5,       1,-29080       , 0.4278    , "t=47s",_
 3735, 77, 195, 0,1.5,       1,-31692.3     , 0         , "t=2.29h",_
 3736, 77, 195, 1,5.5,      -1,-31592       , 0.1       , "t=3.74h",_
 3737, 78, 195, 0,0.5,      -1,-32793.9     , 0         , "t=stbl",_
 3738, 78, 195, 1,6.5,       1,-32534.8     , 0.259077  , "t=4.010d",_
 3739, 79, 195, 0,1.5,       1,-32567.1     , 0         , "t=186.01d",_
 3740, 79, 195, 1,5.5,      -1,-32248.5     , 0.31858   , "t=30.5s",_
 3741, 80, 195, 0,0.5,      -1,-31013       , 0         , "t=10.69h",_
 3742, 80, 195, 1,6.5,       1,-30837       , 0.17607   , "t=41.60h",_
 3743, 81, 195, 0,0.5,       1,-28155       , 0         , "t=1.16h",_
 3744, 81, 195, 1,4.5,      -1,-27672       , 0.48263   , "t=3.6s",_
 3745, 82, 195, 0,1.5,      -1,-23738       , 0         , "t=15.0m",_
 3746, 82, 195, 1,6.5,       1,-23535       , 0.2029    , "t=15.0m",_
 3747, 83, 195, 0,4.5,      -1,-18026       , 0         , "t=183s",_
 3748, 83, 195, 1,0.5,       1,-17626       , 0.399     , "t=87s",_
 3749, 84, 195, 0,1.5,      -1,-11117       , 0         , "t=4.64s",_
 3750, 84, 195, 1,6.5,       1,-10968       , 0.148     , "t=1.92s",_
 3751, 85, 195, 0,0.5,       1,-3470        , 0         , "t=290ms",_
 3752, 85, 195, 1,3.5,      -1,-3441        , 0.029     , "t=143ms",_
 3753, 86, 195, 0,1.5,      -1,5050         , 0         , "t=7ms",_
 3754, 86, 195, 1,6.5,       1,5131         , 0.08      , "t=6ms",_
 3755, 74, 196, 0,0,         1,-18740       , 0         , "t=25s",_
 3756, 75, 196, 0,-77.777,   0,-22360       , 0         , "t=2.4s",_
 3757, 75, 196, 1,-77.777,   0,-22240       , 0.12      , "t=3.6us",_
 3758, 76, 196, 0,0,         1,-28280       , 0         , "t=34.9m",_
 3759, 77, 196, 0,1,         0,-29440       , 0         , "t=52.0s",_
 3760, 77, 196, 1,11,       -1,-29227       , 0.21      , "t=1.40h",_
 3761, 78, 196, 0,0,         1,-32644.5     , 0         , "t=stbl",_
 3762, 79, 196, 0,2,        -1,-31138.7     , 0         , "t=6.165d",_
 3763, 79, 196, 1,5,         1,-31054       , 0.084656  , "t=8.1s",_
 3764, 80, 196, 0,0,         1,-31825.9     , 0         , "t=stbl",_
 3765, 81, 196, 0,2,        -1,-27497       , 0         , "t=1.84h",_
 3766, 81, 196, 1,7,         1,-27103       , 0.3942    , "t=1.41h",_
 3767, 82, 196, 0,0,         1,-25348       , 0         , "t=37m",_
 3768, 83, 196, 0,3,         1,-18009       , 0         , "t=5.13m",_
 3769, 83, 196, 1,7,         1,-17843       , 0.1664    , "t=0.6s",_
 3770, 84, 196, 0,0,         1,-13469       , 0         , "t=5.63s",_
 3771, 84, 196, 1,11,       -1,-10975       , 2.4939    , "t=856ns",_
 3772, 85, 196, 0,3,         1,-3910        , 0         , "t=377ms",_
 3773, 85, 196, 1,10,       -1,-3950        ,-0.04      , "t=20ms",_
 3774, 86, 196, 0,0,         1,1975         , 0         , "t=4.7ms",_
 3775, 74, 197, 0,2.5,      -1,-14870       , 0         , "t=1s",_
 3776, 75, 197, 0,2.5,       1,-20350       , 0         , "t=400ms",_
 3777, 76, 197, 0,2.5,      -1,-25080       , 0         , "t=93s",_
 3778, 76, 197, 1,6.5,       1,-24580       , 0.5       , "t=&lt;0.1s",_
 3779, 77, 197, 0,1.5,       1,-28264       , 0         , "t=5.8m",_
 3780, 77, 197, 1,5.5,      -1,-28149       , 0.115     , "t=8.9m",_
 3781, 78, 197, 0,0.5,      -1,-30419.8     , 0         , "t=19.8915h",_
 3782, 78, 197, 1,6.5,       1,-30020.2     , 0.39959   , "t=95.41m",_
 3783, 79, 197, 0,1.5,       1,-31139.8     , 0         , "t=stbl",_
 3784, 79, 197, 1,5.5,      -1,-30730.7     , 0.40915   , "t=7.73s",_
 3785, 80, 197, 0,0.5,      -1,-30540       , 0         , "t=64.93h",_
 3786, 80, 197, 1,6.5,       1,-30241       , 0.29893   , "t=23.82h",_
 3787, 81, 197, 0,0.5,       1,-28354       , 0         , "t=2.84h",_
 3788, 81, 197, 1,4.5,      -1,-27746       , 0.60822   , "t=540ms",_
 3789, 82, 197, 0,1.5,      -1,-24745       , 0         , "t=8.1m",_
 3790, 82, 197, 1,6.5,       1,-24426       , 0.31931   , "t=42.9m",_
 3791, 83, 197, 0,4.5,      -1,-19687       , 0         , "t=9.33m",_
 3792, 83, 197, 1,0.5,       1,-19155       , 0.533     , "t=5.04m",_
 3793, 84, 197, 0,1.5,      -1,-13393       , 0         , "t=53.6s",_
 3794, 84, 197, 1,6.5,       1,-13197       , 0.196     , "t=25.8s",_
 3795, 85, 197, 0,4.5,      -1,-6355        , 0         , "t=388.2ms",_
 3796, 85, 197, 1,0.5,       1,-6311        , 0.045     , "t=2.0s",_
 3797, 86, 197, 0,1.5,      -1,1510         , 0         , "t=54ms",_
 3798, 86, 197, 1,6.5,       1,1709         , 0.199     , "t=25.6ms",_
 3799, 87, 197, 0,3.5,      -1,10250        , 0         , "t=2.3ms",_
 3800, 75, 198, 0,-77.777,   0,-16990       , 0         , "t=1s",_
 3801, 76, 198, 0,0,         1,-23600       , 0         , "t=125s",_
 3802, 77, 198, 0,1,        -1,-25710       , 0         , "t=8.7s",_
 3803, 78, 198, 0,0,         1,-29904.0     , 0         , "t=stbl",_
 3804, 79, 198, 0,2,        -1,-29580.8     , 0         , "t=2.69464d",_
 3805, 79, 198, 1,5,         1,-29268.6     , 0.3122227 , "t=124ns",_
 3806, 80, 198, 0,0,         1,-30954.3     , 0         , "t=stbl",_
 3807, 81, 198, 0,2,        -1,-27529       , 0         , "t=5.3h",_
 3808, 81, 198, 1,7,         1,-26985       , 0.5436    , "t=1.87h",_
 3809, 82, 198, 0,0,         1,-26067       , 0         , "t=2.4h",_
 3810, 82, 198, 1,7,        -1,-23926       , 2.1414    , "t=4.12us",_
 3811, 83, 198, 0,3,         1,-19374       , 0         , "t=10.3m",_
 3812, 83, 198, 1,7,         1,-19085       , 0.29      , "t=11.6m",_
 3813, 84, 198, 0,0,         1,-15473       , 0         , "t=1.760m",_
 3814, 84, 198, 1,11,       -1,-12907       , 2.56592   , "t=200ns",_
 3815, 85, 198, 0,3,         1,-6709        , 0         , "t=4.47s",_
 3816, 85, 198, 1,10,       -1,-6442        , 0.2666    , "t=1.23s",_
 3817, 86, 198, 0,0,         1,-1230        , 0         , "t=64.4ms",_
 3818, 87, 198, 0,3,         1,9580         , 0         , "t=15ms",_
 3819, 87, 198, 1,10,       -1,9580         , 0         , "t=1.1ms",_
 3820, 75, 199, 0,2.5,       1,-14730       , 0         , "t=250ms",_
 3821, 76, 199, 0,2.5,      -1,-20270       , 0         , "t=6s",_
 3822, 77, 199, 0,1.5,       1,-24400       , 0         , "t=7s",_
 3823, 78, 199, 0,2.5,      -1,-27388.7     , 0         , "t=30.80m",_
 3824, 78, 199, 1,6.5,       1,-26964.7     , 0.424     , "t=13.48s",_
 3825, 79, 199, 0,1.5,       1,-29093.8     , 0         , "t=3.139d",_
 3826, 79, 199, 1,5.5,      -1,-28544.9     , 0.5489405 , "t=440us",_
 3827, 80, 199, 0,0.5,      -1,-29546.1     , 0         , "t=stbl",_
 3828, 80, 199, 1,6.5,       1,-29013.6     , 0.53248   , "t=42.67m",_
 3829, 81, 199, 0,0.5,       1,-28059       , 0         , "t=7.42h",_
 3830, 81, 199, 1,4.5,      -1,-27310       , 0.74887   , "t=28.4ms",_
 3831, 82, 199, 0,1.5,      -1,-25232       , 0         , "t=90m",_
 3832, 82, 199, 1,6.5,       1,-24803       , 0.4295    , "t=12.2m",_
 3833, 83, 199, 0,4.5,      -1,-20798       , 0         , "t=27m",_
 3834, 83, 199, 1,0.5,       1,-20131       , 0.667     , "t=24.70m",_
 3835, 84, 199, 0,1.5,      -1,-15239       , 0         , "t=5.47m",_
 3836, 84, 199, 1,6.5,       1,-14927       , 0.3117    , "t=4.17m",_
 3837, 85, 199, 0,4.5,      -1,-8823        , 0         , "t=7.02s",_
 3838, 85, 199, 1,0.5,       1,-8579        , 0.244     , "t=273ms",_
 3839, 86, 199, 0,1.5,      -1,-1560        , 0         , "t=590ms",_
 3840, 86, 199, 1,6.5,       1,-1340        , 0.22      , "t=310ms",_
 3841, 87, 199, 0,0.5,       1,6771         , 0         , "t=6.6ms",_
 3842, 87, 199, 1,3.5,      -1,6817         , 0.045     , "t=6.5ms",_
 3843, 76, 200, 0,0,         1,-18550       , 0         , "t=7s",_
 3844, 77, 200, 0,2,        -1,-21570       , 0         , "t=43s",_
 3845, 78, 200, 0,0,         1,-26599       , 0         , "t=12.6h",_
 3846, 79, 200, 0,1,        -1,-27240       , 0         , "t=48.4m",_
 3847, 79, 200, 1,12,       -1,-26233       , 1.01      , "t=18.7h",_
 3848, 80, 200, 0,0,         1,-29503.3     , 0         , "t=stbl",_
 3849, 81, 200, 0,2,        -1,-27047       , 0         , "t=26.1h",_
 3850, 81, 200, 1,7,         1,-26293       , 0.7536    , "t=34.0ms",_
 3851, 82, 200, 0,0,         1,-26251       , 0         , "t=21.5h",_
 3852, 82, 200, 1,9,        -1,-24068       , 2.1833    , "t=456ns",_
 3853, 83, 200, 0,7,         1,-20371       , 0         , "t=36.4m",_
 3854, 83, 200, 1,2,         1,-20270       , 0.1       , "t=31m",_
 3855, 84, 200, 0,0,         1,-16942       , 0         , "t=11.51m",_
 3856, 84, 200, 1,11,       -1,-14346       , 2.5961    , "t=100ns",_
 3857, 85, 200, 0,3,         1,-8988        , 0         , "t=43.2s",_
 3858, 85, 200, 1,7,         1,-8875        , 0.1129    , "t=47s",_
 3859, 86, 200, 0,0,         1,-4000        , 0         , "t=1.09s",_
 3860, 86, 200, 1,-77.777,   0,-1680        , 2.32      , "t=28us",_
 3861, 87, 200, 0,3,         1,6130         , 0         , "t=47.5ms",_
 3862, 87, 200, 1,10,       -1,6180         , 0.05      , "t=190ms",_
 3863, 76, 201, 0,0.5,      -1,-14840       , 0         , "t=3s",_
 3864, 77, 201, 0,1.5,       1,-19840       , 0         , "t=21s",_
 3865, 78, 201, 0,2.5,      -1,-23740       , 0         , "t=2.5m",_
 3866, 78, 201, 1,6.5,       1,-22890       , 0.85      , "t=10s",_
 3867, 79, 201, 0,1.5,       1,-26401       , 0         , "t=26.0m",_
 3868, 79, 201, 1,5.5,      -1,-25807       , 0.594     , "t=730us",_
 3869, 80, 201, 0,1.5,      -1,-27662.5     , 0         , "t=stbl",_
 3870, 80, 201, 1,6.5,       1,-26896.3     , 0.76622   , "t=94.0us",_
 3871, 81, 201, 0,0.5,       1,-27181       , 0         , "t=3.0421d",_
 3872, 81, 201, 1,4.5,      -1,-26262       , 0.91916   , "t=2.01ms",_
 3873, 82, 201, 0,2.5,      -1,-25271       , 0         , "t=9.33h",_
 3874, 82, 201, 1,6.5,       1,-24642       , 0.6291    , "t=60.8s",_
 3875, 83, 201, 0,4.5,      -1,-21429       , 0         , "t=103m",_
 3876, 83, 201, 1,0.5,       1,-20583       , 0.84635   , "t=57.5m",_
 3877, 84, 201, 0,1.5,      -1,-16521       , 0         , "t=15.6m",_
 3878, 84, 201, 1,6.5,       1,-16097       , 0.4238    , "t=8.96m",_
 3879, 85, 201, 0,4.5,      -1,-10789       , 0         , "t=85.2s",_
 3880, 85, 201, 1,0.5,       1,-10330       , 0.459     , "t=45ms",_
 3881, 86, 201, 0,1.5,      -1,-4107        , 0         , "t=7.0s",_
 3882, 86, 201, 1,6.5,       1,-3863        , 0.245     , "t=3.8s",_
 3883, 87, 201, 0,4.5,      -1,3589         , 0         , "t=62.8ms",_
 3884, 87, 201, 1,0.5,       1,3718         , 0.129     , "t=24ms",_
 3885, 88, 201, 0,1.5,      -1,11937        , 0         , "t=20ms",_
 3886, 88, 201, 1,6.5,       1,12200        , 0.263     , "t=6ms",_
 3887, 76, 202, 0,0,         1,-12530       , 0         , "t=2s",_
 3888, 77, 202, 0,2,        -1,-16640       , 0         , "t=11s",_
 3889, 77, 202, 1,-77.777,   0,-14040       , 2.6       , "t=3.4us",_
 3890, 78, 202, 0,0,         1,-22692       , 0         , "t=44h",_
 3891, 78, 202, 1,7,        -1,-20904       , 1.7885    , "t=141us",_
 3892, 79, 202, 0,1,        -1,-24353       , 0         , "t=28.4s",_
 3893, 80, 202, 0,0,         1,-27345.3     , 0         , "t=stbl",_
 3894, 81, 202, 0,2,        -1,-25980.4     , 0         , "t=12.31d",_
 3895, 81, 202, 1,7,         1,-25030.2     , 0.95019   , "t=591us",_
 3896, 82, 202, 0,0,         1,-25941       , 0         , "t=52.5ky",_
 3897, 82, 202, 1,9,        -1,-23771       , 2.16985   , "t=3.54h",_
 3898, 83, 202, 0,5,         1,-20751       , 0         , "t=1.72h",_
 3899, 83, 202, 1,10,       -1,-20126       , 0.625     , "t=3.04us",_
 3900, 84, 202, 0,0,         1,-17942       , 0         , "t=44.6m",_
 3901, 84, 202, 1,8,         1,-16230       , 1.712     , "t=110ns",_
 3902, 85, 202, 0,3,         1,-10595       , 0         , "t=184s",_
 3903, 85, 202, 1,7,         1,-10401       , 0.19      , "t=182s",_
 3904, 86, 202, 0,0,         1,-6275        , 0         , "t=9.7s",_
 3905, 86, 202, 1,11,       -1,-3970        , 2.31      , "t=2.22us",_
 3906, 87, 202, 0,3,         1,3102         , 0         , "t=372ms",_
 3907, 87, 202, 1,10,       -1,3359         , 0.257     , "t=286ms",_
 3908, 88, 202, 0,0,         1,9075         , 0         , "t=4.1ms",_
 3909, 76, 203, 0,4.5,       1,-7270        , 0         , "t=300ms",_
 3910, 77, 203, 0,1.5,       1,-14370       , 0         , "t=7s",_
 3911, 77, 203, 1,5.5,      -1,-14170       , 0.2       , "t=&gt;100ns",_
 3912, 78, 203, 0,0.5,      -1,-19510       , 0         , "t=22s",_
 3913, 78, 203, 1,6.5,       1,-18140       , 1.367     , "t=12s",_
 3914, 79, 203, 0,1.5,       1,-23143       , 0         , "t=60s",_
 3915, 79, 203, 1,5.5,      -1,-22502       , 0.641     , "t=140us",_
 3916, 80, 203, 0,2.5,      -1,-25269.2     , 0         , "t=46.610d",_
 3917, 80, 203, 1,6.5,       1,-24336.1     , 0.93314   , "t=22.1us",_
 3918, 81, 203, 0,0.5,       1,-25761.3     , 0         , "t=stbl",_
 3919, 81, 203, 1,4.5,      -1,-24277.6     , 1.4837    , "t=&lt;1us",_
 3920, 82, 203, 0,2.5,      -1,-24786       , 0         , "t=51.924h",_
 3921, 82, 203, 1,6.5,       1,-23961       , 0.8252    , "t=6.21s",_
 3922, 83, 203, 0,4.5,      -1,-21525       , 0         , "t=11.76h",_
 3923, 83, 203, 1,0.5,       1,-20427       , 1.09821   , "t=305ms",_
 3924, 84, 203, 0,2.5,      -1,-17311       , 0         , "t=36.7m",_
 3925, 84, 203, 1,6.5,       1,-16669       , 0.64168   , "t=45s",_
 3926, 85, 203, 0,4.5,      -1,-12163       , 0         , "t=7.4m",_
 3927, 85, 203, 1,0.5,       1,-11480       , 0.6834    , "t=3.5ms",_
 3928, 86, 203, 0,1.5,      -1,-6184        , 0         , "t=44.2s",_
 3929, 86, 203, 1,6.5,       1,-5822        , 0.362     , "t=26.9s",_
 3930, 87, 203, 0,4.5,      -1,876          , 0         , "t=550ms",_
 3931, 87, 203, 1,0.5,       1,1237         , 0.361     , "t=43ms",_
 3932, 88, 203, 0,1.5,      -1,8601         , 0         , "t=36ms",_
 3933, 88, 203, 1,6.5,       1,8848         , 0.246     , "t=25ms",_
 3934, 77, 204, 0,-77.777,   0,-9570        , 0         , "t=2s",_
 3935, 78, 204, 0,0,         1,-17620       , 0         , "t=10.3s",_
 3936, 78, 204, 1,5,        -1,-15630       , 1.9951    , "t=5.5us",_
 3937, 79, 204, 0,2,        -1,-20390       , 0         , "t=38.3s",_
 3938, 79, 204, 1,16,        1,-16570       , 3.816     , "t=2.1us",_
 3939, 80, 204, 0,0,         1,-24690.1     , 0         , "t=stbl",_
 3940, 81, 204, 0,2,        -1,-24346.1     , 0         , "t=3.783y",_
 3941, 81, 204, 1,7,         1,-23242.0     , 1.1041    , "t=61.7us",_
 3942, 82, 204, 0,0,         1,-25109.8     , 0         , "t=stbl",_
 3943, 82, 204, 1,4,         1,-23835.7     , 1.27413   , "t=265ns",_
 3944, 83, 204, 0,6,         1,-20646       , 0         , "t=11.22h",_
 3945, 83, 204, 1,10,       -1,-19841       , 0.8055    , "t=13.0ms",_
 3946, 84, 204, 0,0,         1,-18341       , 0         , "t=3.519h",_
 3947, 84, 204, 1,8,         1,-16702       , 1.63903   , "t=158.6ns",_
 3948, 85, 204, 0,7,         1,-11875       , 0         , "t=9.12m",_
 3949, 85, 204, 1,10,       -1,-11288       , 0.5873    , "t=108ms",_
 3950, 86, 204, 0,0,         1,-7970        , 0         , "t=1.242m",_
 3951, 87, 204, 0,3,         1,607          , 0         , "t=1.75s",_
 3952, 87, 204, 1,7,         1,658          , 0.05      , "t=2.41s",_
 3953, 88, 204, 0,0,         1,6061         , 0         , "t=60ms",_
 3954, 77, 205, 0,1.5,       1,-5600        , 0         , "t=1s",_
 3955, 78, 205, 0,4.5,       1,-12820       , 0         , "t=2s",_
 3956, 79, 205, 0,1.5,       1,-18570       , 0         , "t=32.0s",_
 3957, 79, 205, 1,5.5,      -1,-17660       , 0.907     , "t=6s",_
 3958, 80, 205, 0,0.5,      -1,-22288       , 0         , "t=5.14m",_
 3959, 80, 205, 1,6.5,       1,-20732       , 1.5564    , "t=1.09ms",_
 3960, 81, 205, 0,0.5,       1,-23820.8     , 0         , "t=stbl",_
 3961, 81, 205, 1,12.5,      1,-20530.2     , 3.29061   , "t=2.6us",_
 3962, 82, 205, 0,2.5,      -1,-23770.2     , 0         , "t=17.0My",_
 3963, 82, 205, 1,0.5,      -1,-23767.9     , 0.002329  , "t=24.2us",_
 3964, 83, 205, 0,4.5,      -1,-21066       , 0         , "t=14.91d",_
 3965, 83, 205, 1,0.5,       1,-19569       , 1.49717   , "t=7.9us",_
 3966, 84, 205, 0,2.5,      -1,-17521       , 0         , "t=1.74h",_
 3967, 84, 205, 1,0.5,      -1,-17378       , 0.143166  , "t=310ns",_
 3968, 85, 205, 0,4.5,      -1,-12985       , 0         , "t=26.9m",_
 3969, 85, 205, 1,14.5,      1,-10645       , 2.33964   , "t=7.76us",_
 3970, 86, 205, 0,2.5,      -1,-7710        , 0         , "t=170s",_
 3971, 86, 205, 1,6.5,       1,-7053        , 0.6571    , "t=&gt;10s",_
 3972, 87, 205, 0,4.5,      -1,-1310        , 0         , "t=3.90s",_
 3973, 87, 205, 1,6.5,       1,-766         , 0.544     , "t=80ns",_
 3974, 88, 205, 0,1.5,      -1,5804         , 0         , "t=220ms",_
 3975, 88, 205, 1,6.5,       1,6067         , 0.263     , "t=180ms",_
 3976, 89, 205, 0,4.5,      -1,14110        , 0         , "t=80ms",_
 3977, 78, 206, 0,0,         1,-9240        , 0         , "t=500ms",_
 3978, 79, 206, 0,6,         1,-14190       , 0         , "t=47s",_
 3979, 80, 206, 0,0,         1,-20946       , 0         , "t=8.32m",_
 3980, 80, 206, 1,5,        -1,-18844       , 2.1024    , "t=2.088us",_
 3981, 81, 206, 0,0,        -1,-22253.3     , 0         , "t=4.202m",_
 3982, 81, 206, 1,12,       -1,-19610.2     , 2.6431    , "t=3.74m",_
 3983, 82, 206, 0,0,         1,-23785.5     , 0         , "t=stbl",_
 3984, 82, 206, 1,7,        -1,-21585.3     , 2.20016   , "t=125us",_
 3985, 83, 206, 0,6,         1,-20028       , 0         , "t=6.243d",_
 3986, 83, 206, 1,4,         1,-19968       , 0.059897  , "t=7.7us",_
 3987, 84, 206, 0,0,         1,-18189       , 0         , "t=8.8d",_
 3988, 84, 206, 1,8,         1,-16603       , 1.5859    , "t=232ns",_
 3989, 85, 206, 0,6,         1,-12439       , 0         , "t=30.6m",_
 3990, 85, 206, 1,10,       -1,-11629       , 0.81      , "t=813ns",_
 3991, 86, 206, 0,0,         1,-9133        , 0         , "t=5.67m",_
 3992, 87, 206, 0,3,         1,-1247        , 0         , "t=~16s",_
 3993, 87, 206, 1,7,         1,-1048        , 0.2       , "t=~16s",_
 3994, 88, 206, 0,0,         1,3566         , 0         , "t=240ms",_
 3995, 89, 206, 0,3,         1,13480        , 0         , "t=25ms",_
 3996, 89, 206, 1,10,       -1,13690        , 0.2       , "t=41ms",_
 3997, 78, 207, 0,4.5,       1,-4140        , 0         , "t=600ms",_
 3998, 79, 207, 0,1.5,       1,-10640       , 0         , "t=3s",_
 3999, 80, 207, 0,4.5,       1,-16487       , 0         , "t=2.9m",_
 4000, 81, 207, 0,0.5,       1,-21034       , 0         , "t=4.77m",_
 4001, 81, 207, 1,5.5,      -1,-19686       , 1.34818   , "t=1.33s",_
 4002, 82, 207, 0,0.5,      -1,-22452.0     , 0         , "t=stbl",_
 4003, 82, 207, 1,6.5,       1,-20818.6     , 1.633356  , "t=806ms",_
 4004, 83, 207, 0,4.5,      -1,-20054.6     , 0         , "t=31.22y",_
 4005, 83, 207, 1,10.5,      1,-17953.0     , 2.10161   , "t=182us",_
 4006, 84, 207, 0,2.5,      -1,-17146       , 0         , "t=5.80h",_
 4007, 84, 207, 1,0.5,      -1,-17077       , 0.068557  , "t=205ns",_
 4008, 85, 207, 0,4.5,      -1,-13227       , 0         , "t=1.81h",_
 4009, 85, 207, 1,12.5,      1,-11110       , 2.1173    , "t=108ns",_
 4010, 86, 207, 0,2.5,      -1,-8635        , 0         , "t=9.25m",_
 4011, 86, 207, 1,6.5,       1,-7736        , 0.8991    , "t=184.5us",_
 4012, 87, 207, 0,4.5,      -1,-2849        , 0         , "t=14.8s",_
 4013, 88, 207, 0,2.5,      -1,3510         , 0         , "t=1.38s",_
 4014, 88, 207, 1,6.5,       1,4071         , 0.56      , "t=57ms",_
 4015, 89, 207, 0,4.5,      -1,11150        , 0         , "t=31ms",_
 4016, 78, 208, 0,0,         1,-500         , 0         , "t=220ms",_
 4017, 79, 208, 0,6,         1,-5910        , 0         , "t=20s",_
 4018, 80, 208, 0,0,         1,-13270       , 0         , "t=135s",_
 4019, 80, 208, 1,8,         1,-11930       , 1.338     , "t=99ns",_
 4020, 81, 208, 0,5,         1,-16750.1     , 0         , "t=3.053m",_
 4021, 81, 208, 1,0,        -1,-14943.1     , 1.807     , "t=1.3us",_
 4022, 82, 208, 0,0,         1,-21748.5     , 0         , "t=stbl",_
 4023, 82, 208, 1,10,        1,-16853.3     , 4.89523   , "t=535ns",_
 4024, 83, 208, 0,5,         1,-18870.2     , 0         , "t=368ky",_
 4025, 83, 208, 1,10,       -1,-17299.1     , 1.5711    , "t=2.58ms",_
 4026, 84, 208, 0,0,         1,-17469.2     , 0         , "t=2.898y",_
 4027, 84, 208, 1,8,         1,-15941.0     , 1.52822   , "t=373ns",_
 4028, 85, 208, 0,6,         1,-12470       , 0         , "t=1.63h",_
 4029, 85, 208, 1,16,       -1,-10194       , 2.2764    , "t=1.5us",_
 4030, 86, 208, 0,0,         1,-9655        , 0         , "t=24.35m",_
 4031, 86, 208, 1,8,         1,-7827        , 1.8283    , "t=487ns",_
 4032, 87, 208, 0,7,         1,-2665        , 0         , "t=59.1s",_
 4033, 87, 208, 1,10,       -1,-1839        , 0.8263    , "t=432ns",_
 4034, 88, 208, 0,0,         1,1728         , 0         , "t=1.110s",_
 4035, 88, 208, 1,8,         1,3875         , 2.1474    , "t=263ns",_
 4036, 89, 208, 0,3,         1,10760        , 0         , "t=97ms",_
 4037, 89, 208, 1,10,       -1,11258        , 0.5       , "t=28ms",_
 4038, 90, 208, 0,0,         1,16690        , 0         , "t=2.4ms",_
 4039, 79, 209, 0,1.5,       1,-2230        , 0         , "t=1s",_
 4040, 80, 209, 0,4.5,       1,-8610        , 0         , "t=6.3s",_
 4041, 81, 209, 0,0.5,       1,-13645       , 0         , "t=2.162m",_
 4042, 81, 209, 1,8.5,       1,-12417       , 1.2281    , "t=146ns",_
 4043, 82, 209, 0,4.5,       1,-17614.6     , 0         , "t=3.235h",_
 4044, 83, 209, 0,4.5,      -1,-18258.6     , 0         , "t=20.1Ey",_
 4045, 84, 209, 0,0.5,      -1,-16366.0     , 0         , "t=124y",_
 4046, 84, 209, 1,15.5,     -1,-12100.6     , 4.2654    , "t=119ns",_
 4047, 85, 209, 0,4.5,      -1,-12884       , 0         , "t=5.42h",_
 4048, 85, 209, 1,14.5,      1,-10455       , 2.42932   , "t=916ns",_
 4049, 86, 209, 0,2.5,      -1,-8941        , 0         , "t=28.8m",_
 4050, 86, 209, 1,6.5,       1,-7767        , 1.17401   , "t=13.4us",_
 4051, 87, 209, 0,4.5,      -1,-3782        , 0         , "t=50.5s",_
 4052, 87, 209, 1,22.5,     -1,878          , 4.6598    , "t=420ns",_
 4053, 88, 209, 0,2.5,      -1,1858         , 0         , "t=4.71s",_
 4054, 88, 209, 1,6.5,       1,2740         , 0.8824    , "t=117us",_
 4055, 89, 209, 0,4.5,      -1,8840         , 0         , "t=94ms",_
 4056, 90, 209, 0,2.5,      -1,16400        , 0         , "t=60ms",_
 4057, 90, 209, 1,6.5,       1,16765        , 0.37      , "t=3.1ms",_
 4058, 79, 210, 0,6,         1,2680         , 0         , "t=10s",_
 4059, 80, 210, 0,0,         1,-5300        , 0         , "t=64s",_
 4060, 80, 210, 1,3,        -1,-4640        , 0.663     , "t=2.1us",_
 4061, 81, 210, 0,5,         1,-9247        , 0         , "t=1.30m",_
 4062, 81, 210, 1,9,         1,-8050        , 1.2       , "t=1m",_
 4063, 82, 210, 0,0,         1,-14728.4     , 0         , "t=22.20y",_
 4064, 82, 210, 1,6,         1,-13533.8     , 1.19461   , "t=92ns",_
 4065, 83, 210, 0,1,        -1,-14791.9     , 0         , "t=5.012d",_
 4066, 83, 210, 1,9,        -1,-14520.6     , 0.27131   , "t=3.04My",_
 4067, 84, 210, 0,0,         1,-15953.1     , 0         , "t=138.376d",_
 4068, 84, 210, 1,8,         1,-14396.1     , 1.55697   , "t=98.9ns",_
 4069, 85, 210, 0,5,         1,-11972       , 0         , "t=8.1h",_
 4070, 85, 210, 1,15,       -1,-9422        , 2.5496    , "t=482ns",_
 4071, 86, 210, 0,0,         1,-9605        , 0         , "t=2.4h",_
 4072, 86, 210, 1,8,         1,-7900        , 1.71      , "t=644ns",_
 4073, 87, 210, 0,6,         1,-3344        , 0         , "t=3.18m",_
 4074, 87, 210, 1,23,        1,1073         , 4.4172    , "t=475ns",_
 4075, 88, 210, 0,0,         1,443          , 0         , "t=4.0s",_
 4076, 88, 210, 1,8,         1,2494         , 2.0509    , "t=2.29us",_
 4077, 89, 210, 0,7,         1,8760         , 0         , "t=350ms",_
 4078, 90, 210, 0,0,         1,14060        , 0         , "t=16.0ms",_
 4079, 80, 211, 0,4.5,       1,-390         , 0         , "t=26.4s",_
 4080, 81, 211, 0,0.5,       1,-6080        , 0         , "t=81s",_
 4081, 81, 211, 1,8.5,       1,-4840        , 1.244     , "t=580ns",_
 4082, 82, 211, 0,4.5,       1,-10493.0     , 0         , "t=36.1628m",_
 4083, 82, 211, 1,13.5,      1,-8774        , 1.719     , "t=159ns",_
 4084, 83, 211, 0,4.5,      -1,-11859       , 0         , "t=2.14m",_
 4085, 83, 211, 1,12.5,     -1,-10602       , 1.257     , "t=1.4us",_
 4086, 84, 211, 0,4.5,       1,-12432.5     , 0         , "t=516ms",_
 4087, 84, 211, 1,12.5,      1,-10970       , 1.462     , "t=25.2s",_
 4088, 85, 211, 0,4.5,      -1,-11647.2     , 0         , "t=7.214h",_
 4089, 85, 211, 1,19.5,     -1,-6832.7      , 4.8145    , "t=4.23us",_
 4090, 86, 211, 0,0.5,      -1,-8755        , 0         , "t=14.6h",_
 4091, 86, 211, 1,8.5,      -1,-7152        , 1.603     , "t=596ns",_
 4092, 87, 211, 0,4.5,      -1,-4140        , 0         , "t=3.10m",_
 4093, 87, 211, 1,14.5,      1,-1717        , 2.42316   , "t=146ns",_
 4094, 88, 211, 0,2.5,      -1,832          , 0         , "t=12.6s",_
 4095, 88, 211, 1,6.5,       1,2030         , 1.1981    , "t=9.5us",_
 4096, 89, 211, 0,4.5,      -1,7140         , 0         , "t=213ms",_
 4097, 90, 211, 0,2.5,      -1,13880        , 0         , "t=48ms",_
 4098, 91, 211, 0,4.5,      -1,22050        , 0         , "t=6ms",_
 4099, 80, 212, 0,0,         1,3020         , 0         , "t=30s",_
 4100, 81, 212, 0,5,         1,-1550        , 0         , "t=31s",_
 4101, 82, 212, 0,0,         1,-7548.9      , 0         , "t=10.627h",_
 4102, 82, 212, 1,8,         1,-6213.9      , 1.335     , "t=6.0us",_
 4103, 83, 212, 0,1,        -1,-8117.9      , 0         , "t=60.55m",_
 4104, 83, 212, 1,8,        -1,-7870        , 0.25      , "t=25.0m",_
 4105, 84, 212, 0,0,         1,-10369.4     , 0         , "t=294.4ns",_
 4106, 84, 212, 1,18,        1,-7446        , 2.923     , "t=45.1s",_
 4107, 85, 212, 0,1,        -1,-8628.1      , 0         , "t=314ms",_
 4108, 85, 212, 1,9,        -1,-8405.2      , 0.2229    , "t=119ms",_
 4109, 86, 212, 0,0,         1,-8659        , 0         , "t=23.9m",_
 4110, 86, 212, 1,6,         1,-7019        , 1.63968   , "t=118ns",_
 4111, 87, 212, 0,5,         1,-3516        , 0         , "t=20.0m",_
 4112, 87, 212, 1,11,        1,-1965        , 1.5514    , "t=31.9us",_
 4113, 88, 212, 0,0,         1,-199         , 0         , "t=13.0s",_
 4114, 88, 212, 1,8,         1,1759         , 1.9584    , "t=9.3us",_
 4115, 89, 212, 0,7,         1,7300         , 0         , "t=895ms",_
 4116, 90, 212, 0,0,         1,12111        , 0         , "t=31.7ms",_
 4117, 91, 212, 0,3,         1,21600        , 0         , "t=5.8ms",_
 4118, 80, 213, 0,4.5,       1,8200         , 0         , "t=15s",_
 4119, 81, 213, 0,0.5,       1,1784         , 0         , "t=23.8s",_
 4120, 81, 213, 1,-77.777,   0,2460         , 0.68      , "t=4.1us",_
 4121, 82, 213, 0,4.5,       1,-3204        , 0         , "t=10.2m",_
 4122, 82, 213, 1,10.5,      1,-1873        , 1.331     , "t=260ns",_
 4123, 83, 213, 0,4.5,      -1,-5232        , 0         , "t=45.60m",_
 4124, 83, 213, 1,12.5,     -1,-3879        , 1.353     , "t=&gt;168s",_
 4125, 84, 213, 0,4.5,       1,-6654        , 0         , "t=3.705us",_
 4126, 85, 213, 0,4.5,      -1,-6580        , 0         , "t=125ns",_
 4127, 85, 213, 1,12.5,     -1,-5222        , 1.358     , "t=110ns",_
 4128, 86, 213, 0,4.5,       1,-5696        , 0         , "t=19.5ms",_
 4129, 86, 213, 1,12.5,      1,-4014        , 1.682     , "t=1.00us",_
 4130, 87, 213, 0,4.5,      -1,-3554        , 0         , "t=34.14s",_
 4131, 87, 213, 1,10.5,     -1,-1964        , 1.59041   , "t=505ns",_
 4132, 88, 213, 0,0.5,      -1,346          , 0         , "t=2.73m",_
 4133, 88, 213, 1,8.5,      -1,2114         , 1.768     , "t=2.20ms",_
 4134, 89, 213, 0,4.5,      -1,6141         , 0         , "t=738ms",_
 4135, 90, 213, 0,2.5,      -1,12120        , 0         , "t=144ms",_
 4136, 90, 213, 1,6.5,       1,13300        , 1.18      , "t=1.4us",_
 4137, 91, 213, 0,4.5,      -1,19650        , 0         , "t=7.4ms",_
 4138, 80, 214, 0,0,         1,11770        , 0         , "t=8s",_
 4139, 81, 214, 0,5,         1,6470         , 0         , "t=11.0s",_
 4140, 82, 214, 0,0,         1,-183.0       , 0         , "t=27.06m",_
 4141, 82, 214, 1,8,         1,1237         , 1.42      , "t=6.2us",_
 4142, 83, 214, 0,1,        -1,-1201        , 0         , "t=19.9m",_
 4143, 83, 214, 1,8,        -1,-660         , 0.539     , "t=&gt;93s",_
 4144, 84, 214, 0,0,         1,-4470.0      , 0         , "t=163.47us",_
 4145, 85, 214, 0,1,        -1,-3379        , 0         , "t=558ns",_
 4146, 85, 214, 1,-77.777,   0,-3321        , 0.059     , "t=265ns",_
 4147, 86, 214, 0,0,         1,-4320        , 0         , "t=259ns",_
 4148, 86, 214, 1,22,        1,275          , 4.5954    , "t=245ns",_
 4149, 87, 214, 0,1,        -1,-958         , 0         , "t=5.51ms",_
 4150, 87, 214, 1,8,        -1,-837         , 0.121     , "t=3.35ms",_
 4151, 88, 214, 0,0,         1,93          , 0          , "t=2.437s",_
 4152, 88, 214, 1,6,         1,1913         , 1.8197    , "t=118ns",_
 4153, 88, 214, 0,25,       -1,6670         , 6.577     , "t=128ns",_
 4154, 89, 214, 0,5,         1,6433         , 0         , "t=8.2s",_
 4155, 90, 214, 0,0,         1,10695        , 0         , "t=87ms",_
 4156, 90, 214, 1,8,         1,12876        , 2.181     , "t=1.24us",_
 4157, 91, 214, 0,7,         1,19460        , 0         , "t=17ms",_
 4158, 80, 215, 0,4.5,       1,17110        , 0         , "t=600ms",_
 4159, 81, 215, 0,0.5,       1,10030        , 0         , "t=9.7s",_
 4160, 82, 215, 0,4.5,       1,4340         , 0         , "t=142s",_
 4161, 83, 215, 0,4.5,      -1,1629         , 0         , "t=7.62m",_
 4162, 83, 215, 1,12.5,     -1,2996         , 1.367     , "t=36.9s",_
 4163, 84, 215, 0,4.5,       1,-541.8       , 0         , "t=1.781ms",_
 4164, 85, 215, 0,4.5,      -1,-1257        , 0         , "t=37us",_
 4165, 86, 215, 0,4.5,       1,-1169        , 0         , "t=2.30us",_
 4166, 87, 215, 0,4.5,      -1,318          , 0         , "t=90ns",_
 4167, 88, 215, 0,4.5,       1,2532         , 0         , "t=1.669ms",_
 4168, 88, 215, 1,12.5,      1,4410         , 1.8778    , "t=7.31us",_
 4169, 89, 215, 0,4.5,      -1,6031         , 0         , "t=171ms",_
 4170, 89, 215, 1,10.5,     -1,7827         , 1.796     , "t=185ns",_
 4171, 90, 215, 0,0.5,      -1,10921        , 0         , "t=1.35s",_
 4172, 90, 215, 1,4.5,       1,12390        , 1.471     , "t=770ns",_
 4173, 91, 215, 0,4.5,      -1,17800        , 0         , "t=14ms",_
 4174, 92, 215, 0,2.5,      -1,24890        , 0         , "t=1.4ms",_
 4175, 80, 216, 0,0,         1,20920        , 0         , "t=2s",_
 4176, 81, 216, 0,5,         1,14870        , 0         , "t=5.9s",_
 4177, 82, 216, 0,0,         1,7510         , 0         , "t=1.66m",_
 4178, 82, 216, 1,8,         1,9020         , 1.514     , "t=400ns",_
 4179, 83, 216, 0,6,        -1,5874         , 0         , "t=2.21m",_
 4180, 83, 216, 1,3,        -1,5898         , 0.024     , "t=6.6m",_
 4181, 84, 216, 0,0,         1,1782.3       , 0         , "t=144.0ms",_
 4182, 85, 216, 0,1,        -1,2257         , 0         , "t=300us",_
 4183, 85, 216, 1,9,        -1,2417         , 0.161     , "t=100us",_
 4184, 86, 216, 0,0,         1,253          , 0         , "t=29us",_
 4185, 87, 216, 0,1,        -1,2971         , 0         , "t=700ns",_
 4186, 87, 216, 1,9,        -1,3190         , 0.219     , "t=850ns",_
 4187, 88, 216, 0,0,         1,3291         , 0         , "t=172ns",_
 4188, 89, 216, 0,1,        -1,8150         , 0         , "t=440us",_
 4189, 89, 216, 1,9,        -1,8188         , 0.038     , "t=441us",_
 4190, 90, 216, 0,0,         1,10299        , 0         , "t=26.28ms",_
 4191, 90, 216, 1,8,         1,12340        , 2.041     , "t=135.4us",_
 4192, 91, 216, 0,5,         1,17824        , 0         , "t=105ms",_
 4193, 92, 216, 0,0,         1,23066        , 0         , "t=6.9ms",_
 4194, 92, 216, 1,8,         1,25320        , 2.25      , "t=1.4ms",_
 4195, 81, 217, 0,0.5,       1,18660        , 0         , "t=2s",_
 4196, 82, 217, 0,4.5,       1,12260        , 0         , "t=19.9s",_
 4197, 83, 217, 0,4.5,      -1,8730         , 0         , "t=98.5s",_
 4198, 83, 217, 1,12.5,     -1,10221        , 1.491     , "t=3.0us",_
 4199, 84, 217, 0,4.5,       1,5883         , 0         , "t=1.53s",_
 4200, 85, 217, 0,4.5,      -1,4395         , 0         , "t=32.6ms",_
 4201, 86, 217, 0,4.5,       1,3659         , 0         , "t=593us",_
 4202, 87, 217, 0,4.5,      -1,4315         , 0         , "t=22us",_
 4203, 88, 217, 0,4.5,       1,5890         , 0         , "t=1.95us",_
 4204, 89, 217, 0,4.5,      -1,8702         , 0         , "t=69ns",_
 4205, 89, 217, 1,14.5,      1,10715        , 2.012     , "t=740ns",_
 4206, 90, 217, 0,4.5,       1,12206        , 0         , "t=248us",_
 4207, 90, 217, 1,7.5,      -1,12879        , 0.6733    , "t=141ns",_
 4208, 91, 217, 0,4.5,      -1,17055        , 0         , "t=3.8ms",_
 4209, 91, 217, 1,11.5,     -1,18915        , 1.86      , "t=1.08ms",_
 4210, 92, 217, 0,0.5,      -1,22970        , 0         , "t=850us",_
 4211, 81, 218, 0,6,         1,23710        , 0         , "t=1s",_
 4212, 82, 218, 0,0,         1,15630        , 0         , "t=14.8s",_
 4213, 83, 218, 0,8,        -1,13216        , 0         , "t=33s",_
 4214, 84, 218, 0,0,         1,8356.7       , 0         , "t=3.097m",_
 4215, 85, 218, 0,2,        -1,8100         , 0         , "t=1.28s",_
 4216, 86, 218, 0,0,         1,5217.4       , 0         , "t=33.75ms",_
 4217, 87, 218, 0,1,        -1,7059         , 0         , "t=1.4ms",_
 4218, 87, 218, 1,8,        -1,7147         , 0.087     , "t=21.9ms",_
 4219, 88, 218, 0,0,         1,6646         , 0         , "t=25.91us",_
 4220, 89, 218, 0,1,        -1,10850        , 0         , "t=1.00us",_
 4221, 89, 218, 1,8,        -1,10900        , 0.05      , "t=&gt;100ns",_
 4222, 90, 218, 0,0,         1,12367        , 0         , "t=122ns",_
 4223, 91, 218, 0,8,        -1,18650        , 0         , "t=108us",_
 4224, 91, 218, 1,1,        -1,18731        , 0.081     , "t=150us",_
 4225, 92, 218, 0,0,         1,21895        , 0         , "t=354us",_
 4226, 92, 218, 1,8,         1,24004        , 2.109     , "t=408us",_
 4227, 82, 219, 0,5.5,       1,20620        , 0         , "t=3s",_
 4228, 83, 219, 0,4.5,      -1,16320        , 0         , "t=8.7s",_
 4229, 84, 219, 0,4.5,       1,12681        , 0         , "t=10.3m",_
 4230, 85, 219, 0,4.5,      -1,10396        , 0         , "t=56s",_
 4231, 86, 219, 0,2.5,       1,8829.3       , 0         , "t=3.96s",_
 4232, 87, 219, 0,4.5,      -1,8617         , 0         , "t=22.5ms",_
 4233, 88, 219, 0,3.5,       1,9394         , 0         , "t=9ms",_
 4234, 88, 219, 1,5.5,       1,9411         , 0.0167    , "t=10ms",_
 4235, 89, 219, 0,4.5,      -1,11570        , 0         , "t=9.4us",_
 4236, 90, 219, 0,4.5,       1,14460        , 0         , "t=1.023us",_
 4237, 91, 219, 0,4.5,      -1,18580        , 0         , "t=56ns",_
 4238, 92, 219, 0,4.5,       1,23296        , 0         , "t=60us",_
 4239, 93, 219, 0,4.5,      -1,29440        , 0         , "t=570us",_
 4240, 82, 220, 0,0,         1,24130        , 0         , "t=1s",_
 4241, 83, 220, 0,1,        -1,20960        , 0         , "t=9.5s",_
 4242, 84, 220, 0,0,         1,15263        , 0         , "t=10s",_
 4243, 85, 220, 0,3,        -1,14376        , 0         , "t=3.71m",_
 4244, 86, 220, 0,0,         1,10612.0      , 0         , "t=55.6s",_
 4245, 87, 220, 0,1,         1,11482        , 0         , "t=27.4s",_
 4246, 88, 220, 0,0,         1,10272        , 0         , "t=18.1ms",_
 4247, 89, 220, 0,3,        -1,13744        , 0         , "t=26.36ms",_
 4248, 90, 220, 0,0,         1,14690        , 0         , "t=10.2us",_
 4249, 91, 220, 0,1,        -1,20278        , 0         , "t=0.85us",_
 4250, 91, 220, 1,-77.777,   0,20304        , 0.026     , "t=410ns",_
 4251, 92, 220, 0,0,         1,23010        , 0         , "t=60ns",_
 4252, 93, 220, 0,1,        -1,30480        , 0         , "t=29ns",_
 4253, 83, 221, 0,4.5,      -1,24200        , 0         , "t=2s",_
 4254, 84, 221, 0,4.5,       1,19774        , 0         , "t=2.2m",_
 4255, 85, 221, 0,1.5,      -1,16783        , 0         , "t=2.3m",_
 4256, 86, 221, 0,3.5,       1,14471        , 0         , "t=25.7m",_
 4257, 87, 221, 0,2.5,      -1,13277        , 0         , "t=4.801m",_
 4258, 88, 221, 0,2.5,       1,12964        , 0         , "t=25s",_
 4259, 89, 221, 0,4.5,      -1,14530        , 0         , "t=52ms",_
 4260, 90, 221, 0,3.5,       1,16940        , 0         , "t=1.75ms",_
 4261, 91, 221, 0,4.5,      -1,20370        , 0         , "t=5.9us",_
 4262, 92, 221, 0,4.5,       1,24520        , 0         , "t=660ns",_
 4263, 93, 221, 0,4.5,      -1,29910        , 0         , "t=30ns",_
 4264, 94, 221, 0,4.5,       1,35930        , 0         , "t=100us",_
 4265, 83, 222, 0,1,        -1,28950        , 0         , "t=3s",_
 4266, 84, 222, 0,0,         1,22490        , 0         , "t=9.1m",_
 4267, 85, 222, 0,-77.777,   0,20953        , 0         , "t=54s",_
 4268, 86, 222, 0,0,         1,16372.0      , 0         , "t=3.8215d",_
 4269, 87, 222, 0,2,        -1,16378        , 0         , "t=14.2m",_
 4270, 88, 222, 0,0,         1,14320        , 0         , "t=33.6s",_
 4271, 89, 222, 0,1,        -1,16622        , 0         , "t=5.0s",_
 4272, 89, 222, 1,5,         1,16700        , 0.078     , "t=1.05m",_
 4273, 90, 222, 0,0,         1,17203        , 0         , "t=2.24ms",_
 4274, 91, 222, 0,1,        -1,22060        , 0         , "t=3.8ms",_
 4275, 92, 222, 0,0,         1,24270        , 0         , "t=4.7us",_
 4276, 93, 222, 0,1,        -1,31270        , 0         , "t=480ns",_
 4277, 94, 222, 0,0,         1,35060        , 0         , "t=10us",_
 4278, 83, 223, 0,4.5,      -1,32240        , 0         , "t=1s",_
 4279, 84, 223, 0,5.5,       1,27080        , 0         , "t=6s",_
 4280, 85, 223, 0,1.5,      -1,23428        , 0         , "t=50s",_
 4281, 86, 223, 0,3.5,       1,20390        , 0         , "t=24.3m",_
 4282, 87, 223, 0,1.5,      -1,18382.3      , 0         , "t=22.00m",_
 4283, 88, 223, 0,1.5,       1,17233.2      , 0         , "t=11.4352d",_
 4284, 89, 223, 0,2.5,      -1,17825        , 0         , "t=2.10m",_
 4285, 90, 223, 0,2.5,       1,19385        , 0         , "t=600ms",_
 4286, 91, 223, 0,4.5,      -1,22340        , 0         , "t=5.3ms",_
 4287, 92, 223, 0,3.5,       1,26050        , 0         , "t=65us",_
 4288, 93, 223, 0,4.5,      -1,30660        , 0         , "t=2.5us",_
 4289, 94, 223, 0,4.5,       1,36120        , 0         , "t=10us",_
 4290, 95, 223, 0,4.5,      -1,42700        , 0         , "t=10ms",_
 4291, 83, 224, 0,1,        -1,37070        , 0         , "t=1s",_
 4292, 84, 224, 0,0,         1,29910        , 0         , "t=3m",_
 4293, 85, 224, 0,2,         1,27711        , 0         , "t=2.5m",_
 4294, 86, 224, 0,0,         1,22445        , 0         , "t=107m",_
 4295, 87, 224, 0,1,        -1,21749        , 0         , "t=3.33m",_
 4296, 88, 224, 0,0,         1,18825.8      , 0         , "t=3.6316d",_
 4297, 89, 224, 0,0,        -1,20234        , 0         , "t=2.78h",_
 4298, 90, 224, 0,0,         1,19996        , 0         , "t=1.04s",_
 4299, 91, 224, 0,5,        -1,23862        , 0         , "t=844ms",_
 4300, 92, 224, 0,0,         1,25743        , 0         , "t=396us",_
 4301, 93, 224, 0,2,        -1,32032        , 0         , "t=48us",_
 4302, 94, 224, 0,0,         1,35280        , 0         , "t=10us",_
 4303, 95, 224, 0,-77.777,   0,43260        , 0         , "t=1ms",_
 4304, 84, 225, 0,1.5,       1,34580        , 0         , "t=10s",_
 4305, 85, 225, 0,0.5,       1,30300        , 0         , "t=3s",_
 4306, 86, 225, 0,3.5,      -1,26534        , 0         , "t=4.66m",_
 4307, 87, 225, 0,1.5,      -1,23821        , 0         , "t=3.95m",_
 4308, 88, 225, 0,0.5,       1,21993.0      , 0         , "t=14.82d",_
 4309, 89, 225, 0,1.5,      -1,21637        , 0         , "t=9.9190d",_
 4310, 90, 225, 0,1.5,       1,22310        , 0         , "t=8.75m",_
 4311, 91, 225, 0,2.5,      -1,24360        , 0         , "t=1.71s",_
 4312, 92, 225, 0,2.5,       1,27372        , 0         , "t=62ms",_
 4313, 93, 225, 0,4.5,      -1,31620        , 0         , "t=6.5ms",_
 4314, 94, 225, 0,3.5,       1,36300        , 0         , "t=100us",_
 4315, 95, 225, 0,4.5,      -1,42390        , 0         , "t=100us",_
 4316, 84, 226, 0,0,         1,37550        , 0         , "t=1m",_
 4317, 85, 226, 0,2,         1,34660        , 0         , "t=7m",_
 4318, 86, 226, 0,0,         1,28747        , 0         , "t=7.4m",_
 4319, 87, 226, 0,1,        -1,27521        , 0         , "t=48.5s",_
 4320, 88, 226, 0,0,         1,23667.6      , 0         , "t=1.600ky",_
 4321, 89, 226, 0,1,        -1,24309        , 0         , "t=29.37h",_
 4322, 90, 226, 0,0,         1,23198        , 0         , "t=30.70m",_
 4323, 91, 226, 0,1,        -1,26034        , 0         , "t=1.8m",_
 4324, 92, 226, 0,0,         1,27329        , 0         , "t=269ms",_
 4325, 93, 226, 0,-77.777,   0,32820        , 0         , "t=35ms",_
 4326, 94, 226, 0,0,         1,35630        , 0         , "t=10ms",_
 4327, 95, 226, 0,-77.777,   0,42970        , 0         , "t=100us",_
 4328, 84, 227, 0,2.5,       1,42280        , 0         , "t=2s",_
 4329, 85, 227, 0,0.5,       1,37430        , 0         , "t=5s",_
 4330, 86, 227, 0,1.5,       1,32886        , 0         , "t=20.2s",_
 4331, 87, 227, 0,0.5,       1,29682        , 0         , "t=2.47m",_
 4332, 88, 227, 0,1.5,       1,27177.5      , 0         , "t=42.2m",_
 4333, 89, 227, 0,1.5,      -1,25849.5      , 0         , "t=21.772y",_
 4334, 90, 227, 0,0.5,       1,25804.8      , 0         , "t=18.693d",_
 4335, 91, 227, 0,2.5,      -1,26830        , 0         , "t=38.3m",_
 4336, 92, 227, 0,1.5,       1,29045        , 0         , "t=1.1m",_
 4337, 93, 227, 0,2.5,       1,32580        , 0         , "t=510ms",_
 4338, 94, 227, 0,2.5,       1,36770        , 0         , "t=2s",_
 4339, 95, 227, 0,4.5,      -1,42180        , 0         , "t=20ms",_
 4340, 85, 228, 0,3,         1,41880        , 0         , "t=1m",_
 4341, 86, 228, 0,0,         1,35243        , 0         , "t=65s",_
 4342, 87, 228, 0,2,        -1,33384        , 0         , "t=38s",_
 4343, 87, 228, 1,-77.777,   0,34390        , 1.004     , "t=180s",_
 4344, 88, 228, 0,0,         1,28940.2      , 0         , "t=5.75y",_
 4345, 89, 228, 0,3,         1,28894.7      , 0         , "t=6.15h",_
 4346, 89, 228, 1,-77.777,   0,29430        , 0.539     , "t=180s",_
 4347, 90, 228, 0,0,         1,26770.9      , 0         , "t=1.9125y",_
 4348, 91, 228, 0,3,         1,28924        , 0         , "t=22h",_
 4349, 92, 228, 0,0,         1,29220        , 0         , "t=9.1m",_
 4350, 93, 228, 0,4,         1,33830        , 0         , "t=61.4s",_
 4351, 94, 228, 0,0,         1,36108        , 0         , "t=2.1s",_
 4352, 95, 228, 0,-77.777,   0,42850        , 0         , "t=100ms",_
 4353, 85, 229, 0,0.5,       1,44890        , 0         , "t=1s",_
 4354, 86, 229, 0,2.5,       1,39362        , 0         , "t=11.9s",_
 4355, 87, 229, 0,0.5,       1,35668        , 0         , "t=50.2s",_
 4356, 88, 229, 0,2.5,       1,32562        , 0         , "t=4.0m",_
 4357, 89, 229, 0,1.5,       1,30690        , 0         , "t=62.7m",_
 4358, 90, 229, 0,2.5,       1,29585.5      , 0         , "t=7.916ky",_
 4359, 90, 229, 1,1.5,       1,29585.5      , 8.15e-06  , "t=7us",_
 4360, 91, 229, 0,2.5,       1,29897        , 0         , "t=1.55d",_
 4361, 91, 229, 1,1.5,      -1,29909        , 0.0122    , "t=420ns",_
 4362, 92, 229, 0,1.5,       1,31211        , 0         , "t=57.8m",_
 4363, 93, 229, 0,2.5,       1,33800        , 0         , "t=4.00m",_
 4364, 94, 229, 0,1.5,       1,37390        , 0         , "t=91s",_
 4365, 95, 229, 0,2.5,      -1,42180        , 0         , "t=1.8s",_
 4366, 86, 230, 0,0,         1,42170        , 0         , "t=24s",_
 4367, 87, 230, 0,2,         1,39487        , 0         , "t=19.1s",_
 4368, 88, 230, 0,0,         1,34516        , 0         , "t=93m",_
 4369, 89, 230, 0,1,         1,33838        , 0         , "t=122s",_
 4370, 90, 230, 0,0,         1,30862.5      , 0         , "t=75.4ky",_
 4371, 91, 230, 0,2,        -1,32174        , 0         , "t=17.4d",_
 4372, 92, 230, 0,0,         1,31615        , 0         , "t=20.23d",_
 4373, 93, 230, 0,4,         1,35240        , 0         , "t=4.6m",_
 4374, 94, 230, 0,0,         1,36932        , 0         , "t=105s",_
 4375, 95, 230, 0,1,        -1,42870        , 0         , "t=40s",_
 4376, 86, 231, 0,0.5,       1,46550        , 0         , "t=2s",_
 4377, 87, 231, 0,0.5,       1,42081        , 0         , "t=17.6s",_
 4378, 88, 231, 0,2.5,       1,38216        , 0         , "t=104s",_
 4379, 88, 231, 1,0.5,       1,38282        , 0.06621   , "t=~53us",_
 4380, 89, 231, 0,0.5,       1,35763        , 0         , "t=7.5m",_
 4381, 90, 231, 0,2.5,       1,33815.8      , 0         , "t=25.52h",_
 4382, 91, 231, 0,1.5,      -1,33424.3      , 0         , "t=32.65ky",_
 4383, 92, 231, 0,2.5,       1,33806.0      , 0         , "t=4.2d",_
 4384, 93, 231, 0,2.5,       1,35620        , 0         , "t=48.8m",_
 4385, 94, 231, 0,1.5,       1,38309        , 0         , "t=8.6m",_
 4386, 95, 231, 0,2.5,      -1,42410        , 0         , "t=1m",_
 4387, 96, 231, 0,1.5,       1,47270        , 0         , "t=20s",_
 4388, 87, 232, 0,5,         0,46073        , 0         , "t=5.5s",_
 4389, 88, 232, 0,0,         1,40497        , 0         , "t=4.0m",_
 4390, 89, 232, 0,1,         1,39154        , 0         , "t=1.98m",_
 4391, 90, 232, 0,0,         1,35446.7      , 0         , "t=14.0Gy",_
 4392, 91, 232, 0,2,        -1,35947        , 0         , "t=1.32d",_
 4393, 92, 232, 0,0,         1,34609.4      , 0         , "t=68.9y",_
 4394, 93, 232, 0,5,        -1,37360        , 0         , "t=14.7m",_
 4395, 94, 232, 0,0,         1,38361        , 0         , "t=33.7m",_
 4396, 95, 232, 0,1,        -1,43420        , 0         , "t=1.31m",_
 4397, 96, 232, 0,0,         1,46330        , 0         , "t=10s",_
 4398, 87, 233, 0,0.5,       1,48920        , 0         , "t=900ms",_
 4399, 88, 233, 0,0.5,       1,44334        , 0         , "t=30s",_
 4400, 89, 233, 0,0.5,       1,41308        , 0         , "t=143s",_
 4401, 90, 233, 0,0.5,       1,38731.6      , 0         , "t=21.83m",_
 4402, 90, 233, 1,3.5,      -1,38737.7      , 0.00606   , "t=2s",_
 4403, 91, 233, 0,1.5,      -1,37489.4      , 0         , "t=26.975d",_
 4404, 92, 233, 0,2.5,       1,36919.1      , 0         , "t=159.19ky",_
 4405, 93, 233, 0,2.5,       1,37950        , 0         , "t=36.2m",_
 4406, 94, 233, 0,2.5,       1,40050        , 0         , "t=20.9m",_
 4407, 95, 233, 0,2.5,      -1,43290        , 0         , "t=3.2m",_
 4408, 96, 233, 0,1.5,       1,47290        , 0         , "t=27s",_
 4409, 97, 233, 0,1.5,      -1,52770        , 0         , "t=40s",_
 4410, 88, 234, 0,0,         1,46931        , 0         , "t=30s",_
 4411, 89, 234, 0,1,         1,44841        , 0         , "t=45s",_
 4412, 89, 234, 1,-77.777,   0,44980        , 0.14      , "t=&gt;93s",_
 4413, 90, 234, 0,0,         1,40613.0      , 0         , "t=24.107d",_
 4414, 91, 234, 0,4,         1,40339        , 0         , "t=6.70h",_
 4415, 91, 234, 1,0,        -1,40417.9      , 0.079     , "t=1.159m",_
 4416, 92, 234, 0,0,         1,38145.0      , 0         , "t=245.5ky",_
 4417, 92, 234, 1,6,        -1,39566.3      , 1.421257  , "t=33.5us",_
 4418, 93, 234, 0,0,         1,39955        , 0         , "t=4.4d",_
 4419, 94, 234, 0,0,         1,40350        , 0         , "t=8.8h",_
 4420, 95, 234, 0,0,        -1,44460        , 0         , "t=2.32m",_
 4421, 96, 234, 0,0,         1,46722        , 0         , "t=52s",_
 4422, 97, 234, 0,3,        -1,53400        , 0         , "t=20s",_
 4423, 88, 235, 0,2.5,       1,51130        , 0         , "t=5s",_
 4424, 89, 235, 0,0.5,       1,47357        , 0         , "t=62s",_
 4425, 90, 235, 0,0.5,       1,44018        , 0         , "t=7.2m",_
 4426, 91, 235, 0,1.5,      -1,42289        , 0         , "t=24.4m",_
 4427, 92, 235, 0,3.5,      -1,40918.8      , 0         , "t=704My",_
 4428, 92, 235, 1,0.5,       1,40918.9      , 7.6737e-05              , "t=25.7m",_
 4429, 93, 235, 0,2.5,       1,41043.0      , 0         , "t=396.1d",_
 4430, 94, 235, 0,2.5,       1,42182        , 0         , "t=25.3m",_
 4431, 95, 235, 0,2.5,      -1,44620        , 0         , "t=10.3m",_
 4432, 96, 235, 0,2.5,       1,48010        , 0         , "t=7m",_
 4433, 97, 235, 0,1.5,      -1,52770        , 0         , "t=1m",_
 4434, 89, 236, 0,3,         1,51220        , 0         , "t=4.5m",_
 4435, 90, 236, 0,0,         1,46255        , 0         , "t=37.3m",_
 4436, 91, 236, 0,1,        -1,45334        , 0         , "t=9.1m",_
 4437, 92, 236, 0,0,         1,42444.6      , 0         , "t=23.42My",_
 4438, 92, 236, 1,4,        -1,43497.1      , 1.0525    , "t=100ns",_
 4439, 93, 236, 0,6,        -1,43380        , 0         , "t=153ky",_
 4440, 93, 236, 1,1,        -1,43438        , 0.06      , "t=22.5h",_
 4441, 94, 236, 0,0,         1,42901.5      , 0         , "t=2.858y",_
 4442, 94, 236, 1,5,        -1,44087.0      , 1.18545   , "t=1.2us",_
 4443, 95, 236, 0,5,        -1,46040        , 0         , "t=3.6m",_
 4444, 95, 236, 1,1,        -1,46090        , 0.05      , "t=2.9m",_
 4445, 96, 236, 0,0,         1,47853        , 0         , "t=6.8m",_
 4446, 97, 236, 0,4,         1,53540        , 0         , "t=26s",_
 4447, 89, 237, 0,0.5,       1,54020        , 0         , "t=23s",_
 4448, 90, 237, 0,2.5,       1,49955        , 0         , "t=4.8m",_
 4449, 91, 237, 0,0.5,       1,47528        , 0         , "t=8.7m",_
 4450, 92, 237, 0,0.5,       1,45390.1      , 0         , "t=6.752d",_
 4451, 92, 237, 1,3.5,      -1,45664.1      , 0.274     , "t=155ns",_
 4452, 93, 237, 0,2.5,       1,44871.6      , 0         , "t=2.144My",_
 4453, 93, 237, 1,6.5,      -1,45816.8      , 0.9452    , "t=710ns",_
 4454, 94, 237, 0,3.5,      -1,45091.7      , 0         , "t=45.64d",_
 4455, 94, 237, 1,0.5,       1,45237.2      , 0.145543  , "t=180ms",_
 4456, 95, 237, 0,2.5,      -1,46570        , 0         , "t=73.6m",_
 4457, 96, 237, 0,2.5,       1,49250        , 0         , "t=&gt;10m",_
 4458, 97, 237, 0,1.5,      -1,53210        , 0         , "t=2m",_
 4459, 98, 237, 0,2.5,       1,57940        , 0         , "t=0.8s",_
 4460, 90, 238, 0,0,         1,52530        , 0         , "t=9.4m",_
 4461, 91, 238, 0,3,        -1,50894        , 0         , "t=2.28m",_
 4462, 92, 238, 0,0,         1,47307.7      , 0         , "t=4.463Gy",_
 4463, 92, 238, 1,0,         1,49865.6      , 2.5579    , "t=280ns",_
 4464, 93, 238, 0,2,         1,47454.6      , 0         , "t=2.099d",_
 4465, 93, 238, 1,-77.777,   0,49760        , 2.3       , "t=112ns",_
 4466, 94, 238, 0,0,         1,46163.1      , 0         , "t=87.7y",_
 4467, 95, 238, 0,1,         1,48420        , 0         , "t=98m",_
 4468, 95, 238, 1,-77.777,   0,50920        , 2.5       , "t=35us",_
 4469, 96, 238, 0,0,         1,49445        , 0         , "t=2.2h",_
 4470, 97, 238, 0,1,         0,54220        , 0         , "t=2.40m",_
 4471, 98, 238, 0,0,         1,57280        , 0         , "t=21.1ms",_
 4472, 90, 239, 0,3.5,       1,56500        , 0         , "t=1m",_
 4473, 91, 239, 0,0.5,       1,53340        , 0         , "t=1.8h",_
 4474, 92, 239, 0,2.5,       1,50572.7      , 0         , "t=23.45m",_
 4475, 92, 239, 1,0.5,       1,50706.5      , 0.1337991 , "t=780ns",_
 4476, 93, 239, 0,2.5,       1,49311.0      , 0         , "t=2.356d",_
 4477, 94, 239, 0,0.5,       1,48588.2      , 0         , "t=24.11ky",_
 4478, 94, 239, 1,3.5,      -1,48979.8      , 0.391584  , "t=193ns",_
 4479, 95, 239, 0,2.5,      -1,49390.4      , 0         , "t=11.9h",_
 4480, 95, 239, 1,3.5,       1,51890        , 2.5       , "t=163ns",_
 4481, 96, 239, 0,3.5,      -1,51150        , 0         , "t=2.5h",_
 4482, 97, 239, 0,3.5,       1,54250        , 0         , "t=100s",_
 4483, 98, 239, 0,2.5,       1,58200        , 0         , "t=28s",_
 4484, 99, 239, 0,1.5,      -1,63630        , 0         , "t=1s",_
 4485, 91, 240, 0,3,         1,57010        , 0         , "t=20s",_
 4486, 92, 240, 0,0,         1,52715.5      , 0         , "t=14.1h",_
 4487, 93, 240, 0,5,         1,52316        , 0         , "t=61.9m",_
 4488, 93, 240, 1,1,         1,52334        , 0.018     , "t=7.22m",_
 4489, 94, 240, 0,0,         1,50125.3      , 0         , "t=6.561ky",_
 4490, 94, 240, 1,5,        -1,51434.0      , 1.30874   , "t=165ns",_
 4491, 95, 240, 0,3,        -1,51510        , 0         , "t=50.8h",_
 4492, 95, 240, 1,-77.777,   0,54510        , 3         , "t=940us",_
 4493, 96, 240, 0,0,         1,51724.2      , 0         , "t=30.4d",_
 4494, 97, 240, 0,7,        -1,55660        , 0         , "t=4.8m",_
 4495, 98, 240, 0,0,         1,57989        , 0         , "t=40.3s",_
 4496, 99, 240, 0,4,        -1,64230        , 0         , "t=6.0s",_
 4497, 91, 241, 0,0.5,       1,59740        , 0         , "t=28m",_
 4498, 92, 241, 0,3.5,       1,56200        , 0         , "t=4m",_
 4499, 93, 241, 0,2.5,       1,54320        , 0         , "t=13.9m",_
 4500, 94, 241, 0,2.5,       1,52955.1      , 0         , "t=14.329y",_
 4501, 94, 241, 1,0.5,       1,53116.8      , 0.1616853 , "t=880ns",_
 4502, 95, 241, 0,2.5,      -1,52934.3      , 0         , "t=432.6y",_
 4503, 95, 241, 1,-77.777,   0,55130        , 2.2       , "t=1.2us",_
 4504, 96, 241, 0,0.5,       1,53701.8      , 0         , "t=32.8d",_
 4505, 97, 241, 0,3.5,       1,55980        , 0         , "t=4.6m",_
 4506, 98, 241, 0,3.5,      -1,59330        , 0         , "t=2.35m",_
 4507, 99, 241, 0,1.5,      -1,63890        , 0         , "t=5.1s",_
 4508, 100, 241, 0,2.5,      1,69220        , 0         , "t=730us",_
 4509, 92, 242, 0,0,         1,58620        , 0         , "t=16.8m",_
 4510, 93, 242, 0,1,         1,57420        , 0         , "t=2.2m",_
 4511, 93, 242, 1,6,         1,57470        , 0.05      , "t=5.5m",_
 4512, 94, 242, 0,0,         1,54716.9      , 0         , "t=375ky",_
 4513, 95, 242, 0,1,        -1,55468.0      , 0         , "t=16.02h",_
 4514, 95, 242, 1,5,        -1,55516.6      , 0.0486    , "t=141y",_
 4515, 96, 242, 0,0,         1,54803.7      , 0         , "t=162.8d",_
 4516, 96, 242, 1,-77.777,   0,57600        , 2.8       , "t=180ns",_
 4517, 97, 242, 0,3,         1,57750        , 0         , "t=7.0m",_
 4518, 97, 242, 1,-77.777,   0,59750        , 2         , "t=600ns",_
 4519, 98, 242, 0,0,         1,59387        , 0         , "t=3.49m",_
 4520, 99, 242, 0,2,         1,64800        , 0         , "t=17.8s",_
 4521, 100, 242, 0,0,        1,68400        , 0         , "t=800us",_
 4522, 92, 243, 0,4.5,      -1,62480        , 0         , "t=16m",_
 4523, 93, 243, 0,2.5,       1,59810        , 0         , "t=1.85m",_
 4524, 94, 243, 0,3.5,       1,57754.6      , 0         , "t=4.9553h",_
 4525, 94, 243, 1,0.5,       1,58138.2      , 0.38364   , "t=330ns",_
 4526, 95, 243, 0,2.5,      -1,57175.0      , 0         , "t=7.350ky",_
 4527, 95, 243, 1,-77.777,   0,59480        , 2.3       , "t=5.5us",_
 4528, 96, 243, 0,2.5,       1,57181.9      , 0         , "t=29.1y",_
 4529, 96, 243, 1,0.5,       1,57269.3      , 0.0874    , "t=1.08us",_
 4530, 97, 243, 0,1.5,      -1,58690        , 0         , "t=4.6h",_
 4531, 98, 243, 0,0.5,       1,60990        , 0         , "t=10.8m",_
 4532, 99, 243, 0,3.5,       1,64750        , 0         , "t=22.1s",_
 4533, 99, 243, 1,1.5,      -1,64800        , 0.05      , "t=&gt;50us",_
 4534, 100, 243, 0,3.5,     -1,69320        , 0         , "t=231ms",_
 4535, 93, 244, 0,7,        -1,63240        , 0         , "t=2.29m",_
 4536, 94, 244, 0,0,         1,59806.0      , 0         , "t=81.3My",_
 4537, 94, 244, 1,8,        -1,61022.0      , 1.216     , "t=1.75s",_
 4538, 95, 244, 0,6,        -1,59879.1      , 0         , "t=10.01h",_
 4539, 95, 244, 1,1,         1,59968.4      , 0.0893    , "t=26.13m",_
 4540, 96, 244, 0,0,         1,58451.8      , 0         , "t=18.11y",_
 4541, 96, 244, 1,6,         1,59492.0      , 1.040181  , "t=34ms",_
 4542, 97, 244, 0,4,        -1,60714        , 0         , "t=5.02h",_
 4543, 97, 244, 1,-77.777,   0,62210        , 1.5       , "t=820ns",_
 4544, 98, 244, 0,0,         1,61478.1      , 0         , "t=19.5m",_
 4545, 99, 244, 0,6,         1,66030        , 0         , "t=37s",_
 4546, 100, 244, 0,0,        1,68960        , 0         , "t=3.12ms",_
 4547, 101, 244, 0,3,        1,75600        , 0         , "t=0.36s",_
 4548, 101, 244, 1,7,        1,75800        , 0.2       , "t=~9us",_
 4549, 93, 245, 0,2.5,       1,65850        , 0         , "t=6m",_
 4550, 94, 245, 0,4.5,      -1,63178        , 0         , "t=10.5h",_
 4551, 94, 245, 1,2.5,       1,63443        , 0.2645    , "t=330ns",_
 4552, 95, 245, 0,2.5,       1,61900.4      , 0         , "t=2.05h",_
 4553, 95, 245, 1,-77.777,   0,64300        , 2.4       , "t=640ns",_
 4554, 96, 245, 0,3.5,       1,61004.5      , 0         , "t=8.25ky",_
 4555, 96, 245, 1,0.5,       1,61360.4      , 0.35592   , "t=290ns",_
 4556, 97, 245, 0,1.5,      -1,61813.8      , 0         , "t=4.95d",_
 4557, 98, 245, 0,0.5,       1,63385.2      , 0         , "t=45.0m",_
 4558, 99, 245, 0,1.5,      -1,66320        , 0         , "t=1.11m",_
 4559, 99, 245, 1,3.5,       1,66350        , 0.03      , "t=&gt;50us",_
 4560, 100, 245, 0,0.5,      1,70190        , 0         , "t=4.2s",_
 4561, 101, 245, 0,3.5,     -1,75330        , 0         , "t=0.38s",_
 4562, 101, 245, 1,0.5,     -1,75430        , 0.1       , "t=0.90ms",_
 4563, 94, 246, 0,0,         1,65395        , 0         , "t=10.84d",_
 4564, 95, 246, 0,7,        -1,64994        , 0         , "t=39m",_
 4565, 95, 246, 1,2,        -1,65024        , 0.03      , "t=25.0m",_
 4566, 96, 246, 0,0,         1,62616.9      , 0         , "t=4.706ky",_
 4567, 96, 246, 1,8,        -1,63796.6      , 1.17966   , "t=1.12s",_
 4568, 97, 246, 0,2,        -1,63970        , 0         , "t=1.80d",_
 4569, 98, 246, 0,0,         1,64090.2      , 0         , "t=35.7h",_
 4570, 99, 246, 0,4,        -1,67820        , 0         , "t=7.5m",_
 4571, 100, 246, 0,0,        1,70191        , 0         , "t=1.54s",_
 4572, 101, 246, 0,1,       -1,76120        , 0         , "t=0.92s",_
 4573, 101, 246, 1,4,       -1,76170        , 0.06      , "t=4.4s",_
 4574, 94, 247, 0,0.5,       1,69210        , 0         , "t=2.27d",_
 4575, 95, 247, 0,2.5,       0,67150        , 0         , "t=23.0m",_
 4576, 96, 247, 0,4.5,      -1,65533        , 0         , "t=15.6My",_
 4577, 96, 247, 1,2.5,       1,65760        , 0.22738   , "t=26.3us",_
 4578, 97, 247, 0,1.5,      -1,65490        , 0         , "t=1.38ky",_
 4579, 98, 247, 0,3.5,       1,66109        , 0         , "t=3.11h",_
 4580, 99, 247, 0,3.5,       1,68578        , 0         , "t=4.55m",_
 4581, 99, 247, 1,1.5,      -1,68630        , 0.05      , "t=&gt;20us",_
 4582, 100, 247, 0,3.5,      1,71670        , 0         , "t=31s",_
 4583, 100, 247, 1,0.5,      1,71720        , 0.049     , "t=5.1s",_
 4584, 101, 247, 0,3.5,     -1,75940        , 0         , "t=1.19s",_
 4585, 101, 247, 1,0.5,     -1,76200        , 0.26      , "t=250ms",_
 4586, 95, 248, 0,3,         1,70560        , 0         , "t=3m",_
 4587, 96, 248, 0,0,         1,67392.7      , 0         , "t=348ky",_
 4588, 96, 248, 1,8,        -1,68850.8      , 1.4581    , "t=146us",_
 4589, 97, 248, 0,6,         1,68130        , 0         , "t=&gt;9y",_
 4590, 97, 248, 1,1,        -1,68108        ,-0.02      , "t=23.7h",_
 4591, 98, 248, 0,0,         1,67238        , 0         , "t=333.5d",_
 4592, 99, 248, 0,2,        -1,70300        , 0         , "t=24m",_
 4593, 100, 248, 0,0,        1,71898        , 0         , "t=34.5s",_
 4594, 100, 248, 1,6,        1,73100        , 1.2       , "t=10.1ms",_
 4595, 101, 248, 0,-77.777,  0,76950        , 0         , "t=7s",_
 4596, 102, 248, 0,0,        1,80690        , 0         , "t=?",_
 4597, 95, 249, 0,2.5,       0,73100        , 0         , "t=3m",_
 4598, 96, 249, 0,0.5,       1,70750.7      , 0         , "t=64.15m",_
 4599, 96, 249, 1,3.5,       1,70799.5      , 0.04876   , "t=23us",_
 4600, 97, 249, 0,3.5,       1,69846.3      , 0         , "t=327.2d",_
 4601, 97, 249, 1,1.5,      -1,69855.1      , 0.008777  , "t=300us",_
 4602, 98, 249, 0,4.5,      -1,69722.7      , 0         , "t=351y",_
 4603, 98, 249, 1,2.5,       1,69867.7      , 0.14498   , "t=45us",_
 4604, 99, 249, 0,3.5,       1,71180        , 0         , "t=102.2m",_
 4605, 100, 249, 0,3.5,      1,73519        , 0         , "t=1.6m",_
 4606, 101, 249, 0,3.5,     -1,77180        , 0         , "t=25.6s",_
 4607, 101, 249, 1,0.5,     -1,77280        , 0.1       , "t=1.9s",_
 4608, 102, 249, 0,2.5,      1,81790        , 0         , "t=57us",_
 4609, 96, 250, 0,0,         1,72990        , 0         , "t=8300y",_
 4610, 97, 250, 0,2,        -1,72952.0      , 0         , "t=3.212h",_
 4611, 97, 250, 1,4,         1,72987.6      , 0.03559   , "t=29us",_
 4612, 98, 250, 0,0,         1,71170.3      , 0         , "t=13.08y",_
 4613, 99, 250, 0,6,         1,73230        , 0         , "t=8.6h",_
 4614, 99, 250, 1,1,        -1,73430        , 0.2       , "t=2.22h",_
 4615, 100, 250, 0,0,        1,74072        , 0         , "t=31.0m",_
 4616, 100, 250, 1,8,       -1,75271        , 1.1992    , "t=1.92s",_
 4617, 101, 250, 0,2,       -1,78400        , 0         , "t=54s",_
 4618, 101, 250, 1,7,        1,78520        , 0.12      , "t=42.4s",_
 4619, 102, 250, 0,0,        1,81570        , 0         , "t=5.08us",_
 4620, 102, 250, 1,6,        1,82620        , 1.05      , "t=36.3us",_
 4621, 96, 251, 0,1.5,       1,76648        , 0         , "t=16.8m",_
 4622, 97, 251, 0,1.5,      -1,75228        , 0         , "t=55.6m",_
 4623, 97, 251, 1,3.5,       1,75264        , 0.0355    , "t=58us",_
 4624, 98, 251, 0,0.5,       1,74135        , 0         , "t=898y",_
 4625, 98, 251, 1,5.5,      -1,74505        , 0.37047   , "t=1.3us",_
 4626, 99, 251, 0,1.5,      -1,74512        , 0         , "t=33h",_
 4627, 99, 251, 1,3.5,       1,74520        , 0.0084    , "t=&gt;200us",_
 4628, 100, 251, 0,4.5,     -1,75959        , 0         , "t=5.30h",_
 4629, 100, 251, 1,2.5,      1,76159        , 0.2       , "t=21.8us",_
 4630, 101, 251, 0,3.5,     -1,78967        , 0         , "t=4.21m",_
 4631, 102, 251, 0,3.5,      1,82850        , 0         , "t=800ms",_
 4632, 102, 251, 1,0.5,      1,82960        , 0.106     , "t=1.02s",_
 4633, 103, 251, 0,-77.777,  0,87830        , 0         , "t=300us",_
 4634, 96, 252, 0,0,         1,79060        , 0         , "t=1m",_
 4635, 97, 252, 0,-77.777,   0,78540        , 0         , "t=1.8m",_
 4636, 98, 252, 0,0,         1,76034.6      , 0         , "t=2.645y",_
 4637, 99, 252, 0,4,         1,77290        , 0         , "t=471.7d",_
 4638, 100, 252, 0,0,        1,76817        , 0         , "t=25.39h",_
 4639, 101, 252, 0,1,        1,80470        , 0         , "t=2.3m",_
 4640, 102, 252, 0,0,        1,82871        , 0         , "t=2.467s",_
 4641, 102, 252, 1,8,       -1,84125        , 1.2541    , "t=109.1ms",_
 4642, 103, 252, 0,7,       -1,88540        , 0         , "t=369ms",_
 4643, 97, 253, 0,1.5,      -1,80930        , 0         , "t=60m",_
 4644, 98, 253, 0,3.5,       1,79302        , 0         , "t=17.81d",_
 4645, 99, 253, 0,3.5,       1,79010.5      , 0         , "t=20.47d",_
 4646, 99, 253, 1,1.5,      -1,79117        , 0.106     , "t=&gt;10us",_
 4647, 100, 253, 0,0.5,      1,79345.5      , 0         , "t=3.00d",_
 4648, 100, 253, 1,3.5,      1,79486        , 0.14      , "t=&gt;100ns",_
 4649, 101, 253, 0,3.5,     -1,81170        , 0         , "t=12m",_
 4650, 102, 253, 0,4.5,     -1,84359        , 0         , "t=1.57m",_
 4651, 102, 253, 1,2.5,      1,84527        , 0.1675    , "t=30.3us",_
 4652, 103, 253, 0,3.5,     -1,88520        , 0         , "t=632ms",_
 4653, 103, 253, 1,0.5,     -1,88560        , 0.03      , "t=1.32s",_
 4654, 104, 253, 0,3.5,      1,93640        , 0         , "t=13ms",_
 4655, 104, 253, 1,0.5,      1,93840        , 0.2       , "t=52us",_
 4656, 97, 254, 0,-77.777,   0,84390        , 0         , "t=1m",_
 4657, 98, 254, 0,0,         1,81341        , 0         , "t=60.5d",_
 4658, 99, 254, 0,7,         1,81994.2      , 0         , "t=275.7d",_
 4659, 99, 254, 1,2,         1,82074.5      , 0.0804    , "t=39.3h",_
 4660, 100, 254, 0,0,        1,80902.5      , 0         , "t=3.240h",_
 4661, 101, 254, 0,0,       -1,83450        , 0         , "t=10m",_
 4662, 101, 254, 1,3,       -1,83500        , 0.05      , "t=28m",_
 4663, 102, 254, 0,0,        1,84723        , 0         , "t=51.2s",_
 4664, 102, 254, 1,8,       -1,86019        , 1.2964    , "t=264.9ms",_
 4665, 103, 254, 0,4,        1,89650        , 0         , "t=12.0s",_
 4666, 103, 254, 1,1,        1,89750        , 0.107     , "t=20.3s",_
 4667, 104, 254, 0,0,        1,93200        , 0         , "t=22.9us",_
 4668, 104, 254, 1,8,       -1,94500        , 1.3       , "t=4.3us",_
 4669, 98, 255, 0,3.5,       1,84810        , 0         , "t=85m",_
 4670, 99, 255, 0,3.5,       1,84089        , 0         , "t=39.8d",_
 4671, 100, 255, 0,3.5,      1,83800        , 0         , "t=20.07h",_
 4672, 101, 255, 0,3.5,     -1,84842        , 0         , "t=27m",_
 4673, 102, 255, 0,0.5,      1,86812        , 0         , "t=3.52m",_
 4674, 102, 255, 1,5.5,     -1,87020        , 0.21      , "t=1s",_
 4675, 103, 255, 0,0.5,     -1,89947        , 0         , "t=31.1s",_
 4676, 103, 255, 1,3.5,     -1,89988        , 0.041     , "t=2.54s",_
 4677, 104, 255, 0,4.5,     -1,94330        , 0         , "t=1.63s",_
 4678, 104, 255, 1,2.5,      1,94480        , 0.15      , "t=43us",_
 4679, 105, 255, 0,4.5,      1,99600        , 0         , "t=54ms",_
 4680, 105, 255, 1,0.5,     -1,99700        , 0.1       , "t=2.8ms",_
 4681, 98, 256, 0,0,         1,87040        , 0         , "t=12.3m",_
 4682, 99, 256, 0,7,         1,87190        , 0         , "t=7.6h",_
 4683, 99, 256, 1,0,         1,87190        , 0         , "t=25.4m",_
 4684, 100, 256, 0,0,        1,85485        , 0         , "t=157.1m",_
 4685, 101, 256, 0,1,       -1,87460        , 0         , "t=77.7m",_
 4686, 101, 256, 1,7,       -1,87620        , 0.16      , "t=100m",_
 4687, 102, 256, 0,0,        1,87823        , 0         , "t=2.91s",_
 4688, 103, 256, 0,0,       -1,91750        , 0         , "t=27.9s",_
 4689, 104, 256, 0,0,        1,94222        , 0         , "t=6.60ms",_
 4690, 104, 256, 1,4,       -1,95340        , 1.12      , "t=25us",_
 4691, 105, 256, 0,9,       -1,100300       , 0         , "t=1.7s",_
 4692, 99, 257, 0,3.5,       1,89400        , 0         , "t=7.7d",_
 4693, 100, 257, 0,4.5,      1,88590        , 0         , "t=100.5d",_
 4694, 101, 257, 0,3.5,     -1,88992.5      , 0         , "t=5.52h",_
 4695, 102, 257, 0,1.5,      1,90247        , 0         , "t=24.5s",_
 4696, 103, 257, 0,3.5,     -1,92670        , 0         , "t=6.0s",_
 4697, 103, 257, 1,0.5,     -1,92770        , 0.1       , "t=0.27s",_
 4698, 104, 257, 0,0.5,      1,95866        , 0         , "t=5.0s",_
 4699, 104, 257, 1,5.5,     -1,95940        , 0.073     , "t=4.5s",_
 4700, 105, 257, 0,4.5,      1,100150       , 0         , "t=2.3s",_
 4701, 105, 257, 1,0.5,     -1,100290       , 0.14      , "t=670ms",_
 4702, 99, 258, 0,-77.777,   0,92700        , 0         , "t=4m",_
 4703, 100, 258, 0,0,        1,90430        , 0         , "t=370us",_
 4704, 101, 258, 0,8,       -1,91690        , 0         , "t=51.59d",_
 4705, 101, 258, 1,1,       -1,91690        , 0         , "t=57.0m",_
 4706, 102, 258, 0,0,        1,91480        , 0         , "t=1.23ms",_
 4707, 103, 258, 0,-77.777,  0,94780        , 0         , "t=3.92s",_
 4708, 104, 258, 0,0,        1,96344        , 0         , "t=12.5ms",_
 4709, 104, 258, 1,-77.777,  0,97540        , 1.2       , "t=3.4ms",_
 4710, 105, 258, 0,0,       -1,101510       , 0         , "t=2.17s",_
 4711, 105, 258, 1,5,        1,101560       , 0.053     , "t=4.41s",_
 4712, 106, 258, 0,0,        1,105300       , 0         , "t=2.7ms",_
 4713, 100, 259, 0,-77.777,  0,93700        , 0         , "t=1.5s",_
 4714, 101, 259, 0,3.5,     -1,93560        , 0         , "t=1.60h",_
 4715, 102, 259, 0,4.5,      1,94079        , 0         , "t=58m",_
 4716, 103, 259, 0,0.5,     -1,95850        , 0         , "t=6.2s",_
 4717, 104, 259, 0,1.5,      1,98370        , 0         , "t=2.63s",_
 4718, 105, 259, 0,4.5,      1,101990       , 0         , "t=510ms",_
 4719, 106, 259, 0,5.5,     -1,106520       , 0         , "t=402ms",_
 4720, 106, 259, 1,0.5,      1,106610       , 0.087     , "t=226ms",_
 4721, 100, 260, 0,0,        1,95770        , 0         , "t=1m",_
 4722, 101, 260, 0,-77.777,  0,96550        , 0         , "t=27.8d",_
 4723, 102, 260, 0,0,        1,95610        , 0         , "t=106ms",_
 4724, 103, 260, 0,-77.777,  0,98280        , 0         , "t=3.0m",_
 4725, 104, 260, 0,0,        1,99150        , 0         , "t=21ms",_
 4726, 105, 260, 0,-77.777,  0,103670       , 0         , "t=1.52s",_
 4727, 106, 260, 0,0,        1,106547       , 0         , "t=4.95ms",_
 4728, 107, 260, 0,-77.777,  0,113120       , 0         , "t=41ms",_
 4729, 101, 261, 0,3.5,     -1,98580        , 0         , "t=40m",_
 4730, 102, 261, 0,-77.777,  0,98460        , 0         , "t=3h",_
 4731, 103, 261, 0,0.5,     -1,99560        , 0         , "t=39m",_
 4732, 104, 261, 0,1.5,      1,101320       , 0         , "t=2.1s",_
 4733, 104, 261, 1,5.5,     -1,101390       , 0.07      , "t=74s",_
 4734, 105, 261, 0,4.5,      1,104310       , 0         , "t=4.7s",_
 4735, 106, 261, 0,1.5,      1,108005       , 0         , "t=183ms",_
 4736, 106, 261, 1,3.5,      1,108110       , 0.1       , "t=9.3us",_
 4737, 107, 261, 0,2.5,     -1,113080       , 0         , "t=12.8ms",_
 4738, 101, 262, 0,-77.777,  0,101670       , 0         , "t=3m",_
 4739, 102, 262, 0,0,        1,100100       , 0         , "t=~5ms",_
 4740, 103, 262, 0,-77.777,  0,102110       , 0         , "t=~4h",_
 4741, 104, 262, 0,0,        1,102390       , 0         , "t=250ms",_
 4742, 104, 262, 1,8,       -1,103390       , 1         , "t=47ms",_
 4743, 105, 262, 0,-77.777,  0,106250       , 0         , "t=34s",_
 4744, 106, 262, 0,0,        1,108369       , 0         , "t=10.3ms",_
 4745, 107, 262, 0,-77.777,  0,114250       , 0         , "t=84ms",_
 4746, 107, 262, 1,-77.777,  0,114470       , 0.22      , "t=9.5ms",_
 4747, 102, 263, 0,-77.777,  0,103130       , 0         , "t=20m",_
 4748, 103, 263, 0,0.5,     -1,103670       , 0         , "t=5h",_
 4749, 104, 263, 0,-77.777,  0,104760       , 0         , "t=11m",_
 4750, 105, 263, 0,4.5,      1,107110       , 0         , "t=29s",_
 4751, 106, 263, 0,1.5,      1,110200       , 0         , "t=940ms",_
 4752, 106, 263, 1,3.5,      1,110250       , 0.051     , "t=420ms",_
 4753, 107, 263, 0,2.5,     -1,114500       , 0         , "t=200ms",_
 4754, 108, 263, 0,1.5,      1,119680       , 0         , "t=0.9ms",_
 4755, 108, 263, 1,5.5,     -1,120000       , 0.33      , "t=1ms",_
 4756, 102, 264, 0,0,        1,105010       , 0         , "t=1m",_
 4757, 103, 264, 0,-77.777,  0,106380       , 0         , "t=10h",_
 4758, 104, 264, 0,0,        1,106080       , 0         , "t=1h",_
 4759, 105, 264, 0,-77.777,  0,109260       , 0         , "t=3m",_
 4760, 106, 264, 0,0,        1,110780       , 0         , "t=78ms",_
 4761, 107, 264, 0,-77.777,  0,115960       , 0         , "t=1.07s",_
 4762, 108, 264, 0,0,        1,119563       , 0         , "t=0.7s",_
 4763, 103, 265, 0,0.5,     -1,108230       , 0         , "t=10h",_
 4764, 104, 265, 0,4.5,      1,108690       , 0         , "t=1.6m",_
 4765, 105, 265, 0,4.5,      1,110380       , 0         , "t=15m",_
 4766, 106, 265, 0,5.5,     -1,112790       , 0         , "t=9.2s",_
 4767, 106, 265, 1,-77.777,  0,112790       ,-0.01      , "t=16.4s",_
 4768, 107, 265, 0,2.5,     -1,116400       , 0         , "t=1.19s",_
 4769, 108, 265, 0,1.5,      1,120900       , 0         , "t=1.96ms",_
 4770, 108, 265, 1,5.5,     -1,121130       , 0.229     , "t=360us",_
 4771, 109, 265, 0,-77.777,  0,126620       , 0         , "t=2ms",_
 4772, 103, 266, 0,-77.777,  0,111660       , 0         , "t=22h",_
 4773, 104, 266, 0,0,        1,110140       , 0         , "t=4h",_
 4774, 105, 266, 0,-77.777,  0,112740       , 0         , "t=80m",_
 4775, 106, 266, 0,0,        1,113620       , 0         , "t=390ms",_
 4776, 107, 266, 0,-77.777,  0,118100       , 0         , "t=10.6s",_
 4777, 108, 266, 0,0,        1,121140       , 0         , "t=3.0ms",_
 4778, 108, 266, 1,9,       -1,122240       , 1.1       , "t=280ms",_
 4779, 109, 266, 0,-77.777,  0,127670       , 0         , "t=2.0ms",_
 4780, 109, 266, 1,-77.777,  0,128810       , 1.14      , "t=6ms",_
 4781, 104, 267, 0,-77.777,  0,113440       , 0         , "t=2.5h",_
 4782, 105, 267, 0,4.5,      1,114010       , 0         , "t=2.0h",_
 4783, 106, 267, 0,-77.777,  0,115810       , 0         , "t=1.8m",_
 4784, 107, 267, 0,2.5,     -1,118770       , 0         , "t=22s",_
 4785, 108, 267, 0,-77.777,  0,122660       , 0         , "t=55ms",_
 4786, 108, 267, 1,-77.777,  0,122700       , 0.039     , "t=990us",_
 4787, 109, 267, 0,-77.777,  0,127790       , 0         , "t=10ms",_
 4788, 110, 267, 0,1.5,      1,133880       , 0         , "t=10us",_
 4789, 104, 268, 0,0,        1,115480       , 0         , "t=1h",_
 4790, 105, 268, 0,-77.777,  0,117060       , 0         , "t=29h",_
 4791, 106, 268, 0,0,        1,116800       , 0         , "t=2m",_
 4792, 107, 268, 0,-77.777,  0,120710       , 0         , "t=190s",_
 4793, 108, 268, 0,0,        1,122970       , 0         , "t=1.4s",_
 4794, 109, 268, 0,-77.777,  0,129150       , 0         , "t=23ms",_
 4795, 110, 268, 0,0,        1,133650       , 0         , "t=100us",_
 4796, 105, 269, 0,4.5,      1,119150       , 0         , "t=3h",_
 4797, 106, 269, 0,-77.777,  0,119690       , 0         , "t=5m",_
 4798, 107, 269, 0,2.5,     -1,121480       , 0         , "t=1m",_
 4799, 108, 269, 0,4.5,      1,124490       , 0         , "t=15s",_
 4800, 109, 269, 0,-77.777,  0,129300       , 0         , "t=100ms",_
 4801, 110, 269, 0,-77.777,  0,134830       , 0         , "t=230us",_
 4802, 105, 270, 0,-77.777,  0,122400       , 0         , "t=1.7h",_
 4803, 106, 270, 0,0,        1,121430       , 0         , "t=3m",_
 4804, 107, 270, 0,-77.777,  0,124230       , 0         , "t=3.8m",_
 4805, 108, 270, 0,0,        1,125110       , 0         , "t=9s",_
 4806, 109, 270, 0,-77.777,  0,130710       , 0         , "t=800ms",_
 4807, 110, 270, 0,0,        1,134680       , 0         , "t=205us",_
 4808, 110, 270, 1,10,      -1,136070       , 1.39      , "t=4.3ms",_
 4809, 106, 271, 0,-77.777,  0,124620       , 0         , "t=2.2m",_
 4810, 107, 271, 0,-77.777,  0,125860       , 0         , "t=2.9s",_
 4811, 108, 271, 0,-77.777,  0,127690       , 0         , "t=10s",_
 4812, 109, 271, 0,-77.777,  0,131100       , 0         , "t=400ms",_
 4813, 110, 271, 0,-77.777,  0,135950       , 0         , "t=144ms",_
 4814, 110, 271, 1,-77.777,  0,136020       , 0.068     , "t=1.7ms",_
 4815, 106, 272, 0,0,        1,126520       , 0         , "t=4m",_
 4816, 107, 272, 0,-77.777,  0,128790       , 0         , "t=11.3s",_
 4817, 108, 272, 0,0,        1,129000       , 0         , "t=10s",_
 4818, 109, 272, 0,-77.777,  0,133480       , 0         , "t=400ms",_
 4819, 110, 272, 0,0,        1,136080       , 0         , "t=200ms",_
 4820, 111, 272, 0,-77.777,  0,142770       , 0         , "t=4.2ms",_
 4821, 106, 273, 0,-77.777,  0,129920       , 0         , "t=5m",_
 4822, 107, 273, 0,-77.777,  0,130680       , 0         , "t=1m",_
 4823, 108, 273, 0,-77.777,  0,131770       , 0         , "t=1060ms",_
 4824, 109, 273, 0,-77.777,  0,134780       , 0         , "t=800ms",_
 4825, 110, 273, 0,-77.777,  0,138290       , 0         , "t=240us",_
 4826, 110, 273, 1,-77.777,  0,138490       , 0.198     , "t=120ms",_
 4827, 111, 273, 0,-77.777,  0,142890       , 0         , "t=2ms",_
 4828, 107, 274, 0,-77.777,  0,133760       , 0         , "t=57s",_
 4829, 108, 274, 0,0,        1,133410       , 0         , "t=500ms",_
 4830, 109, 274, 0,-77.777,  0,137250       , 0         , "t=850ms",_
 4831, 110, 274, 0,0,        1,139200       , 0         , "t=10ms",_
 4832, 111, 274, 0,-77.777,  0,144610       , 0         , "t=20ms",_
 4833, 107, 275, 0,2.5,     -1,135780       , 0         , "t=1m",_
 4834, 108, 275, 0,-77.777,  0,136490       , 0         , "t=280ms",_
 4835, 109, 275, 0,-77.777,  0,138770       , 0         , "t=31ms",_
 4836, 110, 275, 0,-77.777,  0,141670       , 0         , "t=10ms",_
 4837, 111, 275, 0,-77.777,  0,145400       , 0         , "t=5ms",_
 4838, 107, 276, 0,-77.777,  0,138950       , 0         , "t=60s",_
 4839, 108, 276, 0,0,        1,138190       , 0         , "t=100ms",_
 4840, 109, 276, 0,-77.777,  0,141310       , 0         , "t=700ms",_
 4841, 109, 276, 1,-77.777,  0,141560       , 0.25      , "t=7s",_
 4842, 110, 276, 0,0,        1,142540       , 0         , "t=16ms",_
 4843, 111, 276, 0,-77.777,  0,147390       , 0         , "t=10ms",_
 4844, 107, 277, 0,-77.777,  0,141100       , 0         , "t=10s",_
 4845, 108, 277, 0,-77.777,  0,141380       , 0         , "t=12ms",_
 4846, 108, 277, 1,-77.777,  0,141480       , 0.1       , "t=130s",_
 4847, 109, 277, 0,-77.777,  0,143010       , 0         , "t=9s",_
 4848, 110, 277, 0,-77.777,  0,145090       , 0         , "t=6ms",_
 4849, 111, 277, 0,-77.777,  0,148410       , 0         , "t=4ms",_
 4850, 107, 278, 0,-77.777,  0,144370       , 0         , "t=2s",_
 4851, 108, 278, 0,0,        1,143220       , 0         , "t=2s",_
 4852, 109, 278, 0,-77.777,  0,145770       , 0         , "t=6s",_
 4853, 110, 278, 0,0,        1,146250       , 0         , "t=270ms",_
 4854, 111, 278, 0,-77.777,  0,150520       , 0         , "t=8ms",_
 4855, 108, 279, 0,-77.777,  0,146500       , 0         , "t=1s",_
 4856, 109, 279, 0,-77.777,  0,147590       , 0         , "t=20s",_
 4857, 110, 279, 0,-77.777,  0,149020       , 0         , "t=210ms",_
 4858, 111, 279, 0,-77.777,  0,151720       , 0         , "t=170ms",_
 4859, 108, 280, 0,0,        1,148420       , 0         , "t=100ms",_
 4860, 109, 280, 0,-77.777,  0,150510       , 0         , "t=10s",_
 4861, 110, 280, 0,0,        1,150320       , 0         , "t=25ms",_
 4862, 111, 280, 0,-77.777,  0,153890       , 0         , "t=4.3s",_
 4863, 109, 281, 0,-77.777,  0,152400       , 0         , "t=1s",_
 4864, 110, 281, 0,-77.777,  0,153270       , 0         , "t=14s",_
 4865, 110, 281, 1,-77.777,  0,153350       , 0.08      , "t=0.9s",_
 4866, 111, 281, 0,-77.777,  0,155330       , 0         , "t=19s",_
 4867, 109, 282, 0,-77.777,  0,155460       , 0         , "t=100ms",_
 4868, 110, 282, 0,0,        1,154790       , 0         , "t=4.2m",_
 4869, 111, 282, 0,-77.777,  0,157740       , 0         , "t=130s",_
 4870, 110, 283, 0,-77.777,  0,157830       , 0         , "t=1m",_
 4871, 111, 283, 0,-77.777,  0,159380       , 0         , "t=2m",_
 4872, 110, 284, 0,0,        1,159460       , 0         , "t=1m",_
 4873, 111, 284, 0,-77.777,  0,161970       , 0         , "t=1m",_
 4874, 111, 285, 0,-77.777,  0,163730       , 0         , "t=30s",_
 4875, 111, 286, 0,-77.777,  0,166510       , 0         , "t=10s",_
 9999
